using System;
using System.Collections.Generic;
using System.Drawing;
using System.Linq;
using System.Reflection;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using System.Xml;
using CreateFolder.Properties;
using log4net;

namespace CreateFolder;

public class AddressBookListControl
{
	public enum COLUMN
	{
		REGISTRATION_NO,
		NAME,
		DATE_LAST_USED,
		FOLDER,
		KEY_CODE
	}

	public enum ADDRESSBOOK_LIST_ITEM
	{
		ENTRY_INDEX,
		ENTRY_NAME,
		ENTRY_INDEX_NAME,
		ENTRY_DISPLAY_NAME,
		ENTRY_TAG_INFO_1,
		ENTRY_TAG_INFO_2,
		ENTRY_TAG_INFO_3,
		ENTRY_TAG_INFO_FREQ,
		FOLDER_PROTOCOL,
		FOLDER_PORT_NO,
		FOLDER_PATH_NAME,
		FOLDER_CHAR_CODE,
		FOLDER_AUTH_USER_NAME,
		FOLDER_PASSWORD_CHANGE,
		FOLDER_PASSWORD,
		KEY_CODE
	}

	public enum COLLECTION_STATE
	{
		NONE,
		RUN,
		STOP
	}

	private enum MODE
	{
		ALL,
		SELECT
	}

	private Button buttonMachineSelect;

	private ComboBox comboBoxSelectWay;

	private TextBox textBoxSearch;

	private Button buttonSearch;

	private Button buttonToTop;

	private Button buttonPrevious;

	private Button buttonNext;

	private Button buttonToBottom;

	private Button buttonResume;

	private Button buttonBreak;

	private Label displayedPage;

	private Label progressText;

	private ListView listViewAddressList;

	private string mfpIPAddress = string.Empty;

	private Color selectDeniedColor = SystemColors.ControlLight;

	private static readonly ILog LOG = LogManager.GetLogger(MethodBase.GetCurrentMethod().DeclaringType);

	private readonly string ADDRESSBOOK_XPATH_ENTRY_INDEX = "/div/div[@id='step_BASE']/form/div/div/ul/li/div/dl/dd/input[@name='entryIndexIn']";

	private readonly string ADDRESSBOOK_XPATH_ENTRY_NAME = "/div/div[@id='step_BASE']/form/div/div/ul/li/div/dl/dd/input[@name='entryNameIn']";

	private readonly string ADDRESSBOOK_XPATH_ENTRY_READ_NAME = "/div/div[@id='step_BASE']/form/div/div/ul/li/div/dl/dd/input[@name='entryReadNameIn']";

	private readonly string ADDRESSBOOK_XPATH_ENTRY_DISPLAY_NAME = "/div/div[@id='step_BASE']/form/div/div/ul/li/div/dl/dd/input[@name='entryDisplayNameIn']";

	private readonly string ADDRESSBOOK_XPATH_ENTRY_TAG_INFO = "/div/div[@id='step_BASE']/form/div/div/ul/li/div/dl/dd/select[@name='entryTagInfoIn']";

	private readonly string ADDRESSBOOK_XPATH_ENTRY_TAG_INFO_FREQ = "/div/div[@id='step_BASE']/form/div/div/ul/li/div/dl/dd/label/input[@name='entryTagInfoIn']";

	private readonly string ADDRESSBOOK_XPATH_FOLDER_PROTOCOL = "/div/div[@id='step_FOLDER']/form/div/div/ul/li/div/dl/dd/label/input[@name='folderProtocolIn']";

	private readonly string ADDRESSBOOK_XPATH_FOLDER_PORT_NO = "/div/div[@id='step_FOLDER']/form/div/div/ul/li/div/dl/dd/input[@name='folderPortNoIn']";

	private readonly string ADDRESSBOOK_XPATH_FOLDER_PATH_NAME = "/div/div[@id='step_FOLDER']/form/div/div/ul/li/div/dl/dd/input[@name='folderPathNameIn']";

	private readonly string ADDRESSBOOK_XPATHFOLDER_CHAR_CODE = "/div/div[@id='step_FOLDER']/form/div/div/ul/li/div/dl/dd/select[@name='folderCharCodeIn']";

	private readonly string ADDRESSBOOK_XPATH_FOLDER_AUTH_USER_NAME = "/div/div[@id='step_FOLDER']/form/div/div/ul/li/div/dl/dd/input[@name='folderAuthUserNameIn']";

	private readonly string NON_BREAK_SPACE_ENTITY = "&nbsp;";

	private readonly string NON_BREAK_SPACE_SUBSTITUTE_ENTITY = "&#160;";

	private bool PrimaxModel;

	private bool PrimaxUnicode;

	private List<string> searchWayList = new List<string>
	{
		Resources.ADDRESSBOOK_REGISTRATION_NO_NAME,
		Resources.ADDRESSBOOK_NAME,
		Resources.FORM_MAIN_PATH_NAME
	};

	private List<string> wimWayList = new List<string>
	{
		Resources.ADDRESSBOOK_REGISTRATION_NO_NAME,
		Resources.ADDRESSBOOK_NAME + "/" + Resources.ADDRESSBOOK_INDEX_NAME,
		Resources.ADDRESSBOOK_FOLDER
	};

	private List<int> wimSearchLengthLimit = new List<int>
	{
		Settings.Default.wim_search_length_limit_regNo,
		Settings.Default.wim_search_length_limit_name,
		Settings.Default.wim_search_length_limit_folder
	};

	private MachineControl mc;

	private Dictionary<string, Dictionary<MachineControl.ADDRESSBOOK_ITEM, string>> addressBookTable = new Dictionary<string, Dictionary<MachineControl.ADDRESSBOOK_ITEM, string>>();

	private int totalLines;

	private int currentPage = 1;

	private int numPages;

	private static readonly int NUM_LINES_PER_PAGE = 10;

	private readonly int ADDRESSBOOK_GET_LINES_ALL_MODE = 50;

	private readonly int ADDRESSBOOK_GET_LINES_LIST_MODE = NUM_LINES_PER_PAGE;

	private readonly int LISTVIEW_NUM_COLUMNS = 4;

	private Dictionary<object, bool> controlesState = new Dictionary<object, bool>();

	private COLLECTION_STATE collectState;

	private MODE workMode;

	private SettingItemsSetupAddress setting;

	private int progressTextWidth_default;

	private int progressTextWidth_1Button;

	private int progressTextWidth_2Buttons;

	private string machineLang;

	public Button ButtonMachineSelect
	{
		set
		{
			buttonMachineSelect = value;
		}
	}

	public ComboBox ComboBoxSelectWay
	{
		set
		{
			comboBoxSelectWay = value;
		}
	}

	public TextBox TextBoxSearch
	{
		set
		{
			textBoxSearch = value;
		}
	}

	public Button ButtonSearch
	{
		set
		{
			buttonSearch = value;
		}
	}

	public Button ButtonToTop
	{
		set
		{
			buttonToTop = value;
		}
	}

	public Button ButtonPrevious
	{
		set
		{
			buttonPrevious = value;
		}
	}

	public Button ButtonNext
	{
		set
		{
			buttonNext = value;
		}
	}

	public Button ButtonToBottom
	{
		set
		{
			buttonToBottom = value;
		}
	}

	public Button ButtonResume
	{
		set
		{
			buttonResume = value;
		}
	}

	public Button ButtonBreak
	{
		set
		{
			buttonBreak = value;
		}
	}

	public Label DisplayedPage
	{
		set
		{
			displayedPage = value;
		}
	}

	public Label ProgressText
	{
		set
		{
			progressText = value;
		}
	}

	public ListView ListViewAddressList
	{
		set
		{
			listViewAddressList = value;
		}
	}

	public string MFP_SelectedAddress
	{
		set
		{
			mfpIPAddress = value;
		}
	}

	public Color ListViewSelectDeniedColor => selectDeniedColor;

	public AddressBookListControl(string lang, MachineControl mci = null)
	{
		mc = mci;
		machineLang = lang;
	}

	public void initialize()
	{
		//IL_0064: Unknown result type (might be due to invalid IL or missing references)
		//IL_006a: Expected O, but got Unknown
		//IL_00b2: Unknown result type (might be due to invalid IL or missing references)
		//IL_00b8: Expected O, but got Unknown
		//IL_0103: Unknown result type (might be due to invalid IL or missing references)
		//IL_0109: Expected O, but got Unknown
		//IL_0123: Unknown result type (might be due to invalid IL or missing references)
		//IL_0129: Expected O, but got Unknown
		//IL_0224: Unknown result type (might be due to invalid IL or missing references)
		//IL_0229: Unknown result type (might be due to invalid IL or missing references)
		//IL_0239: Unknown result type (might be due to invalid IL or missing references)
		//IL_023e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0265: Unknown result type (might be due to invalid IL or missing references)
		//IL_026a: Unknown result type (might be due to invalid IL or missing references)
		//IL_027a: Unknown result type (might be due to invalid IL or missing references)
		//IL_027f: Unknown result type (might be due to invalid IL or missing references)
		comboBoxSelectWay.Items.Clear();
		foreach (string searchWay in searchWayList)
		{
			comboBoxSelectWay.Items.Add((object)searchWay);
		}
		comboBoxSelectWay.SelectedItem = Resources.ADDRESSBOOK_NAME;
		ColumnHeader val = new ColumnHeader();
		val.Text = Resources.ADDRESSBOOK_REG_NO;
		val.TextAlign = (HorizontalAlignment)0;
		if (machineLang.Equals("ja") || machineLang.Equals("en"))
		{
			val.Width = 60;
		}
		else
		{
			val.Width = 110;
		}
		ColumnHeader val2 = new ColumnHeader();
		val2.Text = Resources.ADDRESSBOOK_NAME;
		val2.TextAlign = (HorizontalAlignment)0;
		if (machineLang.Equals("ja") || machineLang.Equals("en"))
		{
			val2.Width = 100;
		}
		else
		{
			val2.Width = 150;
		}
		ColumnHeader val3 = new ColumnHeader();
		val3.Text = Resources.ADDRESSBOOK_DATE_LAST_USED;
		val3.TextAlign = (HorizontalAlignment)0;
		val3.Width = 120;
		ColumnHeader val4 = new ColumnHeader();
		val4.Text = Resources.FORM_MAIN_PATH_NAME;
		val4.TextAlign = (HorizontalAlignment)0;
		val4.Width = 200;
		listViewAddressList.Columns.Add(val);
		listViewAddressList.Columns.Add(val2);
		listViewAddressList.Columns.Add(val3);
		listViewAddressList.Columns.Add(val4);
		listViewAddressList.SelectedItems.Clear();
		listViewAddressList.Items.Clear();
		mfpIPAddress = string.Empty;
		((Control)progressText).Text = string.Empty;
		progressTextWidth_default = ((Control)progressText).Width;
		progressTextWidth_1Button = progressTextWidth_default - ((Control)buttonBreak).Width - 5;
		progressTextWidth_2Buttons = progressTextWidth_1Button - ((Control)buttonResume).Width - 5;
		int height = ((Control)listViewAddressList).Font.Height;
		Padding margin = ((Control)listViewAddressList).Margin;
		int num = height + ((Padding)(ref margin)).Bottom;
		margin = ((Control)listViewAddressList).Margin;
		int num2 = (num + ((Padding)(ref margin)).Top) * 10;
		int num3 = num2;
		int height2 = ((Control)val.ListView).Font.Height;
		margin = ((Control)listViewAddressList).Margin;
		int num4 = height2 + ((Padding)(ref margin)).Bottom;
		margin = ((Control)listViewAddressList).Margin;
		num2 = num3 + (num4 + ((Padding)(ref margin)).Top);
		if (((Control)listViewAddressList).Height <= num2)
		{
			((Control)listViewAddressList).Height = num2;
		}
	}

	public void disposeMachineControlInstance()
	{
		if (mc != null)
		{
			mc.Dispose();
			mc = null;
		}
	}

	public MachineControl getMachineControlInstance()
	{
		return mc;
	}

	public async void buttonSearch_Click()
	{
		LOG.Debug((object)"buttonSearch_Click：start");
		workMode = ((!string.IsNullOrEmpty(((Control)textBoxSearch).Text)) ? MODE.SELECT : MODE.ALL);
		if (workMode == MODE.ALL)
		{
			if ((int)MessageBox.Show($"{Resources.ADDRESSBOOK_GETALL_CAUTION_01}\n{Resources.ADDRESSBOOK_GETALL_CAUTION_02}\n{Resources.ADDRESSBOOK_GETALL_CAUTION_03}\n", Resources.ADDRESSBOOK_FIND, (MessageBoxButtons)4, (MessageBoxIcon)48) == 7)
			{
				return;
			}
		}
		else
		{
			LOG.DebugFormat("Search string：{0}:{1}", comboBoxSelectWay.SelectedItem, (object)((Control)textBoxSearch).Text);
			if (!checkSearchStringLength())
			{
				return;
			}
		}
		resetSeachEnvironments();
		setAllControlesEnable(enable: false);
		await searchAddressBook();
		setAllControlesEnable(enable: true);
		LOG.Debug((object)"buttonSearch_Click：end");
	}

	private bool checkSearchStringLength()
	{
		//IL_0084: Unknown result type (might be due to invalid IL or missing references)
		int num = wimSearchLengthLimit[((ListControl)comboBoxSelectWay).SelectedIndex];
		bool flag = Encoding.GetEncoding("Shift_JIS").GetByteCount(((Control)textBoxSearch).Text) <= num;
		if (!flag)
		{
			string text = $"{Resources.SEARCH_LENGTH_ERROR_TEXT_01}{comboBoxSelectWay.SelectedItem}{Resources.SEARCH_LENGTH_ERROR_TEXT_02}{num}{Resources.SEARCH_LENGTH_ERROR_TEXT_03}";
			MessageBox.Show(text, Resources.ADDRESSBOOK_FIND, (MessageBoxButtons)0, (MessageBoxIcon)48);
			LOG.DebugFormat("checkSearchStringLength：{0}", (object)text);
		}
		return flag;
	}

	private async Task<bool> searchAddressBook()
	{
		LOG.Debug((object)"searchAddressBook：start");
		bool neetResetListMode = false;
		try
		{
			neetResetListMode = await searchAddressBookMain();
			await mc.goBackWimAddressbookDisplayItems();
		}
		catch (Exception ex)
		{
			checkException(ex, "searchAddressBook");
			LOG.DebugFormat("searchAddressBook： Exception occur", new object[0]);
		}
		if (neetResetListMode)
		{
			try
			{
				await mc.getAddressListFirstpage();
			}
			catch (Exception ex2)
			{
				checkException(ex2, "searchAddressBook");
				LOG.DebugFormat("searchAddressBook： Exception occur", new object[0]);
			}
		}
		LOG.Debug((object)"searchAddressBook：end");
		return true;
	}

	private async Task<bool> searchAddressBookMain()
	{
		LOG.Debug((object)"searchAddressBookMain：start");
		bool neetResetListMode = false;
		string resultMsg = string.Empty;
		try
		{
			mc.SetPrimaxModel(PrimaxModel);
			mc.SetPrimaxUnicode(PrimaxUnicode);
			COMMUNICATION_ERROR_CODE cOMMUNICATION_ERROR_CODE = mc.communicateConfirm(mfpIPAddress);
			switch (cOMMUNICATION_ERROR_CODE)
			{
			case COMMUNICATION_ERROR_CODE.ERROR:
				LOG.Debug((object)"searchAddressBookMain：communicateConfirm failed");
				return false;
			case COMMUNICATION_ERROR_CODE.NOT_SUPPORT:
				LOG.Debug((object)"searchAddressBookMain：machine not support");
				return false;
			default:
			{
				setting = new SettingItemsSetupAddress
				{
					host = mfpIPAddress,
					adminName = "admin",
					passwd = "",
					firstFlg = true,
					httpsFlg = (cOMMUNICATION_ERROR_CODE != COMMUNICATION_ERROR_CODE.HTTP_ONLY)
				};
				if (!PrimaxModel)
				{
					if (!(await mc.checkUserAdminPermission(setting)))
					{
						mc.retryLoginState(setting.host, setting.adminName);
						neetResetListMode = true;
						LOG.Debug((object)"searchAddressBookMain：end");
						return neetResetListMode;
					}
					if (!(await mc.checkMachineAdminPermission(setting)))
					{
						mc.retryLoginState(setting.host, setting.adminName);
						neetResetListMode = true;
						LOG.Debug((object)"searchAddressBookMain：end");
						return neetResetListMode;
					}
				}
				if (workMode == MODE.ALL)
				{
					setCollectionMode(COLLECTION_STATE.RUN);
					((Control)progressText).TextChanged += progressText_TextChanged;
					resultMsg = ((!PrimaxModel) ? (await getAddressBookAll(setting)) : (await getAddressBookAllToPrimax(setting)));
					LOG.DebugFormat("searchAddressBookMain： getAddressBookAll returns:{0}", (object)resultMsg);
					LOG.DebugFormat("searchAddressBookMain： addressBookTable.Count/totalLines:{0}/{1}", (object)addressBookTable.Count, (object)totalLines);
					if (addressBookTable.Count == 0 || addressBookTable.Count == totalLines)
					{
						setCollectionMode(COLLECTION_STATE.NONE);
					}
					numPages = (addressBookTable.Count - 1) / NUM_LINES_PER_PAGE + 1;
					updateAddressBookListViewAllMode();
					break;
				}
				bool result = false;
				((Control)progressText).Text = Resources.ADDRESSBOOK_SEARCH_EXECUTING;
				if (totalLines == 0)
				{
					resultMsg = await mc.getAddressBookFilteredTotalLines(setting);
					LOG.DebugFormat("searchAddressBookMain： getAddressBookFilteredTotalLines returns:{0}", (object)resultMsg);
					if (string.IsNullOrEmpty(resultMsg))
					{
						totalLines = 0;
					}
					else
					{
						result = int.TryParse(resultMsg, out totalLines);
						LOG.DebugFormat("searchAddressBookMain： TryParse result:{0} totalLines:{1}", (object)result, (object)totalLines);
						if (!result)
						{
							totalLines = 0;
							addressBookTable.Clear();
						}
					}
				}
				if (!result)
				{
					break;
				}
				int page = 1;
				resultMsg = await getAddressBookFiltered(setting, page);
				LOG.DebugFormat("searchAddressBookMain： getAddressBookFiltered returns:{0}", (object)resultMsg);
				if (string.IsNullOrEmpty(resultMsg))
				{
					if (addressBookTable.Count == 0)
					{
						MessageBox.Show($"{Resources.ERR_MSG_WIM_SEARCH_EMPTY}\n\n{Resources.ERR_MSG_WIM_SEARCH_RETRY}", Resources.ADDRESSBOOK_FIND, (MessageBoxButtons)0, (MessageBoxIcon)64);
					}
					else
					{
						updateAddressBookListViewSelectMode();
					}
				}
				break;
			}
			}
		}
		catch (Exception ex)
		{
			resultMsg = checkException(ex, "searchAddressBookMain");
			LOG.DebugFormat("searchAddressBookMain： Exception resultMsg:{0}", (object)resultMsg);
		}
		finally
		{
			if (workMode == MODE.ALL)
			{
				((Control)progressText).TextChanged -= progressText_TextChanged;
			}
		}
		if (!string.IsNullOrEmpty(resultMsg))
		{
			MessageBox.Show(resultMsg, Resources.ERR_MSG_SEARCH_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
			LOG.DebugFormat("searchAddressBookMain： MessageBox.Show:{0}", (object)resultMsg);
			if (resultMsg.Contains(Resources.ERR_MSG_WIM_SEARCH_FULL))
			{
				neetResetListMode = true;
			}
		}
		LOG.Debug((object)"searchAddressBookMain：end");
		return neetResetListMode;
	}

	private async Task<string> getAddressBookAll(SettingItemsSetupAddress setting)
	{
		LOG.Debug((object)"getAddressBookAll：start");
		string text = string.Empty;
		((Control)progressText).Text = Resources.ADDRESSBOOK_SEARCH_EXECUTING;
		if (totalLines == 0)
		{
			text = await mc.getAddressBookTotalLines(setting);
			if (!int.TryParse(text, out totalLines))
			{
				totalLines = 0;
				addressBookTable.Clear();
				if (string.Equals(text, MACHINE_CONTROL_RESULT.ABORT.ToString()) || string.Equals(text, MACHINE_CONTROL_RESULT.ERROR.ToString()))
				{
					text = string.Empty;
				}
				LOG.DebugFormat("getAddressBookAll：end. resultMsg:{0}", (object)text);
				return text;
			}
			if (text.Equals("0"))
			{
				text = Resources.MSG_ADDRESSBOOK_EMPTY;
				LOG.DebugFormat("getAddressBookAll：end. resultMsg:{0}", (object)text);
				return text;
			}
		}
		int numLines = 0;
		int numPages = (totalLines - 1) / ADDRESSBOOK_GET_LINES_ALL_MODE + 1;
		int page = 1;
		if (addressBookTable.Count > 0)
		{
			numLines = addressBookTable.Count;
			page = numLines / ADDRESSBOOK_GET_LINES_ALL_MODE + 1;
		}
		for (; page <= numPages; page++)
		{
			((Control)progressText).Text = $"{Resources.ADDRESSBOOK_READING} {numLines} / {totalLines} {Resources.ADDRESSBOOK_ITEM_UNIT}";
			if (collectState == COLLECTION_STATE.STOP)
			{
				setCollectionMode(COLLECTION_STATE.STOP);
				LOG.Debug((object)"getAddressBookAll:中断");
				break;
			}
			text = await mc.getAddressBook(ADDRESSBOOK_GET_LINES_ALL_MODE, page, addressBookTable);
			if (!string.IsNullOrEmpty(text))
			{
				break;
			}
			numLines += ADDRESSBOOK_GET_LINES_ALL_MODE;
		}
		LOG.DebugFormat("getAddressBookAll：end resultMsg:{0}", (object)text);
		return text;
	}

	public void setCollectionMode(COLLECTION_STATE newState)
	{
		LOG.DebugFormat("setCollectionMode {0}->{1}", (object)collectState, (object)newState);
		switch (collectState)
		{
		case COLLECTION_STATE.NONE:
			if (newState == COLLECTION_STATE.RUN)
			{
				((Control)progressText).Width = progressTextWidth_1Button;
				((Control)buttonBreak).Visible = true;
				((Control)buttonBreak).Enabled = true;
			}
			break;
		case COLLECTION_STATE.RUN:
			switch (newState)
			{
			case COLLECTION_STATE.STOP:
				((Control)progressText).Width = progressTextWidth_2Buttons;
				((Control)buttonResume).Visible = true;
				((Control)buttonResume).Enabled = false;
				((Control)buttonBreak).Text = Resources.ITEM_BUTTON_STOP;
				break;
			case COLLECTION_STATE.NONE:
				((Control)progressText).Width = progressTextWidth_default;
				((Control)buttonBreak).Visible = false;
				((Control)buttonBreak).Text = Resources.ITEM_BUTTON_SUSPEND;
				break;
			}
			break;
		case COLLECTION_STATE.STOP:
			switch (newState)
			{
			case COLLECTION_STATE.RUN:
				((Control)progressText).Width = progressTextWidth_1Button;
				((Control)buttonResume).Visible = false;
				((Control)buttonBreak).Text = Resources.ITEM_BUTTON_SUSPEND;
				break;
			case COLLECTION_STATE.NONE:
				((Control)progressText).Width = progressTextWidth_default;
				((Control)buttonBreak).Visible = false;
				((Control)buttonResume).Visible = false;
				((Control)buttonBreak).Text = Resources.ITEM_BUTTON_SUSPEND;
				break;
			}
			break;
		}
		if (newState == COLLECTION_STATE.NONE)
		{
			((Control)progressText).Text = string.Empty;
		}
		collectState = newState;
		LOG.DebugFormat("setCollectionMode end.", new object[0]);
	}

	private async Task<string> getAddressBookFiltered(SettingItemsSetupAddress setting, int page)
	{
		LOG.Debug((object)"getAddressBookFiltered：start");
		if (machineLang != "ja" && wimWayList[((ListControl)comboBoxSelectWay).SelectedIndex] == Resources.ADDRESSBOOK_NAME + "/" + Resources.ADDRESSBOOK_INDEX_NAME)
		{
			wimWayList[((ListControl)comboBoxSelectWay).SelectedIndex] = Resources.ADDRESSBOOK_NAME;
		}
		((Control)progressText).Text = $"{Resources.ADDRESSBOOK_READING}";
		string text = await mc.getAddressBookFilteredOnePage(ADDRESSBOOK_GET_LINES_LIST_MODE, page, totalLines, addressBookTable, wimWayList[((ListControl)comboBoxSelectWay).SelectedIndex], ((Control)textBoxSearch).Text);
		if (string.IsNullOrEmpty(text))
		{
			LOG.Debug((object)"getAddressBookFiltered：end [Suspended]");
			return string.Empty;
		}
		string[] array = text.Split(new char[1] { '/' });
		if (array.Length == 2 && (int.TryParse(array[0], out currentPage) & int.TryParse(array[1], out numPages)))
		{
			text = string.Empty;
		}
		((Control)progressText).Text = string.Empty;
		LOG.DebugFormat("getAddressBookFiltered：end\u3000result:{0}", (object)string.IsNullOrEmpty(text));
		return text;
	}

	public void listViewAddressList_DrawColumnHeader(DrawListViewColumnHeaderEventArgs e)
	{
		//IL_003b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0041: Expected O, but got Unknown
		//IL_0051: Unknown result type (might be due to invalid IL or missing references)
		//IL_005b: Unknown result type (might be due to invalid IL or missing references)
		e.DrawBackground();
		if (e.ColumnIndex >= 0 && e.ColumnIndex < LISTVIEW_NUM_COLUMNS)
		{
			Rectangle bounds = e.Bounds;
			e.Graphics.FillRectangle(Brushes.LightSteelBlue, bounds);
			StringFormat val = new StringFormat();
			val.LineAlignment = (StringAlignment)1;
			val.Trimming = (StringTrimming)3;
			val.FormatFlags = (StringFormatFlags)(val.FormatFlags | 0x1000);
			string text = e.Header.Text;
			if (PrimaxModel && text.Equals(Resources.ADDRESSBOOK_REGISTRATION_NO_NAME))
			{
				text = Resources.PRIMAX_ONE_TOUCH_KEY;
			}
			e.Graphics.DrawString(text, ((Control)listViewAddressList).Font, Brushes.Black, (RectangleF)e.Bounds, val);
			bounds.Size -= ((e.ColumnIndex == LISTVIEW_NUM_COLUMNS - 1) ? new Size(1, 1) : new Size(0, 1));
			e.Graphics.DrawRectangle(Pens.Gray, bounds);
		}
		else
		{
			e.DrawDefault = true;
		}
	}

	public void listViewAddressList_DrawItem(DrawListViewItemEventArgs e)
	{
		e.DrawDefault = true;
	}

	public async void buttonNext_Click()
	{
		LOG.Debug((object)"buttonNext_Click");
		try
		{
			if (workMode == MODE.ALL)
			{
				currentPage++;
				updateAddressBookListViewAllMode();
			}
			else
			{
				await getAddressBookFiltered(setting, currentPage + 1);
				updateAddressBookListViewSelectMode();
			}
		}
		catch (Exception ex)
		{
			string text = checkException(ex, "buttonNext_Click");
			LOG.DebugFormat("buttonNext_Click： Exception popupMsg:{0}", (object)text);
			MessageBox.Show(text, Resources.ERR_MSG_SEARCH_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
		}
	}

	public async void buttonPrevious_Click()
	{
		LOG.Debug((object)"buttonPrevious_Click");
		try
		{
			if (workMode == MODE.ALL)
			{
				currentPage--;
				updateAddressBookListViewAllMode();
			}
			else
			{
				await getAddressBookFiltered(setting, currentPage - 1);
				updateAddressBookListViewSelectMode();
			}
		}
		catch (Exception ex)
		{
			string text = checkException(ex, "buttonPrevious_Click");
			LOG.DebugFormat("buttonPrevious_Click： Exception popupMsg:{0}", (object)text);
			MessageBox.Show(text, Resources.ERR_MSG_SEARCH_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
		}
	}

	public async void buttonToTheTop_Click()
	{
		LOG.Debug((object)"buttonToTheTop_Click");
		try
		{
			if (workMode == MODE.ALL)
			{
				currentPage = 1;
				updateAddressBookListViewAllMode();
			}
			else
			{
				int page = 1;
				await getAddressBookFiltered(setting, page);
				updateAddressBookListViewSelectMode();
			}
		}
		catch (Exception ex)
		{
			string text = checkException(ex, "buttonToTheTop_Click");
			LOG.DebugFormat("buttonToTheTop_Click： Exception popupMsg:{0}", (object)text);
			MessageBox.Show(text, Resources.ERR_MSG_SEARCH_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
		}
	}

	public async void buttonToTheButtom_Click()
	{
		LOG.Debug((object)"buttonToTheButtom_Click");
		try
		{
			if (workMode == MODE.ALL)
			{
				currentPage = numPages;
				updateAddressBookListViewAllMode();
			}
			else
			{
				await getAddressBookFiltered(setting, numPages);
				updateAddressBookListViewSelectMode();
			}
		}
		catch (Exception ex)
		{
			string text = checkException(ex, "buttonToTheButtom_Click");
			LOG.DebugFormat("buttonToTheButtom_Click： Exception popupMsg:{0}", (object)text);
			MessageBox.Show(text, Resources.ERR_MSG_SEARCH_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
		}
	}

	private void updateAddressBookListViewAllMode()
	{
		LOG.Debug((object)"updateAddressBookListViewAllMode");
		listViewAddressList.SelectedItems.Clear();
		listViewAddressList.Items.Clear();
		((Control)displayedPage).Text = $"{currentPage}/{numPages}";
		int num = 0;
		int num2 = 1;
		int num3 = (currentPage - 1) * NUM_LINES_PER_PAGE;
		foreach (KeyValuePair<string, Dictionary<MachineControl.ADDRESSBOOK_ITEM, string>> item in addressBookTable)
		{
			if (num2++ > num3)
			{
				if (PrimaxModel)
				{
					addListViewOneLineToPrimax(item);
				}
				else
				{
					addListViewOneLine(item);
				}
				if (++num >= NUM_LINES_PER_PAGE)
				{
					break;
				}
			}
		}
		bool visible = num3 + num < addressBookTable.Count;
		((Control)buttonNext).Visible = visible;
		((Control)buttonToBottom).Visible = visible;
		visible = currentPage > 1;
		((Control)buttonPrevious).Visible = visible;
		((Control)buttonToTop).Visible = visible;
		if (controlesState.Count > 0)
		{
			controlesState[buttonToTop] = ((Control)buttonToTop).Visible;
			controlesState[buttonNext] = ((Control)buttonNext).Visible;
			controlesState[buttonPrevious] = ((Control)buttonPrevious).Visible;
			controlesState[buttonToBottom] = ((Control)buttonToBottom).Visible;
		}
	}

	private void updateAddressBookListViewSelectMode()
	{
		LOG.Debug((object)"updateAddressBookListViewSelectMode：start");
		listViewAddressList.SelectedItems.Clear();
		listViewAddressList.Items.Clear();
		((Control)displayedPage).Text = $"{currentPage}/{numPages}";
		foreach (KeyValuePair<string, Dictionary<MachineControl.ADDRESSBOOK_ITEM, string>> item in addressBookTable)
		{
			addListViewOneLine(item);
		}
		bool visible = currentPage < numPages;
		((Control)buttonNext).Visible = visible;
		((Control)buttonToBottom).Visible = visible;
		visible = currentPage > 1;
		((Control)buttonPrevious).Visible = visible;
		((Control)buttonToTop).Visible = visible;
		if (controlesState.Count > 0)
		{
			controlesState[buttonToTop] = ((Control)buttonToTop).Visible;
			controlesState[buttonNext] = ((Control)buttonNext).Visible;
			controlesState[buttonPrevious] = ((Control)buttonPrevious).Visible;
			controlesState[buttonToBottom] = ((Control)buttonToBottom).Visible;
		}
		LOG.Debug((object)"updateAddressBookListViewSelectMode：end");
	}

	private int addListViewOneLine(KeyValuePair<string, Dictionary<MachineControl.ADDRESSBOOK_ITEM, string>> user)
	{
		//IL_00b8: Unknown result type (might be due to invalid IL or missing references)
		//IL_00c2: Expected O, but got Unknown
		LOG.Debug((object)"addListViewOneLine：start");
		string[] array = new string[4];
		array[0] = (user.Key.Contains("*") ? string.Empty : user.Key);
		array[1] = (user.Value.ContainsKey(MachineControl.ADDRESSBOOK_ITEM.NAME) ? user.Value[MachineControl.ADDRESSBOOK_ITEM.NAME] : string.Empty);
		array[3] = (user.Value.ContainsKey(MachineControl.ADDRESSBOOK_ITEM.FOLDER) ? user.Value[MachineControl.ADDRESSBOOK_ITEM.FOLDER] : string.Empty);
		array[2] = (user.Value.ContainsKey(MachineControl.ADDRESSBOOK_ITEM.DATE_LAST_USED) ? user.Value[MachineControl.ADDRESSBOOK_ITEM.DATE_LAST_USED] : string.Empty);
		ListViewItem obj = listViewAddressList.Items.Add(new ListViewItem(array));
		Color backColor = (((array[3].IndexOf(":\\") >= 0) | string.IsNullOrEmpty(array[0])) ? ListViewSelectDeniedColor : SystemColors.Window);
		obj.BackColor = backColor;
		LOG.Debug((object)"addListViewOneLine：end");
		return obj.Index;
	}

	private int addListViewOneLineToPrimax(KeyValuePair<string, Dictionary<MachineControl.ADDRESSBOOK_ITEM, string>> user)
	{
		//IL_00b3: Unknown result type (might be due to invalid IL or missing references)
		//IL_00bd: Expected O, but got Unknown
		LOG.Debug((object)"addListViewOneLinePrimax：start");
		string[] array = new string[4] { "-", null, null, null };
		string text = (user.Value.ContainsKey(MachineControl.ADDRESSBOOK_ITEM.REGISTRATION_NUMBER) ? user.Value[MachineControl.ADDRESSBOOK_ITEM.REGISTRATION_NUMBER] : string.Empty);
		if (!"-".Equals(text))
		{
			array[0] = text;
		}
		array[1] = (user.Value.ContainsKey(MachineControl.ADDRESSBOOK_ITEM.NAME) ? user.Value[MachineControl.ADDRESSBOOK_ITEM.NAME] : string.Empty);
		array[3] = (user.Value.ContainsKey(MachineControl.ADDRESSBOOK_ITEM.FOLDER) ? user.Value[MachineControl.ADDRESSBOOK_ITEM.FOLDER] : string.Empty);
		array[2] = "-";
		ListViewItem obj = listViewAddressList.Items.Add(new ListViewItem(array));
		Color backColor = (((array[3].IndexOf(":\\") >= 0) | string.IsNullOrEmpty(array[0])) ? ListViewSelectDeniedColor : SystemColors.Window);
		obj.BackColor = backColor;
		LOG.Debug((object)"addListViewOneLinePrimax：end");
		return obj.Index;
	}

	public void setAllControlesEnable(bool enable)
	{
		//IL_0173: Unknown result type (might be due to invalid IL or missing references)
		//IL_0179: Expected O, but got Unknown
		//IL_01de: Unknown result type (might be due to invalid IL or missing references)
		//IL_020c: Unknown result type (might be due to invalid IL or missing references)
		//IL_023a: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("AddressBookListControl:setAllControlesEnable：{0}", (object)enable);
		if (!enable)
		{
			Cursor.Current = Cursors.WaitCursor;
			controlesState.Clear();
			if (buttonMachineSelect != null)
			{
				controlesState.Add(buttonMachineSelect, ((Control)buttonMachineSelect).Enabled);
			}
			controlesState.Add(comboBoxSelectWay, ((Control)comboBoxSelectWay).Enabled);
			controlesState.Add(textBoxSearch, ((Control)textBoxSearch).Enabled);
			controlesState.Add(buttonSearch, ((Control)buttonSearch).Enabled);
			controlesState.Add(buttonToTop, ((Control)buttonToTop).Visible);
			controlesState.Add(buttonPrevious, ((Control)buttonPrevious).Visible);
			controlesState.Add(buttonNext, ((Control)buttonNext).Visible);
			controlesState.Add(buttonToBottom, ((Control)buttonToBottom).Visible);
			controlesState.Add(listViewAddressList, ((Control)listViewAddressList).Enabled);
		}
		foreach (KeyValuePair<object, bool> item in controlesState)
		{
			Type type = item.Key.GetType();
			if (type == typeof(Button))
			{
				Button val = (Button)item.Key;
				if (val == buttonToTop || val == buttonPrevious || val == buttonNext || val == buttonToBottom)
				{
					((Control)val).Visible = item.Value && enable;
				}
				else
				{
					((Control)val).Enabled = item.Value && enable;
				}
			}
			else if (type == typeof(ComboBox))
			{
				((Control)(ComboBox)item.Key).Enabled = item.Value && enable;
			}
			else if (type == typeof(TextBox))
			{
				((Control)(TextBox)item.Key).Enabled = item.Value && enable;
			}
			else if (type == typeof(ListView))
			{
				((Control)(ListView)item.Key).Enabled = item.Value && enable;
			}
		}
		if (enable)
		{
			controlesState.Clear();
			((Control)listViewAddressList).Focus();
			((Control)buttonBreak).Enabled = true;
			((Control)buttonResume).Enabled = true;
			Cursor.Current = Cursors.Default;
		}
	}

	public void textBoxSearch_KeyPress(KeyPressEventArgs e)
	{
		setCollectionMode(COLLECTION_STATE.NONE);
		if (e.KeyChar == '\r')
		{
			buttonSearch_Click();
			e.Handled = true;
		}
	}

	public void progressText_TextChanged(object sender, EventArgs e)
	{
		if (addressBookTable != null)
		{
			numPages = (addressBookTable.Count - 1) / NUM_LINES_PER_PAGE + 1;
			updateAddressBookListViewAllMode();
		}
	}

	public void buttonBreak_Click()
	{
		LOG.DebugFormat("buttonBreak_Click {0}", (object)((Control)buttonBreak).Text);
		if (collectState == COLLECTION_STATE.RUN)
		{
			setCollectionMode(COLLECTION_STATE.STOP);
			mc.stopAddressbookCollection();
		}
		else
		{
			setCollectionMode(COLLECTION_STATE.NONE);
			mc.stopAddressbookCollection(state: false);
		}
		((Control)buttonBreak).Enabled = false;
	}

	public async void buttonResume_Click()
	{
		LOG.DebugFormat("buttonResume_Click {0}", new object[0]);
		if (collectState == COLLECTION_STATE.STOP)
		{
			setCollectionMode(COLLECTION_STATE.RUN);
			mc.stopAddressbookCollection(state: false);
			setAllControlesEnable(enable: false);
			await searchAddressBook();
			setAllControlesEnable(enable: true);
		}
		LOG.Debug((object)"buttonResume_Click：end");
	}

	public string checkException(Exception ex, string functionName)
	{
		LOG.Debug((object)"checkException：start");
		string empty = string.Empty;
		string message = ex.Message;
		if (!string.IsNullOrEmpty(message) && message.IndexOf(Resources.WIM_ERROR_DETECT) >= 0)
		{
			empty = ex.Message.Substring(Resources.WIM_ERROR_DETECT.Length);
			LOG.ErrorFormat("checkException {0}：{1}", (object)functionName, (object)message);
		}
		else
		{
			empty = Resources.ERR_MSG_FATAL_RETRY;
			LOG.ErrorFormat("checkException {0}：{1}", (object)functionName, (object)ex.ToString());
		}
		((Control)progressText).Text = string.Empty;
		LOG.Debug((object)"checkException：end");
		return empty;
	}

	public void exchangeAddressBookItem(string removeKey, KeyValuePair<string, Dictionary<MachineControl.ADDRESSBOOK_ITEM, string>> updata)
	{
		addressBookTable.Remove(removeKey);
		addressBookTable.Add(updata.Key, updata.Value);
		SortedDictionary<string, Dictionary<MachineControl.ADDRESSBOOK_ITEM, string>> source = new SortedDictionary<string, Dictionary<MachineControl.ADDRESSBOOK_ITEM, string>>(addressBookTable);
		addressBookTable = source.ToDictionary((KeyValuePair<string, Dictionary<MachineControl.ADDRESSBOOK_ITEM, string>> x) => x.Key, (KeyValuePair<string, Dictionary<MachineControl.ADDRESSBOOK_ITEM, string>> x) => x.Value);
		int num = 0;
		foreach (string key in addressBookTable.Keys)
		{
			if (string.Equals(updata.Key, key))
			{
				break;
			}
			num++;
		}
		currentPage = num / NUM_LINES_PER_PAGE + 1;
		updateAddressBookListViewAllMode();
		listViewAddressList.Items[num % NUM_LINES_PER_PAGE].Selected = true;
	}

	public void resetSeachEnvironments()
	{
		setCollectionMode(COLLECTION_STATE.NONE);
		((Control)progressText).Text = string.Empty;
		((Control)displayedPage).Text = string.Empty;
		listViewAddressList.SelectedItems.Clear();
		listViewAddressList.Items.Clear();
		addressBookTable.Clear();
		totalLines = 0;
		currentPage = 1;
		numPages = 0;
		((Control)buttonToTop).Visible = false;
		((Control)buttonPrevious).Visible = false;
		((Control)buttonNext).Visible = false;
		((Control)buttonToBottom).Visible = false;
		((Control)buttonBreak).Visible = false;
		((Control)buttonResume).Visible = false;
		mc.stopAddressbookCollection(state: false);
	}

	public async Task<Dictionary<ADDRESSBOOK_LIST_ITEM, string>> GetAddressBookInfo(string ipAddress, string regNo, COMMUNICATION_ERROR_CODE comResult)
	{
		LOG.Debug((object)"GetAddressBookInfo：start");
		Dictionary<ADDRESSBOOK_LIST_ITEM, string> addressBookInfo;
		try
		{
			SettingItemsSetupAddress info = new SettingItemsSetupAddress
			{
				host = ipAddress,
				adminName = "admin",
				passwd = "",
				firstFlg = true,
				httpsFlg = (comResult != COMMUNICATION_ERROR_CODE.HTTP_ONLY)
			};
			addressBookInfo = parseAddressBookInfoXml(await mc.getAddressBookInfoXml(info, regNo));
		}
		catch (Exception ex)
		{
			LOG.ErrorFormat("GetAddressBookInfo：HTTP Error. {0}", (object)ex.ToString());
			throw new Exception(Resources.WIM_ERROR_DETECT + Resources.FAILED_GET_ADDRESSBOOK_SPECIFIED);
		}
		if (addressBookInfo == null)
		{
			MessageBox.Show(Resources.FAILED_GET_ADDRESSBOOK_SPECIFIED, Resources.ERR_MSG_SEARCH_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
		}
		LOG.Debug((object)"GetAddressBookInfo：end");
		return addressBookInfo;
	}

	private Dictionary<ADDRESSBOOK_LIST_ITEM, string> parseAddressBookInfoXml(string addressBookInfoXml)
	{
		LOG.Debug((object)"parseAddressBookInfoXml：start");
		Dictionary<ADDRESSBOOK_LIST_ITEM, string> dictionary = new Dictionary<ADDRESSBOOK_LIST_ITEM, string>();
		XmlDocument xmlDocument = new XmlDocument();
		try
		{
			addressBookInfoXml = addressBookInfoXml.Replace(NON_BREAK_SPACE_ENTITY, NON_BREAK_SPACE_SUBSTITUTE_ENTITY);
			xmlDocument.LoadXml(addressBookInfoXml);
			XmlNode xmlNode = xmlDocument.SelectNodes(ADDRESSBOOK_XPATH_ENTRY_INDEX)[0];
			if (xmlNode != null)
			{
				dictionary.Add(ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX, xmlNode.Attributes.GetNamedItem("value").Value);
			}
			xmlNode = xmlDocument.SelectNodes(ADDRESSBOOK_XPATH_ENTRY_NAME)[0];
			if (xmlNode != null)
			{
				dictionary.Add(ADDRESSBOOK_LIST_ITEM.ENTRY_NAME, xmlNode.Attributes.GetNamedItem("value").Value);
			}
			xmlNode = xmlDocument.SelectNodes(ADDRESSBOOK_XPATH_ENTRY_READ_NAME)[0];
			if (xmlNode != null)
			{
				dictionary.Add(ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX_NAME, xmlNode.Attributes.GetNamedItem("value").Value);
			}
			xmlNode = xmlDocument.SelectNodes(ADDRESSBOOK_XPATH_ENTRY_DISPLAY_NAME)[0];
			if (xmlNode != null)
			{
				dictionary.Add(ADDRESSBOOK_LIST_ITEM.ENTRY_DISPLAY_NAME, xmlNode.Attributes.GetNamedItem("value").Value);
			}
			ADDRESSBOOK_LIST_ITEM aDDRESSBOOK_LIST_ITEM = ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_1;
			foreach (XmlNode item in xmlDocument.SelectNodes(ADDRESSBOOK_XPATH_ENTRY_TAG_INFO))
			{
				foreach (XmlNode childNode in item.ChildNodes)
				{
					XmlNode namedItem = childNode.Attributes.GetNamedItem("selected");
					if (namedItem != null)
					{
						string value = namedItem.Value;
						if (!string.IsNullOrEmpty(value) && string.Equals("true", value))
						{
							dictionary.Add(aDDRESSBOOK_LIST_ITEM++, childNode.Attributes.GetNamedItem("value").Value);
							break;
						}
					}
				}
			}
			foreach (XmlNode item2 in xmlDocument.SelectNodes(ADDRESSBOOK_XPATH_ENTRY_TAG_INFO_FREQ))
			{
				XmlNode namedItem2 = item2.Attributes.GetNamedItem("checked");
				if (namedItem2 != null)
				{
					string value2 = namedItem2.Value;
					if (!string.IsNullOrEmpty(value2) && string.Equals("true", value2))
					{
						dictionary.Add(ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_FREQ, item2.Attributes.GetNamedItem("value").Value);
						break;
					}
				}
			}
			foreach (XmlNode item3 in xmlDocument.SelectNodes(ADDRESSBOOK_XPATH_FOLDER_PROTOCOL))
			{
				XmlNode namedItem3 = item3.Attributes.GetNamedItem("checked");
				if (namedItem3 != null)
				{
					string value3 = namedItem3.Value;
					if (!string.IsNullOrEmpty(value3) && string.Equals("true", value3))
					{
						dictionary.Add(ADDRESSBOOK_LIST_ITEM.FOLDER_PROTOCOL, item3.Attributes.GetNamedItem("value").Value);
						break;
					}
				}
			}
			xmlNode = xmlDocument.SelectNodes(ADDRESSBOOK_XPATH_FOLDER_PORT_NO)[0];
			if (xmlNode != null)
			{
				dictionary.Add(ADDRESSBOOK_LIST_ITEM.FOLDER_PORT_NO, xmlNode.Attributes.GetNamedItem("value").Value);
			}
			xmlNode = xmlDocument.SelectNodes(ADDRESSBOOK_XPATH_FOLDER_PATH_NAME)[0];
			if (xmlNode != null)
			{
				dictionary.Add(ADDRESSBOOK_LIST_ITEM.FOLDER_PATH_NAME, xmlNode.Attributes.GetNamedItem("value").Value);
			}
			foreach (XmlNode item4 in xmlDocument.SelectNodes(ADDRESSBOOK_XPATHFOLDER_CHAR_CODE))
			{
				foreach (XmlNode childNode2 in item4.ChildNodes)
				{
					XmlNode namedItem4 = childNode2.Attributes.GetNamedItem("selected");
					if (namedItem4 != null)
					{
						string value4 = namedItem4.Value;
						if (!string.IsNullOrEmpty(value4) && string.Equals("true", value4))
						{
							dictionary.Add(ADDRESSBOOK_LIST_ITEM.FOLDER_CHAR_CODE, childNode2.Attributes.GetNamedItem("value").Value);
							break;
						}
					}
				}
			}
			xmlNode = xmlDocument.SelectNodes(ADDRESSBOOK_XPATH_FOLDER_AUTH_USER_NAME)[0];
			if (xmlNode != null)
			{
				dictionary.Add(ADDRESSBOOK_LIST_ITEM.FOLDER_AUTH_USER_NAME, xmlNode.Attributes.GetNamedItem("value").Value);
			}
		}
		catch (Exception ex)
		{
			LOG.ErrorFormat("parseAddressBookInfoXml：アドレス帳解析エラー\n{0}\n*******************************", (object)ex.ToString());
			dictionary.Clear();
			dictionary = null;
		}
		finally
		{
			LOG.Debug((object)"parseAddressBookInfoXml：end");
		}
		return dictionary;
	}

	private bool selected()
	{
		return listViewAddressList.SelectedItems.Count > 0;
	}

	public string getSelectedItem(COLUMN column)
	{
		string result = string.Empty;
		if (selected())
		{
			result = listViewAddressList.SelectedItems[0].SubItems[(int)column].Text;
		}
		return result;
	}

	public bool SetPrimaxModel(string mfpIPAddress)
	{
		PrimaxModel = FormWizard.IsPrimax(FormWizard.GetHostNameFromIP(mfpIPAddress));
		PrimaxUnicode = FormWizard.IsPrimaxUnicode(FormWizard.GetHostNameFromIP(mfpIPAddress));
		return PrimaxModel;
	}

	private async Task<string> getAddressBookAllToPrimax(SettingItemsSetupAddress setting)
	{
		LOG.Debug((object)"getAddressBookAllToPrimax：start");
		List<OneTouchKeyInfo> oneTouchKeyInfo = await mc.getPrimaxOneTouchKeyInfo(setting.httpsFlg, setting.host);
		string text = await mc.getPrimaxAddressBook(setting, addressBookTable, oneTouchKeyInfo);
		LOG.DebugFormat("getAddressBookAllToPrimax：end resultMsg:{0}", (object)text);
		return text;
	}

	public async Task<Dictionary<ADDRESSBOOK_LIST_ITEM, string>> GetAddressBookInfoToPrimax(string ipAddress, string reqdestname, List<OneTouchKeyInfo> oneTouchKeyList)
	{
		LOG.Debug((object)"GetAddressBookInfoToPrimax：start");
		Dictionary<ADDRESSBOOK_LIST_ITEM, string> addressBookInfo;
		try
		{
			SettingItemsSetupAddress info = new SettingItemsSetupAddress
			{
				host = ipAddress
			};
			string keycode = string.Empty;
			foreach (KeyValuePair<string, Dictionary<MachineControl.ADDRESSBOOK_ITEM, string>> item in addressBookTable)
			{
				if (item.Value[MachineControl.ADDRESSBOOK_ITEM.NAME].Equals(reqdestname))
				{
					keycode = item.Value[MachineControl.ADDRESSBOOK_ITEM.KEY_CODE];
					break;
				}
			}
			addressBookInfo = await mc.getPrimaxAddressBookInfo(info, reqdestname, keycode);
		}
		catch (Exception ex)
		{
			LOG.ErrorFormat("GetAddressBookInfoToPrimax：HTTP Error. {0}", (object)ex.ToString());
			throw new Exception(Resources.WIM_ERROR_DETECT + Resources.FAILED_GET_ADDRESSBOOK_SPECIFIED);
		}
		if (addressBookInfo == null)
		{
			MessageBox.Show(Resources.FAILED_GET_ADDRESSBOOK_SPECIFIED, Resources.ERR_MSG_SEARCH_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
		}
		addressBookInfo[ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX] = "0";
		for (int i = 0; i < oneTouchKeyList.Count; i++)
		{
			if (reqdestname.Equals(oneTouchKeyList[i].name))
			{
				addressBookInfo[ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX] = oneTouchKeyList[i].no.ToString();
				break;
			}
		}
		LOG.Debug((object)"GetAddressBookInfoToPrimax：end");
		return addressBookInfo;
	}

	public void exchangeAddressBookItemToPrimax(KeyValuePair<string, Dictionary<MachineControl.ADDRESSBOOK_ITEM, string>> updata)
	{
		LOG.Debug((object)"exchangeAddressBookItemToPrimax：start");
		string text = updata.Value[MachineControl.ADDRESSBOOK_ITEM.REGISTRATION_NUMBER];
		string text2 = updata.Value[MachineControl.ADDRESSBOOK_ITEM.NAME];
		string text3 = updata.Value[MachineControl.ADDRESSBOOK_ITEM.FOLDER];
		text3 = text3[..text3.LastIndexOf("\\")];
		string value = updata.Value[MachineControl.ADDRESSBOOK_ITEM.INDEX];
		string value2 = updata.Value[MachineControl.ADDRESSBOOK_ITEM.DATE_LAST_USED];
		string[] array = null;
		List<string[]> list = new List<string[]>();
		List<string> list2 = new List<string>();
		bool flag = false;
		if (!text2.Equals(value) && "0".Equals(text) && "0".Equals(value2))
		{
			array = new string[3] { "", "", "" };
			array[0] = "0";
			array[1] = text2;
			array[2] = text3;
			list.Add(array);
			list2.Add(array[1]);
			flag = true;
		}
		foreach (KeyValuePair<string, Dictionary<MachineControl.ADDRESSBOOK_ITEM, string>> item in addressBookTable)
		{
			string text4 = (item.Value.ContainsKey(MachineControl.ADDRESSBOOK_ITEM.REGISTRATION_NUMBER) ? item.Value[MachineControl.ADDRESSBOOK_ITEM.REGISTRATION_NUMBER] : string.Empty);
			string text5 = (item.Value.ContainsKey(MachineControl.ADDRESSBOOK_ITEM.NAME) ? item.Value[MachineControl.ADDRESSBOOK_ITEM.NAME] : string.Empty);
			string text6 = (item.Value.ContainsKey(MachineControl.ADDRESSBOOK_ITEM.FOLDER) ? item.Value[MachineControl.ADDRESSBOOK_ITEM.FOLDER] : string.Empty);
			if (!flag && text5.Equals(value))
			{
				text4 = text;
				text5 = text2;
				text6 = text3;
			}
			array = new string[3] { "", "", "" };
			array[0] = text4;
			array[1] = text5;
			array[2] = text6;
			list.Add(array);
			list2.Add(array[1]);
		}
		list2.Sort();
		addressBookTable.Clear();
		int num = 0;
		int num2 = 0;
		for (int i = 0; i < list2.Count; i++)
		{
			if (list2[i].Equals(text2))
			{
				num = i;
			}
			for (int j = 0; j < list.Count; j++)
			{
				if (list2[i].Equals(list[j][1]))
				{
					Dictionary<MachineControl.ADDRESSBOOK_ITEM, string> dictionary = new Dictionary<MachineControl.ADDRESSBOOK_ITEM, string>();
					string value3 = list[j][0];
					if ("0".Equals(list[j][0]))
					{
						value3 = "-";
					}
					dictionary.Add(MachineControl.ADDRESSBOOK_ITEM.REGISTRATION_NUMBER, value3);
					dictionary.Add(MachineControl.ADDRESSBOOK_ITEM.NAME, list[j][1]);
					dictionary.Add(MachineControl.ADDRESSBOOK_ITEM.INDEX, "");
					dictionary.Add(MachineControl.ADDRESSBOOK_ITEM.DATE_LAST_USED, "");
					dictionary.Add(MachineControl.ADDRESSBOOK_ITEM.FOLDER, list[j][2]);
					addressBookTable.Add((num2 + 1).ToString(), dictionary);
					num2++;
					break;
				}
			}
		}
		currentPage = num / NUM_LINES_PER_PAGE + 1;
		updateAddressBookListViewAllMode();
		listViewAddressList.Items[num % NUM_LINES_PER_PAGE].Selected = true;
		LOG.Debug((object)"exchangeAddressBookItemToPrimax：end");
	}
}
