using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Reflection;
using System.Threading.Tasks;
using System.Windows.Forms;
using log4net;

namespace CreateFolder;

public class ComboBoxMFPSelector : ComboBox
{
	private static readonly ILog LOG = LogManager.GetLogger(MethodBase.GetCurrentMethod().DeclaringType);

	private bool eventStopped;

	private List<string> machineList = new List<string>();

	private IContainer components;

	[Category("表示")]
	[DefaultValue("")]
	[Description("最初に設定されている文字列です。")]
	[RefreshProperties(RefreshProperties.Repaint)]
	public string First_Displayed { get; set; }

	[Category("表示")]
	[DefaultValue("")]
	[Description("手動入力を行う選択肢のデフォルトの表示文字列です。")]
	[RefreshProperties(RefreshProperties.Repaint)]
	public string DefaultManualInput { get; set; }

	public ComboBoxMFPSelector()
	{
		InitializeComponent();
	}

	public ComboBoxMFPSelector(IContainer container)
	{
		container.Add((IComponent?)this);
		InitializeComponent();
	}

	public void AddMachine(params string[] addedChoices)
	{
		machineList.AddRange(addedChoices);
	}

	public void ClearList()
	{
		machineList.Clear();
	}

	public void RecreateDropDownList()
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		((ComboBox)this).BeginUpdate();
		eventStopped = true;
		((ComboBox)this).Items.Clear();
		if (machineList.Count > 0)
		{
			((ComboBox)this).Items.Add((object)First_Displayed);
		}
		((ComboBox)this).Items.AddRange((object[])machineList.ToArray());
		((ComboBox)this).Items.Add((object)DefaultManualInput);
		((ListControl)this).SelectedIndex = 0;
		eventStopped = false;
		((ComboBox)this).EndUpdate();
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	public void RecreateDropDownList(string selectedItem)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		((ComboBox)this).BeginUpdate();
		eventStopped = true;
		((ComboBox)this).Items.Clear();
		if (machineList.Count > 0)
		{
			((ComboBox)this).Items.Add((object)First_Displayed);
		}
		((ComboBox)this).Items.AddRange((object[])machineList.ToArray());
		((ComboBox)this).Items.Add((object)DefaultManualInput);
		if (((ComboBox)this).Items.Contains((object)selectedItem))
		{
			if (selectedItem != First_Displayed)
			{
				eventStopped = true;
				((ComboBox)this).Items.Remove((object)First_Displayed);
				eventStopped = false;
			}
			((ListControl)this).SelectedIndex = ((ComboBox)this).Items.IndexOf((object)selectedItem);
		}
		else
		{
			((ListControl)this).SelectedIndex = 0;
		}
		eventStopped = false;
		((ComboBox)this).EndUpdate();
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	public void callIPAdressSetting()
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		if (eventStopped)
		{
			Console.WriteLine("Event Passed.");
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
			return;
		}
		int num = ((ComboBox)this).Items.IndexOf((object)First_Displayed);
		if (num >= 0 && ((ListControl)this).SelectedIndex != num)
		{
			eventStopped = true;
			((ComboBox)this).Items.Remove((object)First_Displayed);
			eventStopped = false;
		}
		int num2 = ((ComboBox)this).Items.IndexOf((object)DefaultManualInput);
		if (((ListControl)this).SelectedIndex != num2)
		{
			return;
		}
		eventStopped = true;
		string setIPAddress = GetSetIPAddress();
		if (setIPAddress == null || setIPAddress == string.Empty)
		{
			eventStopped = false;
			Console.WriteLine("None change.");
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
			return;
		}
		string displayedContents = GetDisplayedContents(setIPAddress);
		if (machineList.Contains(displayedContents))
		{
			int selectedIndex = ((ComboBox)this).Items.IndexOf((object)displayedContents);
			((ListControl)this).SelectedIndex = selectedIndex;
			LOG.DebugFormat("{0}：The entered address({1}) already exists.", (object)MethodBase.GetCurrentMethod().Name, (object)setIPAddress);
		}
		else
		{
			string empty = string.Empty;
			int num3 = ((ComboBox)this).Items.IndexOf((object)displayedContents);
			if (num3 < 0)
			{
				empty = displayedContents.TrimStart(new char[1] { ' ' });
				((ComboBox)this).Items.Insert(((ComboBox)this).Items.Count - 1, (object)empty);
				num3 = ((ComboBox)this).Items.IndexOf((object)empty);
			}
			((ListControl)this).SelectedIndex = num3;
		}
		eventStopped = false;
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	protected override void OnVisibleChanged(EventArgs e)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		((Control)this).OnVisibleChanged(e);
		if (((Control)this).Visible)
		{
			eventStopped = true;
			if (((ComboBox)this).SelectedItem != null)
			{
				RecreateDropDownList((string)((ComboBox)this).SelectedItem);
			}
			eventStopped = false;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	private string GetSetIPAddress()
	{
		return FormSetIPAddress.GetSetIPAddress();
	}

	private string GetDisplayedContents(string setIPAddress)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		string hostName = string.Empty;
		foreach (string item in ((ComboBox)this).Items)
		{
			if (item.Contains(setIPAddress))
			{
				return item;
			}
		}
		((Control)this).Cursor = Cursors.WaitCursor;
		Task task = Task.Factory.StartNew(delegate
		{
			hostName = GetHostName(setIPAddress);
		});
		task.Wait();
		while (task.Status != TaskStatus.RanToCompletion)
		{
		}
		((Control)this).Cursor = Cursors.Default;
		string empty = string.Empty;
		empty = ((!string.IsNullOrWhiteSpace(hostName)) ? $"{hostName} ({setIPAddress})" : $"{setIPAddress}");
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return empty;
	}

	private string GetHostName(string setIPAddress)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		string hostNameFromIP = FormWizard.GetHostNameFromIP(setIPAddress);
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return hostNameFromIP;
	}

	protected override void Dispose(bool disposing)
	{
		if (disposing && components != null)
		{
			components.Dispose();
		}
		((ComboBox)this).Dispose(disposing);
	}

	private void InitializeComponent()
	{
		components = new Container();
	}
}
