using System;
using System.ComponentModel;
using System.Drawing;
using System.Reflection;
using System.Windows.Forms;
using CreateFolder.Properties;
using log4net;

namespace CreateFolder;

public class CustomDialogBox : Form
{
	private static readonly ILog LOG = LogManager.GetLogger(MethodBase.GetCurrentMethod().DeclaringType);

	private Font currentFont;

	private IContainer components;

	private RichTextBox richTextBox1;

	private PictureBox pictureBox;

	private Button closeButton;

	private Button agreeButton;

	public CustomDialogBox()
	{
		InitializeComponent();
		((Control)richTextBox1).Font = SystemFonts.MessageBoxFont;
		((Control)agreeButton).Font = SystemFonts.MessageBoxFont;
		((Control)closeButton).Font = SystemFonts.MessageBoxFont;
		currentFont = richTextBox1.SelectionFont;
		richTextBox1.SelectionIndent = 50;
		richTextBox1.SelectionRightIndent = 50;
		((Control)agreeButton).Text = Resources.BUTTON_AGREE;
		((Control)closeButton).Text = Resources.BUTTON_CLOSE;
		((Control)this).Text = Resources.SECURITY_DLG_CAPTION;
		((TextBoxBase)richTextBox1).ReadOnly = true;
	}

	public void SetIcon(Icon icon)
	{
		//IL_0018: Unknown result type (might be due to invalid IL or missing references)
		//IL_001e: Expected O, but got Unknown
		Graphics val = null;
		try
		{
			Bitmap val2 = new Bitmap(((Control)pictureBox).Width, ((Control)pictureBox).Height);
			val = Graphics.FromImage((Image)(object)val2);
			val.DrawIcon(icon, 0, 0);
			val.Dispose();
			pictureBox.Image = (Image)(object)val2;
		}
		catch (Exception ex)
		{
			LOG.Error((object)"Icon用Graphicsオブジェクト作成失敗 ", ex);
		}
		finally
		{
			if (val != null)
			{
				val.Dispose();
			}
		}
	}

	public void SetBoldMode(bool sw)
	{
		//IL_001a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0037: Unknown result type (might be due to invalid IL or missing references)
		//IL_0038: Unknown result type (might be due to invalid IL or missing references)
		//IL_0042: Expected O, but got Unknown
		if (richTextBox1.SelectionFont.Bold != sw)
		{
			FontStyle val = (FontStyle)(sw ? 1 : 0);
			richTextBox1.SelectionFont = new Font(currentFont.FontFamily, currentFont.Size, val);
		}
	}

	public void SetUnderLineMode(bool sw)
	{
		//IL_001a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0037: Unknown result type (might be due to invalid IL or missing references)
		//IL_0038: Unknown result type (might be due to invalid IL or missing references)
		//IL_0042: Expected O, but got Unknown
		if (richTextBox1.SelectionFont.Underline != sw)
		{
			FontStyle val = (FontStyle)(sw ? 4 : 0);
			richTextBox1.SelectionFont = new Font(currentFont.FontFamily, currentFont.Size, val);
		}
	}

	public void SetSelectionBullet(bool sw, int bulletIndent = -1)
	{
		richTextBox1.SelectionBullet = sw;
		if (bulletIndent > 0)
		{
			richTextBox1.BulletIndent = bulletIndent;
		}
	}

	public void SetMesages(string messages)
	{
		((TextBoxBase)richTextBox1).SelectedText = messages;
	}

	public void SetHangingIndent(int indent)
	{
		richTextBox1.SelectionHangingIndent = indent;
	}

	public void SetMessageBoxSize(int width, int height)
	{
		((Control)richTextBox1).Width = width;
		((Control)richTextBox1).Height = height;
		((Control)this).Width = width + 16;
		((Control)this).Height = height + 72;
		int num = ((Control)this).Width - 24 - ((Control)closeButton).Width;
		int y = ((Control)this).Height - 66;
		((Control)closeButton).Location = new Point(num, y);
		num = num - 8 - ((Control)agreeButton).Width;
		((Control)agreeButton).Location = new Point(num, y);
	}

	public void HideAgreeButton()
	{
		((Control)agreeButton).Visible = false;
	}

	public void ResizeWindow()
	{
		//IL_0000: Unknown result type (might be due to invalid IL or missing references)
		//IL_0005: Unknown result type (might be due to invalid IL or missing references)
		//IL_0016: Unknown result type (might be due to invalid IL or missing references)
		//IL_0027: Unknown result type (might be due to invalid IL or missing references)
		//IL_002e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0035: Unknown result type (might be due to invalid IL or missing references)
		//IL_0046: Unknown result type (might be due to invalid IL or missing references)
		RichTextBox val = new RichTextBox
		{
			Size = ((Control)richTextBox1).Size,
			Rtf = richTextBox1.Rtf
		};
		((Control)val).Focus();
		((Control)val).Height = 0;
		((TextBoxBase)val).SelectionStart = ((TextBoxBase)richTextBox1).TextLength;
		((TextBoxBase)val).ScrollToCaret();
		int height = Math.Abs(((TextBoxBase)val).GetPositionFromCharIndex(0).Y) + 6;
		SetMessageBoxSize(((Control)richTextBox1).Width, height);
		((TextBoxBase)richTextBox1).SelectionStart = 0;
		((TextBoxBase)richTextBox1).ScrollToCaret();
	}

	private void agreeButton_Click(object sender, EventArgs e)
	{
		((Form)this).DialogResult = (DialogResult)1;
		((Form)this).Close();
	}

	private void closeButton_Click(object sender, EventArgs e)
	{
		((Form)this).DialogResult = (DialogResult)2;
		((Form)this).Close();
	}

	private void CustomDialogBox_SizeChanged(object sender, EventArgs e)
	{
		((Control)richTextBox1).Width = ((Control)this).Width - 16;
		((Control)richTextBox1).Height = ((Control)this).Height - 72;
		int num = ((Control)this).Width - 24 - ((Control)closeButton).Width;
		int y = ((Control)this).Height - 66;
		((Control)closeButton).Location = new Point(num, y);
		num = num - 8 - ((Control)agreeButton).Width;
		((Control)agreeButton).Location = new Point(num, y);
	}

	protected override void Dispose(bool disposing)
	{
		if (disposing && components != null)
		{
			components.Dispose();
		}
		((Form)this).Dispose(disposing);
	}

	private void InitializeComponent()
	{
		//IL_0001: Unknown result type (might be due to invalid IL or missing references)
		//IL_000b: Expected O, but got Unknown
		//IL_000c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0016: Expected O, but got Unknown
		//IL_0017: Unknown result type (might be due to invalid IL or missing references)
		//IL_0021: Expected O, but got Unknown
		//IL_0022: Unknown result type (might be due to invalid IL or missing references)
		//IL_002c: Expected O, but got Unknown
		richTextBox1 = new RichTextBox();
		pictureBox = new PictureBox();
		closeButton = new Button();
		agreeButton = new Button();
		((ISupportInitialize)pictureBox).BeginInit();
		((Control)this).SuspendLayout();
		((Control)richTextBox1).BackColor = SystemColors.Window;
		richTextBox1.DetectUrls = false;
		((TextBoxBase)richTextBox1).HideSelection = false;
		((Control)richTextBox1).Location = new Point(0, 0);
		((Control)richTextBox1).Name = "richTextBox1";
		((TextBoxBase)richTextBox1).ReadOnly = true;
		richTextBox1.ScrollBars = (RichTextBoxScrollBars)1;
		((TextBoxBase)richTextBox1).ShortcutsEnabled = false;
		((Control)richTextBox1).Size = new Size(374, 400);
		((Control)richTextBox1).TabIndex = 0;
		((Control)richTextBox1).TabStop = false;
		((Control)richTextBox1).Text = "";
		((Control)pictureBox).BackColor = SystemColors.Window;
		((Control)pictureBox).Location = new Point(13, 23);
		((Control)pictureBox).Name = "pictureBox";
		((Control)pictureBox).Size = new Size(30, 30);
		pictureBox.TabIndex = 1;
		pictureBox.TabStop = false;
		closeButton.DialogResult = (DialogResult)2;
		((Control)closeButton).Location = new Point(291, 406);
		((Control)closeButton).Name = "closeButton";
		((Control)closeButton).Size = new Size(75, 23);
		((Control)closeButton).TabIndex = 2;
		((Control)closeButton).Text = "Close";
		((ButtonBase)closeButton).UseVisualStyleBackColor = true;
		((Control)closeButton).Click += closeButton_Click;
		agreeButton.DialogResult = (DialogResult)1;
		((Control)agreeButton).Location = new Point(208, 406);
		((Control)agreeButton).Name = "agreeButton";
		((Control)agreeButton).Size = new Size(75, 23);
		((Control)agreeButton).TabIndex = 3;
		((Control)agreeButton).Text = "Agree";
		((ButtonBase)agreeButton).UseVisualStyleBackColor = true;
		((Control)agreeButton).Click += agreeButton_Click;
		((ContainerControl)this).AutoScaleMode = (AutoScaleMode)0;
		((ContainerControl)this).AutoValidate = (AutoValidate)0;
		((Form)this).CancelButton = (IButtonControl)(object)closeButton;
		((Form)this).ClientSize = new Size(374, 433);
		((Control)this).Controls.Add((Control)(object)agreeButton);
		((Control)this).Controls.Add((Control)(object)closeButton);
		((Control)this).Controls.Add((Control)(object)pictureBox);
		((Control)this).Controls.Add((Control)(object)richTextBox1);
		((Form)this).FormBorderStyle = (FormBorderStyle)1;
		((Form)this).MaximizeBox = false;
		((Form)this).MinimizeBox = false;
		((Control)this).Name = "CustomDialogBox";
		((Form)this).ShowIcon = false;
		((Form)this).ShowInTaskbar = false;
		((Control)this).Text = "Security Setting";
		((Control)this).SizeChanged += CustomDialogBox_SizeChanged;
		((ISupportInitialize)pictureBox).EndInit();
		((Control)this).ResumeLayout(false);
	}
}
