using System;
using System.Runtime.InteropServices;
using System.Windows.Forms;

namespace CreateFolder;

internal class CustomizableMessageBox
{
	public class CustomButtonText
	{
		public string OK { get; set; }

		public string Cancel { get; set; }

		public string Abort { get; set; }

		public string Retry { get; set; }

		public string Ignore { get; set; }

		public string Yes { get; set; }

		public string No { get; set; }
	}

	private delegate IntPtr HOOKPROC(int nCode, IntPtr wParam, IntPtr lParam);

	private IntPtr hHook = IntPtr.Zero;

	private const int WH_CBT = 5;

	private const int HCBT_ACTIVATE = 5;

	private const int ID_BUT_OK = 1;

	private const int ID_BUT_CANCEL = 2;

	private const int ID_BUT_ABORT = 3;

	private const int ID_BUT_RETRY = 4;

	private const int ID_BUT_IGNORE = 5;

	private const int ID_BUT_YES = 6;

	private const int ID_BUT_NO = 7;

	public CustomButtonText ButtonText { get; set; }

	public CustomizableMessageBox()
	{
		ButtonText = new CustomButtonText();
	}

	public DialogResult Show(string text, string caption, MessageBoxButtons buttons, MessageBoxIcon icon)
	{
		//IL_0008: Unknown result type (might be due to invalid IL or missing references)
		//IL_0009: Unknown result type (might be due to invalid IL or missing references)
		//IL_000b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0010: Unknown result type (might be due to invalid IL or missing references)
		//IL_001a: Unknown result type (might be due to invalid IL or missing references)
		try
		{
			BeginHook();
			return MessageBox.Show(text, caption, buttons, icon);
		}
		finally
		{
			EndHook();
		}
	}

	private void BeginHook()
	{
		EndHook();
		hHook = SetWindowsHookEx(5, HookProc, IntPtr.Zero, GetCurrentThreadId());
	}

	private IntPtr HookProc(int nCode, IntPtr wParam, IntPtr lParam)
	{
		if (nCode == 5)
		{
			if (ButtonText.Abort != null)
			{
				SetDlgItemText(wParam, 3, ButtonText.Abort);
			}
			if (ButtonText.Cancel != null)
			{
				SetDlgItemText(wParam, 2, ButtonText.Cancel);
			}
			if (ButtonText.Ignore != null)
			{
				SetDlgItemText(wParam, 5, ButtonText.Ignore);
			}
			if (ButtonText.No != null)
			{
				SetDlgItemText(wParam, 7, ButtonText.No);
			}
			if (ButtonText.OK != null)
			{
				SetDlgItemText(wParam, 1, ButtonText.OK);
			}
			if (ButtonText.Retry != null)
			{
				SetDlgItemText(wParam, 4, ButtonText.Retry);
			}
			if (ButtonText.Yes != null)
			{
				SetDlgItemText(wParam, 6, ButtonText.Yes);
			}
			EndHook();
		}
		return CallNextHookEx(hHook, nCode, wParam, lParam);
	}

	private void EndHook()
	{
		if (hHook != IntPtr.Zero)
		{
			UnhookWindowsHookEx(hHook);
			hHook = IntPtr.Zero;
		}
	}

	[DllImport("user32.dll")]
	private static extern IntPtr SetWindowsHookEx(int idHook, HOOKPROC lpfn, IntPtr hInstance, IntPtr threadId);

	[DllImport("user32.dll")]
	private static extern bool UnhookWindowsHookEx(IntPtr hHook);

	[DllImport("user32.dll")]
	private static extern IntPtr CallNextHookEx(IntPtr hHook, int nCode, IntPtr wParam, IntPtr lParam);

	[DllImport("kernel32.dll")]
	private static extern IntPtr GetCurrentThreadId();

	[DllImport("user32.dll", CharSet = CharSet.Auto)]
	private static extern bool SetDlgItemText(IntPtr hWnd, int nIDDlgItem, string lpString);
}
