using System;
using System.Collections;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Management;
using System.Reflection;
using System.Windows.Forms;
using CreateFolder.Properties;
using log4net;

namespace CreateFolder;

internal class FolderSetting
{
	private static readonly ILog LOG = LogManager.GetLogger(MethodBase.GetCurrentMethod().DeclaringType);

	private Hashtable folderTable = new Hashtable(StringComparer.InvariantCultureIgnoreCase);

	private Hashtable lonlyFolderTable = new Hashtable(StringComparer.InvariantCultureIgnoreCase);

	public void setSharedFolderListTable()
	{
		//IL_015a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0034: Unknown result type (might be due to invalid IL or missing references)
		//IL_003a: Expected O, but got Unknown
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		try
		{
			folderTable.Clear();
			lonlyFolderTable.Clear();
			ManagementObjectSearcher val = new ManagementObjectSearcher("SELECT * FROM win32_share");
			try
			{
				foreach (var item in from ManagementObject x in (IEnumerable)val.Get()
					select new
					{
						Name = ((ManagementBaseObject)x)["Name"],
						Path = ((ManagementBaseObject)x)["Path"]
					})
				{
					if (((string)item.Name).EndsWith("$"))
					{
						LOG.DebugFormat("隠しフォルダ # 共有名:{0} パス:{1}", item.Name, item.Path);
					}
					else if (!Directory.Exists(item.Path.ToString()))
					{
						LOG.DebugFormat("実体なし # 共有名:{0} パス:{1}", item.Name, item.Path);
						lonlyFolderTable.Add(item.Name, item.Path);
					}
					else
					{
						LOG.DebugFormat("共有名:{0} パス:{1}", item.Name, item.Path);
						folderTable.Add(item.Name, item.Path);
					}
				}
			}
			finally
			{
				((IDisposable)val)?.Dispose();
			}
		}
		catch (Exception ex)
		{
			MessageBox.Show(Resources.ERR_MSG_FATAL, Resources.ERR_TITLE_CREATE_FOLDER, (MessageBoxButtons)0, (MessageBoxIcon)16);
			LOG.ErrorFormat("{0}：！！！ 共有フォルダー一覧生成処理でエラー  \n" + ex.ToString() + "\n*******************************", (object)MethodBase.GetCurrentMethod().Name);
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	public bool setComboBoxFolderList(ComboBox pComboBoxFolder, string folderName = "")
	{
		//IL_00dd: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		bool result = false;
		if (pComboBoxFolder == null)
		{
			throw new Exception("pComboBoxFolder is NULL!!!!");
		}
		try
		{
			if (string.IsNullOrEmpty(folderName) && ((ListControl)pComboBoxFolder).SelectedIndex >= 0)
			{
				folderName = pComboBoxFolder.SelectedItem.ToString();
			}
			pComboBoxFolder.Items.Clear();
			foreach (DictionaryEntry item in folderTable)
			{
				pComboBoxFolder.Items.Add(item.Key);
			}
			if (pComboBoxFolder.Items.Contains((object)folderName))
			{
				pComboBoxFolder.SelectedItem = folderName;
				result = true;
			}
			else
			{
				((ListControl)pComboBoxFolder).SelectedIndex = ((pComboBoxFolder.Items.Count <= 0) ? (-1) : 0);
			}
		}
		catch (Exception ex)
		{
			MessageBox.Show(Resources.ERR_MSG_FATAL, Resources.ERR_TITLE_CREATE_FOLDER, (MessageBoxButtons)0, (MessageBoxIcon)16);
			LOG.ErrorFormat("{0}：！！！ 共有フォルダー一覧生成処理でエラー  \n" + ex.ToString() + "\n*******************************", (object)MethodBase.GetCurrentMethod().Name);
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return result;
	}

	public void setComboBoxPCUserList(ComboBox pComboBoxFolder, ComboBox pComboBoxPCUser)
	{
		//IL_01fb: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		if (pComboBoxFolder == null)
		{
			throw new Exception("pComboBoxFolder is NULL!!!!");
		}
		if (pComboBoxPCUser == null)
		{
			throw new Exception("pComboBoxPCUser is NULL!!!!");
		}
		try
		{
			List<string> list = new List<string>();
			string text = (string)pComboBoxFolder.SelectedItem;
			if (string.IsNullOrEmpty(text))
			{
				text = ((Control)pComboBoxFolder).Text;
			}
			if (string.IsNullOrEmpty(text) || string.IsNullOrEmpty((string)folderTable[text]))
			{
				return;
			}
			try
			{
				list = ShareFolderManager.GetUserList((string)folderTable[text]);
			}
			catch (DirectoryNotFoundException ex)
			{
				LOG.DebugFormat("{0}：Folder Not Found", (object)MethodBase.GetCurrentMethod().Name, (object)ex.ToString());
				folderTable.Remove(text);
			}
			catch (Exception ex2)
			{
				LOG.ErrorFormat("{0}：User List Error", (object)MethodBase.GetCurrentMethod().Name, (object)ex2.ToString());
			}
			pComboBoxPCUser.Items.Clear();
			((Control)pComboBoxPCUser).Text = "";
			((Control)pComboBoxPCUser).Refresh();
			string text2 = Environment.UserDomainName + "\\" + Environment.UserName;
			if (list != null && list.Count > 0)
			{
				list = excludeUserList(text, list);
				if (list != null && list.Count > 0)
				{
					foreach (string item in list)
					{
						pComboBoxPCUser.Items.Add((object)item);
						if (pComboBoxPCUser.Items.Count > 0)
						{
							((ListControl)pComboBoxPCUser).SelectedIndex = 0;
						}
					}
				}
				else
				{
					LOG.DebugFormat("{0}：User List count zero", (object)MethodBase.GetCurrentMethod().Name);
				}
			}
			else
			{
				LOG.DebugFormat("{0}：User List2 count zero", (object)MethodBase.GetCurrentMethod().Name);
			}
			Console.Out.WriteLine(text2);
			LOG.DebugFormat("{0}：loginUserName = {1}", (object)MethodBase.GetCurrentMethod().Name, (object)text2);
		}
		catch (Exception ex3)
		{
			MessageBox.Show(Resources.ERR_MSG_FATAL, Resources.ERR_TITLE_CREATE_FOLDER, (MessageBoxButtons)0, (MessageBoxIcon)16);
			LOG.ErrorFormat("{0}：フォルダについているユーザ一覧表示でエラー：\n{1}", (object)MethodBase.GetCurrentMethod().Name, (object)ex3.ToString());
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	private List<string> excludeUserList(string shareFolderName, List<string> userList)
	{
		//IL_0016: Unknown result type (might be due to invalid IL or missing references)
		//IL_003a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0041: Expected O, but got Unknown
		//IL_00c8: Unknown result type (might be due to invalid IL or missing references)
		//IL_00cf: Expected O, but got Unknown
		string value = "\\Everyone";
		ManagementObjectSearcher val = new ManagementObjectSearcher("SELECT * FROM Win32_LogicalShareSecuritySetting where Name ='" + shareFolderName + "' ");
		List<string> list = new List<string>();
		List<ManagementObject> list2 = new List<ManagementObject>();
		ManagementObjectEnumerator enumerator = val.Get().GetEnumerator();
		try
		{
			while (enumerator.MoveNext())
			{
				ManagementObject item = (ManagementObject)enumerator.Current;
				list2.Add(item);
			}
		}
		finally
		{
			((IDisposable)enumerator)?.Dispose();
		}
		for (int i = 0; i < userList.Count; i++)
		{
			string text = userList[i];
			bool flag = false;
			foreach (ManagementObject item2 in list2)
			{
				Console.WriteLine(((ManagementBaseObject)item2)["Name"] as string);
				LOG.DebugFormat("{0}：Name:{1}", (object)MethodBase.GetCurrentMethod().Name, (object)(((ManagementBaseObject)item2)["Name"] as string));
				InvokeMethodOptions val2 = new InvokeMethodOptions();
				object obj = item2.InvokeMethod("GetSecurityDescriptor", (ManagementBaseObject)null, val2)["Descriptor"];
				ManagementBaseObject[] array = ((ManagementBaseObject)((obj is ManagementBaseObject) ? obj : null))["DACL"] as ManagementBaseObject[];
				foreach (ManagementBaseObject val3 in array)
				{
					try
					{
						object obj2 = val3["Trustee"];
						ManagementBaseObject val4 = (ManagementBaseObject)((obj2 is ManagementBaseObject) ? obj2 : null);
						Console.WriteLine(string.Concat(val4["Domain"] as string, "\\", val4["Name"], ": ", val3["AccessMask"], " = ", val3["AceType"]));
						LOG.DebugFormat("{0}：User Account:{1}@{2} , Access Mask:{3} , AceType:{4}", new object[5]
						{
							MethodBase.GetCurrentMethod().Name,
							val4["Domain"] as string,
							val4["Name"] as string,
							val3["AccessMask"] as string,
							val3["AceType"] as string
						});
						uint num = (uint)val3["AceType"];
						string text2 = (val4["Domain"] as string) + "\\" + val4["Name"];
						if ((text2.Equals(text) && num == 0) || (text2.Equals(value) && num == 0))
						{
							flag = true;
							break;
						}
					}
					catch (Exception ex)
					{
						Console.WriteLine("Error: " + ex.ToString());
					}
				}
			}
			if (flag)
			{
				list.Add(text);
			}
		}
		return list;
	}

	public void setComboBoxUserList(ComboBox pComboBoxUser)
	{
		//IL_013d: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		try
		{
			List<UserInfo> list = UserInfo.GetList("WinNT://" + Environment.MachineName);
			pComboBoxUser.Items.Clear();
			((Control)pComboBoxUser).Text = "";
			((Control)pComboBoxUser).Refresh();
			foreach (UserInfo item in list)
			{
				pComboBoxUser.Items.Add((object)(item.ParentName + item.Name));
			}
			string text = Environment.UserDomainName + "\\" + Environment.UserName;
			Console.Out.WriteLine(text);
			int num = 0;
			foreach (UserInfo item2 in list)
			{
				if (!text.Equals(item2.ParentName + item2.Name, StringComparison.CurrentCultureIgnoreCase))
				{
					num++;
					continue;
				}
				break;
			}
			if (num == list.Count)
			{
				pComboBoxUser.Items.Add((object)text);
			}
			if (pComboBoxUser.Items.Count > 0)
			{
				((ListControl)pComboBoxUser).SelectedIndex = num;
			}
		}
		catch (Exception ex)
		{
			MessageBox.Show(Resources.ERR_MSG_FATAL, Resources.ERR_TITLE_CREATE_FOLDER, (MessageBoxButtons)0, (MessageBoxIcon)16);
			LOG.ErrorFormat("{0}：PCユーザ一覧表示でエラー：\n{1}", (object)MethodBase.GetCurrentMethod().Name, (object)ex.ToString());
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	public void setComboBoxMFPList(MachineSelectControl machineSelectControl, List<string> machineInfoList = null)
	{
		//IL_0046: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		try
		{
			machineSelectControl.initialize();
			_ = string.Empty;
			if (machineInfoList == null)
			{
				machineInfoList = FormWizard.GetMFPList();
			}
			machineSelectControl.setMachineList(machineInfoList);
		}
		catch (Exception ex)
		{
			MessageBox.Show(Resources.ERR_MSG_FATAL, Resources.ERR_TITLE_CREATE_FOLDER, (MessageBoxButtons)0, (MessageBoxIcon)16);
			LOG.ErrorFormat("{0}：機器情報一覧表示でエラー：\n{1}", (object)MethodBase.GetCurrentMethod().Name, (object)ex.ToString());
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	public string getSharedFolderPath(string sharedFolderName, bool lonly = false)
	{
		string text = string.Empty;
		if (folderTable.ContainsKey(sharedFolderName))
		{
			text = (string)folderTable[sharedFolderName];
		}
		LOG.DebugFormat("{0}：path=[{1}]", (object)MethodBase.GetCurrentMethod().Name, (object)text);
		if (string.IsNullOrEmpty(text) && lonly)
		{
			text = (string)lonlyFolderTable[sharedFolderName];
			LOG.DebugFormat("{0}：実体の無いフォルダー path=[{1}]", (object)MethodBase.GetCurrentMethod().Name, (object)text);
		}
		return text;
	}
}
