using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Linq;
using System.Net;
using System.Net.Http;
using System.Reflection;
using System.Threading.Tasks;
using System.Windows.Forms;
using CreateFolder.Properties;
using log4net;

namespace CreateFolder;

public class FormAddressBookEdit : Form
{
	public enum RADIO_BUTTON
	{
		DO = 1,
		IDO_NOT
	}

	private static readonly ILog LOG = LogManager.GetLogger(MethodBase.GetCurrentMethod().DeclaringType);

	private List<string> machineList = new List<string>();

	private MachineControl mc;

	private string ipaddrPC = string.Empty;

	private Dictionary<object, bool> controlesState = new Dictionary<object, bool>();

	private AddressBookListControl adrBookListCtrl;

	private Dictionary<string, string> inputAreaConverter = new Dictionary<string, string>
	{
		{
			"entryIndexIn",
			Resources.ADDRESSBOOK_REGISTRATION_NO_NAME
		},
		{
			"entryNameIn",
			Resources.CREATE_HTML_DEFAULT_DEST
		},
		{
			"entryReadNameIn",
			Resources.ADDRESSBOOK_INDEX_NAME
		},
		{
			"entryDisplayNameIn",
			Resources.ADDRESSBOOK_KEY_DISPLAY_NAME
		},
		{
			"folderPathNameIn",
			Resources.FORM_MAIN_FOLDER_NAME
		}
	};

	private bool PrimaxModel;

	private bool PrimaxUnicode;

	public string PrimaxAdminPasswd = "";

	private string machineLang = "";

	private IContainer components;

	private Button buttonEdit;

	private Button buttonClose;

	private Label label1;

	private Label labelMFP_Info;

	private Button buttonMachineSelect;

	private Label labelMFP_Select;

	private Label labelMFP_Selected;

	private ListView listViewAddressList;

	private TextBox textBoxSearch;

	private Button buttonSearch;

	private ComboBox comboBoxSelectWay;

	private Label labelPage;

	private Label displayedPage;

	private Button buttonToTop;

	private Button buttonPrevious;

	private Button buttonNext;

	private Button buttonToBottom;

	private Label progressText;

	private Button buttonBreak;

	private Button buttonResume;

	public FormAddressBookEdit(string ipaddr, string lang)
	{
		if (lang.Equals("ja") || lang.Equals("en"))
		{
			InitializeComponent();
		}
		else
		{
			InitializeComponent_MultiLang();
		}
		machineLang = lang;
		Control[] allControls = CreateFolderUtil.GetAllControls((Control)(object)this);
		CreateFolderUtil.ResetFontToControl(((object)this).GetType().Name, allControls);
		((Control)this).Text = Resources.ADDRESSBOOK_TITLE;
		((Control)buttonEdit).Text = Resources.ADDRESSBOOK_BUTTON_EDIT_NAME;
		((Control)buttonClose).Text = Resources.ITEM_BUTTON_BACK;
		((Control)buttonBreak).Text = Resources.ITEM_BUTTON_SUSPEND;
		((Control)buttonResume).Text = Resources.ITEM_BUTTON_RESUME;
		((Control)buttonSearch).Text = Resources.ITEM_BUTTON_SEARCH;
		((Control)buttonMachineSelect).Text = Resources.FORM_MFPINFO_SELECT_BUTTON;
		((Control)labelPage).Text = Resources.LABEL_PAGE_NAME;
		((Control)labelMFP_Info).Text = Resources.FORM_MFPINFO_OPE_MESSAGE;
		((Control)labelMFP_Select).Text = Resources.FORM_MFPINFO_SELECTED_MACHINE;
		((Control)labelMFP_Selected).Text = string.Empty;
		((Control)progressText).Text = string.Empty;
		((Control)displayedPage).Text = string.Empty;
		mc = new MachineControl(lang);
		ipaddrPC = ipaddr;
		adrBookListCtrl = new AddressBookListControl(lang, mc);
		machineLang = lang;
	}

	public void initialize()
	{
		adrBookListCtrl.ButtonBreak = buttonBreak;
		adrBookListCtrl.ButtonResume = buttonResume;
		adrBookListCtrl.ButtonNext = buttonNext;
		adrBookListCtrl.ButtonPrevious = buttonPrevious;
		adrBookListCtrl.ButtonSearch = buttonSearch;
		adrBookListCtrl.ButtonToBottom = buttonToBottom;
		adrBookListCtrl.ButtonToTop = buttonToTop;
		adrBookListCtrl.ButtonMachineSelect = buttonMachineSelect;
		adrBookListCtrl.ComboBoxSelectWay = comboBoxSelectWay;
		adrBookListCtrl.DisplayedPage = displayedPage;
		adrBookListCtrl.ListViewAddressList = listViewAddressList;
		adrBookListCtrl.ProgressText = progressText;
		adrBookListCtrl.TextBoxSearch = textBoxSearch;
		adrBookListCtrl.initialize();
	}

	public void clearMachineList()
	{
		machineList.Clear();
	}

	public void setMachineList(List<string> machines)
	{
		foreach (string machine in machines)
		{
			if (!machineList.Contains(machine))
			{
				machineList.Add(machine);
			}
		}
	}

	private async Task<Dictionary<string, Dictionary<MachineControl.ADDRESSBOOK_ITEM, string>>> updateMfpAddressbook(string ipAddress, Dictionary<AddressBookListControl.ADDRESSBOOK_LIST_ITEM, string> userInfoOrg, Dictionary<AddressBookListControl.ADDRESSBOOK_LIST_ITEM, string> newUserInfo, COMMUNICATION_ERROR_CODE comResult)
	{
		LOG.Debug((object)"updateMfpAddressbook：start");
		SettingItemsSetupAddress setting = new SettingItemsSetupAddress
		{
			host = ipAddress,
			adminName = "admin",
			passwd = "",
			firstFlg = true,
			httpsFlg = (comResult != COMMUNICATION_ERROR_CODE.HTTP_ONLY),
			addressName = newUserInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_NAME],
			readName = newUserInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX_NAME],
			displayName = newUserInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_DISPLAY_NAME],
			authUserName = newUserInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_AUTH_USER_NAME],
			authPassword = newUserInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PASSWORD],
			folderPath = newUserInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PATH_NAME]
		};
		int result = 0;
		int.TryParse(newUserInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_1], out result);
		setting.headlineIndex1 = result;
		int.TryParse(newUserInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_2], out result);
		setting.headlineIndex2 = result;
		int.TryParse(newUserInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_3], out result);
		setting.headlineIndex3 = result;
		int.TryParse(newUserInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_FREQ], out result);
		setting.regularHeadingIndex = result;
		int.TryParse(newUserInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX], out result);
		setting.registrationNo = result;
		int.TryParse(userInfoOrg[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX], out var _);
		HttpResponseMessage httpResponseMessage = await mc.setAddressbookBase(setting);
		if (httpResponseMessage.StatusCode != HttpStatusCode.OK)
		{
			LOG.Debug((object)"updateMfpAddressbook：end（エラー）");
			return null;
		}
		WimError winError = mc.checkWimErrorCode(httpResponseMessage);
		LOG.DebugFormat("WIM Info. id:[{0}] msg:[{1}] [{2}]", (object)winError.id, (object)winError.message, (object)winError.errPoint);
		if (winError.kind != 0)
		{
			httpResponseMessage = await mc.setAddressbookFolder(setting);
			if (httpResponseMessage.StatusCode != HttpStatusCode.OK)
			{
				LOG.Debug((object)"updateMfpAddressbook：end（エラー）");
				return null;
			}
			winError = mc.checkWimErrorCode(httpResponseMessage);
			LOG.DebugFormat("WIM Info. id:[{0}] msg:[{1}] [{2}]", (object)winError.id, (object)winError.message, (object)winError.errPoint);
			if (winError.kind != 0)
			{
				Dictionary<string, Dictionary<MachineControl.ADDRESSBOOK_ITEM, string>> result3 = await mc.setAddressbookGo();
				LOG.Debug((object)"updateMfpAddressbook：end");
				return result3;
			}
		}
		string text = string.Empty;
		if (string.Equals(winError.id, "INDEX_E"))
		{
			text = $"{Resources.ASK_IF_RESUNDANT_REGISTRATION_NUMBER_01}\n\n No. {setting.registrationNo:D5}";
			LOG.Debug((object)"checkWimError：end（登録番号重複）");
		}
		else if (string.Equals(winError.id, "NGPARAM_WIZARD_E"))
		{
			text = $"{winError.message}\n\n{winError.errPoint}";
			LOG.Debug((object)"checkWimError：end（入力エラー）");
		}
		if (!string.IsNullOrEmpty(text))
		{
			MessageBox.Show(text, Resources.SET_REGISTRATION_NUMBER_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
		}
		return new Dictionary<string, Dictionary<MachineControl.ADDRESSBOOK_ITEM, string>>();
	}

	private async void buttonEdit_Click(object sender, EventArgs e)
	{
		LOG.Debug((object)"buttonEdit_Click：start");
		setCollectionMode(AddressBookListControl.COLLECTION_STATE.NONE);
		string machineIPAddress = FormMFPSelect.getIpAddress();
		((Control)buttonEdit).Enabled = false;
		FormAddressBookSetting userInfoSettingDlg = null;
		string regNo = adrBookListCtrl.getSelectedItem(AddressBookListControl.COLUMN.REGISTRATION_NO);
		((Control)progressText).Text = Resources.ADDRESSBOOK_GET_ONE_RECORD;
		try
		{
			setAllControlesEnable(enable: false);
			((Control)this).Cursor = Cursors.WaitCursor;
			mc.SetPrimaxModel(PrimaxModel);
			mc.SetPrimaxUnicode(PrimaxUnicode);
			COMMUNICATION_ERROR_CODE comResult = mc.communicateConfirm(machineIPAddress);
			switch (comResult)
			{
			case COMMUNICATION_ERROR_CODE.ERROR:
				LOG.Debug((object)"buttonEdit_Click：communicateConfirm failed");
				return;
			case COMMUNICATION_ERROR_CODE.NOT_SUPPORT:
				LOG.Debug((object)"buttonEdit_Click：machine not support");
				return;
			}
			bool thhpsFlg = false;
			if (!comResult.Equals(COMMUNICATION_ERROR_CODE.HTTP_ONLY))
			{
				thhpsFlg = true;
			}
			List<OneTouchKeyInfo> oneTouchKeyInfo = null;
			Dictionary<AddressBookListControl.ADDRESSBOOK_LIST_ITEM, string> userInfoOrg;
			if (PrimaxModel)
			{
				string reqdestname = adrBookListCtrl.getSelectedItem(AddressBookListControl.COLUMN.NAME);
				oneTouchKeyInfo = await mc.getPrimaxOneTouchKeyInfo(thhpsFlg, machineIPAddress);
				userInfoOrg = await adrBookListCtrl.GetAddressBookInfoToPrimax(machineIPAddress, reqdestname, oneTouchKeyInfo);
			}
			else
			{
				userInfoOrg = await adrBookListCtrl.GetAddressBookInfo(machineIPAddress, regNo, comResult);
			}
			((Control)progressText).Text = string.Empty;
			if (userInfoOrg == null)
			{
				return;
			}
			userInfoSettingDlg = new FormAddressBookSetting(machineLang);
			userInfoSettingDlg.machineLang = machineLang;
			userInfoSettingDlg.setParameters(ipaddrPC, userInfoOrg);
			while (true)
			{
				userInfoSettingDlg.isPrimax = PrimaxModel;
				userInfoSettingDlg.isUnicodePrimax = PrimaxUnicode;
				userInfoSettingDlg.PrimaxOneTouchKeyList = oneTouchKeyInfo;
				if ((int)((Form)userInfoSettingDlg).ShowDialog() == 2)
				{
					break;
				}
				((Control)progressText).Text = Resources.ADDRESSBOOK_SET_ONE_RECORD;
				Dictionary<AddressBookListControl.ADDRESSBOOK_LIST_ITEM, string> newUserInfo = userInfoSettingDlg.getParameters();
				if (!FormWizard.PCSMBcheck(machineLang))
				{
					break;
				}
				Dictionary<string, Dictionary<MachineControl.ADDRESSBOOK_ITEM, string>> dictionary;
				if (PrimaxModel)
				{
					if (!FormWizard.PrimaxSMBcheck(machineIPAddress, FormWizard.GetHostNameFromIP(machineIPAddress), machineLang))
					{
						break;
					}
					dictionary = await updateMfpAddressbookToPrimax(machineIPAddress, userInfoOrg, newUserInfo, oneTouchKeyInfo, userInfoSettingDlg, comResult);
				}
				else
				{
					if (!(await FormWizard.MFPSMBcheck(machineIPAddress, FormWizard.GetHostNameFromIP(machineIPAddress), machineLang)))
					{
						break;
					}
					dictionary = await updateMfpAddressbook(machineIPAddress, userInfoOrg, newUserInfo, comResult);
				}
				if (dictionary == null)
				{
					break;
				}
				if (dictionary.Count != 0)
				{
					if (PrimaxModel)
					{
						adrBookListCtrl.exchangeAddressBookItemToPrimax(dictionary.First());
					}
					else
					{
						adrBookListCtrl.exchangeAddressBookItem(regNo, dictionary.First());
					}
					break;
				}
			}
		}
		catch (Exception ex)
		{
			MessageBox.Show(adrBookListCtrl.checkException(ex, "buttonEdit_Click"), Resources.ERR_MSG_SEARCH_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
		}
		finally
		{
			((Control)progressText).Text = string.Empty;
			((Component)(object)userInfoSettingDlg)?.Dispose();
			setAllControlesEnable(enable: true);
			((Control)this).Cursor = Cursors.Default;
			((Control)buttonEdit).Enabled = listViewAddressList.SelectedItems.Count > 0;
			LOG.Debug((object)"buttonEdit_Click：end");
		}
	}

	private void buttonClose_Click(object sender, EventArgs e)
	{
		LOG.Debug((object)"buttonClose_Click");
		((Control)this).Visible = false;
	}

	private void buttonMachineSelect_Click(object sender, EventArgs e)
	{
		LOG.Debug((object)"buttonMachineSelect_Click：start");
		setCollectionMode(AddressBookListControl.COLLECTION_STATE.NONE);
		adrBookListCtrl.resetSeachEnvironments();
		((Control)labelMFP_Selected).Text = "";
		FormMFPSelect.initialize(machineLang);
		FormMFPSelect.setMachineList(machineList);
		((Control)labelMFP_Selected).Text = FormMFPSelect.GetDisplayedIPAddress();
		adrBookListCtrl.MFP_SelectedAddress = FormMFPSelect.getIpAddress();
		PrimaxModel = adrBookListCtrl.SetPrimaxModel(FormMFPSelect.getIpAddress());
		PrimaxUnicode = FormWizard.IsPrimaxUnicode(FormWizard.GetHostNameFromIP(FormMFPSelect.getIpAddress()));
		if (PrimaxModel)
		{
			((Control)comboBoxSelectWay).Visible = false;
			((Control)textBoxSearch).Visible = false;
			listViewAddressList.Columns[0].Text = Resources.PRIMAX_ONE_TOUCH_KEY;
		}
		else
		{
			((Control)comboBoxSelectWay).Visible = true;
			((Control)textBoxSearch).Visible = true;
			listViewAddressList.Columns[0].Text = Resources.ADDRESSBOOK_REGISTRATION_NO_NAME;
		}
		PrimaxAdminPasswd = "";
		LOG.Debug((object)"buttonMachineSelect_Click：end");
	}

	private void labelMFP_Selected_TextChanged(object sender, EventArgs e)
	{
		((Control)buttonSearch).Enabled = !string.IsNullOrEmpty(((Control)labelMFP_Selected).Text);
	}

	private void buttonSearch_Click(object sender, EventArgs e)
	{
		adrBookListCtrl.buttonSearch_Click();
		if (!((Control)labelMFP_Selected).Text.Contains("("))
		{
			string arg = mc.DisplayMachineName;
			if (PrimaxModel)
			{
				arg = FormWizard.GetHostNameFromIP(((Control)labelMFP_Selected).Text);
			}
			((Control)labelMFP_Selected).Text = $"{arg} ({((Control)labelMFP_Selected).Text})";
		}
	}

	private void setCollectionMode(AddressBookListControl.COLLECTION_STATE newState)
	{
		adrBookListCtrl.setCollectionMode(newState);
	}

	private void listViewAddressList_DrawColumnHeader(object sender, DrawListViewColumnHeaderEventArgs e)
	{
		adrBookListCtrl.listViewAddressList_DrawColumnHeader(e);
	}

	private void listViewAddressList_DrawItem(object sender, DrawListViewItemEventArgs e)
	{
		adrBookListCtrl.listViewAddressList_DrawItem(e);
	}

	private void buttonNext_Click(object sender, EventArgs e)
	{
		adrBookListCtrl.buttonNext_Click();
	}

	private void buttonPrevious_Click(object sender, EventArgs e)
	{
		adrBookListCtrl.buttonPrevious_Click();
	}

	private void buttonToTheTop_Click(object sender, EventArgs e)
	{
		adrBookListCtrl.buttonToTheTop_Click();
	}

	private void buttonToTheButtom_Click(object sender, EventArgs e)
	{
		adrBookListCtrl.buttonToTheButtom_Click();
	}

	private void listViewAddressList_ItemSelectionChanged(object sender, ListViewItemSelectionChangedEventArgs e)
	{
		if (e.IsSelected && e.Item.BackColor == adrBookListCtrl.ListViewSelectDeniedColor)
		{
			e.Item.Selected = false;
		}
		else
		{
			((Control)buttonEdit).Enabled = e.IsSelected;
		}
	}

	private void setAllControlesEnable(bool enable)
	{
		//IL_00a6: Unknown result type (might be due to invalid IL or missing references)
		//IL_00d7: Unknown result type (might be due to invalid IL or missing references)
		//IL_0105: Unknown result type (might be due to invalid IL or missing references)
		//IL_0133: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("FormAddressbookEdit:setAllControlesEnable：{0}", (object)enable);
		adrBookListCtrl.setAllControlesEnable(enable);
		if (!enable)
		{
			controlesState.Clear();
			controlesState.Add(buttonClose, ((Control)buttonClose).Enabled);
			controlesState.Add(buttonEdit, ((Control)buttonEdit).Enabled);
		}
		foreach (KeyValuePair<object, bool> item in controlesState)
		{
			Type type = item.Key.GetType();
			if (type == typeof(Button))
			{
				((Control)(Button)item.Key).Enabled = item.Value && enable;
			}
			else if (type == typeof(ComboBox))
			{
				((Control)(ComboBox)item.Key).Enabled = item.Value && enable;
			}
			else if (type == typeof(TextBox))
			{
				((Control)(TextBox)item.Key).Enabled = item.Value && enable;
			}
			else if (type == typeof(ListView))
			{
				((Control)(ListView)item.Key).Enabled = item.Value && enable;
			}
		}
		if (enable)
		{
			controlesState.Clear();
		}
	}

	private void textBoxSearch_KeyPress(object sender, KeyPressEventArgs e)
	{
		adrBookListCtrl.textBoxSearch_KeyPress(e);
	}

	private void buttonBreak_Click(object sender, EventArgs e)
	{
		adrBookListCtrl.buttonBreak_Click();
	}

	private void buttonResume_Click(object sender, EventArgs e)
	{
		adrBookListCtrl.buttonResume_Click();
	}

	private async Task<Dictionary<string, Dictionary<MachineControl.ADDRESSBOOK_ITEM, string>>> updateMfpAddressbookToPrimax(string ipAddress, Dictionary<AddressBookListControl.ADDRESSBOOK_LIST_ITEM, string> userInfoOrg, Dictionary<AddressBookListControl.ADDRESSBOOK_LIST_ITEM, string> newUserInfo, List<OneTouchKeyInfo> oneTouchKeyInfo, FormAddressBookSetting userInfoSettingDlg, COMMUNICATION_ERROR_CODE comResult)
	{
		LOG.Debug((object)"updateMfpAddressbookToPrimax：start");
		Dictionary<string, Dictionary<MachineControl.ADDRESSBOOK_ITEM, string>> retAddressBookInfo = new Dictionary<string, Dictionary<MachineControl.ADDRESSBOOK_ITEM, string>>();
		string entry_index = userInfoOrg[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX].ToString();
		string old_entry_index = userInfoOrg[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX].ToString();
		if (!userInfoOrg[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX].ToString().Equals(newUserInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX].ToString()))
		{
			entry_index = int.Parse(newUserInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX].ToString()).ToString();
		}
		bool primaxIndexRelease = userInfoSettingDlg.PrimaxIndexRelease;
		string value = userInfoOrg[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX].ToString();
		if (int.Parse(newUserInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX].ToString()).ToString().Equals(value) && primaxIndexRelease)
		{
			entry_index = "0";
		}
		string entry_name = newUserInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_NAME].ToString();
		if (!userInfoOrg[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_NAME].ToString().Equals(newUserInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_NAME].ToString()) && "0".Equals(old_entry_index) && (int)MessageBox.Show($"{Resources.PRIMAX_NEW_UPDATE_CAUTION_01}\n{Resources.PRIMAX_NEW_UPDATE_CAUTION_02}\n{Resources.PRIMAX_NEW_UPDATE_CAUTION_03}\n", Resources.ADDRESSBOOK_EDIT, (MessageBoxButtons)4, (MessageBoxIcon)32) == 7)
		{
			return retAddressBookInfo;
		}
		string old_entry_name = ((!PrimaxUnicode) ? userInfoOrg[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.KEY_CODE].ToString() : userInfoOrg[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_NAME].ToString());
		string folder_path_name2 = userInfoOrg[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PATH_NAME].ToString();
		if (!userInfoOrg[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PATH_NAME].ToString().Equals(newUserInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PATH_NAME].ToString()))
		{
			folder_path_name2 = newUserInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PATH_NAME].ToString();
		}
		folder_path_name2 = folder_path_name2.Trim();
		string text = userInfoOrg[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_AUTH_USER_NAME].ToString();
		if (!userInfoOrg[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_AUTH_USER_NAME].ToString().Equals(newUserInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_AUTH_USER_NAME].ToString()))
		{
			text = newUserInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_AUTH_USER_NAME].ToString();
		}
		text = text.Trim();
		string folder_password_change = newUserInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PASSWORD_CHANGE];
		string passwd = "%26%2365533%3B%26%2365533%3B%26%2365533%3B%26%2365533%3B%26%2365533%3B%26%2365533%3B%26%2365533%3B%26%2365533%3B";
		if ("1".Equals(folder_password_change))
		{
			passwd = newUserInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PASSWORD].ToString();
		}
		SettingItemsSetupAddress setting = new SettingItemsSetupAddress
		{
			host = ipAddress,
			adminName = PrimaxAdminPasswd,
			passwd = passwd,
			firstFlg = false,
			httpsFlg = (comResult != COMMUNICATION_ERROR_CODE.HTTP_ONLY)
		};
		setting.registrationNo = int.Parse(entry_index);
		setting.addressName = entry_name;
		setting.authUserName = text;
		setting.folderPath = folder_path_name2;
		MachineControl.PRIMAX_MACHINE_CONTROL_RESULT pRIMAX_MACHINE_CONTROL_RESULT;
		while (true)
		{
			pRIMAX_MACHINE_CONTROL_RESULT = await mc.executeSetupAddressToPrimax(setting, old_entry_name, folder_password_change);
			if (MachineControl.PRIMAX_MACHINE_CONTROL_RESULT.PW_RESETTING != pRIMAX_MACHINE_CONTROL_RESULT)
			{
				break;
			}
			FormAdminAuthConfirm formAdminAuthConfirm = new FormAdminAuthConfirm();
			formAdminAuthConfirm.InitializeToPrimax();
			formAdminAuthConfirm.setMsg(firstFlg: true);
			((Form)formAdminAuthConfirm).StartPosition = (FormStartPosition)4;
			((Form)formAdminAuthConfirm).ShowDialog();
			if ((int)((Form)formAdminAuthConfirm).DialogResult != 1)
			{
				return null;
			}
			setting.adminName = formAdminAuthConfirm.getAuthPass();
			PrimaxAdminPasswd = formAdminAuthConfirm.getAuthPass();
		}
		if (MachineControl.PRIMAX_MACHINE_CONTROL_RESULT.ADD_DUPLICATE == pRIMAX_MACHINE_CONTROL_RESULT)
		{
			LOG.InfoFormat("[primax]アドレス重複:{0}", (object)entry_name);
			MessageBox.Show(Resources.DUPLICATE_REGISTRATION_NAME, Resources.SET_REGISTRATION_NAME_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
			return null;
		}
		if (MachineControl.PRIMAX_MACHINE_CONTROL_RESULT.ADD_OVER == pRIMAX_MACHINE_CONTROL_RESULT)
		{
			LOG.InfoFormat("[primax]登録数超過:{0}", (object)entry_name);
			MessageBox.Show(Resources.OVER_REGISTRATION_NAME, Resources.SET_REGISTRATION_NAME_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
			return null;
		}
		if (pRIMAX_MACHINE_CONTROL_RESULT == MachineControl.PRIMAX_MACHINE_CONTROL_RESULT.SUCCESS)
		{
			PrimaxAdminPasswd = setting.adminName;
			Dictionary<MachineControl.ADDRESSBOOK_ITEM, string> dictionary = new Dictionary<MachineControl.ADDRESSBOOK_ITEM, string>();
			dictionary.Add(MachineControl.ADDRESSBOOK_ITEM.REGISTRATION_NUMBER, entry_index);
			dictionary.Add(MachineControl.ADDRESSBOOK_ITEM.NAME, entry_name);
			dictionary.Add(MachineControl.ADDRESSBOOK_ITEM.INDEX, old_entry_name);
			dictionary.Add(MachineControl.ADDRESSBOOK_ITEM.DATE_LAST_USED, old_entry_index);
			dictionary.Add(MachineControl.ADDRESSBOOK_ITEM.FOLDER, folder_path_name2);
			retAddressBookInfo.Add("0", dictionary);
			LOG.Debug((object)"updateMfpAddressbookToPrimax：end");
			return retAddressBookInfo;
		}
		LOG.InfoFormat("[primax]宛先の登録に失敗しました。:{0}", (object)entry_name);
		MessageBox.Show(Resources.EXE_RESULT_MSG_ERROR_REGIST_ADDRESS, Resources.ERR_TITLE_REGIST_ADDR, (MessageBoxButtons)0, (MessageBoxIcon)16);
		return null;
	}

	protected override void Dispose(bool disposing)
	{
		if (disposing && components != null)
		{
			components.Dispose();
		}
		((Form)this).Dispose(disposing);
	}

	private void InitializeComponent()
	{
		//IL_0011: Unknown result type (might be due to invalid IL or missing references)
		//IL_001b: Expected O, but got Unknown
		//IL_001c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0026: Expected O, but got Unknown
		//IL_0027: Unknown result type (might be due to invalid IL or missing references)
		//IL_0031: Expected O, but got Unknown
		//IL_0032: Unknown result type (might be due to invalid IL or missing references)
		//IL_003c: Expected O, but got Unknown
		//IL_003d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0047: Expected O, but got Unknown
		//IL_0048: Unknown result type (might be due to invalid IL or missing references)
		//IL_0052: Expected O, but got Unknown
		//IL_0053: Unknown result type (might be due to invalid IL or missing references)
		//IL_005d: Expected O, but got Unknown
		//IL_005e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0068: Expected O, but got Unknown
		//IL_0069: Unknown result type (might be due to invalid IL or missing references)
		//IL_0073: Expected O, but got Unknown
		//IL_0074: Unknown result type (might be due to invalid IL or missing references)
		//IL_007e: Expected O, but got Unknown
		//IL_007f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0089: Expected O, but got Unknown
		//IL_008a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0094: Expected O, but got Unknown
		//IL_0095: Unknown result type (might be due to invalid IL or missing references)
		//IL_009f: Expected O, but got Unknown
		//IL_00a0: Unknown result type (might be due to invalid IL or missing references)
		//IL_00aa: Expected O, but got Unknown
		//IL_00ab: Unknown result type (might be due to invalid IL or missing references)
		//IL_00b5: Expected O, but got Unknown
		//IL_00b6: Unknown result type (might be due to invalid IL or missing references)
		//IL_00c0: Expected O, but got Unknown
		//IL_00c1: Unknown result type (might be due to invalid IL or missing references)
		//IL_00cb: Expected O, but got Unknown
		//IL_00cc: Unknown result type (might be due to invalid IL or missing references)
		//IL_00d6: Expected O, but got Unknown
		//IL_00d7: Unknown result type (might be due to invalid IL or missing references)
		//IL_00e1: Expected O, but got Unknown
		//IL_00e2: Unknown result type (might be due to invalid IL or missing references)
		//IL_00ec: Expected O, but got Unknown
		//IL_04fb: Unknown result type (might be due to invalid IL or missing references)
		//IL_0505: Expected O, but got Unknown
		//IL_0512: Unknown result type (might be due to invalid IL or missing references)
		//IL_051c: Expected O, but got Unknown
		//IL_0529: Unknown result type (might be due to invalid IL or missing references)
		//IL_0533: Expected O, but got Unknown
		//IL_0588: Unknown result type (might be due to invalid IL or missing references)
		//IL_0592: Expected O, but got Unknown
		//IL_0ccc: Unknown result type (might be due to invalid IL or missing references)
		//IL_0cd6: Expected O, but got Unknown
		ComponentResourceManager componentResourceManager = new ComponentResourceManager(typeof(FormAddressBookEdit));
		buttonEdit = new Button();
		buttonClose = new Button();
		label1 = new Label();
		labelMFP_Info = new Label();
		buttonMachineSelect = new Button();
		labelMFP_Select = new Label();
		labelMFP_Selected = new Label();
		listViewAddressList = new ListView();
		textBoxSearch = new TextBox();
		buttonSearch = new Button();
		comboBoxSelectWay = new ComboBox();
		labelPage = new Label();
		displayedPage = new Label();
		buttonToTop = new Button();
		buttonPrevious = new Button();
		buttonNext = new Button();
		buttonToBottom = new Button();
		progressText = new Label();
		buttonBreak = new Button();
		buttonResume = new Button();
		((Control)this).SuspendLayout();
		((Control)buttonEdit).Anchor = (AnchorStyles)9;
		((Control)buttonEdit).AutoSize = true;
		((Control)buttonEdit).Enabled = false;
		((Control)buttonEdit).Location = new Point(402, 408);
		((Control)buttonEdit).Name = "buttonEdit";
		((Control)buttonEdit).Size = new Size(98, 23);
		((Control)buttonEdit).TabIndex = 2;
		((Control)buttonEdit).Text = "button5";
		((ButtonBase)buttonEdit).UseVisualStyleBackColor = true;
		((Control)buttonEdit).Click += buttonEdit_Click;
		((Control)buttonClose).AutoSize = true;
		((Control)buttonClose).Location = new Point(12, 408);
		((Control)buttonClose).Name = "buttonClose";
		((Control)buttonClose).Size = new Size(98, 23);
		((Control)buttonClose).TabIndex = 1;
		((Control)buttonClose).Text = "button4";
		((ButtonBase)buttonClose).UseVisualStyleBackColor = true;
		((Control)buttonClose).Click += buttonClose_Click;
		((Control)label1).Anchor = (AnchorStyles)13;
		label1.BorderStyle = (BorderStyle)2;
		((Control)label1).Location = new Point(10, 400);
		((Control)label1).Name = "label1";
		((Control)label1).Size = new Size(490, 1);
		((Control)label1).TabIndex = 8;
		((Control)labelMFP_Info).AutoSize = true;
		((Control)labelMFP_Info).Location = new Point(13, 11);
		((Control)labelMFP_Info).Name = "labelMFP_Info";
		((Control)labelMFP_Info).Size = new Size(35, 12);
		((Control)labelMFP_Info).TabIndex = 4;
		((Control)labelMFP_Info).Text = "label2";
		((Control)buttonMachineSelect).Location = new Point(12, 36);
		((Control)buttonMachineSelect).Name = "buttonMachineSelect";
		((Control)buttonMachineSelect).Size = new Size(487, 23);
		((Control)buttonMachineSelect).TabIndex = 0;
		((Control)buttonMachineSelect).Text = "button1";
		((ButtonBase)buttonMachineSelect).UseVisualStyleBackColor = true;
		((Control)buttonMachineSelect).Click += buttonMachineSelect_Click;
		((Control)labelMFP_Select).AutoSize = true;
		((Control)labelMFP_Select).Location = new Point(13, 76);
		((Control)labelMFP_Select).Name = "labelMFP_Select";
		((Control)labelMFP_Select).Size = new Size(35, 12);
		((Control)labelMFP_Select).TabIndex = 5;
		((Control)labelMFP_Select).Text = "label3";
		((Control)labelMFP_Selected).AutoSize = true;
		((Control)labelMFP_Selected).Location = new Point(112, 76);
		((Control)labelMFP_Selected).Name = "labelMFP_Selected";
		((Control)labelMFP_Selected).Size = new Size(0, 12);
		((Control)labelMFP_Selected).TabIndex = 6;
		((Control)labelMFP_Selected).TextChanged += labelMFP_Selected_TextChanged;
		listViewAddressList.Activation = (ItemActivation)1;
		listViewAddressList.AutoArrange = false;
		listViewAddressList.FullRowSelect = true;
		listViewAddressList.GridLines = true;
		listViewAddressList.HeaderStyle = (ColumnHeaderStyle)1;
		listViewAddressList.HideSelection = false;
		((Control)listViewAddressList).Location = new Point(12, 171);
		listViewAddressList.MultiSelect = false;
		((Control)listViewAddressList).Name = "listViewAddressList";
		listViewAddressList.OwnerDraw = true;
		listViewAddressList.ShowGroups = false;
		((Control)listViewAddressList).Size = new Size(487, 210);
		((Control)listViewAddressList).TabIndex = 10;
		listViewAddressList.UseCompatibleStateImageBehavior = false;
		listViewAddressList.View = (View)1;
		listViewAddressList.DrawColumnHeader += new DrawListViewColumnHeaderEventHandler(listViewAddressList_DrawColumnHeader);
		listViewAddressList.DrawItem += new DrawListViewItemEventHandler(listViewAddressList_DrawItem);
		listViewAddressList.ItemSelectionChanged += new ListViewItemSelectionChangedEventHandler(listViewAddressList_ItemSelectionChanged);
		((Control)textBoxSearch).Location = new Point(127, 107);
		((Control)textBoxSearch).Name = "textBoxSearch";
		((Control)textBoxSearch).Size = new Size(269, 19);
		((Control)textBoxSearch).TabIndex = 12;
		((Control)textBoxSearch).KeyPress += new KeyPressEventHandler(textBoxSearch_KeyPress);
		((Control)buttonSearch).Anchor = (AnchorStyles)9;
		((Control)buttonSearch).AutoSize = true;
		((Control)buttonSearch).Enabled = false;
		((Control)buttonSearch).Location = new Point(401, 105);
		((Control)buttonSearch).Name = "buttonSearch";
		((Control)buttonSearch).Size = new Size(98, 23);
		((Control)buttonSearch).TabIndex = 13;
		((Control)buttonSearch).Text = "button2";
		((ButtonBase)buttonSearch).UseVisualStyleBackColor = true;
		((Control)buttonSearch).Click += buttonSearch_Click;
		((ListControl)comboBoxSelectWay).FormattingEnabled = true;
		((Control)comboBoxSelectWay).Location = new Point(12, 106);
		((Control)comboBoxSelectWay).Name = "comboBoxSelectWay";
		((Control)comboBoxSelectWay).Size = new Size(110, 20);
		((Control)comboBoxSelectWay).TabIndex = 14;
		((Control)labelPage).AutoSize = true;
		((Control)labelPage).Location = new Point(13, 144);
		((Control)labelPage).Name = "labelPage";
		((Control)labelPage).Size = new Size(35, 12);
		((Control)labelPage).TabIndex = 15;
		((Control)labelPage).Text = "label5";
		((Control)displayedPage).AutoSize = true;
		((Control)displayedPage).Location = new Point(122, 144);
		((Control)displayedPage).Name = "displayedPage";
		((Control)displayedPage).Size = new Size(35, 12);
		((Control)displayedPage).TabIndex = 16;
		((Control)displayedPage).Text = "label6";
		((Control)buttonToTop).AutoSize = true;
		((Control)buttonToTop).Location = new Point(50, 139);
		((Control)buttonToTop).Name = "buttonToTop";
		((Control)buttonToTop).Size = new Size(30, 23);
		((Control)buttonToTop).TabIndex = 17;
		((Control)buttonToTop).Text = "<<";
		((ButtonBase)buttonToTop).UseVisualStyleBackColor = true;
		((Control)buttonToTop).Visible = false;
		((Control)buttonToTop).Click += buttonToTheTop_Click;
		((Control)buttonPrevious).AutoSize = true;
		((Control)buttonPrevious).Location = new Point(86, 139);
		((Control)buttonPrevious).Name = "buttonPrevious";
		((Control)buttonPrevious).Size = new Size(30, 23);
		((Control)buttonPrevious).TabIndex = 18;
		((Control)buttonPrevious).Text = "<";
		((ButtonBase)buttonPrevious).UseVisualStyleBackColor = true;
		((Control)buttonPrevious).Visible = false;
		((Control)buttonPrevious).Click += buttonPrevious_Click;
		((Control)buttonNext).AutoSize = true;
		((Control)buttonNext).Location = new Point(157, 139);
		((Control)buttonNext).Name = "buttonNext";
		((Control)buttonNext).Size = new Size(30, 23);
		((Control)buttonNext).TabIndex = 19;
		((Control)buttonNext).Text = ">";
		((ButtonBase)buttonNext).UseVisualStyleBackColor = true;
		((Control)buttonNext).Visible = false;
		((Control)buttonNext).Click += buttonNext_Click;
		((Control)buttonToBottom).AutoSize = true;
		((Control)buttonToBottom).Location = new Point(193, 139);
		((Control)buttonToBottom).Name = "buttonToBottom";
		((Control)buttonToBottom).Size = new Size(30, 23);
		((Control)buttonToBottom).TabIndex = 20;
		((Control)buttonToBottom).Text = ">>";
		((ButtonBase)buttonToBottom).UseVisualStyleBackColor = true;
		((Control)buttonToBottom).Visible = false;
		((Control)buttonToBottom).Click += buttonToTheButtom_Click;
		((Control)progressText).Location = new Point(250, 144);
		((Control)progressText).Name = "progressText";
		((Control)progressText).Size = new Size(249, 17);
		((Control)progressText).TabIndex = 22;
		((Control)progressText).Text = "label7";
		progressText.TextAlign = (ContentAlignment)64;
		((Control)buttonBreak).AutoSize = true;
		((Control)buttonBreak).Location = new Point(434, 139);
		((Control)buttonBreak).Name = "buttonBreak";
		((Control)buttonBreak).Size = new Size(65, 23);
		((Control)buttonBreak).TabIndex = 24;
		((Control)buttonBreak).Text = "btn4";
		((ButtonBase)buttonBreak).UseVisualStyleBackColor = true;
		((Control)buttonBreak).Visible = false;
		((Control)buttonBreak).Click += buttonBreak_Click;
		((Control)buttonResume).AutoSize = true;
		((Control)buttonResume).Location = new Point(363, 139);
		((Control)buttonResume).Name = "buttonResume";
		((Control)buttonResume).Size = new Size(65, 23);
		((Control)buttonResume).TabIndex = 23;
		((Control)buttonResume).Text = "btn3";
		((ButtonBase)buttonResume).UseVisualStyleBackColor = true;
		((Control)buttonResume).Visible = false;
		((Control)buttonResume).Click += buttonResume_Click;
		((ContainerControl)this).AutoScaleDimensions = new SizeF(6f, 12f);
		((ContainerControl)this).AutoScaleMode = (AutoScaleMode)1;
		((Form)this).ClientSize = new Size(512, 441);
		((Control)this).Controls.Add((Control)(object)buttonResume);
		((Control)this).Controls.Add((Control)(object)buttonBreak);
		((Control)this).Controls.Add((Control)(object)progressText);
		((Control)this).Controls.Add((Control)(object)buttonToBottom);
		((Control)this).Controls.Add((Control)(object)buttonNext);
		((Control)this).Controls.Add((Control)(object)buttonPrevious);
		((Control)this).Controls.Add((Control)(object)buttonToTop);
		((Control)this).Controls.Add((Control)(object)displayedPage);
		((Control)this).Controls.Add((Control)(object)labelPage);
		((Control)this).Controls.Add((Control)(object)comboBoxSelectWay);
		((Control)this).Controls.Add((Control)(object)buttonSearch);
		((Control)this).Controls.Add((Control)(object)textBoxSearch);
		((Control)this).Controls.Add((Control)(object)listViewAddressList);
		((Control)this).Controls.Add((Control)(object)labelMFP_Selected);
		((Control)this).Controls.Add((Control)(object)labelMFP_Select);
		((Control)this).Controls.Add((Control)(object)buttonMachineSelect);
		((Control)this).Controls.Add((Control)(object)labelMFP_Info);
		((Control)this).Controls.Add((Control)(object)label1);
		((Control)this).Controls.Add((Control)(object)buttonClose);
		((Control)this).Controls.Add((Control)(object)buttonEdit);
		((Form)this).FormBorderStyle = (FormBorderStyle)3;
		((Form)this).Icon = (Icon)componentResourceManager.GetObject("$this.Icon");
		((Form)this).MaximizeBox = false;
		((Form)this).MinimizeBox = false;
		((Control)this).Name = "FormAddressBookEdit";
		((Form)this).StartPosition = (FormStartPosition)4;
		((Control)this).Text = "title";
		((Control)this).ResumeLayout(false);
		((Control)this).PerformLayout();
	}

	private void InitializeComponent_MultiLang()
	{
		//IL_0011: Unknown result type (might be due to invalid IL or missing references)
		//IL_001b: Expected O, but got Unknown
		//IL_001c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0026: Expected O, but got Unknown
		//IL_0027: Unknown result type (might be due to invalid IL or missing references)
		//IL_0031: Expected O, but got Unknown
		//IL_0032: Unknown result type (might be due to invalid IL or missing references)
		//IL_003c: Expected O, but got Unknown
		//IL_003d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0047: Expected O, but got Unknown
		//IL_0048: Unknown result type (might be due to invalid IL or missing references)
		//IL_0052: Expected O, but got Unknown
		//IL_0053: Unknown result type (might be due to invalid IL or missing references)
		//IL_005d: Expected O, but got Unknown
		//IL_005e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0068: Expected O, but got Unknown
		//IL_0069: Unknown result type (might be due to invalid IL or missing references)
		//IL_0073: Expected O, but got Unknown
		//IL_0074: Unknown result type (might be due to invalid IL or missing references)
		//IL_007e: Expected O, but got Unknown
		//IL_007f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0089: Expected O, but got Unknown
		//IL_008a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0094: Expected O, but got Unknown
		//IL_0095: Unknown result type (might be due to invalid IL or missing references)
		//IL_009f: Expected O, but got Unknown
		//IL_00a0: Unknown result type (might be due to invalid IL or missing references)
		//IL_00aa: Expected O, but got Unknown
		//IL_00ab: Unknown result type (might be due to invalid IL or missing references)
		//IL_00b5: Expected O, but got Unknown
		//IL_00b6: Unknown result type (might be due to invalid IL or missing references)
		//IL_00c0: Expected O, but got Unknown
		//IL_00c1: Unknown result type (might be due to invalid IL or missing references)
		//IL_00cb: Expected O, but got Unknown
		//IL_00cc: Unknown result type (might be due to invalid IL or missing references)
		//IL_00d6: Expected O, but got Unknown
		//IL_00d7: Unknown result type (might be due to invalid IL or missing references)
		//IL_00e1: Expected O, but got Unknown
		//IL_00e2: Unknown result type (might be due to invalid IL or missing references)
		//IL_00ec: Expected O, but got Unknown
		//IL_04fe: Unknown result type (might be due to invalid IL or missing references)
		//IL_0508: Expected O, but got Unknown
		//IL_0515: Unknown result type (might be due to invalid IL or missing references)
		//IL_051f: Expected O, but got Unknown
		//IL_052c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0536: Expected O, but got Unknown
		//IL_058b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0595: Expected O, but got Unknown
		//IL_0ccf: Unknown result type (might be due to invalid IL or missing references)
		//IL_0cd9: Expected O, but got Unknown
		ComponentResourceManager componentResourceManager = new ComponentResourceManager(typeof(FormAddressBookEdit));
		buttonEdit = new Button();
		buttonClose = new Button();
		label1 = new Label();
		labelMFP_Info = new Label();
		buttonMachineSelect = new Button();
		labelMFP_Select = new Label();
		labelMFP_Selected = new Label();
		listViewAddressList = new ListView();
		textBoxSearch = new TextBox();
		buttonSearch = new Button();
		comboBoxSelectWay = new ComboBox();
		labelPage = new Label();
		displayedPage = new Label();
		buttonToTop = new Button();
		buttonPrevious = new Button();
		buttonNext = new Button();
		buttonToBottom = new Button();
		progressText = new Label();
		buttonBreak = new Button();
		buttonResume = new Button();
		((Control)this).SuspendLayout();
		((Control)buttonEdit).Anchor = (AnchorStyles)9;
		((Control)buttonEdit).AutoSize = true;
		((Control)buttonEdit).Enabled = false;
		((Control)buttonEdit).Location = new Point(402, 408);
		((Control)buttonEdit).Name = "buttonEdit";
		((Control)buttonEdit).Size = new Size(98, 23);
		((Control)buttonEdit).TabIndex = 2;
		((Control)buttonEdit).Text = "button5";
		((ButtonBase)buttonEdit).UseVisualStyleBackColor = true;
		((Control)buttonEdit).Click += buttonEdit_Click;
		((Control)buttonClose).AutoSize = true;
		((Control)buttonClose).Location = new Point(12, 408);
		((Control)buttonClose).Name = "buttonClose";
		((Control)buttonClose).Size = new Size(98, 23);
		((Control)buttonClose).TabIndex = 1;
		((Control)buttonClose).Text = "button4";
		((ButtonBase)buttonClose).UseVisualStyleBackColor = true;
		((Control)buttonClose).Click += buttonClose_Click;
		((Control)label1).Anchor = (AnchorStyles)13;
		label1.BorderStyle = (BorderStyle)2;
		((Control)label1).Location = new Point(10, 400);
		((Control)label1).Name = "label1";
		((Control)label1).Size = new Size(490, 1);
		((Control)label1).TabIndex = 8;
		((Control)labelMFP_Info).AutoSize = true;
		((Control)labelMFP_Info).Location = new Point(13, 11);
		((Control)labelMFP_Info).Name = "labelMFP_Info";
		((Control)labelMFP_Info).Size = new Size(35, 12);
		((Control)labelMFP_Info).TabIndex = 4;
		((Control)labelMFP_Info).Text = "label2";
		((Control)buttonMachineSelect).Location = new Point(12, 36);
		((Control)buttonMachineSelect).Name = "buttonMachineSelect";
		((Control)buttonMachineSelect).Size = new Size(487, 23);
		((Control)buttonMachineSelect).TabIndex = 0;
		((Control)buttonMachineSelect).Text = "button1";
		((ButtonBase)buttonMachineSelect).UseVisualStyleBackColor = true;
		((Control)buttonMachineSelect).Click += buttonMachineSelect_Click;
		((Control)labelMFP_Select).AutoSize = true;
		((Control)labelMFP_Select).Location = new Point(13, 76);
		((Control)labelMFP_Select).Name = "labelMFP_Select";
		((Control)labelMFP_Select).Size = new Size(85, 12);
		((Control)labelMFP_Select).TabIndex = 5;
		((Control)labelMFP_Select).Text = "label3";
		((Control)labelMFP_Selected).AutoSize = true;
		((Control)labelMFP_Selected).Location = new Point(162, 76);
		((Control)labelMFP_Selected).Name = "labelMFP_Selected";
		((Control)labelMFP_Selected).Size = new Size(0, 12);
		((Control)labelMFP_Selected).TabIndex = 6;
		((Control)labelMFP_Selected).TextChanged += labelMFP_Selected_TextChanged;
		listViewAddressList.Activation = (ItemActivation)1;
		listViewAddressList.AutoArrange = false;
		listViewAddressList.FullRowSelect = true;
		listViewAddressList.GridLines = true;
		listViewAddressList.HeaderStyle = (ColumnHeaderStyle)1;
		listViewAddressList.HideSelection = false;
		((Control)listViewAddressList).Location = new Point(12, 171);
		listViewAddressList.MultiSelect = false;
		((Control)listViewAddressList).Name = "listViewAddressList";
		listViewAddressList.OwnerDraw = true;
		listViewAddressList.ShowGroups = false;
		((Control)listViewAddressList).Size = new Size(487, 210);
		((Control)listViewAddressList).TabIndex = 10;
		listViewAddressList.UseCompatibleStateImageBehavior = false;
		listViewAddressList.View = (View)1;
		listViewAddressList.DrawColumnHeader += new DrawListViewColumnHeaderEventHandler(listViewAddressList_DrawColumnHeader);
		listViewAddressList.DrawItem += new DrawListViewItemEventHandler(listViewAddressList_DrawItem);
		listViewAddressList.ItemSelectionChanged += new ListViewItemSelectionChangedEventHandler(listViewAddressList_ItemSelectionChanged);
		((Control)textBoxSearch).Location = new Point(127, 107);
		((Control)textBoxSearch).Name = "textBoxSearch";
		((Control)textBoxSearch).Size = new Size(269, 19);
		((Control)textBoxSearch).TabIndex = 12;
		((Control)textBoxSearch).KeyPress += new KeyPressEventHandler(textBoxSearch_KeyPress);
		((Control)buttonSearch).Anchor = (AnchorStyles)9;
		((Control)buttonSearch).AutoSize = true;
		((Control)buttonSearch).Enabled = false;
		((Control)buttonSearch).Location = new Point(401, 105);
		((Control)buttonSearch).Name = "buttonSearch";
		((Control)buttonSearch).Size = new Size(98, 23);
		((Control)buttonSearch).TabIndex = 13;
		((Control)buttonSearch).Text = "button2";
		((ButtonBase)buttonSearch).UseVisualStyleBackColor = true;
		((Control)buttonSearch).Click += buttonSearch_Click;
		((ListControl)comboBoxSelectWay).FormattingEnabled = true;
		((Control)comboBoxSelectWay).Location = new Point(12, 106);
		((Control)comboBoxSelectWay).Name = "comboBoxSelectWay";
		((Control)comboBoxSelectWay).Size = new Size(110, 20);
		((Control)comboBoxSelectWay).TabIndex = 14;
		((Control)labelPage).AutoSize = true;
		((Control)labelPage).Location = new Point(13, 144);
		((Control)labelPage).Name = "labelPage";
		((Control)labelPage).Size = new Size(35, 12);
		((Control)labelPage).TabIndex = 15;
		((Control)labelPage).Text = "label5";
		((Control)displayedPage).AutoSize = true;
		((Control)displayedPage).Location = new Point(122, 144);
		((Control)displayedPage).Name = "displayedPage";
		((Control)displayedPage).Size = new Size(35, 12);
		((Control)displayedPage).TabIndex = 16;
		((Control)displayedPage).Text = "label6";
		((Control)buttonToTop).AutoSize = true;
		((Control)buttonToTop).Location = new Point(50, 139);
		((Control)buttonToTop).Name = "buttonToTop";
		((Control)buttonToTop).Size = new Size(30, 23);
		((Control)buttonToTop).TabIndex = 17;
		((Control)buttonToTop).Text = "<<";
		((ButtonBase)buttonToTop).UseVisualStyleBackColor = true;
		((Control)buttonToTop).Visible = false;
		((Control)buttonToTop).Click += buttonToTheTop_Click;
		((Control)buttonPrevious).AutoSize = true;
		((Control)buttonPrevious).Location = new Point(86, 139);
		((Control)buttonPrevious).Name = "buttonPrevious";
		((Control)buttonPrevious).Size = new Size(30, 23);
		((Control)buttonPrevious).TabIndex = 18;
		((Control)buttonPrevious).Text = "<";
		((ButtonBase)buttonPrevious).UseVisualStyleBackColor = true;
		((Control)buttonPrevious).Visible = false;
		((Control)buttonPrevious).Click += buttonPrevious_Click;
		((Control)buttonNext).AutoSize = true;
		((Control)buttonNext).Location = new Point(157, 139);
		((Control)buttonNext).Name = "buttonNext";
		((Control)buttonNext).Size = new Size(30, 23);
		((Control)buttonNext).TabIndex = 19;
		((Control)buttonNext).Text = ">";
		((ButtonBase)buttonNext).UseVisualStyleBackColor = true;
		((Control)buttonNext).Visible = false;
		((Control)buttonNext).Click += buttonNext_Click;
		((Control)buttonToBottom).AutoSize = true;
		((Control)buttonToBottom).Location = new Point(193, 139);
		((Control)buttonToBottom).Name = "buttonToBottom";
		((Control)buttonToBottom).Size = new Size(30, 23);
		((Control)buttonToBottom).TabIndex = 20;
		((Control)buttonToBottom).Text = ">>";
		((ButtonBase)buttonToBottom).UseVisualStyleBackColor = true;
		((Control)buttonToBottom).Visible = false;
		((Control)buttonToBottom).Click += buttonToTheButtom_Click;
		((Control)progressText).Location = new Point(250, 144);
		((Control)progressText).Name = "progressText";
		((Control)progressText).Size = new Size(249, 17);
		((Control)progressText).TabIndex = 22;
		((Control)progressText).Text = "label7";
		progressText.TextAlign = (ContentAlignment)64;
		((Control)buttonBreak).AutoSize = true;
		((Control)buttonBreak).Location = new Point(434, 139);
		((Control)buttonBreak).Name = "buttonBreak";
		((Control)buttonBreak).Size = new Size(65, 23);
		((Control)buttonBreak).TabIndex = 24;
		((Control)buttonBreak).Text = "btn4";
		((ButtonBase)buttonBreak).UseVisualStyleBackColor = true;
		((Control)buttonBreak).Visible = false;
		((Control)buttonBreak).Click += buttonBreak_Click;
		((Control)buttonResume).AutoSize = true;
		((Control)buttonResume).Location = new Point(363, 139);
		((Control)buttonResume).Name = "buttonResume";
		((Control)buttonResume).Size = new Size(65, 23);
		((Control)buttonResume).TabIndex = 23;
		((Control)buttonResume).Text = "btn3";
		((ButtonBase)buttonResume).UseVisualStyleBackColor = true;
		((Control)buttonResume).Visible = false;
		((Control)buttonResume).Click += buttonResume_Click;
		((ContainerControl)this).AutoScaleDimensions = new SizeF(6f, 12f);
		((ContainerControl)this).AutoScaleMode = (AutoScaleMode)1;
		((Form)this).ClientSize = new Size(512, 441);
		((Control)this).Controls.Add((Control)(object)buttonResume);
		((Control)this).Controls.Add((Control)(object)buttonBreak);
		((Control)this).Controls.Add((Control)(object)progressText);
		((Control)this).Controls.Add((Control)(object)buttonToBottom);
		((Control)this).Controls.Add((Control)(object)buttonNext);
		((Control)this).Controls.Add((Control)(object)buttonPrevious);
		((Control)this).Controls.Add((Control)(object)buttonToTop);
		((Control)this).Controls.Add((Control)(object)displayedPage);
		((Control)this).Controls.Add((Control)(object)labelPage);
		((Control)this).Controls.Add((Control)(object)comboBoxSelectWay);
		((Control)this).Controls.Add((Control)(object)buttonSearch);
		((Control)this).Controls.Add((Control)(object)textBoxSearch);
		((Control)this).Controls.Add((Control)(object)listViewAddressList);
		((Control)this).Controls.Add((Control)(object)labelMFP_Selected);
		((Control)this).Controls.Add((Control)(object)labelMFP_Select);
		((Control)this).Controls.Add((Control)(object)buttonMachineSelect);
		((Control)this).Controls.Add((Control)(object)labelMFP_Info);
		((Control)this).Controls.Add((Control)(object)label1);
		((Control)this).Controls.Add((Control)(object)buttonClose);
		((Control)this).Controls.Add((Control)(object)buttonEdit);
		((Form)this).FormBorderStyle = (FormBorderStyle)3;
		((Form)this).Icon = (Icon)componentResourceManager.GetObject("$this.Icon");
		((Form)this).MaximizeBox = false;
		((Form)this).MinimizeBox = false;
		((Control)this).Name = "FormAddressBookEdit";
		((Form)this).StartPosition = (FormStartPosition)4;
		((Control)this).Text = "title";
		((Control)this).ResumeLayout(false);
		((Control)this).PerformLayout();
	}
}
