using System;
using System.Collections.Generic;
using System.Collections.Specialized;
using System.ComponentModel;
using System.Drawing;
using System.Globalization;
using System.Linq;
using System.Net;
using System.Reflection;
using System.Text;
using System.Windows.Forms;
using CreateFolder.Properties;
using log4net;

namespace CreateFolder;

public class FormAddressBookSetting : Form
{
	private static readonly ILog LOG = LogManager.GetLogger(MethodBase.GetCurrentMethod().DeclaringType);

	private Dictionary<AddressBookListControl.ADDRESSBOOK_LIST_ITEM, string> userInfoOrg;

	private BitVector32 changeNeeds;

	private FolderSetting fs = new FolderSetting();

	private string ipaddressPC = string.Empty;

	private FormSettingHeadLine fSettingHeadline;

	private string indexName = string.Empty;

	private string displayName = string.Empty;

	private string pathNameOrg = string.Empty;

	private string folderNameOrg = string.Empty;

	public bool PrimaxIndexRelease;

	private static string machineLanguage = (Application.CurrentCulture.Equals(CultureInfo.GetCultureInfo("ja-JP")) ? "ja" : "en");

	private FormMain fMain = new FormMain(FormMain.Mode.DIALOG, machineLanguage);

	private IContainer components;

	private Button buttonOK;

	private Button buttonCancel;

	private Label label_name;

	private Label label_SendPath;

	private Label label_PCUser;

	private Label label_Password;

	private Label label_PasswordConfirm;

	private TextBox name;

	private Label label_PasswordChange;

	private TextBox password;

	private TextBox passwordConfirm;

	private RadioButton radioButtonPasswordOn;

	private RadioButton radioButtonPasswordOff;

	private Panel panel1;

	private ComboBox comboBoxSendPath;

	private ComboBox comboBoxPCUser;

	private Label label_Folder;

	private ComboBox comboBoxFolder;

	private Button btnHeadLine;

	private Label label3;

	private Label label1;

	private Label label_CurrentFolder;

	private Label label_CurrentSendPath;

	private Label label_CurrentPCUser;

	public bool isPrimax { get; set; }

	public bool isUnicodePrimax { get; set; }

	public List<OneTouchKeyInfo> PrimaxOneTouchKeyList { get; set; }

	public string machineLang { get; set; }

	public FormAddressBookSetting(string lang)
	{
		if (lang.Equals("ja") || lang.Equals("en"))
		{
			InitializeComponent();
		}
		else
		{
			InitializeComponent_MultiLang();
		}
		machineLang = lang;
		((Control)this).Text = Resources.ADDRESSBOOK_TITLE;
		((Control)btnHeadLine).Text = Resources.SETTING_HEADLINE;
		((Control)buttonOK).Text = Resources.ITEM_BUTTON_SET;
		((Control)buttonCancel).Text = Resources.ITEM_BUTTON_CANCEL;
		((Control)radioButtonPasswordOn).Text = Resources.ADDRESSBOOK_ON_NAME;
		((Control)radioButtonPasswordOff).Text = Resources.ADDRESSBOOK_OFF_NAME;
		((Control)label_name).Text = Resources.CREATE_HTML_DEFAULT_DEST;
		((Control)label_Folder).Text = Resources.FORM_MAIN_FOLDER_NAME;
		((Control)label_SendPath).Text = Resources.FORM_MAIN_PATH_NAME;
		((Control)label_PCUser).Text = Resources.ADDRESSBOOK_LOGIN_USER_NAME;
		((Control)label_PasswordChange).Text = Resources.ADDRESSBOOK_CHANGE_LOGIN_PASSWORD_NAME;
		((Control)label_Password).Text = Resources.ADDRESSBOOK_LOGIN_PASSWORD_NAME;
		((Control)label_PasswordConfirm).Text = Resources.ADDRESSBOOK_CONFIRM_LOGIN_PASSWORD_NAME;
		fSettingHeadline = new FormSettingHeadLine(lang);
		fSettingHeadline.Initialize();
	}

	public void setParameters(string ipaddress, Dictionary<AddressBookListControl.ADDRESSBOOK_LIST_ITEM, string> userInfo)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		ipaddressPC = ipaddress;
		int result = 0;
		userInfoOrg = userInfo;
		if (userInfo.ContainsKey(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX))
		{
			int.TryParse(userInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX], out result);
			if (result != 0)
			{
				fSettingHeadline.RegistrationNo = result;
			}
		}
		if (userInfo.ContainsKey(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_NAME))
		{
			((Control)name).Text = userInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_NAME];
		}
		if (userInfo.ContainsKey(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX_NAME))
		{
			indexName = userInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX_NAME];
		}
		if (userInfo.ContainsKey(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_DISPLAY_NAME))
		{
			displayName = userInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_DISPLAY_NAME];
		}
		if (userInfo.ContainsKey(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_1))
		{
			int.TryParse(userInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_1], out result);
			fSettingHeadline.Index1Headline = result - 1;
		}
		if (userInfo.ContainsKey(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_2))
		{
			int.TryParse(userInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_2], out result);
			fSettingHeadline.Index2Headline = result - 1;
		}
		if (userInfo.ContainsKey(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_3))
		{
			int.TryParse(userInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_3], out result);
			fSettingHeadline.Index3Headline = result - 1;
		}
		if (userInfo.ContainsKey(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_FREQ))
		{
			int.TryParse(userInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_FREQ], out result);
			fSettingHeadline.IndexRegularHeading = result;
		}
		if (userInfo.ContainsKey(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PATH_NAME))
		{
			pathNameOrg = userInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PATH_NAME];
			string[] array = pathNameOrg.Split(new char[1] { '\\' });
			if (array.Length > 1)
			{
				folderNameOrg = array[^1];
			}
			bool flag = setPathName();
			changeNeeds[10] = !flag;
			((Control)label_CurrentSendPath).Text = Resources.ADDRESSBOOK_CURRENT_VALUE + pathNameOrg;
		}
		if (userInfo.ContainsKey(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_AUTH_USER_NAME))
		{
			setLoginUserName(userInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_AUTH_USER_NAME]);
			((Control)label_CurrentPCUser).Text = Resources.ADDRESSBOOK_CURRENT_VALUE + userInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_AUTH_USER_NAME];
		}
		((Control)buttonOK).Enabled = changeNeeds.Data > 0;
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	private bool setPathName()
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		fs.setSharedFolderListTable();
		bool result = fs.setComboBoxFolderList(comboBoxFolder, folderNameOrg);
		if (!comboBoxFolder.Items.Contains((object)folderNameOrg))
		{
			int selectedIndex = comboBoxFolder.Items.Add((object)folderNameOrg);
			((ListControl)comboBoxFolder).SelectedIndex = selectedIndex;
			result = true;
		}
		((Control)label_CurrentFolder).Text = Resources.ADDRESSBOOK_CURRENT_VALUE + folderNameOrg;
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return result;
	}

	private void setLoginUserName(string authUserName)
	{
		string text = WmiManager.GetUserName();
		if (string.IsNullOrEmpty(text))
		{
			text = Environment.UserDomainName + "\\" + Environment.UserName;
		}
		bool flag = false;
		string text2 = string.Empty;
		foreach (UserInfo item in UserInfo.GetList("WinNT://" + Environment.MachineName))
		{
			string text3 = item.ParentName + item.Name;
			comboBoxPCUser.Items.Add((object)text3);
			flag |= text.Equals(text3, StringComparison.CurrentCultureIgnoreCase);
			if (authUserName.Equals(text3, StringComparison.CurrentCultureIgnoreCase))
			{
				text2 = text3;
			}
		}
		if (!flag)
		{
			comboBoxPCUser.Items.Add((object)text);
		}
		if (string.IsNullOrEmpty(text2))
		{
			text2 = authUserName;
			comboBoxPCUser.Items.Add((object)authUserName);
		}
		comboBoxPCUser.SelectedItem = text2;
	}

	public Dictionary<AddressBookListControl.ADDRESSBOOK_LIST_ITEM, string> getParameters(bool include_password = true)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		Dictionary<AddressBookListControl.ADDRESSBOOK_LIST_ITEM, string> dictionary = new Dictionary<AddressBookListControl.ADDRESSBOOK_LIST_ITEM, string>();
		int registrationNo = fSettingHeadline.RegistrationNo;
		if (registrationNo == 0)
		{
			dictionary.Add(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX, userInfoOrg[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX]);
		}
		else
		{
			dictionary.Add(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX, $"{decimal.ToInt32(registrationNo):D5}");
		}
		dictionary.Add(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_NAME, ((Control)name).Text);
		dictionary.Add(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX_NAME, indexName);
		dictionary.Add(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_DISPLAY_NAME, displayName);
		dictionary.Add(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_1, (fSettingHeadline.Index1Headline + 1).ToString());
		dictionary.Add(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_2, (fSettingHeadline.Index2Headline + 1).ToString());
		dictionary.Add(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_3, (fSettingHeadline.Index3Headline + 1).ToString());
		dictionary.Add(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_FREQ, fSettingHeadline.IndexRegularHeading.ToString());
		dictionary.Add(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PATH_NAME, ((Control)comboBoxSendPath).Text);
		dictionary.Add(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_AUTH_USER_NAME, ((Control)comboBoxPCUser).Text);
		if (include_password)
		{
			dictionary.Add(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PASSWORD_CHANGE, radioButtonPasswordOn.Checked ? 1.ToString() : 2.ToString());
			dictionary.Add(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PASSWORD, ((Control)password).Text);
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return dictionary;
	}

	private void radioButtonPasswordON_CheckedChanged(object sender, EventArgs e)
	{
		bool @checked = radioButtonPasswordOn.Checked;
		((Control)password).Enabled = @checked;
		((Control)passwordConfirm).Enabled = @checked;
		if (@checked)
		{
			textBox_LeaveCommon(password, Resources.TXT_P3_INITIAL_001, passwordUse: true);
			textBox_LeaveCommon(passwordConfirm, Resources.TXT_P3_INITIAL_002, passwordUse: true);
		}
		else
		{
			((Control)password).Text = string.Empty;
			((Control)passwordConfirm).Text = string.Empty;
		}
		int bit = 8192;
		changeNeeds[bit] = @checked;
		((Control)buttonOK).Enabled = changeNeeds.Data > 0;
	}

	private void buttonOK_Click(object sender, EventArgs e)
	{
		//IL_0056: Unknown result type (might be due to invalid IL or missing references)
		//IL_00a4: Unknown result type (might be due to invalid IL or missing references)
		//IL_0179: Unknown result type (might be due to invalid IL or missing references)
		//IL_0283: Unknown result type (might be due to invalid IL or missing references)
		//IL_01df: Unknown result type (might be due to invalid IL or missing references)
		//IL_02d3: Unknown result type (might be due to invalid IL or missing references)
		//IL_0232: Unknown result type (might be due to invalid IL or missing references)
		//IL_0324: Unknown result type (might be due to invalid IL or missing references)
		//IL_0375: Unknown result type (might be due to invalid IL or missing references)
		//IL_03d5: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		if (string.IsNullOrEmpty(((Control)name).Text.Replace(" ", "").Replace("\u3000", "")))
		{
			MessageBox.Show(Resources.TEXT_P4_ADDRESS_NAME_EMPTY_ERROR_TEXT, Resources.ERR_TITLE_FOLDER_NAME, (MessageBoxButtons)0, (MessageBoxIcon)16);
			LOG.InfoFormat("{0}", (object)Resources.TEXT_P4_ADDRESS_NAME_EMPTY_ERROR_TEXT);
			return;
		}
		if (Encoding.GetEncoding("Shift_JIS").GetByteCount(((Control)name).Text) > Settings.Default.userNameLength)
		{
			MessageBox.Show(Resources.ERR_MSG_SEND_FOLDER_NAME_DATA_LIMIT, Resources.ERR_TITLE_FOLDER_NAME, (MessageBoxButtons)0, (MessageBoxIcon)16);
			LOG.InfoFormat("{0}", (object)Resources.ERR_MSG_SEND_FOLDER_NAME_DATA_LIMIT);
			return;
		}
		if (checkItemChange(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_NAME))
		{
			int maxLength = Settings.Default.userKeyDisplayLength;
			displayName = ((Control)name).Text;
			Encoding ec = Encoding.GetEncoding("Shift_JIS");
			if (ec.GetByteCount(displayName) > maxLength)
			{
				displayName = new string(displayName.TakeWhile((char c, int i) => ec.GetByteCount(displayName.Substring(0, i + 1)) <= maxLength).ToArray());
			}
		}
		if (Encoding.GetEncoding("Shift_JIS").GetByteCount(((Control)comboBoxSendPath).Text) > Settings.Default.userPathLength)
		{
			MessageBox.Show(Resources.FOLDER_NAME_LENGTH_ERROR_TEXT, Resources.ERR_TITLE_PATH, (MessageBoxButtons)0, (MessageBoxIcon)16);
			LOG.InfoFormat("{0}", (object)Resources.FOLDER_NAME_LENGTH_ERROR_TEXT);
		}
		else
		{
			if (!checkPassword())
			{
				return;
			}
			if (isPrimax)
			{
				MachineControl machineControl = new MachineControl(machineLang);
				if (isUnicodePrimax)
				{
					if (machineControl.convToUnicode(((Control)name).Text) == null)
					{
						MessageBox.Show(Resources.INPUT_ADDRESS_NAME_FULL_WIDTH_2, Resources.INPUT_ADDRESS_ERROR, (MessageBoxButtons)0, (MessageBoxIcon)16);
						LOG.InfoFormat("{0}：宛先名 入力文字エラー：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)((Control)name).Text);
						return;
					}
					if (!machineControl.checkDestNameCharUnicode(((Control)name).Text))
					{
						MessageBox.Show(Resources.INPUT_ADDRESS_NAME_FULL_WIDTH_2, Resources.INPUT_ADDRESS_ERROR, (MessageBoxButtons)0, (MessageBoxIcon)16);
						LOG.InfoFormat("{0}：宛先名 入力文字エラー：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)((Control)name).Text);
						return;
					}
				}
				else
				{
					if (machineControl.convHexString(((Control)name).Text, MachineControl.PRIMAX_HEX_ENCODINGT.SJIS) == null)
					{
						MessageBox.Show(Resources.INPUT_ADDRESS_NAME_FULL_WIDTH, Resources.INPUT_ADDRESS_ERROR, (MessageBoxButtons)0, (MessageBoxIcon)16);
						LOG.InfoFormat("{0}：宛先名 入力文字エラー：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)((Control)name).Text);
						return;
					}
					if (!machineControl.checkDestNameChar(((Control)name).Text))
					{
						MessageBox.Show(Resources.INPUT_ADDRESS_NAME_FULL_WIDTH, Resources.INPUT_ADDRESS_ERROR, (MessageBoxButtons)0, (MessageBoxIcon)16);
						LOG.InfoFormat("{0}：宛先名 入力文字エラー：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)((Control)name).Text);
						return;
					}
				}
				if (machineControl.convHexString(((Control)comboBoxSendPath).Text, MachineControl.PRIMAX_HEX_ENCODINGT.SJIS) == null)
				{
					MessageBox.Show(Resources.PRIMAX_INPUT_FOLDER_FULL_WIDTH, Resources.PRIMAX_INPUT_FOLDER_ERROR, (MessageBoxButtons)0, (MessageBoxIcon)16);
					LOG.InfoFormat("{0}：共有フォルダー名 入力文字エラー：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)((Control)comboBoxSendPath).Text);
					return;
				}
				if (machineControl.convHexString(((Control)comboBoxPCUser).Text, MachineControl.PRIMAX_HEX_ENCODINGT.SJIS) == null)
				{
					MessageBox.Show(Resources.PRIMAX_INPUT_USERNAME_FULL_WIDTH, Resources.PRIMAX_INPUT_USERNAME_ERROR, (MessageBoxButtons)0, (MessageBoxIcon)16);
					LOG.InfoFormat("{0}：ログインユーザ名 入力文字エラー：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)((Control)comboBoxPCUser).Text);
					return;
				}
				string text = ((Control)password).Text.ToString();
				if (!string.IsNullOrEmpty(text) && machineControl.convHexString(text, MachineControl.PRIMAX_HEX_ENCODINGT.SJIS) == null)
				{
					MessageBox.Show(Resources.PRIMAX_INPUT_PASSWORD_FULL_WIDTH, Resources.PRIMAX_INPUT_PASSWORD_ERROR, (MessageBoxButtons)0, (MessageBoxIcon)16);
					LOG.InfoFormat("{0}：パスワード 入力文字エラー：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)text);
					return;
				}
			}
			((Form)this).DialogResult = (DialogResult)1;
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		}
	}

	private bool checkPassword()
	{
		if (radioButtonPasswordOn.Checked)
		{
			PasswordCheck passwordCheck = new PasswordCheck();
			try
			{
				passwordCheck.checkPassword(((Control)password).Text, ((Control)passwordConfirm).Text, "password", machineLang, Resources.ADDRESSBOOK_PASSWORD_MISMATCH);
			}
			catch (Exception)
			{
				return false;
			}
			finally
			{
				LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
			}
		}
		return true;
	}

	private void buttonCancel_Click(object sender, EventArgs e)
	{
		LOG.DebugFormat("{0}：cancel", (object)MethodBase.GetCurrentMethod().Name);
		((Form)this).Close();
	}

	private void nameValueChanged(object sender, EventArgs e)
	{
		changeOkButtonEnabled(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_NAME, ((Control)name).Text);
	}

	private void changeOkButtonEnabled(AddressBookListControl.ADDRESSBOOK_LIST_ITEM index, int current)
	{
		int result = 0;
		int.TryParse(userInfoOrg[index], out result);
		int bit = 1 << (int)index;
		changeNeeds[bit] = result != current;
		((Control)buttonOK).Enabled = changeNeeds.Data > 0;
	}

	private void changeOkButtonEnabled(AddressBookListControl.ADDRESSBOOK_LIST_ITEM index, string currentStr)
	{
		string a = userInfoOrg[index];
		int bit = 1 << (int)index;
		changeNeeds[bit] = !string.Equals(a, currentStr);
		((Control)buttonOK).Enabled = changeNeeds.Data > 0;
	}

	private bool checkItemChange(AddressBookListControl.ADDRESSBOOK_LIST_ITEM index)
	{
		int bit = 1 << (int)index;
		return changeNeeds[bit];
	}

	private void comboBoxFolder_SelectedIndexChanged(object sender, EventArgs e)
	{
		int num = 0;
		string text = (string)comboBoxFolder.SelectedItem;
		ipaddressPC = string.Empty;
		ipaddressPC = fMain.getIPAddress();
		comboBoxSendPath.Items.Clear();
		comboBoxSendPath.Items.Add((object)("\\\\" + ipaddressPC + "\\" + text));
		comboBoxSendPath.Items.Add((object)("\\\\" + Dns.GetHostName() + "\\" + text));
		if (!string.Equals(text, folderNameOrg))
		{
			num = (fMain.DhcpCaution ? 1 : 0);
		}
		else
		{
			if (!comboBoxSendPath.Items.Contains((object)pathNameOrg))
			{
				comboBoxSendPath.Items.Add((object)pathNameOrg);
			}
			num = comboBoxSendPath.Items.IndexOf((object)pathNameOrg);
		}
		((ListControl)comboBoxSendPath).SelectedIndex = num;
	}

	private void comboBoxSendPath_SelectedIndexChanged(object sender, EventArgs e)
	{
		changeOkButtonEnabled(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PATH_NAME, (string)comboBoxSendPath.SelectedItem);
	}

	private void comboBoxPCUser_SelectedIndexChanged(object sender, EventArgs e)
	{
		changeOkButtonEnabled(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_AUTH_USER_NAME, (string)comboBoxPCUser.SelectedItem);
	}

	private void password_Leave(object sender, EventArgs e)
	{
		textBox_LeaveCommon(password, Resources.TXT_P3_INITIAL_001, passwordUse: true);
	}

	private void password_Enter(object sender, EventArgs e)
	{
		textBox_EnterCommon(password, Resources.TXT_P3_INITIAL_001, passwordUse: true);
	}

	private void passwordConfirm_Leave(object sender, EventArgs e)
	{
		textBox_LeaveCommon(passwordConfirm, Resources.TXT_P3_INITIAL_002, passwordUse: true);
	}

	private void passwordConfirm_Enter(object sender, EventArgs e)
	{
		textBox_EnterCommon(passwordConfirm, Resources.TXT_P3_INITIAL_002, passwordUse: true);
	}

	private void textBox_LeaveCommon(TextBox textBoxObj, string initialStr, bool passwordUse)
	{
		//IL_002e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0038: Expected O, but got Unknown
		if (string.IsNullOrEmpty(((Control)textBoxObj).Text) || string.Equals(((Control)textBoxObj).Text, initialStr))
		{
			((Control)textBoxObj).Text = initialStr;
			((Control)textBoxObj).Font = new Font("MS UI Gothic", 9f, (FontStyle)2);
			((Control)textBoxObj).ForeColor = Color.FromArgb(195, 195, 195);
			if (passwordUse)
			{
				textBoxObj.PasswordChar = '\0';
			}
		}
	}

	private void textBox_EnterCommon(TextBox textBoxObj, string initialStr, bool passwordUse)
	{
		//IL_0025: Unknown result type (might be due to invalid IL or missing references)
		//IL_002f: Expected O, but got Unknown
		if (((Control)textBoxObj).Text.Equals(initialStr))
		{
			((Control)textBoxObj).Text = string.Empty;
			((Control)textBoxObj).Font = new Font("MS UI Gothic", 9f, (FontStyle)0);
			((Control)textBoxObj).ForeColor = Color.Black;
			if (passwordUse)
			{
				textBoxObj.PasswordChar = '*';
			}
		}
	}

	private void buttonHeadLine_Click(object sender, EventArgs e)
	{
		if (isPrimax)
		{
			buttonHeadLine_ClickToPrimax();
			return;
		}
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		fSettingHeadline.SetHeadLine((Form)(object)this);
		if (fSettingHeadline.RegistrationNo > 0)
		{
			changeOkButtonEnabled(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX, fSettingHeadline.RegistrationNo);
		}
		changeOkButtonEnabled(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_1, fSettingHeadline.Index1Headline + 1);
		changeOkButtonEnabled(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_2, fSettingHeadline.Index2Headline + 1);
		changeOkButtonEnabled(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_3, fSettingHeadline.Index3Headline + 1);
		changeOkButtonEnabled(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_FREQ, fSettingHeadline.IndexRegularHeading);
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	public string buttonHeadLine_ClickToPrimax()
	{
		//IL_007c: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		bool flag = true;
		for (int i = 0; i < PrimaxOneTouchKeyList.Count; i++)
		{
			if (string.IsNullOrEmpty(PrimaxOneTouchKeyList[i].name))
			{
				flag = false;
				break;
			}
		}
		int num = int.Parse(userInfoOrg[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX].ToString());
		if (num == 0 && flag)
		{
			MessageBox.Show(Resources.ERR_MSG_PRIMAX_NO_ONE_TOUCH_KEY, Resources.ERR_TITLE_PRIMAX_NO_ONE_TOUCH_KEY, (MessageBoxButtons)0, (MessageBoxIcon)16);
			return "0";
		}
		fSettingHeadline.PrimaxProcMode = FormSettingHeadLine.PRIMAX_PROC_MODE.UPDATE;
		fSettingHeadline.PrimaxOneTouchKeyList = PrimaxOneTouchKeyList;
		fSettingHeadline.PrimaxIndexStatus = PrimaxIndexRelease;
		fSettingHeadline.PrimaxWizToTrp = false;
		int num2 = num;
		if (fSettingHeadline.RegistrationNo != 0)
		{
			num = fSettingHeadline.RegistrationNo;
		}
		fSettingHeadline.PrimaxRegistrationNo = num;
		fSettingHeadline.Initialize();
		fSettingHeadline.SetHeadLine((Form)(object)this);
		bool enabled = false;
		PrimaxIndexRelease = false;
		if (fSettingHeadline.RegistrationNo != num2)
		{
			enabled = true;
		}
		if (num2 != 0 && fSettingHeadline.RegistrationNo == 0)
		{
			PrimaxIndexRelease = true;
			enabled = true;
		}
		if (!((Control)name).Text.Equals(userInfoOrg[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_NAME].ToString()))
		{
			enabled = true;
		}
		if (!comboBoxSendPath.SelectedItem.ToString().Equals(userInfoOrg[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PATH_NAME].ToString()))
		{
			enabled = true;
		}
		if (!comboBoxPCUser.SelectedItem.ToString().Equals(userInfoOrg[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_AUTH_USER_NAME].ToString()))
		{
			enabled = true;
		}
		if (radioButtonPasswordOn.Checked)
		{
			enabled = true;
		}
		((Control)buttonOK).Enabled = enabled;
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return fSettingHeadline.RegistrationNo.ToString();
	}

	protected override void Dispose(bool disposing)
	{
		if (disposing && components != null)
		{
			components.Dispose();
		}
		((Form)this).Dispose(disposing);
	}

	private void InitializeComponent()
	{
		//IL_0011: Unknown result type (might be due to invalid IL or missing references)
		//IL_001b: Expected O, but got Unknown
		//IL_001c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0026: Expected O, but got Unknown
		//IL_0027: Unknown result type (might be due to invalid IL or missing references)
		//IL_0031: Expected O, but got Unknown
		//IL_0032: Unknown result type (might be due to invalid IL or missing references)
		//IL_003c: Expected O, but got Unknown
		//IL_003d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0047: Expected O, but got Unknown
		//IL_0048: Unknown result type (might be due to invalid IL or missing references)
		//IL_0052: Expected O, but got Unknown
		//IL_0053: Unknown result type (might be due to invalid IL or missing references)
		//IL_005d: Expected O, but got Unknown
		//IL_005e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0068: Expected O, but got Unknown
		//IL_0069: Unknown result type (might be due to invalid IL or missing references)
		//IL_0073: Expected O, but got Unknown
		//IL_0074: Unknown result type (might be due to invalid IL or missing references)
		//IL_007e: Expected O, but got Unknown
		//IL_007f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0089: Expected O, but got Unknown
		//IL_008a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0094: Expected O, but got Unknown
		//IL_0095: Unknown result type (might be due to invalid IL or missing references)
		//IL_009f: Expected O, but got Unknown
		//IL_00a0: Unknown result type (might be due to invalid IL or missing references)
		//IL_00aa: Expected O, but got Unknown
		//IL_00ab: Unknown result type (might be due to invalid IL or missing references)
		//IL_00b5: Expected O, but got Unknown
		//IL_00b6: Unknown result type (might be due to invalid IL or missing references)
		//IL_00c0: Expected O, but got Unknown
		//IL_00c1: Unknown result type (might be due to invalid IL or missing references)
		//IL_00cb: Expected O, but got Unknown
		//IL_00cc: Unknown result type (might be due to invalid IL or missing references)
		//IL_00d6: Expected O, but got Unknown
		//IL_00d7: Unknown result type (might be due to invalid IL or missing references)
		//IL_00e1: Expected O, but got Unknown
		//IL_00e2: Unknown result type (might be due to invalid IL or missing references)
		//IL_00ec: Expected O, but got Unknown
		//IL_00ed: Unknown result type (might be due to invalid IL or missing references)
		//IL_00f7: Expected O, but got Unknown
		//IL_00f8: Unknown result type (might be due to invalid IL or missing references)
		//IL_0102: Expected O, but got Unknown
		//IL_0103: Unknown result type (might be due to invalid IL or missing references)
		//IL_010d: Expected O, but got Unknown
		//IL_010e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0118: Expected O, but got Unknown
		//IL_0e5a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0e64: Expected O, but got Unknown
		ComponentResourceManager componentResourceManager = new ComponentResourceManager(typeof(FormAddressBookSetting));
		buttonOK = new Button();
		buttonCancel = new Button();
		label_name = new Label();
		label_SendPath = new Label();
		label_PCUser = new Label();
		label_Password = new Label();
		label_PasswordConfirm = new Label();
		name = new TextBox();
		label_PasswordChange = new Label();
		password = new TextBox();
		passwordConfirm = new TextBox();
		radioButtonPasswordOn = new RadioButton();
		radioButtonPasswordOff = new RadioButton();
		panel1 = new Panel();
		comboBoxSendPath = new ComboBox();
		comboBoxPCUser = new ComboBox();
		label_Folder = new Label();
		comboBoxFolder = new ComboBox();
		btnHeadLine = new Button();
		label3 = new Label();
		label1 = new Label();
		label_CurrentFolder = new Label();
		label_CurrentSendPath = new Label();
		label_CurrentPCUser = new Label();
		((Control)panel1).SuspendLayout();
		((Control)this).SuspendLayout();
		((Control)buttonOK).AutoSize = true;
		((Control)buttonOK).Location = new Point(270, 344);
		((Control)buttonOK).Name = "buttonOK";
		((Control)buttonOK).Size = new Size(75, 23);
		((Control)buttonOK).TabIndex = 20;
		((Control)buttonOK).Text = "buttonOK";
		((ButtonBase)buttonOK).UseVisualStyleBackColor = true;
		((Control)buttonOK).Click += buttonOK_Click;
		((Control)buttonCancel).AutoSize = true;
		buttonCancel.DialogResult = (DialogResult)2;
		((Control)buttonCancel).Location = new Point(365, 344);
		((Control)buttonCancel).Name = "buttonCancel";
		((Control)buttonCancel).Size = new Size(75, 23);
		((Control)buttonCancel).TabIndex = 21;
		((Control)buttonCancel).Text = "buttonCan";
		((ButtonBase)buttonCancel).UseVisualStyleBackColor = true;
		((Control)buttonCancel).Click += buttonCancel_Click;
		((Control)label_name).AutoSize = true;
		((Control)label_name).ForeColor = SystemColors.Highlight;
		((Control)label_name).Location = new Point(12, 17);
		((Control)label_name).Name = "label_name";
		((Control)label_name).Size = new Size(41, 12);
		((Control)label_name).TabIndex = 0;
		((Control)label_name).Text = "label01";
		((Control)label_SendPath).AutoSize = true;
		((Control)label_SendPath).ForeColor = SystemColors.Highlight;
		((Control)label_SendPath).Location = new Point(12, 125);
		((Control)label_SendPath).Name = "label_SendPath";
		((Control)label_SendPath).Size = new Size(41, 12);
		((Control)label_SendPath).TabIndex = 3;
		((Control)label_SendPath).Text = "label03";
		((Control)label_PCUser).AutoSize = true;
		((Control)label_PCUser).ForeColor = SystemColors.Highlight;
		((Control)label_PCUser).Location = new Point(12, 193);
		((Control)label_PCUser).Name = "label_PCUser";
		((Control)label_PCUser).Size = new Size(41, 12);
		((Control)label_PCUser).TabIndex = 5;
		((Control)label_PCUser).Text = "label04";
		((Control)label_Password).AutoSize = true;
		((Control)label_Password).ForeColor = SystemColors.Highlight;
		((Control)label_Password).Location = new Point(12, 277);
		((Control)label_Password).Name = "label_Password";
		((Control)label_Password).Size = new Size(41, 12);
		((Control)label_Password).TabIndex = 7;
		((Control)label_Password).Text = "label06";
		((Control)label_PasswordConfirm).AutoSize = true;
		((Control)label_PasswordConfirm).ForeColor = SystemColors.Highlight;
		((Control)label_PasswordConfirm).Location = new Point(12, 307);
		((Control)label_PasswordConfirm).Name = "label_PasswordConfirm";
		((Control)label_PasswordConfirm).Size = new Size(41, 12);
		((Control)label_PasswordConfirm).TabIndex = 8;
		((Control)label_PasswordConfirm).Text = "label07";
		((Control)name).Location = new Point(140, 14);
		((Control)name).Name = "name";
		((Control)name).Size = new Size(170, 19);
		((Control)name).TabIndex = 9;
		((Control)name).TextChanged += nameValueChanged;
		((Control)label_PasswordChange).AutoSize = true;
		((Control)label_PasswordChange).ForeColor = SystemColors.Highlight;
		((Control)label_PasswordChange).Location = new Point(12, 247);
		((Control)label_PasswordChange).Name = "label_PasswordChange";
		((Control)label_PasswordChange).Size = new Size(41, 12);
		((Control)label_PasswordChange).TabIndex = 6;
		((Control)label_PasswordChange).Text = "label05";
		((Control)password).Enabled = false;
		((Control)password).Location = new Point(140, 274);
		((Control)password).Name = "password";
		password.PasswordChar = '*';
		((Control)password).Size = new Size(300, 19);
		((Control)password).TabIndex = 18;
		((Control)password).Enter += password_Enter;
		((Control)password).Leave += password_Leave;
		((Control)passwordConfirm).Enabled = false;
		((Control)passwordConfirm).Location = new Point(140, 304);
		((Control)passwordConfirm).Name = "passwordConfirm";
		passwordConfirm.PasswordChar = '*';
		((Control)passwordConfirm).Size = new Size(300, 19);
		((Control)passwordConfirm).TabIndex = 19;
		((Control)passwordConfirm).Enter += passwordConfirm_Enter;
		((Control)passwordConfirm).Leave += passwordConfirm_Leave;
		((Control)radioButtonPasswordOn).AutoSize = true;
		((Control)radioButtonPasswordOn).Location = new Point(7, 4);
		((Control)radioButtonPasswordOn).Name = "radioButtonPasswordOn";
		((Control)radioButtonPasswordOn).Size = new Size(35, 16);
		((Control)radioButtonPasswordOn).TabIndex = 0;
		((Control)radioButtonPasswordOn).Text = "on";
		((ButtonBase)radioButtonPasswordOn).UseVisualStyleBackColor = true;
		radioButtonPasswordOn.CheckedChanged += radioButtonPasswordON_CheckedChanged;
		((Control)radioButtonPasswordOff).AutoSize = true;
		radioButtonPasswordOff.Checked = true;
		((Control)radioButtonPasswordOff).Location = new Point(56, 4);
		((Control)radioButtonPasswordOff).Name = "radioButtonPasswordOff";
		((Control)radioButtonPasswordOff).Size = new Size(37, 16);
		((Control)radioButtonPasswordOff).TabIndex = 1;
		radioButtonPasswordOff.TabStop = true;
		((Control)radioButtonPasswordOff).Text = "off";
		((ButtonBase)radioButtonPasswordOff).UseVisualStyleBackColor = true;
		((Control)panel1).Controls.Add((Control)(object)radioButtonPasswordOff);
		((Control)panel1).Controls.Add((Control)(object)radioButtonPasswordOn);
		((Control)panel1).Location = new Point(153, 242);
		((Control)panel1).Name = "panel1";
		((Control)panel1).Size = new Size(187, 20);
		((Control)panel1).TabIndex = 17;
		comboBoxSendPath.DropDownStyle = (ComboBoxStyle)2;
		((ListControl)comboBoxSendPath).FormattingEnabled = true;
		((Control)comboBoxSendPath).Location = new Point(140, 122);
		((Control)comboBoxSendPath).Name = "comboBoxSendPath";
		((Control)comboBoxSendPath).Size = new Size(300, 20);
		comboBoxSendPath.Sorted = true;
		((Control)comboBoxSendPath).TabIndex = 13;
		comboBoxSendPath.SelectedIndexChanged += comboBoxSendPath_SelectedIndexChanged;
		comboBoxPCUser.DropDownStyle = (ComboBoxStyle)2;
		((ListControl)comboBoxPCUser).FormattingEnabled = true;
		((Control)comboBoxPCUser).Location = new Point(140, 190);
		((Control)comboBoxPCUser).Name = "comboBoxPCUser";
		((Control)comboBoxPCUser).Size = new Size(300, 20);
		comboBoxPCUser.Sorted = true;
		((Control)comboBoxPCUser).TabIndex = 15;
		comboBoxPCUser.SelectedIndexChanged += comboBoxPCUser_SelectedIndexChanged;
		((Control)label_Folder).AutoSize = true;
		((Control)label_Folder).ForeColor = SystemColors.Highlight;
		((Control)label_Folder).Location = new Point(12, 70);
		((Control)label_Folder).Name = "label_Folder";
		((Control)label_Folder).Size = new Size(41, 12);
		((Control)label_Folder).TabIndex = 2;
		((Control)label_Folder).Text = "label02";
		comboBoxFolder.DropDownStyle = (ComboBoxStyle)2;
		((ListControl)comboBoxFolder).FormattingEnabled = true;
		((Control)comboBoxFolder).Location = new Point(140, 67);
		((Control)comboBoxFolder).Name = "comboBoxFolder";
		((Control)comboBoxFolder).Size = new Size(300, 20);
		comboBoxFolder.Sorted = true;
		((Control)comboBoxFolder).TabIndex = 11;
		comboBoxFolder.SelectedIndexChanged += comboBoxFolder_SelectedIndexChanged;
		((Control)btnHeadLine).AutoSize = true;
		((ButtonBase)btnHeadLine).ImeMode = (ImeMode)0;
		((Control)btnHeadLine).Location = new Point(326, 12);
		((Control)btnHeadLine).Name = "btnHeadLine";
		((Control)btnHeadLine).Size = new Size(114, 23);
		((Control)btnHeadLine).TabIndex = 10;
		((Control)btnHeadLine).Text = "Index";
		((ButtonBase)btnHeadLine).UseVisualStyleBackColor = true;
		((Control)btnHeadLine).Click += buttonHeadLine_Click;
		label3.BorderStyle = (BorderStyle)2;
		((Control)label3).Location = new Point(12, 51);
		((Control)label3).Name = "label3";
		((Control)label3).Size = new Size(428, 2);
		((Control)label3).TabIndex = 1;
		label1.BorderStyle = (BorderStyle)2;
		((Control)label1).Location = new Point(17, 174);
		((Control)label1).Name = "label1";
		((Control)label1).Size = new Size(428, 2);
		((Control)label1).TabIndex = 4;
		((Control)label_CurrentFolder).AutoSize = true;
		((Control)label_CurrentFolder).ForeColor = SystemColors.Highlight;
		((Control)label_CurrentFolder).Location = new Point(140, 90);
		((Control)label_CurrentFolder).Name = "label_CurrentFolder";
		((Control)label_CurrentFolder).Size = new Size(41, 12);
		((Control)label_CurrentFolder).TabIndex = 12;
		((Control)label_CurrentFolder).Text = "label08";
		((Control)label_CurrentSendPath).AutoSize = true;
		((Control)label_CurrentSendPath).ForeColor = SystemColors.Highlight;
		((Control)label_CurrentSendPath).Location = new Point(140, 145);
		((Control)label_CurrentSendPath).Name = "label_CurrentSendPath";
		((Control)label_CurrentSendPath).Size = new Size(41, 12);
		((Control)label_CurrentSendPath).TabIndex = 14;
		((Control)label_CurrentSendPath).Text = "label09";
		((Control)label_CurrentPCUser).AutoSize = true;
		((Control)label_CurrentPCUser).ForeColor = SystemColors.Highlight;
		((Control)label_CurrentPCUser).Location = new Point(140, 213);
		((Control)label_CurrentPCUser).Name = "label_CurrentPCUser";
		((Control)label_CurrentPCUser).Size = new Size(41, 12);
		((Control)label_CurrentPCUser).TabIndex = 16;
		((Control)label_CurrentPCUser).Text = "label10";
		((ContainerControl)this).AutoScaleDimensions = new SizeF(6f, 12f);
		((ContainerControl)this).AutoScaleMode = (AutoScaleMode)1;
		((Form)this).ClientSize = new Size(463, 385);
		((Control)this).Controls.Add((Control)(object)label_CurrentPCUser);
		((Control)this).Controls.Add((Control)(object)label_CurrentSendPath);
		((Control)this).Controls.Add((Control)(object)label_CurrentFolder);
		((Control)this).Controls.Add((Control)(object)label1);
		((Control)this).Controls.Add((Control)(object)label3);
		((Control)this).Controls.Add((Control)(object)btnHeadLine);
		((Control)this).Controls.Add((Control)(object)comboBoxFolder);
		((Control)this).Controls.Add((Control)(object)label_Folder);
		((Control)this).Controls.Add((Control)(object)comboBoxPCUser);
		((Control)this).Controls.Add((Control)(object)comboBoxSendPath);
		((Control)this).Controls.Add((Control)(object)panel1);
		((Control)this).Controls.Add((Control)(object)passwordConfirm);
		((Control)this).Controls.Add((Control)(object)password);
		((Control)this).Controls.Add((Control)(object)label_PasswordChange);
		((Control)this).Controls.Add((Control)(object)name);
		((Control)this).Controls.Add((Control)(object)label_PasswordConfirm);
		((Control)this).Controls.Add((Control)(object)label_Password);
		((Control)this).Controls.Add((Control)(object)label_PCUser);
		((Control)this).Controls.Add((Control)(object)label_SendPath);
		((Control)this).Controls.Add((Control)(object)label_name);
		((Control)this).Controls.Add((Control)(object)buttonCancel);
		((Control)this).Controls.Add((Control)(object)buttonOK);
		((Form)this).FormBorderStyle = (FormBorderStyle)3;
		((Form)this).Icon = (Icon)componentResourceManager.GetObject("$this.Icon");
		((Form)this).MaximizeBox = false;
		((Form)this).MinimizeBox = false;
		((Control)this).Name = "FormAddressBookSetting";
		((Form)this).StartPosition = (FormStartPosition)4;
		((Control)this).Text = "title";
		((Control)panel1).ResumeLayout(false);
		((Control)panel1).PerformLayout();
		((Control)this).ResumeLayout(false);
		((Control)this).PerformLayout();
	}

	private void InitializeComponent_MultiLang()
	{
		//IL_0011: Unknown result type (might be due to invalid IL or missing references)
		//IL_001b: Expected O, but got Unknown
		//IL_001c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0026: Expected O, but got Unknown
		//IL_0027: Unknown result type (might be due to invalid IL or missing references)
		//IL_0031: Expected O, but got Unknown
		//IL_0032: Unknown result type (might be due to invalid IL or missing references)
		//IL_003c: Expected O, but got Unknown
		//IL_003d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0047: Expected O, but got Unknown
		//IL_0048: Unknown result type (might be due to invalid IL or missing references)
		//IL_0052: Expected O, but got Unknown
		//IL_0053: Unknown result type (might be due to invalid IL or missing references)
		//IL_005d: Expected O, but got Unknown
		//IL_005e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0068: Expected O, but got Unknown
		//IL_0069: Unknown result type (might be due to invalid IL or missing references)
		//IL_0073: Expected O, but got Unknown
		//IL_0074: Unknown result type (might be due to invalid IL or missing references)
		//IL_007e: Expected O, but got Unknown
		//IL_007f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0089: Expected O, but got Unknown
		//IL_008a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0094: Expected O, but got Unknown
		//IL_0095: Unknown result type (might be due to invalid IL or missing references)
		//IL_009f: Expected O, but got Unknown
		//IL_00a0: Unknown result type (might be due to invalid IL or missing references)
		//IL_00aa: Expected O, but got Unknown
		//IL_00ab: Unknown result type (might be due to invalid IL or missing references)
		//IL_00b5: Expected O, but got Unknown
		//IL_00b6: Unknown result type (might be due to invalid IL or missing references)
		//IL_00c0: Expected O, but got Unknown
		//IL_00c1: Unknown result type (might be due to invalid IL or missing references)
		//IL_00cb: Expected O, but got Unknown
		//IL_00cc: Unknown result type (might be due to invalid IL or missing references)
		//IL_00d6: Expected O, but got Unknown
		//IL_00d7: Unknown result type (might be due to invalid IL or missing references)
		//IL_00e1: Expected O, but got Unknown
		//IL_00e2: Unknown result type (might be due to invalid IL or missing references)
		//IL_00ec: Expected O, but got Unknown
		//IL_00ed: Unknown result type (might be due to invalid IL or missing references)
		//IL_00f7: Expected O, but got Unknown
		//IL_00f8: Unknown result type (might be due to invalid IL or missing references)
		//IL_0102: Expected O, but got Unknown
		//IL_0103: Unknown result type (might be due to invalid IL or missing references)
		//IL_010d: Expected O, but got Unknown
		//IL_010e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0118: Expected O, but got Unknown
		//IL_0e5d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0e67: Expected O, but got Unknown
		ComponentResourceManager componentResourceManager = new ComponentResourceManager(typeof(FormAddressBookSetting));
		buttonOK = new Button();
		buttonCancel = new Button();
		label_name = new Label();
		label_SendPath = new Label();
		label_PCUser = new Label();
		label_Password = new Label();
		label_PasswordConfirm = new Label();
		name = new TextBox();
		label_PasswordChange = new Label();
		password = new TextBox();
		passwordConfirm = new TextBox();
		radioButtonPasswordOn = new RadioButton();
		radioButtonPasswordOff = new RadioButton();
		panel1 = new Panel();
		comboBoxSendPath = new ComboBox();
		comboBoxPCUser = new ComboBox();
		label_Folder = new Label();
		comboBoxFolder = new ComboBox();
		btnHeadLine = new Button();
		label3 = new Label();
		label1 = new Label();
		label_CurrentFolder = new Label();
		label_CurrentSendPath = new Label();
		label_CurrentPCUser = new Label();
		((Control)panel1).SuspendLayout();
		((Control)this).SuspendLayout();
		((Control)buttonOK).AutoSize = true;
		((Control)buttonOK).Location = new Point(370, 344);
		((Control)buttonOK).Name = "buttonOK";
		((Control)buttonOK).Size = new Size(75, 23);
		((Control)buttonOK).TabIndex = 20;
		((Control)buttonOK).Text = "buttonOK";
		((ButtonBase)buttonOK).UseVisualStyleBackColor = true;
		((Control)buttonOK).Click += buttonOK_Click;
		((Control)buttonCancel).AutoSize = true;
		buttonCancel.DialogResult = (DialogResult)2;
		((Control)buttonCancel).Location = new Point(465, 344);
		((Control)buttonCancel).Name = "buttonCancel";
		((Control)buttonCancel).Size = new Size(75, 23);
		((Control)buttonCancel).TabIndex = 21;
		((Control)buttonCancel).Text = "buttonCan";
		((ButtonBase)buttonCancel).UseVisualStyleBackColor = true;
		((Control)buttonCancel).Click += buttonCancel_Click;
		((Control)label_name).AutoSize = true;
		((Control)label_name).ForeColor = SystemColors.Highlight;
		((Control)label_name).Location = new Point(12, 17);
		((Control)label_name).Name = "label_name";
		((Control)label_name).Size = new Size(41, 12);
		((Control)label_name).TabIndex = 0;
		((Control)label_name).Text = "label01";
		((Control)label_SendPath).AutoSize = true;
		((Control)label_SendPath).ForeColor = SystemColors.Highlight;
		((Control)label_SendPath).Location = new Point(12, 125);
		((Control)label_SendPath).Name = "label_SendPath";
		((Control)label_SendPath).Size = new Size(41, 12);
		((Control)label_SendPath).TabIndex = 3;
		((Control)label_SendPath).Text = "label03";
		((Control)label_PCUser).AutoSize = true;
		((Control)label_PCUser).ForeColor = SystemColors.Highlight;
		((Control)label_PCUser).Location = new Point(12, 193);
		((Control)label_PCUser).Name = "label_PCUser";
		((Control)label_PCUser).Size = new Size(41, 12);
		((Control)label_PCUser).TabIndex = 5;
		((Control)label_PCUser).Text = "label04";
		((Control)label_Password).AutoSize = true;
		((Control)label_Password).ForeColor = SystemColors.Highlight;
		((Control)label_Password).Location = new Point(12, 277);
		((Control)label_Password).Name = "label_Password";
		((Control)label_Password).Size = new Size(41, 12);
		((Control)label_Password).TabIndex = 7;
		((Control)label_Password).Text = "label06";
		((Control)label_PasswordConfirm).AutoSize = true;
		((Control)label_PasswordConfirm).ForeColor = SystemColors.Highlight;
		((Control)label_PasswordConfirm).Location = new Point(12, 307);
		((Control)label_PasswordConfirm).Name = "label_PasswordConfirm";
		((Control)label_PasswordConfirm).Size = new Size(41, 12);
		((Control)label_PasswordConfirm).TabIndex = 8;
		((Control)label_PasswordConfirm).Text = "label07";
		((Control)name).Location = new Point(240, 14);
		((Control)name).Name = "name";
		((Control)name).Size = new Size(170, 19);
		((Control)name).TabIndex = 9;
		((Control)name).TextChanged += nameValueChanged;
		((Control)label_PasswordChange).AutoSize = true;
		((Control)label_PasswordChange).ForeColor = SystemColors.Highlight;
		((Control)label_PasswordChange).Location = new Point(12, 247);
		((Control)label_PasswordChange).Name = "label_PasswordChange";
		((Control)label_PasswordChange).Size = new Size(141, 12);
		((Control)label_PasswordChange).TabIndex = 6;
		((Control)label_PasswordChange).Text = "label05";
		((Control)password).Enabled = false;
		((Control)password).Location = new Point(240, 274);
		((Control)password).Name = "password";
		password.PasswordChar = '*';
		((Control)password).Size = new Size(300, 19);
		((Control)password).TabIndex = 18;
		((Control)password).Enter += password_Enter;
		((Control)password).Leave += password_Leave;
		((Control)passwordConfirm).Enabled = false;
		((Control)passwordConfirm).Location = new Point(240, 304);
		((Control)passwordConfirm).Name = "passwordConfirm";
		passwordConfirm.PasswordChar = '*';
		((Control)passwordConfirm).Size = new Size(300, 19);
		((Control)passwordConfirm).TabIndex = 19;
		((Control)passwordConfirm).Enter += passwordConfirm_Enter;
		((Control)passwordConfirm).Leave += passwordConfirm_Leave;
		((Control)radioButtonPasswordOn).AutoSize = true;
		((Control)radioButtonPasswordOn).Location = new Point(7, 4);
		((Control)radioButtonPasswordOn).Name = "radioButtonPasswordOn";
		((Control)radioButtonPasswordOn).Size = new Size(35, 16);
		((Control)radioButtonPasswordOn).TabIndex = 0;
		((Control)radioButtonPasswordOn).Text = "on";
		((ButtonBase)radioButtonPasswordOn).UseVisualStyleBackColor = true;
		radioButtonPasswordOn.CheckedChanged += radioButtonPasswordON_CheckedChanged;
		((Control)radioButtonPasswordOff).AutoSize = true;
		radioButtonPasswordOff.Checked = true;
		((Control)radioButtonPasswordOff).Location = new Point(106, 4);
		((Control)radioButtonPasswordOff).Name = "radioButtonPasswordOff";
		((Control)radioButtonPasswordOff).Size = new Size(37, 16);
		((Control)radioButtonPasswordOff).TabIndex = 1;
		radioButtonPasswordOff.TabStop = true;
		((Control)radioButtonPasswordOff).Text = "off";
		((ButtonBase)radioButtonPasswordOff).UseVisualStyleBackColor = true;
		((Control)panel1).Controls.Add((Control)(object)radioButtonPasswordOff);
		((Control)panel1).Controls.Add((Control)(object)radioButtonPasswordOn);
		((Control)panel1).Location = new Point(313, 242);
		((Control)panel1).Name = "panel1";
		((Control)panel1).Size = new Size(187, 20);
		((Control)panel1).TabIndex = 17;
		comboBoxSendPath.DropDownStyle = (ComboBoxStyle)2;
		((ListControl)comboBoxSendPath).FormattingEnabled = true;
		((Control)comboBoxSendPath).Location = new Point(240, 122);
		((Control)comboBoxSendPath).Name = "comboBoxSendPath";
		((Control)comboBoxSendPath).Size = new Size(300, 20);
		comboBoxSendPath.Sorted = true;
		((Control)comboBoxSendPath).TabIndex = 13;
		comboBoxSendPath.SelectedIndexChanged += comboBoxSendPath_SelectedIndexChanged;
		comboBoxPCUser.DropDownStyle = (ComboBoxStyle)2;
		((ListControl)comboBoxPCUser).FormattingEnabled = true;
		((Control)comboBoxPCUser).Location = new Point(240, 190);
		((Control)comboBoxPCUser).Name = "comboBoxPCUser";
		((Control)comboBoxPCUser).Size = new Size(300, 20);
		comboBoxPCUser.Sorted = true;
		((Control)comboBoxPCUser).TabIndex = 15;
		comboBoxPCUser.SelectedIndexChanged += comboBoxPCUser_SelectedIndexChanged;
		((Control)label_Folder).AutoSize = true;
		((Control)label_Folder).ForeColor = SystemColors.Highlight;
		((Control)label_Folder).Location = new Point(12, 70);
		((Control)label_Folder).Name = "label_Folder";
		((Control)label_Folder).Size = new Size(41, 12);
		((Control)label_Folder).TabIndex = 2;
		((Control)label_Folder).Text = "label02";
		comboBoxFolder.DropDownStyle = (ComboBoxStyle)2;
		((ListControl)comboBoxFolder).FormattingEnabled = true;
		((Control)comboBoxFolder).Location = new Point(240, 67);
		((Control)comboBoxFolder).Name = "comboBoxFolder";
		((Control)comboBoxFolder).Size = new Size(300, 20);
		comboBoxFolder.Sorted = true;
		((Control)comboBoxFolder).TabIndex = 11;
		comboBoxFolder.SelectedIndexChanged += comboBoxFolder_SelectedIndexChanged;
		((Control)btnHeadLine).AutoSize = true;
		((ButtonBase)btnHeadLine).ImeMode = (ImeMode)0;
		((Control)btnHeadLine).Location = new Point(426, 12);
		((Control)btnHeadLine).Name = "btnHeadLine";
		((Control)btnHeadLine).Size = new Size(114, 23);
		((Control)btnHeadLine).TabIndex = 10;
		((Control)btnHeadLine).Text = "Index";
		((ButtonBase)btnHeadLine).UseVisualStyleBackColor = true;
		((Control)btnHeadLine).Click += buttonHeadLine_Click;
		label3.BorderStyle = (BorderStyle)2;
		((Control)label3).Location = new Point(12, 51);
		((Control)label3).Name = "label3";
		((Control)label3).Size = new Size(528, 2);
		((Control)label3).TabIndex = 1;
		label1.BorderStyle = (BorderStyle)2;
		((Control)label1).Location = new Point(17, 174);
		((Control)label1).Name = "label1";
		((Control)label1).Size = new Size(528, 2);
		((Control)label1).TabIndex = 4;
		((Control)label_CurrentFolder).AutoSize = true;
		((Control)label_CurrentFolder).ForeColor = SystemColors.Highlight;
		((Control)label_CurrentFolder).Location = new Point(240, 90);
		((Control)label_CurrentFolder).Name = "label_CurrentFolder";
		((Control)label_CurrentFolder).Size = new Size(41, 12);
		((Control)label_CurrentFolder).TabIndex = 12;
		((Control)label_CurrentFolder).Text = "label08";
		((Control)label_CurrentSendPath).AutoSize = true;
		((Control)label_CurrentSendPath).ForeColor = SystemColors.Highlight;
		((Control)label_CurrentSendPath).Location = new Point(240, 145);
		((Control)label_CurrentSendPath).Name = "label_CurrentSendPath";
		((Control)label_CurrentSendPath).Size = new Size(41, 12);
		((Control)label_CurrentSendPath).TabIndex = 14;
		((Control)label_CurrentSendPath).Text = "label09";
		((Control)label_CurrentPCUser).AutoSize = true;
		((Control)label_CurrentPCUser).ForeColor = SystemColors.Highlight;
		((Control)label_CurrentPCUser).Location = new Point(240, 213);
		((Control)label_CurrentPCUser).Name = "label_CurrentPCUser";
		((Control)label_CurrentPCUser).Size = new Size(41, 12);
		((Control)label_CurrentPCUser).TabIndex = 16;
		((Control)label_CurrentPCUser).Text = "label10";
		((ContainerControl)this).AutoScaleDimensions = new SizeF(6f, 12f);
		((ContainerControl)this).AutoScaleMode = (AutoScaleMode)1;
		((Form)this).ClientSize = new Size(563, 385);
		((Control)this).Controls.Add((Control)(object)label_CurrentPCUser);
		((Control)this).Controls.Add((Control)(object)label_CurrentSendPath);
		((Control)this).Controls.Add((Control)(object)label_CurrentFolder);
		((Control)this).Controls.Add((Control)(object)label1);
		((Control)this).Controls.Add((Control)(object)label3);
		((Control)this).Controls.Add((Control)(object)btnHeadLine);
		((Control)this).Controls.Add((Control)(object)comboBoxFolder);
		((Control)this).Controls.Add((Control)(object)label_Folder);
		((Control)this).Controls.Add((Control)(object)comboBoxPCUser);
		((Control)this).Controls.Add((Control)(object)comboBoxSendPath);
		((Control)this).Controls.Add((Control)(object)panel1);
		((Control)this).Controls.Add((Control)(object)passwordConfirm);
		((Control)this).Controls.Add((Control)(object)password);
		((Control)this).Controls.Add((Control)(object)label_PasswordChange);
		((Control)this).Controls.Add((Control)(object)name);
		((Control)this).Controls.Add((Control)(object)label_PasswordConfirm);
		((Control)this).Controls.Add((Control)(object)label_Password);
		((Control)this).Controls.Add((Control)(object)label_PCUser);
		((Control)this).Controls.Add((Control)(object)label_SendPath);
		((Control)this).Controls.Add((Control)(object)label_name);
		((Control)this).Controls.Add((Control)(object)buttonCancel);
		((Control)this).Controls.Add((Control)(object)buttonOK);
		((Form)this).FormBorderStyle = (FormBorderStyle)3;
		((Form)this).Icon = (Icon)componentResourceManager.GetObject("$this.Icon");
		((Form)this).MaximizeBox = false;
		((Form)this).MinimizeBox = false;
		((Control)this).Name = "FormAddressBookSetting";
		((Form)this).StartPosition = (FormStartPosition)4;
		((Control)this).Text = "title";
		((Control)panel1).ResumeLayout(false);
		((Control)panel1).PerformLayout();
		((Control)this).ResumeLayout(false);
		((Control)this).PerformLayout();
	}
}
