using System;
using System.Collections;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Net.Security;
using System.Reflection;
using System.Security.Cryptography.X509Certificates;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using CreateFolder.Properties;
using log4net;

namespace CreateFolder;

public class FormMFPInfo : Form
{
	public enum KEY
	{
		MODELNAME,
		SYSTEMCOPY,
		NETWORKSUPPORT,
		WEBSUPPORT,
		NETBIOSNAME,
		IPV4ADRESS,
		SUBNETMASK,
		GATEWAY,
		PRIMARYWINS,
		SECONDARYWINS,
		DNS1,
		DNS2,
		DNS3,
		SMBENABLE,
		SMBPORT,
		SMBVERSION,
		SMBAUTHLEVEL,
		SMBV3FUNC,
		NBNS,
		NBNSTIMEOUT,
		SCANNER,
		ANIMATION,
		ST_NOSTATE,
		USER_PERMISSION
	}

	private static readonly ILog LOG = LogManager.GetLogger(MethodBase.GetCurrentMethod().DeclaringType);

	private IDictionary<KEY, string> mfpInfoTable = new Dictionary<KEY, string>();

	private string machineLang = string.Empty;

	private readonly string URI_FORMAT_BASE_ADDRESS = "{0}://{1}/";

	private readonly string URI_FORMAT_AUTHFORM = "{0}web/guest/{1}/websys/webArch/authForm.cgi";

	private List<string> machineList = new List<string>();

	private IContainer components;

	private Button buttonGetInfo;

	private Label labelMFP;

	private RichTextBox richTextBoxMachineInfo;

	private Button buttonClose;

	private Label label1;

	private Label labelMFP_Info;

	private Button buttonMachineSelect;

	private Label labelMFP_Select;

	private Label labelMFP_Selected;

	public FormMFPInfo(string lang)
	{
		if (lang.Equals("ja") || lang.Equals("en"))
		{
			InitializeComponent();
		}
		else
		{
			InitializeComponent_MultiLang();
		}
		machineLang = lang;
		((Control)labelMFP).ForeColor = Color.FromArgb(63, 72, 204);
		((Control)buttonGetInfo).Enabled = false;
		Control[] allControls = CreateFolderUtil.GetAllControls((Control)(object)this);
		CreateFolderUtil.ResetFontToControl(((object)this).GetType().Name, allControls);
		((Control)this).Text = Resources.ITEM_MACHINE_ENVIRONMENTS;
		((Control)labelMFP).Text = Resources.FORM_MAIN_MACHINE;
		((Control)labelMFP_Info).Text = Resources.FORM_MFPINFO_OPE_MESSAGE;
		((Control)labelMFP_Select).Text = Resources.FORM_MFPINFO_SELECTED_MACHINE;
		((Control)buttonMachineSelect).Text = Resources.FORM_MFPINFO_SELECT_BUTTON;
		((Control)buttonGetInfo).Text = Resources.FORM_MFPINFO_GET_BUTTON;
		((Control)buttonClose).Text = Resources.ITEM_BUTTON_BACK;
	}

	private void RegistInfo(KEY key, Hashtable mfpSettings)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		string text = mfpSettings[key].ToString();
		if (string.IsNullOrEmpty(text))
		{
			text = "-";
		}
		lock (mfpInfoTable)
		{
			if (mfpInfoTable.ContainsKey(key))
			{
				mfpInfoTable[key] = text;
			}
			else
			{
				mfpInfoTable.Add(key, text);
			}
			LOG.DebugFormat("{0}：Regist {1}:{2}", (object)MethodBase.GetCurrentMethod().Name, (object)key.ToString(), (object)text);
		}
		((Control)labelMFP).ForeColor = Color.FromArgb(63, 72, 204);
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	public void clearMachineList()
	{
		machineList.Clear();
	}

	public void setMachineList(List<string> machines)
	{
		foreach (string machine in machines)
		{
			if (!machineList.Contains(machine))
			{
				machineList.Add(machine);
			}
		}
	}

	public async Task<bool> GetMFPByHTTP(string ipAddress, MachineControl mc)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		bool result = false;
		try
		{
			SettingItemsSetupAddress info = new SettingItemsSetupAddress
			{
				host = ipAddress,
				adminName = "admin",
				passwd = "",
				firstFlg = true,
				httpsFlg = false
			};
			Hashtable hashtable = await mc.GetMFPInfo(info, richTextBoxMachineInfo);
			if (hashtable != null)
			{
				RegistInfo(KEY.MODELNAME, hashtable);
				RegistInfo(KEY.SYSTEMCOPY, hashtable);
				RegistInfo(KEY.NETWORKSUPPORT, hashtable);
				RegistInfo(KEY.WEBSUPPORT, hashtable);
				RegistInfo(KEY.SCANNER, hashtable);
				RegistInfo(KEY.ANIMATION, hashtable);
				RegistInfo(KEY.NETBIOSNAME, hashtable);
				RegistInfo(KEY.IPV4ADRESS, hashtable);
				RegistInfo(KEY.SUBNETMASK, hashtable);
				RegistInfo(KEY.GATEWAY, hashtable);
				RegistInfo(KEY.PRIMARYWINS, hashtable);
				RegistInfo(KEY.SECONDARYWINS, hashtable);
				RegistInfo(KEY.DNS1, hashtable);
				RegistInfo(KEY.DNS2, hashtable);
				RegistInfo(KEY.DNS3, hashtable);
				RegistInfo(KEY.SMBENABLE, hashtable);
				RegistInfo(KEY.SMBPORT, hashtable);
				RegistInfo(KEY.SMBVERSION, hashtable);
				if (hashtable.ContainsKey(KEY.SMBAUTHLEVEL))
				{
					RegistInfo(KEY.SMBAUTHLEVEL, hashtable);
				}
				result = true;
			}
		}
		catch (Exception ex)
		{
			LOG.ErrorFormat("{0}：HTTP Error. {1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)ex.ToString());
			string message = ex.Message;
			if (!string.IsNullOrEmpty(message) && message.IndexOf(Resources.WIM_ERROR_DETECT) >= 0)
			{
				message = message.Substring(Resources.WIM_ERROR_DETECT.Length);
				MessageBox.Show(message, Resources.ERR_MSG_MACHINE_INFO_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
			}
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		return result;
	}

	private async void buttonGetInfo_Click(object sender, EventArgs e)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		((Control)richTextBoxMachineInfo).Text = string.Empty;
		((Control)this).Refresh();
		string machineIPAddress = FormMFPSelect.getIpAddress();
		((Control)buttonGetInfo).Enabled = false;
		((Control)this).Refresh();
		try
		{
			((Control)richTextBoxMachineInfo).Text = Resources.PROGRESS_MESSAGE_0;
			MachineControl mc = new MachineControl(machineLang);
			string hostNameFromIP = FormWizard.GetHostNameFromIP(machineIPAddress);
			bool primaxModel = FormWizard.IsPrimax(hostNameFromIP);
			bool primaxUnicode = FormWizard.IsPrimaxUnicode(hostNameFromIP);
			mc.SetPrimaxModel(primaxModel);
			mc.SetPrimaxUnicode(primaxUnicode);
			COMMUNICATION_ERROR_CODE cOMMUNICATION_ERROR_CODE = mc.communicateConfirm(machineIPAddress);
			if (cOMMUNICATION_ERROR_CODE == COMMUNICATION_ERROR_CODE.ERROR || cOMMUNICATION_ERROR_CODE == COMMUNICATION_ERROR_CODE.NOT_SUPPORT)
			{
				((Control)richTextBoxMachineInfo).Text = string.Empty;
			}
			else
			{
				if (!((Control)labelMFP_Selected).Text.Contains("("))
				{
					if (primaxModel)
					{
						((Control)labelMFP_Selected).Text = $"{hostNameFromIP} ({machineIPAddress})";
					}
					else
					{
						((Control)labelMFP_Selected).Text = $"{mc.DisplayMachineName} ({machineIPAddress})";
					}
				}
				bool flag = ((!primaxModel) ? (await GetMFPByHTTP(machineIPAddress, mc)) : (await GetPrimaxMachineInfo(machineIPAddress, mc)));
				if (flag)
				{
					DisplayInfo(primaxModel);
				}
				else
				{
					LOG.ErrorFormat("{0}：ret = {1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)flag);
				}
			}
			((Control)buttonGetInfo).Enabled = true;
		}
		catch (Exception ex)
		{
			Console.WriteLine(ex.ToString());
			LOG.ErrorFormat("{0}：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)ex.ToString());
			MessageBox.Show(Resources.ERR_MSG_FATAL_RETRY, Resources.ERR_MSG_MACHINE_INFO_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
			((Control)buttonGetInfo).Enabled = true;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
	}

	private void DisplayInfo(bool primaxModel = false)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		StringBuilder stringBuilder = new StringBuilder();
		stringBuilder.AppendFormat("{0}\t : {1}\n", Resources.ITEM_MACHINE_NAME, getMfpInfo(KEY.MODELNAME));
		stringBuilder.AppendFormat("{0}\t : {1}\n", Resources.TXT_MACHINE_INFO_02_13, getMfpInfo(KEY.NETBIOSNAME));
		stringBuilder.AppendFormat("{0}  \t : {1}\n", Resources.TXT_MACHINE_INFO_03_13, getMfpInfo(KEY.IPV4ADRESS));
		stringBuilder.AppendFormat("{0}\t : {1}\n", Resources.TXT_MACHINE_INFO_04_13, getMfpInfo(KEY.SUBNETMASK));
		stringBuilder.AppendFormat("{0}\t : {1}\n", Resources.TXT_MACHINE_INFO_05_13, getMfpInfo(KEY.GATEWAY));
		stringBuilder.AppendFormat("{0}\t : {1}\n", Resources.TXT_MACHINE_INFO_06_13, getMfpInfo(KEY.SMBPORT));
		if (primaxModel)
		{
			stringBuilder.AppendFormat("{0}\t : {1}\n", Resources.TXT_MACHINE_INFO_08_13, Resources.WIM_LABEL_SMB_V2V3_ON_PRIMAX);
		}
		else
		{
			stringBuilder.AppendFormat("{0}\t : {1}\n", Resources.TXT_MACHINE_INFO_08_13, getMfpInfo(KEY.SMBVERSION));
		}
		if (!getMfpInfo(KEY.SMBAUTHLEVEL).Equals(""))
		{
			stringBuilder.AppendFormat("{0}\t : {1}\n", Resources.TXT_MACHINE_INFO_09_13, getMfpInfo(KEY.SMBAUTHLEVEL));
		}
		stringBuilder.AppendFormat("{0} \n", Resources.TXT_MACHINE_INFO_10_13);
		stringBuilder.AppendFormat("\t{0} : {1}\n", Resources.TXT_MACHINE_INFO_11_13, getMfpInfo(KEY.PRIMARYWINS));
		stringBuilder.AppendFormat("\t{0} : {1}\n", Resources.TXT_MACHINE_INFO_12_13, getMfpInfo(KEY.SECONDARYWINS));
		stringBuilder.AppendFormat("{0} \n", Resources.TXT_MACHINE_INFO_13_13);
		stringBuilder.AppendFormat("\t1 : {0}\n", getMfpInfo(KEY.DNS1));
		stringBuilder.AppendFormat("\t2 : {0}\n", getMfpInfo(KEY.DNS2));
		stringBuilder.AppendFormat("\t3 : {0}\n", getMfpInfo(KEY.DNS3));
		stringBuilder.AppendFormat("{0}\n", Resources.TXT_MACHINE_INFO_17_13);
		if (primaxModel)
		{
			stringBuilder.AppendFormat("\t{0}\t : {1}\n", Resources.TXT_MACHINE_INFO_14_13_PRIMAX, getMfpInfo(KEY.SYSTEMCOPY));
		}
		else
		{
			stringBuilder.AppendFormat("\t{0}\t : {1}\n", Resources.TXT_MACHINE_INFO_14_13, getMfpInfo(KEY.SYSTEMCOPY));
		}
		stringBuilder.AppendFormat("\t{0}\t : {1}\n", Resources.TXT_MACHINE_INFO_15_13, getMfpInfo(KEY.NETWORKSUPPORT));
		stringBuilder.AppendFormat("\t{0}\t : {1}\n", Resources.TXT_MACHINE_INFO_16_13, getMfpInfo(KEY.WEBSUPPORT));
		stringBuilder.AppendFormat("\t{0}\t\t : {1}\n", Resources.WIM_ITEM_SCANNER, getMfpInfo(KEY.SCANNER));
		stringBuilder.AppendFormat("\t{0}\t : {1}\n", Resources.WIM_ITEM_ANIMATION, getMfpInfo(KEY.ANIMATION));
		((Control)richTextBoxMachineInfo).Text = stringBuilder.ToString();
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	public string getMfpInfo(KEY key)
	{
		if (!mfpInfoTable.ContainsKey(key))
		{
			return string.Empty;
		}
		return mfpInfoTable[key];
	}

	private bool OnRemoteCertificateValidationCallback(object sender, X509Certificate certificate, X509Chain chain, SslPolicyErrors sslPolicyErrors)
	{
		return true;
	}

	private void buttonClose_Click(object sender, EventArgs e)
	{
		((Control)this).Visible = false;
	}

	private void buttonMachineSelect_Click(object sender, EventArgs e)
	{
		((Control)richTextBoxMachineInfo).Text = string.Empty;
		((Control)this).Refresh();
		FormMFPSelect.initialize(machineLang);
		FormMFPSelect.setMachineList(machineList);
		string displayedIPAddress = FormMFPSelect.GetDisplayedIPAddress();
		((Control)labelMFP_Selected).Text = displayedIPAddress;
		((Control)buttonGetInfo).Enabled = !string.IsNullOrEmpty(displayedIPAddress);
	}

	public async Task<bool> GetPrimaxMachineInfo(string ipAddress, MachineControl mc)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		bool result = false;
		try
		{
			SettingItemsSetupAddress info = new SettingItemsSetupAddress
			{
				host = ipAddress,
				adminName = "",
				passwd = "",
				firstFlg = true,
				httpsFlg = false
			};
			Hashtable hashtable = await mc.GetMFPByHTTPtoPrimax(info);
			if (hashtable != null)
			{
				RegistInfo(KEY.MODELNAME, hashtable);
				RegistInfo(KEY.SYSTEMCOPY, hashtable);
				RegistInfo(KEY.NETWORKSUPPORT, hashtable);
				RegistInfo(KEY.WEBSUPPORT, hashtable);
				RegistInfo(KEY.SCANNER, hashtable);
				RegistInfo(KEY.ANIMATION, hashtable);
				RegistInfo(KEY.NETBIOSNAME, hashtable);
				RegistInfo(KEY.IPV4ADRESS, hashtable);
				RegistInfo(KEY.SUBNETMASK, hashtable);
				RegistInfo(KEY.GATEWAY, hashtable);
				RegistInfo(KEY.PRIMARYWINS, hashtable);
				RegistInfo(KEY.SECONDARYWINS, hashtable);
				RegistInfo(KEY.DNS1, hashtable);
				RegistInfo(KEY.DNS2, hashtable);
				RegistInfo(KEY.DNS3, hashtable);
				RegistInfo(KEY.SMBENABLE, hashtable);
				RegistInfo(KEY.SMBPORT, hashtable);
				RegistInfo(KEY.SMBVERSION, hashtable);
				result = true;
			}
		}
		catch (Exception ex)
		{
			LOG.ErrorFormat("{0}：HTTP Error. {1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)ex.ToString());
			string message = ex.Message;
			if (!string.IsNullOrEmpty(message) && message.IndexOf(Resources.WIM_ERROR_DETECT) >= 0)
			{
				message = message.Substring(Resources.WIM_ERROR_DETECT.Length);
				MessageBox.Show(message, Resources.ERR_MSG_MACHINE_INFO_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
			}
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return result;
	}

	private void FormMFPInfo_Load(object sender, EventArgs e)
	{
	}

	protected override void Dispose(bool disposing)
	{
		if (disposing && components != null)
		{
			components.Dispose();
		}
		((Form)this).Dispose(disposing);
	}

	private void InitializeComponent()
	{
		//IL_0011: Unknown result type (might be due to invalid IL or missing references)
		//IL_001b: Expected O, but got Unknown
		//IL_001c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0026: Expected O, but got Unknown
		//IL_0027: Unknown result type (might be due to invalid IL or missing references)
		//IL_0031: Expected O, but got Unknown
		//IL_0032: Unknown result type (might be due to invalid IL or missing references)
		//IL_003c: Expected O, but got Unknown
		//IL_003d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0047: Expected O, but got Unknown
		//IL_0048: Unknown result type (might be due to invalid IL or missing references)
		//IL_0052: Expected O, but got Unknown
		//IL_0053: Unknown result type (might be due to invalid IL or missing references)
		//IL_005d: Expected O, but got Unknown
		//IL_005e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0068: Expected O, but got Unknown
		//IL_0069: Unknown result type (might be due to invalid IL or missing references)
		//IL_0073: Expected O, but got Unknown
		//IL_0132: Unknown result type (might be due to invalid IL or missing references)
		//IL_013c: Expected O, but got Unknown
		//IL_01d0: Unknown result type (might be due to invalid IL or missing references)
		//IL_01da: Expected O, but got Unknown
		//IL_0591: Unknown result type (might be due to invalid IL or missing references)
		//IL_059b: Expected O, but got Unknown
		ComponentResourceManager componentResourceManager = new ComponentResourceManager(typeof(FormMFPInfo));
		buttonGetInfo = new Button();
		labelMFP = new Label();
		richTextBoxMachineInfo = new RichTextBox();
		buttonClose = new Button();
		label1 = new Label();
		labelMFP_Info = new Label();
		buttonMachineSelect = new Button();
		labelMFP_Select = new Label();
		labelMFP_Selected = new Label();
		((Control)this).SuspendLayout();
		((Control)buttonGetInfo).Anchor = (AnchorStyles)9;
		((Control)buttonGetInfo).AutoSize = true;
		((Control)buttonGetInfo).Location = new Point(402, 362);
		((Control)buttonGetInfo).Name = "buttonGetInfo";
		((Control)buttonGetInfo).Size = new Size(98, 23);
		((Control)buttonGetInfo).TabIndex = 2;
		((Control)buttonGetInfo).Text = "Get Info.";
		((ButtonBase)buttonGetInfo).UseVisualStyleBackColor = true;
		((Control)buttonGetInfo).Click += buttonGetInfo_Click;
		((Control)labelMFP).AutoSize = true;
		((Control)labelMFP).Font = new Font("MS UI Gothic", 9f, (FontStyle)0, (GraphicsUnit)3, (byte)128);
		((Control)labelMFP).ForeColor = Color.Blue;
		labelMFP.ImeMode = (ImeMode)0;
		((Control)labelMFP).Location = new Point(13, 11);
		((Control)labelMFP).Name = "labelMFP";
		((Control)labelMFP).Size = new Size(47, 12);
		((Control)labelMFP).TabIndex = 3;
		((Control)labelMFP).Text = "Machine";
		((Control)richTextBoxMachineInfo).Anchor = (AnchorStyles)15;
		((Control)richTextBoxMachineInfo).Font = new Font("MS UI Gothic", 9f, (FontStyle)0, (GraphicsUnit)3, (byte)128);
		((Control)richTextBoxMachineInfo).Location = new Point(12, 109);
		((Control)richTextBoxMachineInfo).Name = "richTextBoxMachineInfo";
		((TextBoxBase)richTextBoxMachineInfo).ReadOnly = true;
		((Control)richTextBoxMachineInfo).Size = new Size(488, 225);
		((Control)richTextBoxMachineInfo).TabIndex = 7;
		((Control)richTextBoxMachineInfo).Text = "";
		((Control)buttonClose).AutoSize = true;
		((Control)buttonClose).Location = new Point(12, 362);
		((Control)buttonClose).Name = "buttonClose";
		((Control)buttonClose).Size = new Size(75, 23);
		((Control)buttonClose).TabIndex = 1;
		((Control)buttonClose).Text = "Back";
		((ButtonBase)buttonClose).UseVisualStyleBackColor = true;
		((Control)buttonClose).Click += buttonClose_Click;
		((Control)label1).Anchor = (AnchorStyles)13;
		label1.BorderStyle = (BorderStyle)2;
		((Control)label1).Location = new Point(13, 350);
		((Control)label1).Name = "label1";
		((Control)label1).Size = new Size(490, 1);
		((Control)label1).TabIndex = 8;
		((Control)labelMFP_Info).AutoSize = true;
		((Control)labelMFP_Info).Location = new Point(60, 11);
		((Control)labelMFP_Info).Name = "labelMFP_Info";
		((Control)labelMFP_Info).Size = new Size(182, 12);
		((Control)labelMFP_Info).TabIndex = 4;
		((Control)labelMFP_Info).Text = "Select machine push button below.";
		((Control)buttonMachineSelect).Location = new Point(12, 36);
		((Control)buttonMachineSelect).Name = "buttonMachineSelect";
		((Control)buttonMachineSelect).Size = new Size(487, 23);
		((Control)buttonMachineSelect).TabIndex = 0;
		((Control)buttonMachineSelect).Text = "Select Machine";
		((ButtonBase)buttonMachineSelect).UseVisualStyleBackColor = true;
		((Control)buttonMachineSelect).Click += buttonMachineSelect_Click;
		((Control)labelMFP_Select).AutoSize = true;
		((Control)labelMFP_Select).Location = new Point(13, 76);
		((Control)labelMFP_Select).Name = "labelMFP_Select";
		((Control)labelMFP_Select).Size = new Size(105, 12);
		((Control)labelMFP_Select).TabIndex = 5;
		((Control)labelMFP_Select).Text = "Selected Machine : ";
		((Control)labelMFP_Selected).AutoSize = true;
		((Control)labelMFP_Selected).Location = new Point(120, 76);
		((Control)labelMFP_Selected).Name = "labelMFP_Selected";
		((Control)labelMFP_Selected).Size = new Size(0, 12);
		((Control)labelMFP_Selected).TabIndex = 6;
		((ContainerControl)this).AutoScaleDimensions = new SizeF(6f, 12f);
		((ContainerControl)this).AutoScaleMode = (AutoScaleMode)1;
		((Form)this).ClientSize = new Size(512, 392);
		((Control)this).Controls.Add((Control)(object)labelMFP_Selected);
		((Control)this).Controls.Add((Control)(object)labelMFP_Select);
		((Control)this).Controls.Add((Control)(object)buttonMachineSelect);
		((Control)this).Controls.Add((Control)(object)labelMFP_Info);
		((Control)this).Controls.Add((Control)(object)label1);
		((Control)this).Controls.Add((Control)(object)buttonClose);
		((Control)this).Controls.Add((Control)(object)richTextBoxMachineInfo);
		((Control)this).Controls.Add((Control)(object)labelMFP);
		((Control)this).Controls.Add((Control)(object)buttonGetInfo);
		((Form)this).FormBorderStyle = (FormBorderStyle)3;
		((Form)this).Icon = (Icon)componentResourceManager.GetObject("$this.Icon");
		((Form)this).MaximizeBox = false;
		((Form)this).MinimizeBox = false;
		((Control)this).Name = "FormMFPInfo";
		((Form)this).StartPosition = (FormStartPosition)4;
		((Control)this).Text = "Machine Informations";
		((Form)this).Load += FormMFPInfo_Load;
		((Control)this).ResumeLayout(false);
		((Control)this).PerformLayout();
	}

	private void InitializeComponent_MultiLang()
	{
		//IL_0011: Unknown result type (might be due to invalid IL or missing references)
		//IL_001b: Expected O, but got Unknown
		//IL_001c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0026: Expected O, but got Unknown
		//IL_0027: Unknown result type (might be due to invalid IL or missing references)
		//IL_0031: Expected O, but got Unknown
		//IL_0032: Unknown result type (might be due to invalid IL or missing references)
		//IL_003c: Expected O, but got Unknown
		//IL_003d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0047: Expected O, but got Unknown
		//IL_0048: Unknown result type (might be due to invalid IL or missing references)
		//IL_0052: Expected O, but got Unknown
		//IL_0053: Unknown result type (might be due to invalid IL or missing references)
		//IL_005d: Expected O, but got Unknown
		//IL_005e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0068: Expected O, but got Unknown
		//IL_0069: Unknown result type (might be due to invalid IL or missing references)
		//IL_0073: Expected O, but got Unknown
		//IL_0132: Unknown result type (might be due to invalid IL or missing references)
		//IL_013c: Expected O, but got Unknown
		//IL_01d0: Unknown result type (might be due to invalid IL or missing references)
		//IL_01da: Expected O, but got Unknown
		//IL_0594: Unknown result type (might be due to invalid IL or missing references)
		//IL_059e: Expected O, but got Unknown
		ComponentResourceManager componentResourceManager = new ComponentResourceManager(typeof(FormMFPInfo));
		buttonGetInfo = new Button();
		labelMFP = new Label();
		richTextBoxMachineInfo = new RichTextBox();
		buttonClose = new Button();
		label1 = new Label();
		labelMFP_Info = new Label();
		buttonMachineSelect = new Button();
		labelMFP_Select = new Label();
		labelMFP_Selected = new Label();
		((Control)this).SuspendLayout();
		((Control)buttonGetInfo).Anchor = (AnchorStyles)9;
		((Control)buttonGetInfo).AutoSize = true;
		((Control)buttonGetInfo).Location = new Point(402, 362);
		((Control)buttonGetInfo).Name = "buttonGetInfo";
		((Control)buttonGetInfo).Size = new Size(98, 23);
		((Control)buttonGetInfo).TabIndex = 2;
		((Control)buttonGetInfo).Text = "Get Info.";
		((ButtonBase)buttonGetInfo).UseVisualStyleBackColor = true;
		((Control)buttonGetInfo).Click += buttonGetInfo_Click;
		((Control)labelMFP).AutoSize = true;
		((Control)labelMFP).Font = new Font("MS UI Gothic", 9f, (FontStyle)0, (GraphicsUnit)3, (byte)128);
		((Control)labelMFP).ForeColor = Color.Blue;
		labelMFP.ImeMode = (ImeMode)0;
		((Control)labelMFP).Location = new Point(13, 11);
		((Control)labelMFP).Name = "labelMFP";
		((Control)labelMFP).Size = new Size(47, 12);
		((Control)labelMFP).TabIndex = 3;
		((Control)labelMFP).Text = "Machine";
		((Control)richTextBoxMachineInfo).Anchor = (AnchorStyles)15;
		((Control)richTextBoxMachineInfo).Font = new Font("MS UI Gothic", 9f, (FontStyle)0, (GraphicsUnit)3, (byte)128);
		((Control)richTextBoxMachineInfo).Location = new Point(12, 109);
		((Control)richTextBoxMachineInfo).Name = "richTextBoxMachineInfo";
		((TextBoxBase)richTextBoxMachineInfo).ReadOnly = true;
		((Control)richTextBoxMachineInfo).Size = new Size(488, 225);
		((Control)richTextBoxMachineInfo).TabIndex = 7;
		((Control)richTextBoxMachineInfo).Text = "";
		((Control)buttonClose).AutoSize = true;
		((Control)buttonClose).Location = new Point(12, 362);
		((Control)buttonClose).Name = "buttonClose";
		((Control)buttonClose).Size = new Size(75, 23);
		((Control)buttonClose).TabIndex = 1;
		((Control)buttonClose).Text = "Back";
		((ButtonBase)buttonClose).UseVisualStyleBackColor = true;
		((Control)buttonClose).Click += buttonClose_Click;
		((Control)label1).Anchor = (AnchorStyles)13;
		label1.BorderStyle = (BorderStyle)2;
		((Control)label1).Location = new Point(13, 350);
		((Control)label1).Name = "label1";
		((Control)label1).Size = new Size(490, 1);
		((Control)label1).TabIndex = 8;
		((Control)labelMFP_Info).AutoSize = true;
		((Control)labelMFP_Info).Location = new Point(60, 11);
		((Control)labelMFP_Info).Name = "labelMFP_Info";
		((Control)labelMFP_Info).Size = new Size(182, 12);
		((Control)labelMFP_Info).TabIndex = 4;
		((Control)labelMFP_Info).Text = "Select machine push button below.";
		((Control)buttonMachineSelect).Location = new Point(12, 36);
		((Control)buttonMachineSelect).Name = "buttonMachineSelect";
		((Control)buttonMachineSelect).Size = new Size(487, 23);
		((Control)buttonMachineSelect).TabIndex = 0;
		((Control)buttonMachineSelect).Text = "Select Machine";
		((ButtonBase)buttonMachineSelect).UseVisualStyleBackColor = true;
		((Control)buttonMachineSelect).Click += buttonMachineSelect_Click;
		((Control)labelMFP_Select).AutoSize = true;
		((Control)labelMFP_Select).Location = new Point(13, 76);
		((Control)labelMFP_Select).Name = "labelMFP_Select";
		((Control)labelMFP_Select).Size = new Size(105, 12);
		((Control)labelMFP_Select).TabIndex = 5;
		((Control)labelMFP_Select).Text = "Selected Machine : ";
		((Control)labelMFP_Selected).AutoSize = true;
		((Control)labelMFP_Selected).Location = new Point(160, 76);
		((Control)labelMFP_Selected).Name = "labelMFP_Selected";
		((Control)labelMFP_Selected).Size = new Size(0, 12);
		((Control)labelMFP_Selected).TabIndex = 6;
		((ContainerControl)this).AutoScaleDimensions = new SizeF(6f, 12f);
		((ContainerControl)this).AutoScaleMode = (AutoScaleMode)1;
		((Form)this).ClientSize = new Size(512, 392);
		((Control)this).Controls.Add((Control)(object)labelMFP_Selected);
		((Control)this).Controls.Add((Control)(object)labelMFP_Select);
		((Control)this).Controls.Add((Control)(object)buttonMachineSelect);
		((Control)this).Controls.Add((Control)(object)labelMFP_Info);
		((Control)this).Controls.Add((Control)(object)label1);
		((Control)this).Controls.Add((Control)(object)buttonClose);
		((Control)this).Controls.Add((Control)(object)richTextBoxMachineInfo);
		((Control)this).Controls.Add((Control)(object)labelMFP);
		((Control)this).Controls.Add((Control)(object)buttonGetInfo);
		((Form)this).FormBorderStyle = (FormBorderStyle)3;
		((Form)this).Icon = (Icon)componentResourceManager.GetObject("$this.Icon");
		((Form)this).MaximizeBox = false;
		((Form)this).MinimizeBox = false;
		((Control)this).Name = "FormMFPInfo";
		((Form)this).StartPosition = (FormStartPosition)4;
		((Control)this).Text = "Machine Informations";
		((Form)this).Load += FormMFPInfo_Load;
		((Control)this).ResumeLayout(false);
		((Control)this).PerformLayout();
	}
}
