using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Reflection;
using System.Windows.Forms;
using CreateFolder.Properties;
using log4net;

namespace CreateFolder;

public class FormMFPSelect : Form
{
	private static readonly ILog LOG = LogManager.GetLogger(MethodBase.GetCurrentMethod().DeclaringType);

	private static string MachineLang = string.Empty;

	private static FormMFPSelect form;

	private string displayedContents = string.Empty;

	private IContainer components;

	private MachineSelectControl machineSelectControl;

	private Button buttonCancel;

	private Button buttonEnter;

	public FormMFPSelect(string machineLang)
	{
		MachineLang = machineLang;
		if (machineLang.Equals("ja") || machineLang.Equals("en"))
		{
			InitializeComponent(machineLang);
		}
		else
		{
			InitializeComponent_MultiLang(machineLang);
		}
		Control[] allControls = CreateFolderUtil.GetAllControls((Control)(object)this);
		CreateFolderUtil.ResetFontToControl(((object)this).GetType().Name, allControls);
		((Control)this).Text = Resources.FORM_MFPSELECT_CAPTION;
		((Control)buttonCancel).Text = Resources.ITEM_BUTTON_CANCEL;
		((Control)buttonEnter).Text = Resources.ITEM_BUTTON_SET;
	}

	public static void initialize(string machineLang)
	{
		form = new FormMFPSelect(machineLang);
		form.machineSelectControl.initialize();
	}

	public static string GetDisplayedIPAddress()
	{
		//IL_0029: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		((Form)form).StartPosition = (FormStartPosition)4;
		((Form)form).ShowDialog();
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return form.displayedContents;
	}

	public static void setMachineList(List<string> machines)
	{
		form.machineSelectControl.setMachineList(machines);
	}

	public static string getIpAddress()
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		Dictionary<MachineSelectControl.ADDRESS_FORM, string> selectedAddress = form.machineSelectControl.getSelectedAddress();
		string result = (selectedAddress.ContainsKey(MachineSelectControl.ADDRESS_FORM.IP) ? selectedAddress[MachineSelectControl.ADDRESS_FORM.IP] : string.Empty);
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return result;
	}

	private void buttonCancel_Click(object sender, EventArgs e)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		form.displayedContents = string.Empty;
		((Control)this).Visible = false;
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
	}

	private void buttonEnter_Click(object sender, EventArgs e)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		Dictionary<MachineSelectControl.ADDRESS_FORM, string> selectedAddress = machineSelectControl.getSelectedAddress();
		displayedContents = (selectedAddress.ContainsKey(MachineSelectControl.ADDRESS_FORM.NAME) ? selectedAddress[MachineSelectControl.ADDRESS_FORM.NAME] : selectedAddress[MachineSelectControl.ADDRESS_FORM.IP]);
		if (!string.IsNullOrEmpty(displayedContents))
		{
			((Control)this).Visible = false;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
	}

	private void machineSelectControl_Load(object sender, EventArgs e)
	{
	}

	protected override void Dispose(bool disposing)
	{
		if (disposing && components != null)
		{
			components.Dispose();
		}
		((Form)this).Dispose(disposing);
	}

	private void InitializeComponent(string lang)
	{
		//IL_0011: Unknown result type (might be due to invalid IL or missing references)
		//IL_001b: Expected O, but got Unknown
		//IL_001c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0026: Expected O, but got Unknown
		//IL_0235: Unknown result type (might be due to invalid IL or missing references)
		//IL_023f: Expected O, but got Unknown
		ComponentResourceManager componentResourceManager = new ComponentResourceManager(typeof(FormMFPSelect));
		buttonCancel = new Button();
		buttonEnter = new Button();
		machineSelectControl = new MachineSelectControl(lang);
		((Control)this).SuspendLayout();
		((Control)buttonCancel).AutoSize = true;
		((ButtonBase)buttonCancel).ImeMode = (ImeMode)0;
		((Control)buttonCancel).Location = new Point(370, 242);
		((Control)buttonCancel).Name = "buttonCancel";
		((Control)buttonCancel).Size = new Size(75, 23);
		((Control)buttonCancel).TabIndex = 13;
		((Control)buttonCancel).Text = "Cancel";
		((ButtonBase)buttonCancel).UseVisualStyleBackColor = true;
		((Control)buttonCancel).Click += buttonCancel_Click;
		((Control)buttonEnter).AutoSize = true;
		((ButtonBase)buttonEnter).ImeMode = (ImeMode)0;
		((Control)buttonEnter).Location = new Point(282, 242);
		((Control)buttonEnter).Name = "buttonEnter";
		((Control)buttonEnter).Size = new Size(75, 23);
		((Control)buttonEnter).TabIndex = 12;
		((Control)buttonEnter).Text = "Set";
		((ButtonBase)buttonEnter).UseVisualStyleBackColor = true;
		((Control)buttonEnter).Click += buttonEnter_Click;
		((Control)machineSelectControl).Location = new Point(11, 12);
		((Control)machineSelectControl).Name = "machineSelectControl";
		((Control)machineSelectControl).Size = new Size(442, 224);
		((Control)machineSelectControl).TabIndex = 0;
		((UserControl)machineSelectControl).Load += machineSelectControl_Load;
		((ContainerControl)this).AutoScaleDimensions = new SizeF(6f, 12f);
		((ContainerControl)this).AutoScaleMode = (AutoScaleMode)1;
		((Form)this).ClientSize = new Size(459, 277);
		((Control)this).Controls.Add((Control)(object)buttonCancel);
		((Control)this).Controls.Add((Control)(object)buttonEnter);
		((Control)this).Controls.Add((Control)(object)machineSelectControl);
		((Form)this).Icon = (Icon)componentResourceManager.GetObject("$this.Icon");
		((Control)this).Name = "FormMFPSelect";
		((Form)this).StartPosition = (FormStartPosition)4;
		((Control)this).Text = "Select Machine";
		((Control)this).ResumeLayout(false);
		((Control)this).PerformLayout();
	}

	private void InitializeComponent_MultiLang(string lang)
	{
		//IL_0011: Unknown result type (might be due to invalid IL or missing references)
		//IL_001b: Expected O, but got Unknown
		//IL_001c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0026: Expected O, but got Unknown
		//IL_021e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0228: Expected O, but got Unknown
		ComponentResourceManager componentResourceManager = new ComponentResourceManager(typeof(FormMFPSelect));
		buttonCancel = new Button();
		buttonEnter = new Button();
		machineSelectControl = new MachineSelectControl(lang);
		((Control)this).SuspendLayout();
		((Control)buttonCancel).AutoSize = true;
		((ButtonBase)buttonCancel).ImeMode = (ImeMode)0;
		((Control)buttonCancel).Location = new Point(420, 242);
		((Control)buttonCancel).Name = "buttonCancel";
		((Control)buttonCancel).Size = new Size(75, 23);
		((Control)buttonCancel).TabIndex = 13;
		((Control)buttonCancel).Text = "Cancel";
		((ButtonBase)buttonCancel).UseVisualStyleBackColor = true;
		((Control)buttonCancel).Click += buttonCancel_Click;
		((Control)buttonEnter).AutoSize = true;
		((ButtonBase)buttonEnter).ImeMode = (ImeMode)0;
		((Control)buttonEnter).Location = new Point(332, 242);
		((Control)buttonEnter).Name = "buttonEnter";
		((Control)buttonEnter).Size = new Size(75, 23);
		((Control)buttonEnter).TabIndex = 12;
		((Control)buttonEnter).Text = "Set";
		((ButtonBase)buttonEnter).UseVisualStyleBackColor = true;
		((Control)buttonEnter).Click += buttonEnter_Click;
		((Control)machineSelectControl).Location = new Point(11, 12);
		((Control)machineSelectControl).Name = "machineSelectControl";
		((Control)machineSelectControl).Size = new Size(492, 224);
		((Control)machineSelectControl).TabIndex = 0;
		((ContainerControl)this).AutoScaleDimensions = new SizeF(6f, 12f);
		((ContainerControl)this).AutoScaleMode = (AutoScaleMode)1;
		((Form)this).ClientSize = new Size(509, 277);
		((Control)this).Controls.Add((Control)(object)buttonCancel);
		((Control)this).Controls.Add((Control)(object)buttonEnter);
		((Control)this).Controls.Add((Control)(object)machineSelectControl);
		((Form)this).Icon = (Icon)componentResourceManager.GetObject("$this.Icon");
		((Control)this).Name = "FormMFPSelect";
		((Form)this).StartPosition = (FormStartPosition)4;
		((Control)this).Text = "Select Machine";
		((Control)this).ResumeLayout(false);
		((Control)this).PerformLayout();
	}
}
