using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.Specialized;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Management;
using System.Net;
using System.Net.NetworkInformation;
using System.Net.Security;
using System.Reflection;
using System.Security.AccessControl;
using System.Security.Cryptography.X509Certificates;
using System.Text;
using System.Text.RegularExpressions;
using System.Threading;
using System.Windows.Forms;
using CreateFolder.Properties;
using log4net;

namespace CreateFolder;

public class FormMain : Form
{
	public enum Mode
	{
		SIMPLE,
		DIALOG,
		ST_NOSTATE
	}

	private enum ErrorCode
	{
		NOERROR,
		ADRESS_EMPTY,
		ADRESS_FORMAT_ERROR,
		MFP_NOT_FOUND,
		MFP_NOT_SUPPORTED,
		END
	}

	private string hostname = string.Empty;

	private string ipAddr = string.Empty;

	public string HELP_FILE = "help\\Help.html";

	public string HELP_FILE_BASE = "help\\HelpBase.html";

	public string HELP_FILE_IPBASE = "help\\HelpIPBase.html";

	public string HELP_FILE_FOLDERBASE = "help\\HelpFolderBase.html";

	private FolderSetting fs = new FolderSetting();

	private static readonly ILog LOG = LogManager.GetLogger(MethodBase.GetCurrentMethod().DeclaringType);

	private FormSettingHeadLine fSettingHeadline;

	private bool dhcpCaution;

	public readonly string URI_FORMAT_BASE_ADDRESS = "{0}://{1}/";

	public readonly string URI_FORMAT_AUTHFORM = "{0}web/guest/{1}/websys/webArch/authForm.cgi";

	private string machineLang = string.Empty;

	public string primaxAdminPasswd = "";

	private IContainer components;

	private MainMenu mainMenu1;

	private MenuItem menuItemFile;

	private MenuItem menuItemExit;

	private MenuItem menuItemSecurity;

	private MenuItem menuItemVersion;

	private StatusStrip statusStripFolder;

	private ToolStripStatusLabel toolStripStatusLabelProgress;

	private TabControl tabControlCustom;

	private TabPage tabPage1;

	private Label label11_comment;

	private Button btnCreateFolder;

	private TextBox textBoxFolderName;

	private TextBox textBoxFolderPath;

	private ComboBox comboBoxUserName;

	private Label label11_UserName;

	private Label label11_FolderName;

	private Label label11_FolderPath;

	private TabPage tabPage2;

	private ComboBox comboBoxFolder;

	private Label label12_GuideMessage;

	private Label label12_comment;

	private Button btnAdd;

	private TextBox textBoxPassword;

	private TextBox textBoxDestination;

	private Button btnSelectFolder;

	private ToolTip toolTipPath;

	private ToolStripStatusLabel toolStripStatusLabelWork;

	private Label label11_GuideMessage;

	private Label label12_Password;

	private Label label12_UserName;

	private Label label12_Path;

	private Label label12_Destination;

	private Label label12_Machine;

	private Label label12_Folder;

	private LinkLabel linkLabelHelp;

	private MenuItem menuItemClose;

	private Button btnConnectTest;

	private RadioButton radioButtonCreateFolder;

	private Label label_T1_FolderPath;

	private Label label_T1_SharedName;

	private Label label_T1_UserName;

	private Label label_T1_SelectMessage;

	private Label label_T1_CreateMessage;

	private Button btn_T1_SelectFolder;

	private TextBox textBox_T1_FolderPath;

	private TextBox textBox_T1_SharedName;

	private ComboBox comboBox_T1_UserName;

	private RadioButton radioButtonSelectFolder;

	private LinkLabel linkLabelFolderSend;

	private Button btnHeadLine;

	private Label label12_PasswordConfirm;

	private TextBox textBoxPasswordConfirm;

	private ComboBox comboBoxSendPath;

	public ComboBox comboBoxPCUserName;

	private MachineSelectControl machineSelectControl;

	internal string TextBoxFolderPath
	{
		get
		{
			return ((Control)textBoxFolderPath).Text;
		}
		set
		{
			((Control)textBoxFolderPath).Text = value;
		}
	}

	internal ComboBox ComboBoxUser
	{
		get
		{
			return comboBoxUserName;
		}
		set
		{
			comboBoxUserName = value;
		}
	}

	internal ComboBox ComboBoxUser_share
	{
		get
		{
			return comboBox_T1_UserName;
		}
		set
		{
			comboBox_T1_UserName = value;
		}
	}

	internal ComboBox ComboBoxPCUser
	{
		get
		{
			return comboBoxPCUserName;
		}
		set
		{
			comboBoxPCUserName = value;
		}
	}

	internal ComboBox ComboBoxFolder
	{
		get
		{
			return comboBoxFolder;
		}
		set
		{
			comboBoxFolder = value;
		}
	}

	internal MachineSelectControl mcSelectControl
	{
		get
		{
			return machineSelectControl;
		}
		set
		{
			machineSelectControl = value;
		}
	}

	public bool DhcpCaution
	{
		get
		{
			return dhcpCaution;
		}
		set
		{
			dhcpCaution = value;
		}
	}

	public FormMain(Mode mode, string lang)
	{
		machineLang = lang;
		if (machineLang.Equals("ja") || machineLang.Equals("en"))
		{
			InitializeComponent();
		}
		else
		{
			InitializeComponent_MultiLang();
		}
		fSettingHeadline = new FormSettingHeadLine(lang);
		Control[] allControls = CreateFolderUtil.GetAllControls((Control)(object)this);
		CreateFolderUtil.ResetFontToControl(((object)this).GetType().Name, allControls);
		((Control)this).Text = Resources.TXT_DETAIL_SETTING;
		menuItemFile.Text = Resources.FORM_MAIN_MENU_ITEM_FILE;
		menuItemClose.Text = Resources.FORM_MAIN_MENU_ITEM_CLOSE;
		menuItemSecurity.Text = Resources.MENU_ITEM_SECURITY;
		menuItemVersion.Text = Resources.MENU_ITEM_VERSION;
		menuItemExit.Text = Resources.FORM_MAIN_MENU_ITEM_EXIT;
		((ToolStripItem)toolStripStatusLabelProgress).Text = Resources.FORM_MAIN_STATUS;
		((Control)label11_comment).Text = Resources.LABEL_P2_001;
		((Control)radioButtonCreateFolder).Text = Resources.LABEL_P2_002;
		((Control)label11_FolderName).Text = Resources.FORM_MAIN_FOLDER_NAME;
		((Control)label11_FolderPath).Text = Resources.FORM_MAIN_FOLDER_PATH;
		((Control)label11_UserName).Text = Resources.CREATE_HTML_DEFAULT_USER;
		((Control)label_T1_CreateMessage).Text = Resources.FORM_MAIN_CREATE_FOLDER_MESSAGE;
		((Control)label11_GuideMessage).Text = Resources.FORM_MAIN_SELECT_USER_MESSAGE;
		((Control)radioButtonSelectFolder).Text = Resources.FORM_MAIN_NON_SHARED_FOLDER_PATH;
		((Control)label_T1_FolderPath).Text = Resources.LABEL_P2_005;
		((Control)label_T1_SharedName).Text = Resources.FORM_MAIN_FOLDER_NAME;
		((Control)label_T1_UserName).Text = Resources.CREATE_HTML_DEFAULT_USER;
		((Control)label_T1_SelectMessage).Text = Resources.FORM_MAIN_SETTING_FOLDER_MESSAGE;
		setTextBoxInitialString(textBox_T1_SharedName, Resources.TXT_P2_INITIAL_001);
		setTextBoxInitialString(textBox_T1_FolderPath, Resources.TXT_P2_INITIAL_003);
		((Control)btnSelectFolder).Text = Resources.ITEM_BUTTON_REFFER;
		((Control)btn_T1_SelectFolder).Text = Resources.ITEM_BUTTON_REFFER;
		((Control)btnCreateFolder).Text = Resources.FORM_MAIN_CREATE_BUTTON;
		((Control)textBoxFolderName).Text = Resources.DEFAULT_FOLDER_NAME;
		((Control)tabPage1).Text = Resources.ITEM_CREATE_FOLDER;
		((Control)tabPage2).Text = Resources.REGISTER_A_DESTINATION;
		((Control)label12_comment).Text = Resources.REGISTER_DESTINATION_ON_THE_DEVICE;
		((Control)label12_Destination).Text = Resources.CREATE_HTML_DEFAULT_DEST;
		((Control)label12_Folder).Text = Resources.FORM_MAIN_FOLDER;
		((Control)label12_GuideMessage).Text = Resources.FORM_MAIN_SELECT_FOLDER_MESSAGE;
		((Control)label12_UserName).Text = Resources.CREATE_HTML_DEFAULT_USER;
		((Control)label12_Password).Text = Resources.FORM_ADMIN_AUTH_PASSWORD;
		((Control)label12_PasswordConfirm).Text = Resources.FORM_MAIN_CONFIRM_PASSWORD;
		((Control)label12_Path).Text = Resources.FORM_MAIN_PATH_NAME;
		((Control)label12_Machine).Text = Resources.FORM_MAIN_MACHINE;
		((Control)linkLabelFolderSend).Text = Resources.FORM_MAIN_FOLDER_SEND_PROCEDURE_LINK_MESSAGE;
		((Control)linkLabelHelp).Text = Resources.FORM_MAIN_DIRECT_REGIST_PROCEDURE_MESSAGE;
		((Control)btnHeadLine).Text = Resources.SETTING_HEADLINE;
		((Control)btnConnectTest).Text = Resources.FORM_MAIN_COMMUNICATION_TEST_BUTTON;
		((Control)btnAdd).Text = Resources.FORM_MAIN_REGIST_BUTTON;
		((Control)linkLabelFolderSend).Visible = false;
		((Control)linkLabelHelp).Visible = false;
		if (mode == Mode.SIMPLE)
		{
			string winVersion = getWinVersion();
			Console.WriteLine("1:" + DateTime.Now);
			FormSplash formSplash = new FormSplash();
			((Control)formSplash).Show();
			((Control)formSplash).Refresh();
			formSplash.ProgressMsg = Resources.INITIALIZE_MSG_1_4;
			formSplash.ProgressRatio = 25;
			Application.DoEvents();
			((ToolStripItem)toolStripStatusLabelWork).Text = Resources.INITIALIZE_MSG_1_4;
			LOG.InfoFormat("{0}：1:InitializeStart OS Version = {1}", (object)MethodBase.GetCurrentMethod().Name, (object)winVersion);
			LOG.InfoFormat("{0}：設定情報を初期化中 (1/4)……", (object)MethodBase.GetCurrentMethod().Name);
			Thread.Sleep(500);
			((Control)textBoxFolderPath).Text = CreateFolderUtil.getWindowsFolderName(CreateFolderUtil.getDesktopDirectory());
			Console.WriteLine("2:" + DateTime.Now);
			formSplash.ProgressMsg = Resources.INITIALIZE_MSG_2_4;
			((ToolStripItem)toolStripStatusLabelWork).Text = Resources.INITIALIZE_MSG_2_4;
			LOG.InfoFormat("{0}：ユーザー情報を取得中 (2/4)……", (object)MethodBase.GetCurrentMethod().Name);
			formSplash.ProgressRatio = 50;
			Application.DoEvents();
			fs.setComboBoxUserList(comboBoxUserName);
			fs.setComboBoxUserList(comboBox_T1_UserName);
			Console.WriteLine("3:" + DateTime.Now);
			formSplash.ProgressMsg = Resources.INITIALIZE_MSG_3_4;
			((ToolStripItem)toolStripStatusLabelWork).Text = Resources.INITIALIZE_MSG_3_4;
			LOG.InfoFormat("{0}：共有フォルダーを取得中 (3/4)……", (object)MethodBase.GetCurrentMethod().Name);
			formSplash.ProgressRatio = 75;
			Application.DoEvents();
			fs.setSharedFolderListTable();
			fs.setComboBoxFolderList(comboBoxFolder);
			fs.setComboBoxPCUserList(comboBoxFolder, comboBoxPCUserName);
			Thread.Sleep(500);
			Console.WriteLine("4:" + DateTime.Now);
			formSplash.ProgressMsg = Resources.INITIALIZE_MSG_4_4;
			((ToolStripItem)toolStripStatusLabelWork).Text = Resources.INITIALIZE_MSG_4_4;
			LOG.InfoFormat("{0}：機器情報を取得中 (4/4)……", (object)MethodBase.GetCurrentMethod().Name);
			formSplash.ProgressRatio = 100;
			Application.DoEvents();
			machineSelectControl.initialize();
			Application.DoEvents();
			((Control)formSplash).Update();
			Thread.Sleep(500);
			Console.WriteLine("5:" + DateTime.Now);
			LOG.InfoFormat("{0}：初期化完了！……", (object)MethodBase.GetCurrentMethod().Name);
			((ToolStripItem)toolStripStatusLabelWork).Text = Resources.INITIALIZE_MSG_5_4;
			((Form)formSplash).Close();
			((Component)(object)formSplash).Dispose();
			((ToolStripItem)toolStripStatusLabelWork).Text = "  ";
			menuItemClose.Visible = false;
			((Form)this).Activate();
		}
		else
		{
			Color foreColor = Color.FromArgb(63, 72, 204);
			((Control)label11_FolderName).ForeColor = foreColor;
			((Control)label11_FolderPath).ForeColor = foreColor;
			((Control)label11_UserName).ForeColor = foreColor;
			((Control)label_T1_FolderPath).ForeColor = foreColor;
			((Control)label_T1_SharedName).ForeColor = foreColor;
			((Control)label_T1_UserName).ForeColor = foreColor;
			((Control)label12_Destination).ForeColor = foreColor;
			((Control)label12_Folder).ForeColor = foreColor;
			((Control)label12_UserName).ForeColor = foreColor;
			((Control)label12_PasswordConfirm).ForeColor = foreColor;
			((Control)label12_Machine).ForeColor = foreColor;
			((Control)label12_Path).ForeColor = foreColor;
			((Control)label12_Password).ForeColor = foreColor;
			menuItemFile.Visible = false;
			menuItemSecurity.Visible = false;
			menuItemVersion.Visible = false;
		}
	}

	public void SetMachineInfo(List<string> machineList)
	{
		fs.setComboBoxMFPList(machineSelectControl, machineList);
	}

	public void updateSharedFolderInfo()
	{
		fs.setSharedFolderListTable();
		fs.setComboBoxFolderList(comboBoxFolder, ((Control)textBoxFolderName).Text);
	}

	private void menuItemSetup_Click(object sender, EventArgs e)
	{
		//IL_0039: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		((ToolStripItem)toolStripStatusLabelWork).Text = string.Empty;
		((Form)new FormSetup(machineLang)).ShowDialog();
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
	}

	private void tabControlCustom_SelectedIndexChanged(object sender, EventArgs e)
	{
		//IL_02eb: Unknown result type (might be due to invalid IL or missing references)
		//IL_02f5: Expected O, but got Unknown
		//IL_00b9: Unknown result type (might be due to invalid IL or missing references)
		//IL_00c3: Expected O, but got Unknown
		//IL_00f5: Unknown result type (might be due to invalid IL or missing references)
		//IL_00ff: Expected O, but got Unknown
		//IL_035f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0369: Expected O, but got Unknown
		//IL_015a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0164: Expected O, but got Unknown
		//IL_01a2: Unknown result type (might be due to invalid IL or missing references)
		//IL_01ac: Expected O, but got Unknown
		//IL_0214: Unknown result type (might be due to invalid IL or missing references)
		//IL_021e: Expected O, but got Unknown
		//IL_025c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0266: Expected O, but got Unknown
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		if (tabControlCustom.SelectedIndex == 1)
		{
			fs.setSharedFolderListTable();
			fs.setComboBoxFolderList(comboBoxFolder, ((Control)textBoxFolderName).Text);
			fs.setComboBoxPCUserList(comboBoxFolder, comboBoxPCUserName);
			if (((Control)textBoxDestination).Text.Length < 1 || ((Control)textBoxDestination).Text == Resources.TXT_P4_INITIAL_001)
			{
				((Control)textBoxDestination).Text = Resources.TXT_P4_INITIAL_001;
				((Control)textBoxDestination).Font = new Font(Resources.FONT, 9f, (FontStyle)2);
				((Control)textBoxDestination).ForeColor = Color.FromArgb(195, 195, 195);
			}
			else
			{
				((Control)textBoxDestination).Font = new Font(Resources.FONT, 9f, (FontStyle)0);
				((Control)textBoxDestination).ForeColor = Color.Black;
			}
			if (((Control)textBoxPassword).Text.Length < 1 || ((Control)textBoxPassword).Text == Resources.TXT_P3_INITIAL_001)
			{
				((Control)textBoxPassword).Text = Resources.TXT_P3_INITIAL_001;
				((Control)textBoxPassword).Font = new Font(Resources.FONT, 9f, (FontStyle)2);
				((Control)textBoxPassword).ForeColor = Color.FromArgb(195, 195, 195);
				textBoxPassword.PasswordChar = '\0';
			}
			else
			{
				((Control)textBoxPassword).Font = new Font(Resources.FONT, 9f, (FontStyle)0);
				((Control)textBoxPassword).ForeColor = Color.Black;
				textBoxPassword.PasswordChar = '*';
			}
			if (((Control)textBoxPasswordConfirm).Text.Length < 1 || ((Control)textBoxPasswordConfirm).Text == Resources.TXT_P3_INITIAL_002)
			{
				((Control)textBoxPasswordConfirm).Text = Resources.TXT_P3_INITIAL_002;
				((Control)textBoxPasswordConfirm).Font = new Font(Resources.FONT, 9f, (FontStyle)2);
				((Control)textBoxPasswordConfirm).ForeColor = Color.FromArgb(195, 195, 195);
				textBoxPasswordConfirm.PasswordChar = '\0';
			}
			else
			{
				((Control)textBoxPasswordConfirm).Font = new Font(Resources.FONT, 9f, (FontStyle)0);
				((Control)textBoxPasswordConfirm).ForeColor = Color.Black;
				textBoxPasswordConfirm.PasswordChar = '*';
			}
			((Control)linkLabelFolderSend).Visible = false;
			((Control)linkLabelHelp).Visible = false;
		}
		else
		{
			if (((Control)textBoxFolderName).Text.Length < 1 || ((Control)textBoxFolderName).Text == Resources.TXT_P2_INITIAL_001)
			{
				((Control)textBoxFolderName).Text = Resources.TXT_P2_INITIAL_001;
				((Control)textBoxFolderName).Font = new Font(Resources.FONT, 9f, (FontStyle)2);
				((Control)textBoxFolderName).ForeColor = Color.FromArgb(195, 195, 195);
			}
			if (((Control)textBoxFolderPath).Text.Length < 1 || ((Control)textBoxFolderPath).Text == Resources.TXT_P2_INITIAL_002)
			{
				((Control)textBoxFolderPath).Text = Resources.TXT_P2_INITIAL_002;
				((Control)textBoxFolderPath).Font = new Font(Resources.FONT, 9f, (FontStyle)2);
				((Control)textBoxFolderPath).ForeColor = Color.FromArgb(195, 195, 195);
			}
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
	}

	private void menuItemClose_Click(object sender, EventArgs e)
	{
		LOG.InfoFormat("{0}：アプリ終了\n*********************\n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		((Form)this).Close();
	}

	private void linkLabelMainIP_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
	{
		//IL_002b: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：IP設定手順表示リンク押下 (Main)", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		FormHelp formHelp = new FormHelp(HELP_FILE_IPBASE);
		((Form)formHelp).ShowDialog((IWin32Window)(object)this);
		((Component)(object)formHelp).Dispose();
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
	}

	private void buttonConnectTest_Click(object sender, EventArgs e)
	{
		//IL_00ab: Unknown result type (might be due to invalid IL or missing references)
		//IL_013d: Unknown result type (might be due to invalid IL or missing references)
		//IL_018c: Unknown result type (might be due to invalid IL or missing references)
		//IL_020c: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		((Control)btnAdd).Enabled = false;
		((Control)btnConnectTest).Enabled = false;
		((Control)btnHeadLine).Enabled = false;
		((Control)this).Cursor = Cursors.WaitCursor;
		try
		{
			string text = machineSelectControl.getSelectedAddress(msgOn: false)[MachineSelectControl.ADDRESS_FORM.IP];
			int num = 0;
			int num2 = 1;
			int num3 = num;
			ErrorCode errorCode = IsConnectMFP(text);
			switch (errorCode)
			{
			case ErrorCode.ADRESS_EMPTY:
			case ErrorCode.ADRESS_FORMAT_ERROR:
				MessageBox.Show(Resources.ERR_SET_ILLEGAL_FORMAT_1_2 + "\n" + Resources.ERR_SET_ILLEGAL_FORMAT_2_2, Resources.CONNECTION_TEST_RESULT_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
				LOG.ErrorFormat("{0}：IPアドレス入力エラー：IPアドレス無し\n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
				num3 = num2;
				break;
			case ErrorCode.MFP_NOT_FOUND:
			{
				StringBuilder stringBuilder2 = new StringBuilder();
				stringBuilder2.AppendFormat("{0}\n\n", Resources.CONNECTION_FAILED_MFP_NOT_FOUND_MSG_1_4);
				stringBuilder2.AppendFormat("  {0}\n", Resources.CANT_CONNECT_MACHINE_ERROR_TEXT_6_5);
				stringBuilder2.AppendFormat("  {0}\n", Resources.CANT_CONNECT_MACHINE_ERROR_TEXT_2_5);
				stringBuilder2.AppendFormat("  {0}\n", Resources.CANT_CONNECT_MACHINE_ERROR_TEXT_3_5);
				stringBuilder2.AppendFormat("  {0}", Resources.CANT_CONNECT_MACHINE_ERROR_TEXT_4_5);
				MessageBox.Show(stringBuilder2.ToString(), Resources.CONNECTION_TEST_RESULT_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
				LOG.InfoFormat("{0}：IPアドレス：フォーマットエラー：{1}\n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)text);
				num3 = num2;
				break;
			}
			case ErrorCode.MFP_NOT_SUPPORTED:
			{
				StringBuilder stringBuilder = new StringBuilder();
				stringBuilder.AppendFormat("{0}\n\n", Resources.MACHINE_NOT_SUPPORTED);
				MessageBox.Show(stringBuilder.ToString(), Resources.CONNECTION_TEST_RESULT_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
				LOG.DebugFormat("{0}：not supported machine：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)text);
				num3 = num2;
				break;
			}
			case ErrorCode.NOERROR:
				LOG.DebugFormat("{0}：IP Address：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)text);
				break;
			default:
				LOG.ErrorFormat("{0}：State Error：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)errorCode);
				break;
			}
			if (num3 == num)
			{
				MessageBox.Show(Resources.CONNECTION_SUCESS_MSG, Resources.CONNECTION_TEST_RESULT_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)64);
			}
		}
		finally
		{
			((Control)btnAdd).Enabled = true;
			((Control)btnConnectTest).Enabled = true;
			((Control)btnHeadLine).Enabled = true;
			((Control)this).Cursor = Cursors.Default;
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		}
	}

	private ErrorCode IsConnectMFP(string ipAddr)
	{
		ErrorCode result = ErrorCode.NOERROR;
		if (string.IsNullOrEmpty(ipAddr))
		{
			LOG.ErrorFormat("{0}：IPアドレス入力エラー：IPアドレス無し\n", (object)MethodBase.GetCurrentMethod().Name);
			return ErrorCode.ADRESS_EMPTY;
		}
		if (!Regex.IsMatch(ipAddr, "^\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}$"))
		{
			LOG.InfoFormat("{0}：IPアドレス：フォーマットエラー：{1}\n", (object)MethodBase.GetCurrentMethod().Name, (object)ipAddr);
			return ErrorCode.ADRESS_FORMAT_ERROR;
		}
		MachineControl machineControl = new MachineControl(machineLang);
		machineControl.SetPrimaxModel(FormWizard.IsPrimax(FormWizard.GetHostNameFromIP(ipAddr)));
		machineControl.SetPrimaxUnicode(FormWizard.IsPrimaxUnicode(FormWizard.GetHostNameFromIP(ipAddr)));
		COMMUNICATION_ERROR_CODE num = machineControl.communicateConfirm(ipAddr, showErrorDialog: false);
		if (num == COMMUNICATION_ERROR_CODE.ERROR)
		{
			result = ErrorCode.MFP_NOT_FOUND;
		}
		if (num == COMMUNICATION_ERROR_CODE.NOT_SUPPORT)
		{
			result = ErrorCode.MFP_NOT_SUPPORTED;
		}
		return result;
	}

	private void menuItemVersion_Click(object sender, EventArgs e)
	{
		//IL_0023: Unknown result type (might be due to invalid IL or missing references)
		LOG.InfoFormat("{0}：バージョン情報押下", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		((Form)new FormVersion()).ShowDialog();
	}

	private void menuItemExit_Click(object sender, EventArgs e)
	{
		LOG.InfoFormat("{0}：アプリ終了\n*********************\n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		Application.Exit();
	}

	private void buttonCreateFolder_Click(object sender, EventArgs e)
	{
		//IL_050a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0821: Unknown result type (might be due to invalid IL or missing references)
		//IL_00b9: Unknown result type (might be due to invalid IL or missing references)
		//IL_0886: Unknown result type (might be due to invalid IL or missing references)
		//IL_0104: Unknown result type (might be due to invalid IL or missing references)
		//IL_08dc: Unknown result type (might be due to invalid IL or missing references)
		//IL_0144: Unknown result type (might be due to invalid IL or missing references)
		//IL_0927: Unknown result type (might be due to invalid IL or missing references)
		//IL_0272: Unknown result type (might be due to invalid IL or missing references)
		//IL_01e7: Unknown result type (might be due to invalid IL or missing references)
		//IL_0967: Unknown result type (might be due to invalid IL or missing references)
		//IL_02d7: Unknown result type (might be due to invalid IL or missing references)
		//IL_0b48: Unknown result type (might be due to invalid IL or missing references)
		//IL_0b4e: Invalid comparison between Unknown and I4
		//IL_0a33: Unknown result type (might be due to invalid IL or missing references)
		//IL_0bee: Unknown result type (might be due to invalid IL or missing references)
		//IL_0bf3: Unknown result type (might be due to invalid IL or missing references)
		//IL_0405: Unknown result type (might be due to invalid IL or missing references)
		//IL_040a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0475: Unknown result type (might be due to invalid IL or missing references)
		//IL_0478: Invalid comparison between Unknown and I4
		//IL_0388: Unknown result type (might be due to invalid IL or missing references)
		//IL_0c30: Unknown result type (might be due to invalid IL or missing references)
		//IL_0c37: Expected O, but got Unknown
		//IL_0df8: Unknown result type (might be due to invalid IL or missing references)
		//IL_0d67: Unknown result type (might be due to invalid IL or missing references)
		//IL_06ad: Unknown result type (might be due to invalid IL or missing references)
		//IL_060d: Unknown result type (might be due to invalid IL or missing references)
		//IL_070d: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		string empty = string.Empty;
		string empty2 = string.Empty;
		string empty3 = string.Empty;
		string empty4 = string.Empty;
		PowerShellManager powerShellManager = new PowerShellManager();
		try
		{
			((ToolStripItem)toolStripStatusLabelWork).Text = Resources.MSG_START_CREATION_SHARE_FOLDER;
			Application.DoEvents();
			((Control)tabControlCustom).Enabled = false;
			((ToolStripItem)toolStripStatusLabelWork).Text = Resources.MSG_CHECK_SHARE_FOLDER_PARAMETERS;
			Application.DoEvents();
			if (radioButtonCreateFolder.Checked)
			{
				if (string.IsNullOrEmpty(((Control)textBoxFolderName).Text) || ((Control)textBoxFolderName).Text.Equals(Resources.TXT_P2_INITIAL_001))
				{
					MessageBox.Show(Resources.TEXT_BOX_FOLDER_NAME_EMPTY_ERROR_TEXT, Resources.TEXT_BOX_FOLDER_NAME_INPUT_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
					((ToolStripItem)toolStripStatusLabelWork).Text = Resources.STATUS_LABEL_CMD_FOLDER_ERR;
					Application.DoEvents();
					return;
				}
				if (Encoding.GetEncoding("Shift_JIS").GetByteCount(((Control)textBoxFolderName).Text) > 80)
				{
					MessageBox.Show(Resources.FOLDER_NAME_LENGTH_ERROR_TEXT, Resources.TEXT_BOX_FOLDER_NAME_INPUT_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
					((ToolStripItem)toolStripStatusLabelWork).Text = Resources.STATUS_LABEL_CMD_FOLDER_ERR_LENGTH;
					Application.DoEvents();
					return;
				}
				if (!IsSafePath(((Control)textBoxFolderName).Text))
				{
					MessageBox.Show(Resources.TEXT_BOX_FOLDER_NAME_CONTAINS_ILLEGAL_CHARS_ERROR_TEXT, Resources.TEXT_BOX_FOLDER_NAME_INPUT_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
					throw new Exception("input error . textBoxFolderName");
				}
				string sharedFolderPath = getSharedFolderPath(((Control)textBoxFolderName).Text);
				if (sharedFolderPath != string.Empty)
				{
					string text = string.Empty;
					if (Directory.Exists(sharedFolderPath))
					{
						text = $"  {Resources.ITEM_DEST_SHARE_FOLDER}{sharedFolderPath}\n";
					}
					MessageBox.Show($"{Resources.EXISTS_SAME_NAME_SHARE_FOLDER_ERROR_1}{Resources.EXISTS_SAME_NAME_SHARE_FOLDER_ERROR_2_MAIN}{Resources.EXISTS_SAME_NAME_SHARE_FOLDER_ERROR_3}  {Resources.ITEM_SHARE_FOLDER_NAME}{((Control)textBoxFolderName).Text}\n{text}", Resources.ERR_TITLE_CREATE_FOLDER, (MessageBoxButtons)0, (MessageBoxIcon)16);
					LOG.ErrorFormat("{0}：!!! 共有フォルダー作成エラー  \n同じ名前の共有フォルダーが存在します。\n[共有フォルダー名]を変更し[作成]ボタンをクリックしてください。\n\n[見つかった共有フォルダー情報]\n  共有フォルダー名：" + ((Control)textBoxFolderName).Text + "\n" + text, (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
					((ToolStripItem)toolStripStatusLabelWork).Text = Resources.MSG_INTERRUPT_CREATION_SHARE_FOLDER_FOR_EXISTING_SAME_NAME;
					Application.DoEvents();
					return;
				}
				if (string.IsNullOrEmpty(((Control)textBoxFolderPath).Text) || ((Control)textBoxFolderPath).Text.Equals(Resources.TXT_P2_INITIAL_002))
				{
					MessageBox.Show(Resources.ERR_MSG_CMD_FOLDER_PATH_NOT_SET, Resources.TEXT_BOX_FOLDER_PATH_INPUT_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
					((ToolStripItem)toolStripStatusLabelWork).Text = Resources.STATUS_LABEL_CMD_FOLDER_PATH_ERR;
					Application.DoEvents();
					return;
				}
				empty2 = getPathFromWindowsName(((Control)textBoxFolderPath).Text);
				LOG.InfoFormat("{0}：共有フォルダー作成確認 Yes Selected… \n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
				if (!Directory.Exists(empty2))
				{
					MessageBox.Show(Resources.TEXT_BOX_FOLDER_PATH_ERROR_TEXT, Resources.TEXT_BOX_FOLDER_NAME_INPUT_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
					((ToolStripItem)toolStripStatusLabelWork).Text = Resources.STATUS_LABEL_CMD_FOLDER_ERR;
					Application.DoEvents();
					return;
				}
				empty = empty2 + (empty2.EndsWith("\\") ? "" : "\\") + ((Control)textBoxFolderName).Text;
				if (Directory.Exists(empty))
				{
					MessageBox.Show(Resources.ERR_MSG_EXISTING_SAME_NAME_DEST_TEXT_1 + Resources.ERR_MSG_EXISTING_SAME_NAME_DEST_TEXT_2_MAIN + Resources.EXISTS_SAME_NAME_SHARE_FOLDER_ERROR_3 + Resources.ITEM_SHARE_FOLDER_NAME + ((Control)textBoxFolderName).Text + "\n" + Resources.ITEM_DEST_SHARE_FOLDER + empty + "\n", Resources.ERR_TITLE_CREATE_FOLDER, (MessageBoxButtons)0, (MessageBoxIcon)16);
					((ToolStripItem)toolStripStatusLabelWork).Text = Resources.MSG_INTERRUPT_CREATION_SHARE_FOLDER_FOR_EXISTING_SAME_NAME_DEST;
					Application.DoEvents();
					return;
				}
				DialogResult val = MessageBox.Show($"{Resources.ASK_WHETHER_CREATION_SHARE_WITH_SET_CONTENTS_TEXT_1_4}\n\n  {Resources.ITEM_SHARE_FOLDER_NAME}{((Control)textBoxFolderName).Text}\n  {Resources.ITEM_DEST_SHARE_FOLDER}{empty2}\n  {Resources.ITEM_USER_NAME}{(string)comboBoxUserName.SelectedItem}", Resources.ASK_WHETHER_CREATION_SHARE_WITH_SET_CONTENTS_CAPTION, (MessageBoxButtons)4, (MessageBoxIcon)32);
				LOG.InfoFormat("{0}：\n********************************\nこの設定内容で共有フォルダーを作成しますか？\n\n共有フォルダー名：" + ((Control)textBoxFolderName).Text + "\n作成場所：" + empty2 + "\nユーザー名：" + (string)comboBoxUserName.SelectedItem + "\n********************************\n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
				if ((int)val == 7)
				{
					LOG.InfoFormat("{0}：共有フォルダー作成確認 No Selected… \n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
					((ToolStripItem)toolStripStatusLabelWork).Text = Resources.MSG_CANCELED_CREATION_SHARE_FOLDER;
					Application.DoEvents();
					return;
				}
				try
				{
					Directory.CreateDirectory(empty);
					((ToolStripItem)toolStripStatusLabelWork).Text = Resources.MSG_START_CREATION_SHARE_FOLDER;
					Application.DoEvents();
					LOG.InfoFormat("{0}：フォルダ作成完了 … {1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)empty);
				}
				catch (Exception)
				{
					MessageBox.Show(Resources.NOTIFY_OCCUR_UNEXPECTED_ERROR_IN_CREATION_SHARE_FOLDER + "\n\n" + Resources.NOTIFY_ABORTING_CREATION_SHARE_FOLDER, Resources.ERR_TITLE_CREATE_FOLDER);
					LOG.ErrorFormat("{0}：共有フォルダー作成エラー発生 … DUPLICATE_SHARE 共有フォルダー名：{1} / 作成場所：{2}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)((Control)textBoxDestination).Text, (object)empty2);
					throw;
				}
				ShareFolderManager.ErrorCode errorCode = ShareFolderManager.shareFolderAdd(empty, ((Control)textBoxFolderName).Text, "");
				switch (errorCode)
				{
				case ShareFolderManager.ErrorCode.SUCCESS:
					break;
				case ShareFolderManager.ErrorCode.DUPLICATE_SHARE:
				{
					string text2 = string.Empty;
					if (Directory.Exists(sharedFolderPath))
					{
						text2 = $"  {Resources.ITEM_DEST_SHARE_FOLDER}{empty2}\n";
					}
					MessageBox.Show($"{Resources.EXISTS_SAME_NAME_SHARE_FOLDER_ERROR_1}{Resources.EXISTS_SAME_NAME_SHARE_FOLDER_ERROR_2_MAIN}{Resources.EXISTS_SAME_NAME_SHARE_FOLDER_ERROR_3}  {Resources.ITEM_SHARE_FOLDER_NAME}{((Control)textBoxFolderName).Text}\n{text2}", Resources.ERR_TITLE_CREATE_FOLDER, (MessageBoxButtons)0, (MessageBoxIcon)16);
					LOG.ErrorFormat("{0}：共有フォルダー作成エラー発生 … DUPLICATE_SHARE 共有フォルダー名：{1} / 作成場所：{2}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)((Control)textBoxDestination).Text, (object)empty2);
					throw new Exception($"{errorCode}");
				}
				case ShareFolderManager.ErrorCode.INVALID_NAME:
					MessageBox.Show($"{Resources.CREATE_FOLDER_FAILED}ErrorNo=[{9u}]\n\n  {Resources.ITEM_SHARE_FOLDER_NAME}{((Control)textBoxDestination).Text}\n  {Resources.ITEM_DEST_SHARE_FOLDER}{empty2}\n\n{Resources.FAILED_CREATION_TARGET_FOLDER}\n{Resources.FAILED_CREATION_TARGET_FOLDER_MAIN_5_5}", Resources.FAILED_CREATION_TARGET_FOLDER_MAIN_CAPTION);
					LOG.ErrorFormat("{0}：共有フォルダー作成エラー発生 … INVALID_NAME 共有フォルダー名：{1} / 作成場所：{2}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)((Control)textBoxDestination).Text, (object)empty2);
					throw new Exception($"{errorCode}");
				default:
					MessageBox.Show(Resources.NOTIFY_OCCUR_UNEXPECTED_ERROR_IN_CREATION_SHARE_FOLDER + "\n\n" + Resources.NOTIFY_ABORTING_CREATION_SHARE_FOLDER, Resources.ERR_TITLE_CREATE_FOLDER);
					LOG.ErrorFormat("{0}：共有フォルダー作成エラー発生 … DUPLICATE_SHARE 共有フォルダー名：{1} / 作成場所：{2}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)((Control)textBoxDestination).Text, (object)empty2);
					throw new Exception($"{errorCode}");
				}
				LOG.InfoFormat("{0}：フォルダ共有完了 … {1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)((Control)textBoxFolderName).Text);
				ShareFolderManager.ShareUser[] shareUsers = new ShareFolderManager.ShareUser[1]
				{
					new ShareFolderManager.ShareUser
					{
						ShareMode = ShareFolderManager.ShareMode.SHARE_CHANGE,
						AccountName = (string)comboBoxUserName.SelectedItem
					}
				};
				ShareFolderManager.ChangeStatus(((Control)textBoxFolderName).Text, shareUsers);
				ShareFolderManager.AddUsersAndPermissions(empty, (string)comboBoxUserName.SelectedItem, FileSystemRights.FullControl, AccessControlType.Allow);
				empty4 = Path.GetFileName(getPathFromWindowsName(((Control)textBox_T1_FolderPath).Text));
				empty3 = (string)comboBoxUserName.SelectedItem;
			}
			else
			{
				if (string.IsNullOrEmpty(((Control)textBox_T1_FolderPath).Text) || ((Control)textBox_T1_FolderPath).Text.Equals(Resources.TXT_P2_INITIAL_003))
				{
					MessageBox.Show(Resources.TEXT_BOX_NON_SHARED_FOLDER_NAME_EMPTY_ERROR_TEXT, Resources.TEXT_BOX_NON_SHARED_FOLDER_PATH_INPUT_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
					((ToolStripItem)toolStripStatusLabelWork).Text = Resources.TEXT_BOX_NON_SHARED_FOLDER_PATH_INPUT_ERROR_CAPTION;
					Application.DoEvents();
					return;
				}
				empty2 = getPathFromWindowsName(((Control)textBox_T1_FolderPath).Text);
				LOG.InfoFormat("{0}：共有フォルダー作成確認 Yes Selected… \n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
				if (!Directory.Exists(empty2))
				{
					MessageBox.Show(Resources.TEXT_BOX_NON_SHARED_FOLDER_PATH_ERROR_TEXT, Resources.TEXT_BOX_NON_SHARED_FOLDER_PATH_INPUT_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
					((ToolStripItem)toolStripStatusLabelWork).Text = Resources.TEXT_BOX_NON_SHARED_FOLDER_PATH_INPUT_ERROR_CAPTION;
					Application.DoEvents();
					return;
				}
				if (string.IsNullOrEmpty(((Control)textBox_T1_SharedName).Text) || ((Control)textBox_T1_SharedName).Text.Equals(Resources.TXT_P2_INITIAL_001))
				{
					MessageBox.Show(Resources.TEXT_BOX_FOLDER_NAME_EMPTY_ERROR_TEXT, Resources.TEXT_BOX_FOLDER_NAME_INPUT_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
					((ToolStripItem)toolStripStatusLabelWork).Text = Resources.TEXT_BOX_FOLDER_NAME_INPUT_ERROR_CAPTION;
					Application.DoEvents();
					return;
				}
				if (Encoding.GetEncoding("Shift_JIS").GetByteCount(((Control)textBox_T1_SharedName).Text) > 80)
				{
					MessageBox.Show(Resources.FOLDER_NAME_LENGTH_ERROR_TEXT, Resources.TEXT_BOX_FOLDER_NAME_INPUT_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
					((ToolStripItem)toolStripStatusLabelWork).Text = Resources.TEXT_BOX_FOLDER_NAME_INPUT_ERROR_CAPTION;
					Application.DoEvents();
					return;
				}
				if (!IsSafePath(((Control)textBox_T1_SharedName).Text))
				{
					MessageBox.Show(Resources.TEXT_BOX_FOLDER_NAME_CONTAINS_ILLEGAL_CHARS_ERROR_TEXT, Resources.TEXT_BOX_FOLDER_NAME_INPUT_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
					throw new Exception("input error . textBox_T1_SharedName");
				}
				string sharedFolderPath2 = getSharedFolderPath(((Control)textBox_T1_SharedName).Text);
				if (sharedFolderPath2 != string.Empty && !powerShellManager.isSharedSetting(((Control)textBox_T1_SharedName).Text, empty2))
				{
					string text3 = string.Empty;
					if (Directory.Exists(sharedFolderPath2))
					{
						text3 = sharedFolderPath2;
					}
					MessageBox.Show(Resources.EXISTS_SET_SHARE_NAME_FOLDER_ERROR_1 + "\n" + Resources.EXISTS_SET_SHARE_NAME_FOLDER_ERROR_2 + text3 + "\n\n" + Resources.EXISTS_SET_SHARE_NAME_FOLDER_ERROR_3 + "\n" + Resources.EXISTS_SET_SHARE_NAME_FOLDER_ERROR_4 + "\n" + Resources.EXISTS_SET_SHARE_NAME_FOLDER_ERROR_5 + "\n", Resources.ERR_TITLE_SHARED_SETTING, (MessageBoxButtons)0, (MessageBoxIcon)16);
					LOG.ErrorFormat("{0}：!!! 共有フォルダー作成エラー  \n同じ名前の共有フォルダーが存在します。\n[共有フォルダー名]を変更し[作成]ボタンをクリックしてください。\n\n[見つかった共有フォルダー情報]\n  共有フォルダー名：" + ((Control)textBox_T1_SharedName).Text + "\n" + text3, (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
					((ToolStripItem)toolStripStatusLabelWork).Text = Resources.MSG_INTERRUPT_CREATION_SHARE_FOLDER_FOR_EXISTING_SAME_NAME;
					Application.DoEvents();
					return;
				}
				string notShareName = CreateFolderUtil.getNotShareName(empty2);
				if (!string.IsNullOrEmpty(notShareName) && 0 > notShareName.IndexOf(((Control)textBox_T1_SharedName).Text))
				{
					string text4 = Resources.EXISTS_SET_SHARE_NAME_CONFIGURED_ERROR_1 + "\n" + Resources.EXISTS_SET_SHARE_NAME_CONFIGURED_ERROR_2 + notShareName + "\n\n" + Resources.EXISTS_SET_SHARE_NAME_CONFIGURED_ERROR_3 + "\n" + Resources.EXISTS_SET_SHARE_NAME_CONFIGURED_ERROR_4 + "\n" + Resources.EXISTS_SET_SHARE_NAME_CONFIGURED_ERROR_5 + "\n";
					if ((int)new CustomizableMessageBox
					{
						ButtonText = 
						{
							Yes = Resources.ITEM_BUTTON_NEXT,
							No = Resources.ITEM_BUTTON_BACK
						}
					}.Show(text4, Resources.CHECK_SHARING_SETTINGS, (MessageBoxButtons)4, (MessageBoxIcon)48) == 7)
					{
						((ToolStripItem)toolStripStatusLabelWork).Text = "選択したフォルダーは、共有名が存在します。";
						Application.DoEvents();
						return;
					}
				}
				if (!powerShellManager.isSharedSetting(((Control)textBox_T1_SharedName).Text, empty2))
				{
					powerShellManager.SetSharedSetting(((Control)textBox_T1_SharedName).Text, empty2);
				}
				powerShellManager.SetSMBAccount(((Control)textBox_T1_SharedName).Text, (string)comboBox_T1_UserName.SelectedItem, "Full");
				empty = empty2;
				empty4 = Path.GetFileName(getPathFromWindowsName(((Control)textBox_T1_SharedName).Text));
				empty3 = (string)comboBox_T1_UserName.SelectedItem;
			}
			fs.setSharedFolderListTable();
			ManagementObjectSearcher val2 = new ManagementObjectSearcher();
			((ManagementQuery)val2.Query).QueryString = "SELECT * FROM Win32_Share Where Name = '" + ((Control)textBoxFolderName).Text + "'";
			ManagementObjectEnumerator enumerator = val2.Get().GetEnumerator();
			try
			{
				while (enumerator.MoveNext())
				{
					ManagementObject val3 = (ManagementObject)enumerator.Current;
					LOG.InfoFormat("AccessMask : {0}, AllowMaximum : {1}, Caption : {2}, Description : {3}, InstallDate : {4}, MaximumAllowed : {5}, Name : {6}, Path : {7}, Status : {8}, Type : {9} ", new object[10]
					{
						((ManagementBaseObject)val3)["AccessMask"],
						((ManagementBaseObject)val3)["AllowMaximum"],
						((ManagementBaseObject)val3)["Caption"],
						((ManagementBaseObject)val3)["Description"],
						((ManagementBaseObject)val3)["InstallDate"],
						((ManagementBaseObject)val3)["MaximumAllowed"],
						((ManagementBaseObject)val3)["Name"],
						((ManagementBaseObject)val3)["Path"],
						((ManagementBaseObject)val3)["Status"],
						((ManagementBaseObject)val3)["Type"]
					});
				}
			}
			finally
			{
				((IDisposable)enumerator)?.Dispose();
			}
			Directory.GetAccessControl(empty);
			if (radioButtonCreateFolder.Checked)
			{
				MessageBox.Show($"{Resources.NOTIFY_COMPLETED_CREATION_SHARE_FOLDER_MAIN_1_6}\n\n  {Resources.ITEM_SHARE_FOLDER_NAME}{empty4}\n  {Resources.ITEM_DEST_SHARE_FOLDER}{empty2}\n  {Resources.ITEM_USER_NAME}{empty3}\n\n{Resources.NOTIFY_COMPLETED_CREATION_SHARE_FOLDER_MAIN_5_6}\n{Resources.NOTIFY_COMPLETED_CREATION_SHARE_FOLDER_MAIN_6_6}", Resources.MSG_COMPLETED_CREATION_SHARE_FOLDER);
				LOG.InfoFormat("{0}：〇〇〇 共有フォルダー作成完了  \n共有フォルダー名：" + ((Control)textBoxDestination).Text + "\n作成場所：" + empty2, (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			}
			else
			{
				MessageBox.Show($"{Resources.NOTIFY_COMPLETED_SETTING_SHARE_FOLDER_MAIN_1_6}\n\n  {Resources.ITEM_SHARE_FOLDER_NAME}{empty4}\n  {Resources.ITEM_NON_SHARE_FOLDER}{empty2}\n  {Resources.ITEM_USER_NAME}{empty3}\n\n{Resources.NOTIFY_COMPLETED_CREATION_SHARE_FOLDER_MAIN_5_6}\n{Resources.NOTIFY_COMPLETED_CREATION_SHARE_FOLDER_MAIN_6_6}", Resources.MSG_COMPLETED_SETTING_SHARE_FOLDER_STATUS);
				LOG.InfoFormat("{0}：〇〇〇 共有フォルダー作成完了  \n共有フォルダー名：" + ((Control)textBoxDestination).Text + "\n作成場所：" + empty2, (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			}
			((ToolStripItem)toolStripStatusLabelWork).Text = Resources.MSG_COMPLETED_CREATION_SHARE_FOLDER_STATUS;
			Application.DoEvents();
		}
		catch (Exception ex2)
		{
			Console.Out.WriteLine(ex2.ToString());
			LOG.ErrorFormat("{0}：！！！ 共有フォルダー作成エラー  \n" + ex2.ToString() + "\n*******************************", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			((ToolStripItem)toolStripStatusLabelWork).Text = Resources.MSG_FAILED_CREATION_SHARE_FOLDER_STATUS;
			Application.DoEvents();
		}
		finally
		{
			((Control)tabControlCustom).Enabled = true;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
	}

	private void buttonSelectFolder_Click(object sender, EventArgs e)
	{
		//IL_006c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0072: Expected O, but got Unknown
		//IL_008c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0092: Invalid comparison between Unknown and I4
		//IL_00a6: Unknown result type (might be due to invalid IL or missing references)
		//IL_00b0: Expected O, but got Unknown
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		LOG.InfoFormat("{0}：フォルダ選択ボタン押下\n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		((ToolStripItem)toolStripStatusLabelWork).Text = Resources.MSG_START_SELECTING_SHARE_FOLDER;
		string text = getPathFromWindowsName(((Control)textBoxFolderPath).Text);
		if (!Directory.Exists(text))
		{
			text = CreateFolderUtil.getDesktopDirectory();
		}
		FolderBrowserDialog val = new FolderBrowserDialog();
		val.SelectedPath = text;
		val.Description = Resources.SELECT_DEST_SHARE_FOLDER;
		val.ShowNewFolderButton = false;
		if ((int)((CommonDialog)val).ShowDialog() == 1)
		{
			((Control)textBoxFolderPath).Font = new Font(Resources.FONT, 9f, (FontStyle)0);
			((Control)textBoxFolderPath).ForeColor = Color.Black;
			((Control)textBoxFolderPath).Text = CreateFolderUtil.getWindowsFolderName(val.SelectedPath);
			LOG.InfoFormat("{0}：フォルダ選択結果:{1}, 表示名：{2}\n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)val.SelectedPath, (object)((Control)textBoxFolderPath).Text);
			((ToolStripItem)toolStripStatusLabelWork).Text = $"{Resources.MSG_WHAT_YOU_SELECTED_AS_SHARE_FOLDER_1_2}{((Control)textBoxFolderPath).Text}{Resources.MSG_WHAT_YOU_SELECTED_AS_SHARE_FOLDER_2_2}";
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		}
	}

	private void comboBoxFolder_SelectedIndexChanged(object sender, EventArgs e)
	{
		//IL_007a: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		string hostInfo = getHostInfo();
		if (hostInfo != string.Empty)
		{
			setComboBoxSendPath();
			toolTipPath.SetToolTip((Control)(object)comboBoxSendPath, ((Control)comboBoxSendPath).Text);
			fs.setComboBoxPCUserList(comboBoxFolder, comboBoxPCUserName);
		}
		else
		{
			MessageBox.Show(Resources.CANT_GET_NETWORK_INFO_ERROR_TEXT, Resources.CANT_GET_NETWORK_INFO_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
			LOG.InfoFormat("{0}：コンピューターのネットワーク情報が取得できません。\nコンピューターがネットワークに正しく接続されているか確認してください。:{1}\n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)hostInfo);
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
	}

	private async void buttonSend_Click(object sender, EventArgs e)
	{
		LOG.DebugFormat("{0}：アドレス帳登録ボタン押下\n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		((ToolStripItem)toolStripStatusLabelWork).Text = Resources.MSG_START_REGISTER_DEST_METHOD;
		((Control)btnAdd).Enabled = false;
		((Control)btnConnectTest).Enabled = false;
		((Control)btnHeadLine).Enabled = false;
		((Control)tabControlCustom).Enabled = false;
		((Control)linkLabelFolderSend).Visible = false;
		((Control)linkLabelHelp).Visible = false;
		((Control)this).Cursor = Cursors.WaitCursor;
		try
		{
			if (string.IsNullOrEmpty(((Control)textBoxDestination).Text) || ((Control)textBoxDestination).Text.Equals(Resources.TXT_P4_INITIAL_001))
			{
				throw new CreateFolderException(Resources.ERR_TITLE_FOLDER_NAME, Resources.ERR_MSG_SEND_FOLDER_NAME_NOT_SET, Resources.ERR_TITLE_REGIST_ADDR, CreateFolderException.ErrorType.USER_INPUT);
			}
			if (Encoding.GetEncoding("Shift_JIS").GetByteCount(((Control)textBoxDestination).Text) > 16)
			{
				throw new CreateFolderException(Resources.ERR_TITLE_FOLDER_NAME, Resources.ERR_MSG_SEND_FOLDER_NAME_DATA_LIMIT, Resources.ERR_TITLE_REGIST_ADDR, CreateFolderException.ErrorType.USER_INPUT);
			}
			if (string.IsNullOrEmpty(((Control)comboBoxFolder).Text))
			{
				throw new CreateFolderException(Resources.ERR_TITLE_CMB_FOLDER_NAME_ADDR, Resources.ERR_MSG_CMB_FOLDER_NAME_NOT_SET, Resources.ERR_TITLE_REGIST_ADDR, CreateFolderException.ErrorType.USER_INPUT);
			}
			string userInfo = (string)comboBoxPCUserName.SelectedItem;
			if (string.IsNullOrEmpty(userInfo))
			{
				userInfo = ((Control)comboBoxPCUserName).Text;
				LOG.DebugFormat("{0}：this.comboBoxPCUser.Text:{1}\n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)((Control)comboBoxPCUserName).Text);
			}
			if (string.IsNullOrEmpty(userInfo))
			{
				throw new CreateFolderException(Resources.ERR_TITLE_LOGIN_USER, Resources.ERR_MSG_LOGIN_USER_NOT_SET, Resources.ERR_TITLE_REGIST_ADDR, CreateFolderException.ErrorType.USER_INPUT);
			}
			if (Encoding.GetEncoding("Shift_JIS").GetByteCount(userInfo) > 64)
			{
				throw new CreateFolderException(Resources.ERR_TITLE_LOGIN_USER, Resources.ERR_MSG_LOGIN_USER_DATA_LIMIT, Resources.ERR_TITLE_REGIST_ADDR, CreateFolderException.ErrorType.USER_INPUT);
			}
			string passTxt = (((Control)textBoxPassword).Text.Equals(Resources.TXT_P3_INITIAL_001) ? string.Empty : ((Control)textBoxPassword).Text);
			string value = (((Control)textBoxPasswordConfirm).Text.Equals(Resources.TXT_P3_INITIAL_002) ? string.Empty : ((Control)textBoxPasswordConfirm).Text);
			FormSetup fSetup = new FormSetup(machineLang);
			if (string.IsNullOrEmpty(passTxt) && fSetup.isPCDomain())
			{
				throw new CreateFolderException(Resources.ASK_TO_SET_PASSWORD_FOR_PC_BELONGING_DOMAIN_CAPTION, Resources.ASK_TO_SET_PASSWORD_FOR_PC_BELONGING_DOMAIN, Resources.ERR_TITLE_REGIST_ADDR, CreateFolderException.ErrorType.USER_INPUT);
			}
			if (Encoding.GetEncoding("Shift_JIS").GetByteCount(passTxt) > 64)
			{
				throw new CreateFolderException(Resources.ERR_TITLE_LOGIN_PASS, Resources.ERR_MSG_LOGIN_PASS_DATA_LIMIT, Resources.ERR_TITLE_REGIST_ADDR, CreateFolderException.ErrorType.USER_INPUT);
			}
			if (!passTxt.Equals(value))
			{
				throw new CreateFolderException(Resources.ERR_TITLE_LOGIN_PASS, Resources.PASSWORD_MISMATCH_CONFIRMATION_ERROR_TEXT, Resources.ERR_TITLE_REGIST_ADDR, CreateFolderException.ErrorType.USER_INPUT);
			}
			if (string.IsNullOrEmpty(((Control)comboBoxSendPath).Text))
			{
				throw new CreateFolderException(Resources.ERR_TITLE_PATH, Resources.ERR_MSG_PATH_NOT_SET, Resources.ERR_TITLE_REGIST_ADDR, CreateFolderException.ErrorType.USER_INPUT);
			}
			if (Encoding.GetEncoding("Shift_JIS").GetByteCount(((Control)comboBoxSendPath).Text) > 256)
			{
				throw new CreateFolderException(Resources.ERR_TITLE_PATH, Resources.ERR_MSG_PATH_DATA_LIMIT, Resources.ERR_TITLE_REGIST_ADDR, CreateFolderException.ErrorType.USER_INPUT);
			}
			string text = machineSelectControl.getSelectedAddress(msgOn: false)[MachineSelectControl.ADDRESS_FORM.IP];
			string ipAddr = text;
			if (string.IsNullOrEmpty(ipAddr))
			{
				LOG.InfoFormat("{0}：機器の設定エラー：IPアドレス無し", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
				throw new CreateFolderException(Resources.MACHINE_SETTING_ERROR_CAPTION, Resources.MACHINE_NOT_SELECTED_ERROR_TEXT, Resources.STATUS_LABEL_ADDRESS_REGIST_IP_ERR_NONE, CreateFolderException.ErrorType.USER_INPUT);
			}
			MachineControl mc = new MachineControl(machineLang);
			bool primaxModel = FormWizard.IsPrimax(FormWizard.GetHostNameFromIP(ipAddr));
			bool primaxUnicode = FormWizard.IsPrimaxUnicode(FormWizard.GetHostNameFromIP(ipAddr));
			mc.SetPrimaxModel(primaxModel);
			mc.SetPrimaxUnicode(primaxUnicode);
			if (primaxModel)
			{
				int oneKeyNo = fSettingHeadline.RegistrationNo;
				if (primaxUnicode)
				{
					if (mc.convToUnicode(((Control)textBoxDestination).Text) == null)
					{
						LOG.InfoFormat("{0}：宛先名 入力文字エラー：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)((Control)textBoxDestination).Text);
						throw new CreateFolderException(Resources.INPUT_ADDRESS_ERROR, Resources.INPUT_ADDRESS_NAME_FULL_WIDTH_2, Resources.ERR_TITLE_REGIST_ADDR, CreateFolderException.ErrorType.USER_INPUT);
					}
					if (!mc.checkDestNameCharUnicode(((Control)textBoxDestination).Text))
					{
						LOG.InfoFormat("{0}：宛先名 入力文字エラー：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)((Control)textBoxDestination).Text);
						throw new CreateFolderException(Resources.INPUT_ADDRESS_ERROR, Resources.INPUT_ADDRESS_NAME_FULL_WIDTH_2, Resources.ERR_TITLE_REGIST_ADDR, CreateFolderException.ErrorType.USER_INPUT);
					}
				}
				else
				{
					if (mc.convHexString(((Control)textBoxDestination).Text, MachineControl.PRIMAX_HEX_ENCODINGT.SJIS) == null)
					{
						LOG.InfoFormat("{0}：宛先名 入力文字エラー：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)((Control)textBoxDestination).Text);
						throw new CreateFolderException(Resources.INPUT_ADDRESS_ERROR, Resources.INPUT_ADDRESS_NAME_FULL_WIDTH, Resources.ERR_TITLE_REGIST_ADDR, CreateFolderException.ErrorType.USER_INPUT);
					}
					if (!mc.checkDestNameChar(((Control)textBoxDestination).Text))
					{
						LOG.InfoFormat("{0}：宛先名 入力文字エラー：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)((Control)textBoxDestination).Text);
						throw new CreateFolderException(Resources.INPUT_ADDRESS_ERROR, Resources.INPUT_ADDRESS_NAME_FULL_WIDTH, Resources.ERR_TITLE_REGIST_ADDR, CreateFolderException.ErrorType.USER_INPUT);
					}
				}
				if (mc.convHexString(userInfo, MachineControl.PRIMAX_HEX_ENCODINGT.SJIS) == null)
				{
					LOG.InfoFormat("{0}：ユーザー名 入力文字エラー：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)userInfo);
					throw new CreateFolderException(Resources.PRIMAX_INPUT_USERNAME_ERROR, Resources.PRIMAX_INPUT_USERNAME_FULL_WIDTH, Resources.PRIMAX_ERR_TITLE_REGIST_USERNAME, CreateFolderException.ErrorType.USER_INPUT);
				}
				if (mc.convHexString(((Control)comboBoxFolder).Text, MachineControl.PRIMAX_HEX_ENCODINGT.SJIS) == null)
				{
					LOG.InfoFormat("{0}：共有フォルダー名 入力文字エラー：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)((Control)comboBoxFolder).Text);
					throw new CreateFolderException(Resources.PRIMAX_INPUT_FOLDER_ERROR, Resources.PRIMAX_INPUT_FOLDER_FULL_WIDTH, Resources.PRIMAX_ERR_TITLE_REGIST_FOLDER, CreateFolderException.ErrorType.USER_INPUT);
				}
				if (mc.convHexString(passTxt, MachineControl.PRIMAX_HEX_ENCODINGT.SJIS) == null)
				{
					LOG.InfoFormat("{0}：パスワード 入力文字エラー：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)passTxt);
					throw new CreateFolderException(Resources.PRIMAX_INPUT_PASSWORD_ERROR, Resources.PRIMAX_INPUT_PASSWORD_FULL_WIDTH, Resources.PRIMAX_ERR_TITLE_REGIST_PASSWORD, CreateFolderException.ErrorType.USER_INPUT);
				}
				if (oneKeyNo > 0)
				{
					COMMUNICATION_ERROR_CODE cOMMUNICATION_ERROR_CODE = mc.communicateConfirm(ipAddr, showErrorDialog: false);
					bool thhpsFlg = false;
					if (!cOMMUNICATION_ERROR_CODE.Equals(COMMUNICATION_ERROR_CODE.HTTP_ONLY))
					{
						thhpsFlg = true;
					}
					List<OneTouchKeyInfo> list = await mc.getPrimaxOneTouchKeyInfo(thhpsFlg, ipAddr);
					int count = list.Count;
					if (oneKeyNo > count)
					{
						string errorMsg = Resources.ERR_MSG_KEY_NO_MAX_1 + count + Resources.ERR_MSG_KEY_NO_MAX_2 + oneKeyNo + Resources.ERR_MSG_KEY_NO_MAX_3 + "\n" + Resources.ERR_MSG_KEY_NO_MAX_4;
						LOG.InfoFormat("{0}：ワンタッチキー番号入力エラー：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)oneKeyNo.ToString());
						throw new CreateFolderException(Resources.ERR_MSG_TITLE_KEY_NO_MAX, errorMsg, Resources.ERR_MSG_TITLE_KEY_NO_MAX, CreateFolderException.ErrorType.USER_INPUT);
					}
					string text2 = "";
					bool flag = true;
					bool flag2 = false;
					for (int i = 0; i < count; i++)
					{
						if (string.IsNullOrEmpty(list[i].name))
						{
							flag = false;
							if (!string.IsNullOrEmpty(text2))
							{
								text2 += " ,";
							}
							text2 += list[i].no;
						}
						else if (oneKeyNo == list[i].no)
						{
							flag2 = true;
						}
					}
					if (flag)
					{
						string errorMsg2 = Resources.ERR_MSG_KEY_ALL_USING_1 + oneKeyNo + Resources.ERR_MSG_KEY_ALL_USING_2;
						fSettingHeadline.RegistrationNo = 1;
						fSettingHeadline.RegistNumSpecify = false;
						LOG.InfoFormat("{0}：ワンタッチキー番号重複エラー：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)oneKeyNo.ToString());
						throw new CreateFolderException(Resources.ERR_MSG_TITLE_KEY_ALL_USING, errorMsg2, Resources.ERR_MSG_TITLE_KEY_ALL_USING, CreateFolderException.ErrorType.USER_INPUT);
					}
					if (flag2)
					{
						string errorMsg3 = Resources.ERR_MSG_KEY_USING_1 + oneKeyNo + Resources.ERR_MSG_KEY_USING_2 + "\n" + Resources.ERR_MSG_KEY_USING_3 + "\n" + Resources.ERR_MSG_KEY_USING_4 + text2;
						LOG.InfoFormat("{0}：ワンタッチキー番号重複エラー：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)oneKeyNo.ToString());
						throw new CreateFolderException(Resources.ERR_MSG_TITLE_KEY_USING, errorMsg3, Resources.ERR_MSG_TITLE_KEY_USING, CreateFolderException.ErrorType.USER_INPUT);
					}
				}
			}
			if (string.IsNullOrEmpty(passTxt))
			{
				if (fSetup.isPCDomain())
				{
					MessageBox.Show(Resources.ASK_TO_SET_PASSWORD_FOR_PC_BELONGING_DOMAIN, Resources.ASK_TO_SET_PASSWORD_FOR_PC_BELONGING_DOMAIN_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
					return;
				}
				string text3 = $"{Resources.ASK_TO_SET_PASSWORD_FOR_SECURENESS_01}{Resources.ASK_TO_SET_PASSWORD_FOR_SECURENESS_02}{Resources.ASK_TO_SET_PASSWORD_FOR_SECURENESS_03}[{Resources.BUTTON_CLOSE}]{Resources.ASK_TO_SET_PASSWORD_FOR_SECURENESS_05}\n\n\n{Resources.ASK_TO_SET_PASSWORD_FOR_SECURENESS_06}[{Resources.BUTTON_CONTINUE}]{Resources.ASK_TO_SET_PASSWORD_FOR_SECURENESS_07}\n";
				string aSK_TO_SET_PASSWORD_FOR_SECURENESS_CAPTION = Resources.ASK_TO_SET_PASSWORD_FOR_SECURENESS_CAPTION;
				DialogResult val = new CustomizableMessageBox
				{
					ButtonText = 
					{
						OK = Resources.BUTTON_CONTINUE,
						Cancel = Resources.BUTTON_CLOSE
					}
				}.Show(text3, aSK_TO_SET_PASSWORD_FOR_SECURENESS_CAPTION, (MessageBoxButtons)1, (MessageBoxIcon)48);
				if ((int)val == 1)
				{
					CustomDialogBox customDialogBox = new CustomDialogBox();
					customDialogBox.SetIcon(SystemIcons.Exclamation);
					customDialogBox.SetMessageBoxSize(550, 350);
					customDialogBox.SetHangingIndent(0);
					customDialogBox.SetMesages($"\n{Resources.SECURITY_DIALOG_MESSAGE_01}{Resources.SECURITY_DIALOG_MESSAGE_02}{Resources.SECURITY_DIALOG_MESSAGE_03}\n\n\n");
					customDialogBox.SetUnderLineMode(sw: true);
					customDialogBox.SetMesages($"{Resources.SECURITY_DIALOG_MESSAGE_04}\n");
					customDialogBox.SetUnderLineMode(sw: false);
					customDialogBox.SetSelectionBullet(sw: true, 10);
					customDialogBox.SetMesages($"{Resources.SECURITY_DIALOG_MESSAGE_05}\n{Resources.SECURITY_DIALOG_MESSAGE_06}\n");
					customDialogBox.SetSelectionBullet(sw: false);
					customDialogBox.SetMesages($"\n\n{Resources.SECURITY_DIALOG_MESSAGE_07}{Resources.SECURITY_DIALOG_MESSAGE_08}\n\n{Resources.SECURITY_AGREEMENT_03}\n");
					customDialogBox.ResizeWindow();
					val = ((Form)customDialogBox).ShowDialog();
					if ((int)val == 1)
					{
						try
						{
							LOG.InfoFormat("{0}：パスワード保護共有呼び出し", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
							Process.Start(new ProcessStartInfo
							{
								FileName = "control.exe",
								Arguments = "/name Microsoft.NetworkAndSharingCenter /page Advanced",
								UseShellExecute = true
							});
							LOG.InfoFormat("{0}：パスワード保護共有呼び出し終了", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
						}
						catch (Exception ex)
						{
							LOG.ErrorFormat("{0}：パスワード保護共有呼び出しでエラー Exception = {1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)ex.ToString());
						}
						CustomDialogBox customDialogBox2 = new CustomDialogBox();
						customDialogBox2.SetIcon(SystemIcons.Exclamation);
						customDialogBox2.SetMessageBoxSize(550, 430);
						customDialogBox2.SetHangingIndent(0);
						customDialogBox2.SetMesages($"\n{Resources.SECURITY_DIALOG_MESSAGE_11}\n\n\n");
						customDialogBox2.SetUnderLineMode(sw: true);
						customDialogBox2.SetMesages($"{Resources.SECURITY_DIALOG_MESSAGE_12}\n");
						customDialogBox2.SetUnderLineMode(sw: false);
						customDialogBox2.SetHangingIndent(40);
						customDialogBox2.SetMesages($" {Resources.SECURITY_DIALOG_MESSAGE_13}\n {Resources.SECURITY_DIALOG_MESSAGE_14}\n {Resources.SECURITY_DIALOG_MESSAGE_15}\n {Resources.SECURITY_DIALOG_MESSAGE_16}\n {Resources.SECURITY_DIALOG_MESSAGE_17}\n");
						customDialogBox2.HideAgreeButton();
						customDialogBox2.ResizeWindow();
						((Form)customDialogBox2).ShowDialog();
					}
				}
				if ((int)val == 2)
				{
					LOG.InfoFormat("{0}：パスワード保護共有呼び出しでキャンセル選択", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
					((ToolStripItem)toolStripStatusLabelWork).Text = Resources.MSG_CANCELED_REGISTER_DEST_METHOD;
					Application.DoEvents();
					return;
				}
			}
			if (!fSetup.checkEnableSMB())
			{
				LOG.InfoFormat("{0}：ファイアウォールの設定確認 No Selected… \n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
				((ToolStripItem)toolStripStatusLabelWork).Text = Resources.MSG_CANCELED_SET_FW;
				Application.DoEvents();
				return;
			}
			if (dhcpCaution && comboBoxSendPath.SelectedItem.ToString().Contains(getIPAddress()) && (int)MessageBox.Show($"{Resources.TEXT_P4_DHCP_CAUTION_TEXT_01}\n {Resources.TEXT_P4_DHCP_CAUTION_TEXT_02}\n {Resources.TEXT_P4_DHCP_CAUTION_TEXT_03}\n {Resources.TEXT_P4_DHCP_CAUTION_TEXT_04}\n {Resources.TEXT_P4_DHCP_CAUTION_TEXT_05}", Resources.CONFIRM, (MessageBoxButtons)1, (MessageBoxIcon)48) == 2)
			{
				LOG.InfoFormat("{0}：機器の設定：DHCP確認でキャンセル選択", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
				return;
			}
			LOG.DebugFormat("{0}：userInfo:{1}\n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)userInfo);
			string arg = "*****";
			string text4 = ((fSettingHeadline.RegistrationNo == 0) ? Resources.REGISTRATION_NUMBER_NOT_USE : fSettingHeadline.RegistrationNo.ToString());
			StringBuilder stringBuilder = new StringBuilder();
			stringBuilder.AppendFormat("{0}\n\n", Resources.ASK_IF_RESISTERING_DEST_FOR_SET_CONTENTS_CAN_BE_DONE_1_9);
			stringBuilder.AppendFormat("{0}\n", Resources.SETTING_CONTENTS);
			if (primaxModel)
			{
				if (text4.Equals(Resources.REGISTRATION_NUMBER_NOT_USE))
				{
					text4 = Resources.PRIMAX_ONE_TOUCH_KEY_NOT_USE;
				}
				stringBuilder.AppendFormat("  {0}\t{1}\n", Resources.PRIMAX_ONE_TOUCH_KEY_BIG, text4);
			}
			else
			{
				stringBuilder.AppendFormat("  {0}\t{1}\n", Resources.REGISTRATION_NUMBER, text4);
			}
			stringBuilder.AppendFormat("  {0}\t{1}\n", Resources.ITEM_ADDRESS_NAME, ((Control)textBoxDestination).Text);
			stringBuilder.AppendFormat("  {0}{1}\n", Resources.ITEM_SHARE_FOLDER_NAME, comboBoxFolder.SelectedItem);
			stringBuilder.AppendFormat("  {0}\t{1}\n", Resources.ITEM_USER_NAME, userInfo);
			stringBuilder.AppendFormat("  {0}\t{1}\n", Resources.SET_REPORT_CREATE_FOLDER_ADDRESS_MSG_06A_13, arg);
			stringBuilder.AppendFormat("  {0}\t{1}\n", Resources.SET_REPORT_CREATE_FOLDER_ADDRESS_MSG_10_13, ((Control)comboBoxSendPath).Text);
			stringBuilder.AppendFormat("  {0}\t\t{1}\n", Resources.ITEM_MACHINE, ipAddr);
			if (primaxModel)
			{
				stringBuilder.AppendFormat("\n\n");
			}
			else
			{
				stringBuilder.AppendFormat("    {0}:\t{1}\n", Resources.TITLE_01, fSettingHeadline.Str1Headline);
				stringBuilder.AppendFormat("    {0}:\t{1}\n", Resources.TITLE_02, fSettingHeadline.Str2Headline);
				stringBuilder.AppendFormat("    {0}:\t{1}\n", Resources.TITLE_03, fSettingHeadline.Str3Headline);
				stringBuilder.AppendFormat("    {0}:\t{1}\n\n", Resources.TITLE_ADD_TO_FREQ, fSettingHeadline.StrRegularHeading);
				stringBuilder.Append(Resources.ASK_IF_RESISTERING_DEST_FOR_SET_CONTENTS_CAN_BE_DONE_9_9);
			}
			stringBuilder.Append(Resources.ASK_IF_RESISTERING_DEST_FOR_SET_CONTENTS_CAN_BE_DONE_9_9);
			if ((int)MessageBox.Show(stringBuilder.ToString(), Resources.ASK_IF_RESISTERING_DEST_FOR_SET_CONTENTS_CAN_BE_DONE_CAPTION, (MessageBoxButtons)4, (MessageBoxIcon)32) == 7)
			{
				LOG.InfoFormat("{0}：宛先の登録確認 No Selected… \n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
				((ToolStripItem)toolStripStatusLabelWork).Text = Resources.MSG_CANCELED_REGISTER_DEST_METHOD;
				Application.DoEvents();
				return;
			}
			mc.SetPrimaxModel(primaxModel);
			mc.SetPrimaxUnicode(primaxUnicode);
			COMMUNICATION_ERROR_CODE comResult = mc.communicateConfirm(ipAddr);
			if (comResult == COMMUNICATION_ERROR_CODE.ERROR || comResult == COMMUNICATION_ERROR_CODE.NOT_SUPPORT)
			{
				throw new CreateFolderException(string.Empty, string.Empty, string.Empty, CreateFolderException.ErrorType.USER_INPUT);
			}
			fSetup.enableSMB();
			if (!FormWizard.PCSMBcheck(machineLang))
			{
				((ToolStripItem)toolStripStatusLabelWork).Text = Resources.MSG_CANCELED_REGISTER_DEST_METHOD;
				Application.DoEvents();
				return;
			}
			string text5;
			string text6;
			if (primaxModel)
			{
				SettingItemsSetupAddress setting = new SettingItemsSetupAddress
				{
					host = ipAddr,
					adminName = primaxAdminPasswd,
					passwd = passTxt,
					firstFlg = true,
					httpsFlg = (comResult != COMMUNICATION_ERROR_CODE.HTTP_ONLY)
				};
				setting.registrationNo = fSettingHeadline.RegistrationNo;
				setting.addressName = ((Control)textBoxDestination).Text.ToString();
				setting.authUserName = userInfo;
				setting.folderPath = ((Control)comboBoxSendPath).Text.ToString();
				if (!FormWizard.PrimaxSMBcheck(ipAddr, FormWizard.GetHostNameFromIP(ipAddr), machineLang))
				{
					((ToolStripItem)toolStripStatusLabelWork).Text = Resources.MSG_CANCELED_REGISTER_DEST_METHOD;
					Application.DoEvents();
					return;
				}
				MachineControl.PRIMAX_MACHINE_CONTROL_RESULT pRIMAX_MACHINE_CONTROL_RESULT;
				while (true)
				{
					pRIMAX_MACHINE_CONTROL_RESULT = await mc.executeSetupAddressToPrimax(setting);
					if (MachineControl.PRIMAX_MACHINE_CONTROL_RESULT.PW_RESETTING != pRIMAX_MACHINE_CONTROL_RESULT)
					{
						break;
					}
					FormAdminAuthConfirm formAdminAuthConfirm = new FormAdminAuthConfirm();
					formAdminAuthConfirm.InitializeToPrimax();
					formAdminAuthConfirm.setMsg(firstFlg: true);
					((Form)formAdminAuthConfirm).StartPosition = (FormStartPosition)4;
					((Form)formAdminAuthConfirm).ShowDialog();
					if ((int)((Form)formAdminAuthConfirm).DialogResult != 1)
					{
						return;
					}
					setting.adminName = formAdminAuthConfirm.getAuthPass();
					primaxAdminPasswd = formAdminAuthConfirm.getAuthPass();
				}
				if (MachineControl.PRIMAX_MACHINE_CONTROL_RESULT.ADD_DUPLICATE == pRIMAX_MACHINE_CONTROL_RESULT)
				{
					LOG.InfoFormat("[primax]アドレス重複:{0}", (object)((Control)textBoxDestination).Text);
					MessageBox.Show(Resources.DUPLICATE_REGISTRATION_NAME, Resources.SET_REGISTRATION_NAME_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
					return;
				}
				if (MachineControl.PRIMAX_MACHINE_CONTROL_RESULT.ADD_OVER == pRIMAX_MACHINE_CONTROL_RESULT)
				{
					LOG.InfoFormat("[primax]登録数超過:{0}", (object)((Control)textBoxDestination).Text);
					MessageBox.Show(Resources.OVER_REGISTRATION_NAME, Resources.SET_REGISTRATION_NAME_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
					return;
				}
				if (pRIMAX_MACHINE_CONTROL_RESULT != 0)
				{
					LOG.InfoFormat("[primax]宛先の登録に失敗しました。:{0}", (object)((Control)textBoxDestination).Text);
					MessageBox.Show(Resources.EXE_RESULT_MSG_ERROR_REGIST_ADDRESS, Resources.ERR_TITLE_REGIST_ADDR, (MessageBoxButtons)0, (MessageBoxIcon)16);
					return;
				}
				primaxAdminPasswd = setting.adminName;
				text5 = "---";
				if (setting.registrationNo != 0)
				{
					text5 = setting.registrationNo.ToString();
				}
				text6 = ((Control)textBoxDestination).Text;
			}
			else
			{
				SettingItemsSetupAddress setting2 = new SettingItemsSetupAddress
				{
					host = ipAddr,
					adminName = "admin",
					passwd = "",
					addressName = ((Control)textBoxDestination).Text,
					authUserName = userInfo,
					authPassword = passTxt,
					folderPath = ((Control)comboBoxSendPath).Text,
					firstFlg = true,
					httpsFlg = (comResult != COMMUNICATION_ERROR_CODE.HTTP_ONLY)
				};
				if (!(await mc.checkUserAdminPermission(setting2)))
				{
					mc.retryLoginState(setting2.host, setting2.adminName);
					((ToolStripItem)toolStripStatusLabelWork).Text = Resources.MSG_CANCELED_REGISTER_DEST_METHOD;
					Application.DoEvents();
					return;
				}
				if (!(await mc.checkMachineAdminPermission(setting2)))
				{
					mc.retryLoginState(setting2.host, setting2.adminName);
					((ToolStripItem)toolStripStatusLabelWork).Text = Resources.MSG_CANCELED_REGISTER_DEST_METHOD;
					Application.DoEvents();
					return;
				}
				if (!(await FormWizard.MFPSMBcheck(ipAddr, FormWizard.GetHostNameFromIP(ipAddr), machineLang)))
				{
					((ToolStripItem)toolStripStatusLabelWork).Text = Resources.MSG_CANCELED_REGISTER_DEST_METHOD;
					Application.DoEvents();
					return;
				}
				string[] array;
				while (true)
				{
					setting2.registrationNo = fSettingHeadline.RegistrationNo;
					setting2.headlineIndex1 = fSettingHeadline.Index1Headline;
					setting2.headlineIndex2 = fSettingHeadline.Index2Headline;
					setting2.headlineIndex3 = fSettingHeadline.Index3Headline;
					setting2.regularHeadingIndex = fSettingHeadline.IndexRegularHeading;
					if (await mc.executeWimConnect(setting2, toolStripStatusLabelWork, null) != 0)
					{
						LOG.DebugFormat("{0}：executeWimConnect() Failed.\n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
						array = null;
						break;
					}
					array = await mc.executeSetupAddress(setting2);
					if (array == null || !array[0].Equals(MachineControl.REGISTRATION_NUMBER_INUSE))
					{
						LOG.DebugFormat("{0}：宛先登録 {1}.\n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)((array == null) ? "失敗" : "成功"));
						break;
					}
					fSettingHeadline.SetHeadLine((Form)(object)this);
					LOG.DebugFormat("{0}：New Registration No. = {1}\n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)fSettingHeadline.RegistrationNo);
				}
				if (array == null)
				{
					return;
				}
				int num = 2;
				int num2 = 3;
				text5 = array[num].Replace("'", "");
				text6 = array[num2].Replace("'", "");
			}
			((ToolStripItem)toolStripStatusLabelWork).Text = Resources.MSG_COMPLETED_RESITER_DEST_1_3 + text5 + Resources.MSG_COMPLETED_RESITER_DEST_2_3 + text6 + Resources.MSG_COMPLETED_RESITER_DEST_3_3;
			string text7 = Resources.NOTIFY_COMPLETED_RESISTER_DEST_2_5;
			if (primaxModel)
			{
				text7 = Resources.PRIMAX_NOTIFY_COMPLETED_RESISTER_DEST_2_5;
			}
			MessageBox.Show(Resources.NOTIFY_COMPLETED_RESISTER_DEST_1_5 + "\n\n\n    " + text7 + text5 + Resources.NOTIFY_COMPLETED_RESISTER_DEST_3_5 + "\n    " + Resources.ITEM_ADDRESS_NAME + text6 + "\n\n" + Resources.NOTIFY_COMPLETED_RESISTER_DEST_5_5, Resources.NOTIFY_COMPLETED_RESISTER_DEST_CAPTION);
			LOG.InfoFormat("{0} 機器への登録が完了しました  [登録情報]    登録番号：【" + text5 + "】    名称    ：【" + text6 + "】", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			((Control)linkLabelFolderSend).Visible = true;
			((Control)linkLabelHelp).Visible = false;
		}
		catch (CreateFolderException ex2)
		{
			((ToolStripItem)toolStripStatusLabelWork).Text = Resources.MSG_OCCURED_RESISTRATION_ERROR;
			LOG.InfoFormat("{0} CreateFolderException  ErrorMessage = {1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)ex2.ErrorMessage);
			if (!string.IsNullOrEmpty(ex2.ErrorMessage))
			{
				MessageBox.Show(ex2.ErrorMessage, ex2.ErrorTitle, (MessageBoxButtons)0, (MessageBoxIcon)16);
				((ToolStripItem)toolStripStatusLabelWork).Text = ex2.ErrorStatus;
			}
			((Control)linkLabelFolderSend).Visible = false;
			((Control)linkLabelHelp).Visible = true;
		}
		catch (Exception ex3)
		{
			((ToolStripItem)toolStripStatusLabelWork).Text = Resources.MSG_OCCURED_RESISTRATION_ERROR;
			LOG.ErrorFormat("{0}：宛先の登録エラー  \n" + ex3.ToString() + "\n*******************************", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			string aSK_TO_CONFIRM_DEVICE_SIDE_SCREEN = Resources.ASK_TO_CONFIRM_DEVICE_SIDE_SCREEN;
			string message = ex3.Message;
			if (ex3.ToString().IndexOf(aSK_TO_CONFIRM_DEVICE_SIDE_SCREEN) >= 0)
			{
				MessageBox.Show(message, Resources.ERR_TITLE_REGIST_ADDR, (MessageBoxButtons)0, (MessageBoxIcon)16);
			}
			else if (ex3.ToString().IndexOf(Resources.ERR_MSG_WIM_HTTP_SESSION_LIMIT) >= 0)
			{
				MessageBox.Show(message, Resources.ERR_TITLE_REGIST_ADDR, (MessageBoxButtons)0, (MessageBoxIcon)16);
			}
			else if (!string.IsNullOrEmpty(message) && message.IndexOf(Resources.WIM_ERROR_DETECT) >= 0)
			{
				message = message.Substring(Resources.WIM_ERROR_DETECT.Length);
				MessageBox.Show(message, Resources.ERR_TITLE_REGIST_ADDR, (MessageBoxButtons)0, (MessageBoxIcon)16);
			}
			else
			{
				MessageBox.Show(Resources.ERR_MSG_FATAL_RETRY, Resources.ERR_TITLE_REGIST_ADDR, (MessageBoxButtons)0, (MessageBoxIcon)16);
				((Control)linkLabelFolderSend).Visible = false;
				((Control)linkLabelHelp).Visible = true;
			}
		}
		finally
		{
			((Control)btnAdd).Enabled = true;
			((Control)btnConnectTest).Enabled = true;
			((Control)btnHeadLine).Enabled = true;
			((Control)tabControlCustom).Enabled = true;
			((Control)this).Cursor = Cursors.Default;
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		}
	}

	private void linkLabelHelp_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
	{
		//IL_0031: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：設定手順表示リンク押下", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		createHTML();
		FormHelp formHelp = new FormHelp(HELP_FILE);
		((Form)formHelp).ShowDialog((IWin32Window)(object)this);
		((Component)(object)formHelp).Dispose();
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
	}

	private void linkLabelFolderSend_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
	{
		//IL_002b: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：フォルダー送信設定手順表示リンク押下", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		FormHelp formHelp = new FormHelp(HELP_FILE_FOLDERBASE);
		((Form)formHelp).ShowDialog((IWin32Window)(object)this);
		((Component)(object)formHelp).Dispose();
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
	}

	private async void buttonHeadLine_Click(object sender, EventArgs e)
	{
		((Control)btnHeadLine).Enabled = false;
		MachineControl machineControl = new MachineControl(machineLang);
		string text = machineSelectControl.getSelectedAddress(msgOn: false)[MachineSelectControl.ADDRESS_FORM.IP];
		bool flag = FormWizard.IsPrimax(FormWizard.GetHostNameFromIP(text));
		bool primaxUnicode = FormWizard.IsPrimaxUnicode(FormWizard.GetHostNameFromIP(text));
		machineControl.SetPrimaxModel(flag);
		machineControl.SetPrimaxUnicode(primaxUnicode);
		fSettingHeadline.PrimaxProcMode = FormSettingHeadLine.PRIMAX_PROC_MODE.NOT_PRIMAX;
		if (flag)
		{
			COMMUNICATION_ERROR_CODE cOMMUNICATION_ERROR_CODE = machineControl.communicateConfirm(text, showErrorDialog: false);
			bool thhpsFlg = false;
			if (!cOMMUNICATION_ERROR_CODE.Equals(COMMUNICATION_ERROR_CODE.HTTP_ONLY))
			{
				thhpsFlg = true;
			}
			List<OneTouchKeyInfo> list = await machineControl.getPrimaxOneTouchKeyInfo(thhpsFlg, text);
			bool flag2 = true;
			for (int i = 0; i < list.Count; i++)
			{
				if (string.IsNullOrEmpty(list[i].name))
				{
					flag2 = false;
					break;
				}
			}
			if (flag2)
			{
				((Control)btnHeadLine).Enabled = true;
				MessageBox.Show(Resources.ERR_MSG_PRIMAX_NO_ONE_TOUCH_KEY, Resources.ERR_TITLE_PRIMAX_NO_ONE_TOUCH_KEY, (MessageBoxButtons)0, (MessageBoxIcon)16);
				return;
			}
			fSettingHeadline.PrimaxProcMode = FormSettingHeadLine.PRIMAX_PROC_MODE.INSERT;
			fSettingHeadline.PrimaxOneTouchKeyList = list;
			fSettingHeadline.PrimaxWizToTrp = false;
		}
		((Control)btnHeadLine).Enabled = true;
		fSettingHeadline.Initialize();
		fSettingHeadline.SetHeadLine((Form)(object)this);
	}

	private void setComboBoxSendPath()
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		comboBoxSendPath.Items.Clear();
		comboBoxSendPath.Items.Add((object)("\\\\" + getIPAddress() + "\\" + (string)comboBoxFolder.SelectedItem));
		comboBoxSendPath.Items.Add((object)("\\\\" + Dns.GetHostName() + "\\" + (string)comboBoxFolder.SelectedItem));
		if (DhcpCaution)
		{
			((ListControl)comboBoxSendPath).SelectedIndex = 1;
		}
		else
		{
			((ListControl)comboBoxSendPath).SelectedIndex = 0;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	private bool OnRemoteCertificateValidationCallback(object sender, X509Certificate certificate, X509Chain chain, SslPolicyErrors sslPolicyErrors)
	{
		return true;
	}

	private string getSharedFolderPath(string name)
	{
		//IL_00bb: Unknown result type (might be due to invalid IL or missing references)
		//IL_0024: Unknown result type (might be due to invalid IL or missing references)
		//IL_002a: Expected O, but got Unknown
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		string result = string.Empty;
		try
		{
			ManagementObjectSearcher val = new ManagementObjectSearcher("SELECT * FROM win32_share");
			try
			{
				foreach (var item in from ManagementObject x in (IEnumerable)val.Get()
					select new
					{
						Name = ((ManagementBaseObject)x)["Name"],
						Path = ((ManagementBaseObject)x)["Path"]
					})
				{
					if (string.Equals((string)item.Name, name, StringComparison.CurrentCultureIgnoreCase))
					{
						result = (string)item.Path;
						break;
					}
				}
			}
			finally
			{
				((IDisposable)val)?.Dispose();
			}
		}
		catch (Exception ex)
		{
			MessageBox.Show(Resources.ERR_MSG_FATAL, Resources.ERR_TITLE_CREATE_FOLDER, (MessageBoxButtons)0, (MessageBoxIcon)16);
			LOG.ErrorFormat("{0}：！！！ 共有フォルダー確認でエラー  \n" + ex.ToString() + "\n*******************************", (object)MethodBase.GetCurrentMethod().Name);
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return result;
	}

	private string getHostInfo()
	{
		//IL_00d4: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		string result = string.Empty;
		_ = string.Empty;
		string text = string.Empty;
		hostname = string.Empty;
		try
		{
			hostname = Dns.GetHostName();
			_ = Dns.GetHostEntry(hostname).HostName;
			text = getIPAddress();
		}
		catch (Exception ex)
		{
			Console.WriteLine(ex.ToString());
			LOG.ErrorFormat("{0}：！！！ ネットワーク情報取得中にエラー  \n" + ex.ToString() + "\n*******************************", (object)MethodBase.GetCurrentMethod().Name);
		}
		if (hostname != string.Empty)
		{
			string text2 = machineSelectControl.getSelectedAddress(msgOn: false)[MachineSelectControl.ADDRESS_FORM.IP];
			if (string.IsNullOrEmpty(ipAddr))
			{
				MessageBox.Show(Resources.MACHINE_NOT_SELECTED_ERROR2_TEXT, Resources.MACHINE_SETTING_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
				LOG.InfoFormat("{0}：機器の設定エラー：IPアドレス無し", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			}
			if (text != string.Empty)
			{
				int num = text2.LastIndexOf('.');
				int length = text.LastIndexOf('.');
				if (num > 0 && text2.Substring(0, num).Equals(text.Substring(0, length)))
				{
					result = hostname;
				}
				else if (text != string.Empty)
				{
					result = text;
				}
			}
		}
		else if (text != string.Empty)
		{
			result = text;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return result;
	}

	private void createHTML()
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		string empty = string.Empty;
		string empty2 = string.Empty;
		string empty3 = string.Empty;
		string empty4 = string.Empty;
		string empty5 = string.Empty;
		string empty6 = string.Empty;
		string empty7 = string.Empty;
		string newValue = Resources.TXT_SHARE_FOLDER_INCLUDED_PATH_OF_TOOL;
		try
		{
			empty = ((Control)comboBoxPCUserName).Text.Replace("\\", "&yen;");
			if (empty.Equals(""))
			{
				empty = Resources.CREATE_HTML_DEFAULT_USER;
			}
			empty3 = ((!getHostInfo().Equals("")) ? ("\\\\" + getIPAddress()).Replace("\\", "&yen;") : $"</font color='red'>{Resources.CREATE_HTML_NOT_FOUND_IPADRESS}</font>");
			empty2 = ((!hostname.Equals("")) ? ("\\\\" + hostname + "\\" + (string)comboBoxFolder.SelectedItem).Replace("\\", "&yen;") : Resources.CREATE_HTML_NOT_FOUND_PC_NAME);
			empty7 = ((Control)textBoxDestination).Text.Replace("\\", "&yen;");
			if (empty7.Equals(""))
			{
				empty7 = Resources.CREATE_HTML_DEFAULT_DEST;
			}
			if (!((Control)comboBoxFolder).Text.Equals(""))
			{
				newValue = ((Control)comboBoxFolder).Text;
			}
			string baseDirectory = AppDomain.CurrentDomain.BaseDirectory;
			string path = baseDirectory + HELP_FILE_BASE;
			string path2 = baseDirectory + HELP_FILE;
			string text = string.Empty;
			if (File.Exists(path))
			{
				StreamReader streamReader = new StreamReader(path, Encoding.GetEncoding("utf-8"));
				text = streamReader.ReadToEnd();
				streamReader.Close();
			}
			string value = text.Replace("{USER}", empty).Replace("{SetIP}", empty3).Replace("{SetPCName}", empty2)
				.Replace("{SetFQDN}", empty4)
				.Replace("{SetWINS}", empty5)
				.Replace("{SetDNS}", empty6)
				.Replace("{ADDR}", empty7)
				.Replace("{SendFolder}", newValue);
			StreamWriter streamWriter = new StreamWriter(path2, append: false, Encoding.GetEncoding("utf-8"));
			streamWriter.Write(value);
			streamWriter.Close();
		}
		catch (Exception ex)
		{
			LOG.ErrorFormat("{0}：！！！ HTMLファイル作成でエラー  \n" + ex.ToString() + "\n*******************************", (object)MethodBase.GetCurrentMethod().Name);
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	public string getIPAddress()
	{
		//IL_0070: Unknown result type (might be due to invalid IL or missing references)
		//IL_0077: Expected O, but got Unknown
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		if (!string.IsNullOrEmpty(ipAddr))
		{
			return ipAddr;
		}
		List<string> activeIPAddress = getActiveIPAddress();
		if (activeIPAddress == null || activeIPAddress.Count == 0)
		{
			return string.Empty;
		}
		string text = string.Empty;
		string empty = string.Empty;
		try
		{
			ManagementObjectCollection obj = WmiManager.WMIGetter("SELECT * FROM Win32_NetworkAdapterConfiguration");
			uint num = 0u;
			ManagementObjectEnumerator enumerator = obj.GetEnumerator();
			try
			{
				while (enumerator.MoveNext())
				{
					ManagementObject val = (ManagementObject)enumerator.Current;
					object obj2 = ((ManagementBaseObject)val)["IPConnectionMetric"];
					if (obj2 != null)
					{
						empty = ((((ManagementBaseObject)val)["IPAddress"] as string[])[0] ?? string.Empty).ToString();
						LOG.InfoFormat("{0}：DHCP Check IP-Address({1}) IPConnectionMetric({2})", (object)MethodBase.GetCurrentMethod().Name, (object)empty, obj2);
						if (!activeIPAddress.Contains(empty))
						{
							LOG.InfoFormat("{0}：DHCP Check next!", (object)MethodBase.GetCurrentMethod().Name);
						}
						else if (num < (uint)obj2)
						{
							num = (uint)obj2;
							ipAddr = empty;
							text = (((ManagementBaseObject)val)["DHCPEnabled"] ?? string.Empty).ToString();
							LOG.InfoFormat("{0}：DHCP Check Enabled = {1}", (object)MethodBase.GetCurrentMethod().Name, (object)text);
						}
					}
				}
			}
			finally
			{
				((IDisposable)enumerator)?.Dispose();
			}
			DhcpCaution = (text.Equals("TRUE", StringComparison.OrdinalIgnoreCase) ? true : false);
		}
		catch (Exception ex)
		{
			LOG.InfoFormat("{0}：4.5:DHCP Check Error {1}", (object)MethodBase.GetCurrentMethod().Name, (object)ex.ToString());
		}
		LOG.DebugFormat("{0}：ip-address({1}) DHCP({2})", (object)MethodBase.GetCurrentMethod().Name, (object)ipAddr, (object)text);
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return ipAddr;
	}

	private List<string> getActiveIPAddress()
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		List<string> list = new List<string>();
		try
		{
			NetworkInterface[] allNetworkInterfaces = NetworkInterface.GetAllNetworkInterfaces();
			LOG.DebugFormat("NIC個数:{0}", (object)allNetworkInterfaces.Length);
			NetworkInterface[] array = allNetworkInterfaces;
			foreach (NetworkInterface networkInterface in array)
			{
				LOG.DebugFormat("- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - ", new object[0]);
				LOG.DebugFormat("接続名:{0}", (object)networkInterface.Name);
				LOG.DebugFormat("説明:{0}", (object)networkInterface.Description);
				LOG.DebugFormat("種類:{0}", (object)networkInterface.NetworkInterfaceType);
				LOG.DebugFormat("速度:{0}", (object)networkInterface.Speed);
				LOG.DebugFormat("状態:{0}", (object)networkInterface.OperationalStatus.ToString());
				LOG.DebugFormat("MAC(物理)アドレス:{0}", (object)networkInterface.GetPhysicalAddress().ToString());
				if (networkInterface.OperationalStatus == OperationalStatus.Up && networkInterface.NetworkInterfaceType != NetworkInterfaceType.Loopback && networkInterface.NetworkInterfaceType != NetworkInterfaceType.Tunnel)
				{
					bool flag = false;
					string text = networkInterface.GetPhysicalAddress().ToString();
					StringEnumerator enumerator = Settings.Default.ignoreMacAddress.GetEnumerator();
					try
					{
						while (enumerator.MoveNext())
						{
							string[] array2 = enumerator.Current.Split(new char[1] { ',' });
							string text2 = ((array2.Length > 1) ? array2[1] : string.Empty);
							flag = text.StartsWith(array2[0]);
							if (flag)
							{
								LOG.DebugFormat("GetPhysicalAddress start with {0} ({1})", (object)array2[0], (object)text2);
								break;
							}
						}
					}
					finally
					{
						if (enumerator is IDisposable disposable)
						{
							disposable.Dispose();
						}
					}
					if (flag)
					{
						continue;
					}
					IPInterfaceProperties iPProperties = networkInterface.GetIPProperties();
					if (iPProperties != null)
					{
						LOG.DebugFormat("{0}：ipips != null", (object)MethodBase.GetCurrentMethod().Name);
						foreach (UnicastIPAddressInformation unicastAddress in iPProperties.UnicastAddresses)
						{
							LOG.DebugFormat("--------------------------------------------------------", new object[0]);
							LOG.DebugFormat("ユニキャストアドレス:{0}", (object)unicastAddress.Address);
							LOG.DebugFormat("IPv4マスク:{0}", (object)unicastAddress.IPv4Mask);
							if (Regex.IsMatch(unicastAddress.Address.ToString(), "\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}"))
							{
								list.Add(unicastAddress.Address.ToString());
								break;
							}
						}
					}
					else
					{
						LOG.DebugFormat("IPInterfaceProperties is NULL...", new object[0]);
					}
				}
				else
				{
					LOG.DebugFormat("OperationalStatus = {0} / NetworkInterfaceType = {1}", (object)networkInterface.OperationalStatus, (object)networkInterface.NetworkInterfaceType);
				}
			}
		}
		catch (Exception ex)
		{
			LOG.ErrorFormat("{0}：！！！ PCのIPアドレス取得処理でエラー  \n" + ex.ToString() + "\n*******************************", (object)MethodBase.GetCurrentMethod().Name);
		}
		LOG.DebugFormat("- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - ", new object[0]);
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return list;
	}

	private string getPathFromWindowsName(string name)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		string[] array = name.Split('(', ')');
		string result = ((array.Length > 2) ? array[1] : name);
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return result;
	}

	private string getWinVersion()
	{
		_ = string.Empty;
		OperatingSystem oSVersion = Environment.OSVersion;
		Console.WriteLine(oSVersion.ToString());
		Console.WriteLine(oSVersion.VersionString);
		Console.WriteLine(oSVersion.Version.ToString());
		Console.WriteLine(oSVersion.Platform);
		Console.WriteLine(oSVersion.Version.Major);
		Console.WriteLine(oSVersion.Version.Minor);
		Console.WriteLine(oSVersion.Version.Build);
		Console.WriteLine(oSVersion.Version.Revision);
		Console.WriteLine(oSVersion.ServicePack);
		Console.WriteLine(oSVersion.Version.MajorRevision);
		Console.WriteLine(oSVersion.Version.MinorRevision);
		return oSVersion.Version.Major + "." + oSVersion.Version.Minor;
	}

	private bool IsSafePath(string path)
	{
		bool flag = false;
		char[] invalidFileNameChars = Path.GetInvalidFileNameChars();
		if (path.IndexOfAny(invalidFileNameChars) >= 0)
		{
			return false;
		}
		return true;
	}

	private void textBoxSendFolderName_Leave(object sender, EventArgs e)
	{
		//IL_004b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0055: Expected O, but got Unknown
		if (((Control)textBoxDestination).Text.Length < 1 || ((Control)textBoxDestination).Text == Resources.TXT_P4_INITIAL_001)
		{
			((Control)textBoxDestination).Text = Resources.TXT_P4_INITIAL_001;
			((Control)textBoxDestination).Font = new Font(Resources.FONT, 9f, (FontStyle)2);
			((Control)textBoxDestination).ForeColor = Color.FromArgb(195, 195, 195);
		}
	}

	private void textBoxSendFolderName_Enter(object sender, EventArgs e)
	{
		//IL_0038: Unknown result type (might be due to invalid IL or missing references)
		//IL_0042: Expected O, but got Unknown
		if (((Control)textBoxDestination).Text.Equals(Resources.TXT_P4_INITIAL_001))
		{
			((Control)textBoxDestination).Text = string.Empty;
			((Control)textBoxDestination).Font = new Font(Resources.FONT, 9f, (FontStyle)0);
			((Control)textBoxDestination).ForeColor = Color.Black;
		}
	}

	private void textBoxPassword_Leave(object sender, EventArgs e)
	{
		//IL_004b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0055: Expected O, but got Unknown
		if (((Control)textBoxPassword).Text.Length < 1 || ((Control)textBoxPassword).Text == Resources.TXT_P3_INITIAL_001)
		{
			((Control)textBoxPassword).Text = Resources.TXT_P3_INITIAL_001;
			((Control)textBoxPassword).Font = new Font(Resources.FONT, 9f, (FontStyle)2);
			((Control)textBoxPassword).ForeColor = Color.FromArgb(195, 195, 195);
			textBoxPassword.PasswordChar = '\0';
		}
	}

	private void textBoxPassword_Enter(object sender, EventArgs e)
	{
		//IL_0038: Unknown result type (might be due to invalid IL or missing references)
		//IL_0042: Expected O, but got Unknown
		if (((Control)textBoxPassword).Text.Equals(Resources.TXT_P3_INITIAL_001))
		{
			((Control)textBoxPassword).Text = string.Empty;
			((Control)textBoxPassword).Font = new Font(Resources.FONT, 9f, (FontStyle)0);
			((Control)textBoxPassword).ForeColor = Color.Black;
			textBoxPassword.PasswordChar = '*';
		}
	}

	private void textBoxPasswordConfirm_Leave(object sender, EventArgs e)
	{
		//IL_004b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0055: Expected O, but got Unknown
		if (((Control)textBoxPasswordConfirm).Text.Length < 1 || ((Control)textBoxPasswordConfirm).Text == Resources.TXT_P3_INITIAL_002)
		{
			((Control)textBoxPasswordConfirm).Text = Resources.TXT_P3_INITIAL_002;
			((Control)textBoxPasswordConfirm).Font = new Font(Resources.FONT, 9f, (FontStyle)2);
			((Control)textBoxPasswordConfirm).ForeColor = Color.FromArgb(195, 195, 195);
			textBoxPasswordConfirm.PasswordChar = '\0';
		}
	}

	private void textBoxPasswordConfirm_Enter(object sender, EventArgs e)
	{
		//IL_0038: Unknown result type (might be due to invalid IL or missing references)
		//IL_0042: Expected O, but got Unknown
		if (((Control)textBoxPasswordConfirm).Text.Equals(Resources.TXT_P3_INITIAL_002))
		{
			((Control)textBoxPasswordConfirm).Text = string.Empty;
			((Control)textBoxPasswordConfirm).Font = new Font(Resources.FONT, 9f, (FontStyle)0);
			((Control)textBoxPasswordConfirm).ForeColor = Color.Black;
			textBoxPasswordConfirm.PasswordChar = '*';
		}
	}

	private void textBoxFolderName_Leave(object sender, EventArgs e)
	{
		//IL_004b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0055: Expected O, but got Unknown
		if (((Control)textBoxFolderName).Text.Length < 1 || ((Control)textBoxFolderName).Text == string.Empty)
		{
			((Control)textBoxFolderName).Text = Resources.TXT_P2_INITIAL_001;
			((Control)textBoxFolderName).Font = new Font(Resources.FONT, 9f, (FontStyle)2);
			((Control)textBoxFolderName).ForeColor = Color.FromArgb(195, 195, 195);
		}
	}

	private void textBoxFolderName_Enter(object sender, EventArgs e)
	{
		//IL_0038: Unknown result type (might be due to invalid IL or missing references)
		//IL_0042: Expected O, but got Unknown
		if (((Control)textBoxFolderName).Text.Equals(Resources.TXT_P2_INITIAL_001))
		{
			((Control)textBoxFolderName).Text = string.Empty;
			((Control)textBoxFolderName).Font = new Font(Resources.FONT, 9f, (FontStyle)0);
			((Control)textBoxFolderName).ForeColor = Color.Black;
		}
	}

	private void textBoxFolderPath_Leave(object sender, EventArgs e)
	{
		//IL_004b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0055: Expected O, but got Unknown
		if (((Control)textBoxFolderPath).Text.Length < 1 || ((Control)textBoxFolderPath).Text == string.Empty)
		{
			((Control)textBoxFolderPath).Text = Resources.TXT_P2_INITIAL_002;
			((Control)textBoxFolderPath).Font = new Font(Resources.FONT, 9f, (FontStyle)2);
			((Control)textBoxFolderPath).ForeColor = Color.FromArgb(195, 195, 195);
		}
	}

	private void textBoxFolderPath_Enter(object sender, EventArgs e)
	{
		//IL_0038: Unknown result type (might be due to invalid IL or missing references)
		//IL_0042: Expected O, but got Unknown
		if (((Control)textBoxFolderPath).Text.Equals(Resources.TXT_P2_INITIAL_002))
		{
			((Control)textBoxFolderPath).Text = string.Empty;
			((Control)textBoxFolderPath).Font = new Font(Resources.FONT, 9f, (FontStyle)0);
			((Control)textBoxFolderPath).ForeColor = Color.Black;
		}
	}

	private void comboBoxPCUser_Leave(object sender, EventArgs e)
	{
	}

	private void comboBoxPCUser_Enter(object sender, EventArgs e)
	{
		//IL_0038: Unknown result type (might be due to invalid IL or missing references)
		//IL_0042: Expected O, but got Unknown
		if (((Control)comboBoxPCUserName).Text.Equals(Resources.TXT_P2_INITIAL_002))
		{
			((Control)comboBoxPCUserName).Text = string.Empty;
			((Control)comboBoxPCUserName).Font = new Font(Resources.FONT, 9f, (FontStyle)0);
			((Control)comboBoxPCUserName).ForeColor = Color.Black;
		}
	}

	private void radioButtonCreateFolder_CheckedChanged(object sender, EventArgs e)
	{
		if (radioButtonCreateFolder.Checked)
		{
			((Control)label11_FolderPath).Enabled = true;
			((Control)textBoxFolderName).Enabled = true;
			((Control)label11_FolderName).Enabled = true;
			((Control)textBoxFolderPath).Enabled = true;
			((Control)btnSelectFolder).Enabled = true;
			((Control)label11_UserName).Enabled = true;
			((Control)comboBoxUserName).Enabled = true;
			((Control)label_T1_CreateMessage).Enabled = true;
			((Control)textBox_T1_FolderPath).Enabled = false;
			((Control)label_T1_FolderPath).Enabled = false;
			((Control)btn_T1_SelectFolder).Enabled = false;
			((Control)textBox_T1_SharedName).Enabled = false;
			((Control)label_T1_SharedName).Enabled = false;
			((Control)label_T1_UserName).Enabled = false;
			((Control)comboBox_T1_UserName).Enabled = false;
			((Control)label_T1_SelectMessage).Enabled = false;
		}
		else
		{
			((Control)label11_FolderPath).Enabled = false;
			((Control)textBoxFolderName).Enabled = false;
			((Control)label11_FolderName).Enabled = false;
			((Control)textBoxFolderPath).Enabled = false;
			((Control)btnSelectFolder).Enabled = false;
			((Control)label11_UserName).Enabled = false;
			((Control)comboBoxUserName).Enabled = false;
			((Control)label_T1_CreateMessage).Enabled = false;
			((Control)textBox_T1_FolderPath).Enabled = true;
			((Control)label_T1_FolderPath).Enabled = true;
			((Control)btn_T1_SelectFolder).Enabled = true;
			((Control)textBox_T1_SharedName).Enabled = true;
			((Control)label_T1_SharedName).Enabled = true;
			((Control)label_T1_UserName).Enabled = true;
			((Control)comboBox_T1_UserName).Enabled = true;
			((Control)label_T1_SelectMessage).Enabled = true;
		}
	}

	private void textBox_T1_FolderPath_Leave(object sender, EventArgs e)
	{
		//IL_005b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0065: Expected O, but got Unknown
		//IL_00b3: Unknown result type (might be due to invalid IL or missing references)
		//IL_00bd: Expected O, but got Unknown
		textBox_LeaveCommon(sender, Resources.TXT_P2_INITIAL_003);
		if (((Control)textBox_T1_FolderPath).Text == string.Empty || ((Control)textBox_T1_FolderPath).Text == Resources.TXT_P2_INITIAL_003)
		{
			((Control)textBox_T1_SharedName).Text = Resources.TXT_P2_INITIAL_001;
			((Control)textBox_T1_SharedName).Font = new Font("Resources.FONT", 9f, (FontStyle)2);
			((Control)textBox_T1_SharedName).ForeColor = Color.FromArgb(195, 195, 195);
		}
		else
		{
			string fileName = Path.GetFileName(((Control)textBox_T1_FolderPath).Text);
			((Control)textBox_T1_SharedName).Text = fileName;
			((Control)textBox_T1_SharedName).Font = new Font("Resources.FONT", 9f, (FontStyle)0);
			((Control)textBox_T1_SharedName).ForeColor = Color.Black;
		}
	}

	private void textBox_T1_FolderPath_Enter(object sender, EventArgs e)
	{
		textBox_EnterCommon(sender, Resources.TXT_P2_INITIAL_003);
	}

	private void textBox_T1_SharedName_Leave(object sender, EventArgs e)
	{
		textBox_LeaveCommon(sender, Resources.TXT_P2_INITIAL_001);
	}

	private void textBox_T1_SharedName_Enter(object sender, EventArgs e)
	{
		textBox_EnterCommon(sender, Resources.TXT_P2_INITIAL_001);
	}

	private void textBox_LeaveCommon(object sender, string initialStr)
	{
		//IL_0001: Unknown result type (might be due to invalid IL or missing references)
		//IL_0007: Expected O, but got Unknown
		//IL_0035: Unknown result type (might be due to invalid IL or missing references)
		//IL_003f: Expected O, but got Unknown
		TextBox val = (TextBox)sender;
		if (string.IsNullOrEmpty(((Control)val).Text) || string.Equals(((Control)val).Text, initialStr))
		{
			((Control)val).Text = initialStr;
			((Control)val).Font = new Font("Resources.FONT", 9f, (FontStyle)2);
			((Control)val).ForeColor = Color.FromArgb(195, 195, 195);
		}
	}

	private void textBox_EnterCommon(object sender, string initialStr)
	{
		//IL_0001: Unknown result type (might be due to invalid IL or missing references)
		//IL_0007: Expected O, but got Unknown
		//IL_002c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0036: Expected O, but got Unknown
		TextBox val = (TextBox)sender;
		if (((Control)val).Text.Equals(initialStr))
		{
			((Control)val).Text = string.Empty;
			((Control)val).Font = new Font("Resources.FONT", 9f, (FontStyle)0);
			((Control)val).ForeColor = Color.Black;
		}
	}

	private void btn_T1_SelectFolder_Click(object sender, EventArgs e)
	{
		//IL_00bc: Unknown result type (might be due to invalid IL or missing references)
		//IL_00c6: Expected O, but got Unknown
		//IL_005d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0067: Expected O, but got Unknown
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		setSelectFolder(textBox_T1_FolderPath);
		if (((Control)textBox_T1_FolderPath).Text == string.Empty)
		{
			((Control)textBox_T1_SharedName).Text = Resources.TXT_P2_INITIAL_001;
			((Control)textBox_T1_SharedName).Font = new Font("Resources.FONT", 9f, (FontStyle)2);
			((Control)textBox_T1_SharedName).ForeColor = Color.FromArgb(195, 195, 195);
		}
		else
		{
			string fileName = Path.GetFileName(getPathFromWindowsName(((Control)textBox_T1_FolderPath).Text));
			((Control)textBox_T1_SharedName).Text = fileName;
			((Control)textBox_T1_SharedName).Font = new Font("Resources.FONT", 9f, (FontStyle)0);
			((Control)textBox_T1_SharedName).ForeColor = Color.Black;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	private void setTextBoxInitialString(TextBox textBoxObj, string initialStr)
	{
		//IL_002e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0038: Expected O, but got Unknown
		//IL_005f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0069: Expected O, but got Unknown
		if (string.IsNullOrEmpty(((Control)textBoxObj).Text) || string.Equals(((Control)textBoxObj).Text, initialStr))
		{
			((Control)textBoxObj).Text = initialStr;
			((Control)textBoxObj).Font = new Font("Resources.FONT", 9f, (FontStyle)2);
			((Control)textBoxObj).ForeColor = Color.FromArgb(195, 195, 195);
		}
		else
		{
			((Control)textBoxObj).Font = new Font("Resources.FONT", 9f, (FontStyle)0);
			((Control)textBoxObj).ForeColor = Color.Black;
		}
	}

	private void setSelectFolder(TextBox textbox)
	{
		//IL_004d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0053: Expected O, but got Unknown
		//IL_006d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0073: Invalid comparison between Unknown and I4
		//IL_0093: Unknown result type (might be due to invalid IL or missing references)
		//IL_009d: Expected O, but got Unknown
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		LOG.InfoFormat("{0}：フォルダ選択ボタン押下\n", (object)MethodBase.GetCurrentMethod().Name);
		string text = getPathFromWindowsName(((Control)textbox).Text);
		if (!Directory.Exists(text))
		{
			text = CreateFolderUtil.getDesktopDirectory();
		}
		FolderBrowserDialog val = new FolderBrowserDialog();
		val.SelectedPath = text;
		val.Description = Resources.SELECT_DEST_SHARE_FOLDER;
		val.ShowNewFolderButton = false;
		if ((int)((CommonDialog)val).ShowDialog() == 1)
		{
			((Control)textbox).Text = CreateFolderUtil.getWindowsFolderName(val.SelectedPath);
			((Control)textbox).Font = new Font("Resources.FONT", 9f, (FontStyle)0);
			((Control)textbox).ForeColor = Color.Black;
			LOG.InfoFormat("{0}：end フォルダ選択結果:{1}, 表示名：{2}\n", (object)MethodBase.GetCurrentMethod().Name, (object)val.SelectedPath, (object)((Control)textbox).Text);
		}
	}

	private void machineSelectControl_SearchButtonClicked(object sender, ControlEnableFlag e)
	{
		bool enableFlag = e.flag;
		((Control)this).Invoke((Delegate)(Action)delegate
		{
			((Control)btnAdd).Enabled = enableFlag;
			((Control)btnHeadLine).Enabled = enableFlag;
		});
		LOG.DebugFormat("{0} Enabled:{1}", (object)MethodBase.GetCurrentMethod().Name);
	}

	protected override void Dispose(bool disposing)
	{
		if (disposing && components != null)
		{
			components.Dispose();
		}
		((Form)this).Dispose(disposing);
	}

	private void InitializeComponent()
	{
		//IL_0022: Unknown result type (might be due to invalid IL or missing references)
		//IL_002c: Expected O, but got Unknown
		//IL_002d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0037: Expected O, but got Unknown
		//IL_0038: Unknown result type (might be due to invalid IL or missing references)
		//IL_0042: Expected O, but got Unknown
		//IL_0043: Unknown result type (might be due to invalid IL or missing references)
		//IL_004d: Expected O, but got Unknown
		//IL_004e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0058: Expected O, but got Unknown
		//IL_0059: Unknown result type (might be due to invalid IL or missing references)
		//IL_0063: Expected O, but got Unknown
		//IL_0064: Unknown result type (might be due to invalid IL or missing references)
		//IL_006e: Expected O, but got Unknown
		//IL_006f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0079: Expected O, but got Unknown
		//IL_007a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0084: Expected O, but got Unknown
		//IL_0085: Unknown result type (might be due to invalid IL or missing references)
		//IL_008f: Expected O, but got Unknown
		//IL_0090: Unknown result type (might be due to invalid IL or missing references)
		//IL_009a: Expected O, but got Unknown
		//IL_009b: Unknown result type (might be due to invalid IL or missing references)
		//IL_00a5: Expected O, but got Unknown
		//IL_00a6: Unknown result type (might be due to invalid IL or missing references)
		//IL_00b0: Expected O, but got Unknown
		//IL_00b1: Unknown result type (might be due to invalid IL or missing references)
		//IL_00bb: Expected O, but got Unknown
		//IL_00bc: Unknown result type (might be due to invalid IL or missing references)
		//IL_00c6: Expected O, but got Unknown
		//IL_00c7: Unknown result type (might be due to invalid IL or missing references)
		//IL_00d1: Expected O, but got Unknown
		//IL_00d2: Unknown result type (might be due to invalid IL or missing references)
		//IL_00dc: Expected O, but got Unknown
		//IL_00dd: Unknown result type (might be due to invalid IL or missing references)
		//IL_00e7: Expected O, but got Unknown
		//IL_00e8: Unknown result type (might be due to invalid IL or missing references)
		//IL_00f2: Expected O, but got Unknown
		//IL_00f3: Unknown result type (might be due to invalid IL or missing references)
		//IL_00fd: Expected O, but got Unknown
		//IL_00fe: Unknown result type (might be due to invalid IL or missing references)
		//IL_0108: Expected O, but got Unknown
		//IL_0109: Unknown result type (might be due to invalid IL or missing references)
		//IL_0113: Expected O, but got Unknown
		//IL_0114: Unknown result type (might be due to invalid IL or missing references)
		//IL_011e: Expected O, but got Unknown
		//IL_011f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0129: Expected O, but got Unknown
		//IL_012a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0134: Expected O, but got Unknown
		//IL_0135: Unknown result type (might be due to invalid IL or missing references)
		//IL_013f: Expected O, but got Unknown
		//IL_0140: Unknown result type (might be due to invalid IL or missing references)
		//IL_014a: Expected O, but got Unknown
		//IL_014b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0155: Expected O, but got Unknown
		//IL_0156: Unknown result type (might be due to invalid IL or missing references)
		//IL_0160: Expected O, but got Unknown
		//IL_0161: Unknown result type (might be due to invalid IL or missing references)
		//IL_016b: Expected O, but got Unknown
		//IL_016c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0176: Expected O, but got Unknown
		//IL_0177: Unknown result type (might be due to invalid IL or missing references)
		//IL_0181: Expected O, but got Unknown
		//IL_0182: Unknown result type (might be due to invalid IL or missing references)
		//IL_018c: Expected O, but got Unknown
		//IL_018d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0197: Expected O, but got Unknown
		//IL_0198: Unknown result type (might be due to invalid IL or missing references)
		//IL_01a2: Expected O, but got Unknown
		//IL_01a3: Unknown result type (might be due to invalid IL or missing references)
		//IL_01ad: Expected O, but got Unknown
		//IL_01ae: Unknown result type (might be due to invalid IL or missing references)
		//IL_01b8: Expected O, but got Unknown
		//IL_01b9: Unknown result type (might be due to invalid IL or missing references)
		//IL_01c3: Expected O, but got Unknown
		//IL_01c4: Unknown result type (might be due to invalid IL or missing references)
		//IL_01ce: Expected O, but got Unknown
		//IL_01cf: Unknown result type (might be due to invalid IL or missing references)
		//IL_01d9: Expected O, but got Unknown
		//IL_01da: Unknown result type (might be due to invalid IL or missing references)
		//IL_01e4: Expected O, but got Unknown
		//IL_01e5: Unknown result type (might be due to invalid IL or missing references)
		//IL_01ef: Expected O, but got Unknown
		//IL_01f0: Unknown result type (might be due to invalid IL or missing references)
		//IL_01fa: Expected O, but got Unknown
		//IL_01fb: Unknown result type (might be due to invalid IL or missing references)
		//IL_0205: Expected O, but got Unknown
		//IL_0206: Unknown result type (might be due to invalid IL or missing references)
		//IL_0210: Expected O, but got Unknown
		//IL_0211: Unknown result type (might be due to invalid IL or missing references)
		//IL_021b: Expected O, but got Unknown
		//IL_021c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0226: Expected O, but got Unknown
		//IL_0227: Unknown result type (might be due to invalid IL or missing references)
		//IL_0231: Expected O, but got Unknown
		//IL_0232: Unknown result type (might be due to invalid IL or missing references)
		//IL_023c: Expected O, but got Unknown
		//IL_023d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0247: Expected O, but got Unknown
		//IL_0248: Unknown result type (might be due to invalid IL or missing references)
		//IL_0252: Expected O, but got Unknown
		//IL_0253: Unknown result type (might be due to invalid IL or missing references)
		//IL_025d: Expected O, but got Unknown
		//IL_025e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0268: Expected O, but got Unknown
		//IL_027f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0289: Expected O, but got Unknown
		//IL_0522: Unknown result type (might be due to invalid IL or missing references)
		//IL_052c: Expected O, but got Unknown
		//IL_077b: Unknown result type (might be due to invalid IL or missing references)
		//IL_07e3: Unknown result type (might be due to invalid IL or missing references)
		//IL_07ed: Expected O, but got Unknown
		//IL_088f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0899: Expected O, but got Unknown
		//IL_090e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0918: Expected O, but got Unknown
		//IL_0b22: Unknown result type (might be due to invalid IL or missing references)
		//IL_0b2c: Expected O, but got Unknown
		//IL_0bbc: Unknown result type (might be due to invalid IL or missing references)
		//IL_0bc6: Expected O, but got Unknown
		//IL_0c53: Unknown result type (might be due to invalid IL or missing references)
		//IL_0c5d: Expected O, but got Unknown
		//IL_0d9e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0da8: Expected O, but got Unknown
		//IL_0e44: Unknown result type (might be due to invalid IL or missing references)
		//IL_0e4e: Expected O, but got Unknown
		//IL_0eea: Unknown result type (might be due to invalid IL or missing references)
		//IL_0ef4: Expected O, but got Unknown
		//IL_0f90: Unknown result type (might be due to invalid IL or missing references)
		//IL_0f9a: Expected O, but got Unknown
		//IL_101a: Unknown result type (might be due to invalid IL or missing references)
		//IL_1024: Expected O, but got Unknown
		//IL_10b0: Unknown result type (might be due to invalid IL or missing references)
		//IL_10ba: Expected O, but got Unknown
		//IL_115f: Unknown result type (might be due to invalid IL or missing references)
		//IL_1169: Expected O, but got Unknown
		//IL_1200: Unknown result type (might be due to invalid IL or missing references)
		//IL_120a: Expected O, but got Unknown
		//IL_158d: Unknown result type (might be due to invalid IL or missing references)
		//IL_165b: Unknown result type (might be due to invalid IL or missing references)
		//IL_1665: Expected O, but got Unknown
		//IL_1810: Unknown result type (might be due to invalid IL or missing references)
		//IL_181a: Expected O, but got Unknown
		//IL_189a: Unknown result type (might be due to invalid IL or missing references)
		//IL_18a4: Expected O, but got Unknown
		//IL_1956: Unknown result type (might be due to invalid IL or missing references)
		//IL_1960: Expected O, but got Unknown
		//IL_19f0: Unknown result type (might be due to invalid IL or missing references)
		//IL_19fa: Expected O, but got Unknown
		//IL_1a8a: Unknown result type (might be due to invalid IL or missing references)
		//IL_1a94: Expected O, but got Unknown
		//IL_1b24: Unknown result type (might be due to invalid IL or missing references)
		//IL_1b2e: Expected O, but got Unknown
		//IL_1bbb: Unknown result type (might be due to invalid IL or missing references)
		//IL_1bc5: Expected O, but got Unknown
		//IL_1c55: Unknown result type (might be due to invalid IL or missing references)
		//IL_1c5f: Expected O, but got Unknown
		//IL_1d6c: Unknown result type (might be due to invalid IL or missing references)
		//IL_1d76: Expected O, but got Unknown
		//IL_1e17: Unknown result type (might be due to invalid IL or missing references)
		//IL_1e21: Expected O, but got Unknown
		//IL_1e9e: Unknown result type (might be due to invalid IL or missing references)
		//IL_1ea8: Expected O, but got Unknown
		//IL_1f1d: Unknown result type (might be due to invalid IL or missing references)
		//IL_1f27: Expected O, but got Unknown
		//IL_21c9: Unknown result type (might be due to invalid IL or missing references)
		//IL_21d3: Expected O, but got Unknown
		//IL_22a0: Unknown result type (might be due to invalid IL or missing references)
		//IL_22aa: Expected O, but got Unknown
		components = new Container();
		ComponentResourceManager componentResourceManager = new ComponentResourceManager(typeof(FormMain));
		mainMenu1 = new MainMenu(components);
		menuItemFile = new MenuItem();
		menuItemExit = new MenuItem();
		menuItemSecurity = new MenuItem();
		menuItemVersion = new MenuItem();
		menuItemClose = new MenuItem();
		statusStripFolder = new StatusStrip();
		toolStripStatusLabelProgress = new ToolStripStatusLabel();
		toolStripStatusLabelWork = new ToolStripStatusLabel();
		tabControlCustom = new TabControl();
		tabPage1 = new TabPage();
		btnSelectFolder = new Button();
		label11_comment = new Label();
		btnCreateFolder = new Button();
		textBoxFolderName = new TextBox();
		textBoxFolderPath = new TextBox();
		comboBoxUserName = new ComboBox();
		label11_UserName = new Label();
		label11_FolderName = new Label();
		label11_FolderPath = new Label();
		radioButtonCreateFolder = new RadioButton();
		label_T1_FolderPath = new Label();
		label_T1_SharedName = new Label();
		label_T1_UserName = new Label();
		label_T1_SelectMessage = new Label();
		label_T1_CreateMessage = new Label();
		btn_T1_SelectFolder = new Button();
		textBox_T1_FolderPath = new TextBox();
		textBox_T1_SharedName = new TextBox();
		comboBox_T1_UserName = new ComboBox();
		radioButtonSelectFolder = new RadioButton();
		tabPage2 = new TabPage();
		comboBoxSendPath = new ComboBox();
		label12_PasswordConfirm = new Label();
		textBoxPasswordConfirm = new TextBox();
		btnHeadLine = new Button();
		linkLabelFolderSend = new LinkLabel();
		btnConnectTest = new Button();
		label12_Password = new Label();
		label12_UserName = new Label();
		label12_Path = new Label();
		label12_Destination = new Label();
		label12_Machine = new Label();
		label12_Folder = new Label();
		linkLabelHelp = new LinkLabel();
		comboBoxFolder = new ComboBox();
		label12_GuideMessage = new Label();
		label12_comment = new Label();
		btnAdd = new Button();
		textBoxPassword = new TextBox();
		textBoxDestination = new TextBox();
		comboBoxPCUserName = new ComboBox();
		label11_GuideMessage = new Label();
		machineSelectControl = new MachineSelectControl("ja");
		toolTipPath = new ToolTip(components);
		((Control)statusStripFolder).SuspendLayout();
		((Control)tabControlCustom).SuspendLayout();
		((Control)tabPage1).SuspendLayout();
		((Control)tabPage2).SuspendLayout();
		((Control)this).SuspendLayout();
		((Menu)mainMenu1).MenuItems.AddRange((MenuItem[])(object)new MenuItem[4] { menuItemFile, menuItemSecurity, menuItemVersion, menuItemClose });
		menuItemFile.Index = 0;
		((Menu)menuItemFile).MenuItems.AddRange((MenuItem[])(object)new MenuItem[1] { menuItemExit });
		menuItemFile.Text = "File(&F)";
		menuItemExit.Index = 0;
		menuItemExit.Text = "Close(&E)";
		menuItemExit.Click += menuItemExit_Click;
		menuItemSecurity.Index = 1;
		menuItemSecurity.Text = "Security(&S)";
		menuItemSecurity.Click += menuItemSetup_Click;
		menuItemVersion.Index = 2;
		menuItemVersion.Text = "Version(&H)";
		menuItemVersion.Click += menuItemVersion_Click;
		menuItemClose.Index = 3;
		menuItemClose.Text = "Close(&X)";
		menuItemClose.Click += menuItemClose_Click;
		((ToolStrip)statusStripFolder).Items.AddRange((ToolStripItem[])(object)new ToolStripItem[2]
		{
			(ToolStripItem)toolStripStatusLabelProgress,
			(ToolStripItem)toolStripStatusLabelWork
		});
		((Control)statusStripFolder).Location = new Point(0, 656);
		((Control)statusStripFolder).Name = "statusStripFolder";
		((Control)statusStripFolder).Size = new Size(679, 22);
		((Control)statusStripFolder).TabIndex = 9;
		((Control)statusStripFolder).Text = "statusStrip1";
		((ToolStripItem)toolStripStatusLabelProgress).Name = "toolStripStatusLabelProgress";
		((ToolStripItem)toolStripStatusLabelProgress).Size = new Size(61, 17);
		((ToolStripItem)toolStripStatusLabelProgress).Text = "Progress : ";
		((ToolStripItem)toolStripStatusLabelWork).Name = "toolStripStatusLabelWork";
		((ToolStripItem)toolStripStatusLabelWork).Size = new Size(19, 17);
		((ToolStripItem)toolStripStatusLabelWork).Text = "\u3000";
		((Control)tabControlCustom).Controls.Add((Control)(object)tabPage1);
		((Control)tabControlCustom).Controls.Add((Control)(object)tabPage2);
		((Control)tabControlCustom).Font = new Font("MS UI Gothic", 9f);
		((Control)tabControlCustom).Location = new Point(14, 5);
		((Control)tabControlCustom).Name = "tabControlCustom";
		tabControlCustom.SelectedIndex = 0;
		((Control)tabControlCustom).Size = new Size(660, 647);
		((Control)tabControlCustom).TabIndex = 10;
		tabControlCustom.SelectedIndexChanged += tabControlCustom_SelectedIndexChanged;
		((Control)tabPage1).Controls.Add((Control)(object)btnSelectFolder);
		((Control)tabPage1).Controls.Add((Control)(object)label11_comment);
		((Control)tabPage1).Controls.Add((Control)(object)btnCreateFolder);
		((Control)tabPage1).Controls.Add((Control)(object)textBoxFolderName);
		((Control)tabPage1).Controls.Add((Control)(object)textBoxFolderPath);
		((Control)tabPage1).Controls.Add((Control)(object)comboBoxUserName);
		((Control)tabPage1).Controls.Add((Control)(object)label11_UserName);
		((Control)tabPage1).Controls.Add((Control)(object)label11_FolderName);
		((Control)tabPage1).Controls.Add((Control)(object)label11_FolderPath);
		((Control)tabPage1).Controls.Add((Control)(object)radioButtonCreateFolder);
		((Control)tabPage1).Controls.Add((Control)(object)label_T1_FolderPath);
		((Control)tabPage1).Controls.Add((Control)(object)label_T1_SharedName);
		((Control)tabPage1).Controls.Add((Control)(object)label_T1_UserName);
		((Control)tabPage1).Controls.Add((Control)(object)label_T1_SelectMessage);
		((Control)tabPage1).Controls.Add((Control)(object)label_T1_CreateMessage);
		((Control)tabPage1).Controls.Add((Control)(object)btn_T1_SelectFolder);
		((Control)tabPage1).Controls.Add((Control)(object)textBox_T1_FolderPath);
		((Control)tabPage1).Controls.Add((Control)(object)textBox_T1_SharedName);
		((Control)tabPage1).Controls.Add((Control)(object)comboBox_T1_UserName);
		((Control)tabPage1).Controls.Add((Control)(object)radioButtonSelectFolder);
		tabPage1.Location = new Point(4, 22);
		((Control)tabPage1).Name = "tabPage1";
		((Control)tabPage1).Padding = new Padding(3);
		((Control)tabPage1).Size = new Size(652, 621);
		tabPage1.TabIndex = 0;
		((Control)tabPage1).Text = "Create Folder";
		tabPage1.UseVisualStyleBackColor = true;
		((Control)btnSelectFolder).AutoSize = true;
		((Control)btnSelectFolder).Font = new Font("MS UI Gothic", 9f);
		((ButtonBase)btnSelectFolder).ImeMode = (ImeMode)0;
		((Control)btnSelectFolder).Location = new Point(571, 90);
		((Control)btnSelectFolder).Name = "btnSelectFolder";
		((Control)btnSelectFolder).Size = new Size(53, 22);
		((Control)btnSelectFolder).TabIndex = 3;
		((Control)btnSelectFolder).Text = "Refer";
		((ButtonBase)btnSelectFolder).UseVisualStyleBackColor = true;
		((Control)btnSelectFolder).Click += buttonSelectFolder_Click;
		((Control)label11_comment).AutoSize = true;
		((Control)label11_comment).Font = new Font("MS UI Gothic", 9f);
		label11_comment.ImeMode = (ImeMode)0;
		((Control)label11_comment).Location = new Point(24, 26);
		((Control)label11_comment).Name = "label11_comment";
		((Control)label11_comment).Size = new Size(283, 12);
		((Control)label11_comment).TabIndex = 17;
		((Control)label11_comment).Text = "Create folder at computer to sink scanned documents.";
		((Control)btnCreateFolder).Font = new Font("MS UI Gothic", 11f, (FontStyle)1);
		((ButtonBase)btnCreateFolder).ImeMode = (ImeMode)0;
		((Control)btnCreateFolder).Location = new Point(33, 400);
		((Control)btnCreateFolder).Name = "btnCreateFolder";
		((Control)btnCreateFolder).Size = new Size(588, 34);
		((Control)btnCreateFolder).TabIndex = 5;
		((Control)btnCreateFolder).Text = "Create";
		((ButtonBase)btnCreateFolder).UseVisualStyleBackColor = true;
		((Control)btnCreateFolder).Click += buttonCreateFolder_Click;
		((Control)textBoxFolderName).Location = new Point(164, 120);
		((Control)textBoxFolderName).Name = "textBoxFolderName";
		((Control)textBoxFolderName).Size = new Size(460, 19);
		((Control)textBoxFolderName).TabIndex = 1;
		((Control)textBoxFolderName).Text = "ScanDoc";
		((Control)textBoxFolderName).Enter += textBoxFolderName_Enter;
		((Control)textBoxFolderName).Leave += textBoxFolderName_Leave;
		((Control)textBoxFolderPath).Location = new Point(164, 90);
		((Control)textBoxFolderPath).Name = "textBoxFolderPath";
		((Control)textBoxFolderPath).Size = new Size(400, 19);
		((Control)textBoxFolderPath).TabIndex = 2;
		((Control)textBoxFolderPath).Enter += textBoxFolderPath_Enter;
		((Control)textBoxFolderPath).Leave += textBoxFolderPath_Leave;
		comboBoxUserName.DropDownStyle = (ComboBoxStyle)2;
		((ListControl)comboBoxUserName).FormattingEnabled = true;
		((Control)comboBoxUserName).Location = new Point(164, 150);
		((Control)comboBoxUserName).Name = "comboBoxUserName";
		((Control)comboBoxUserName).Size = new Size(460, 20);
		((Control)comboBoxUserName).TabIndex = 4;
		((Control)label11_UserName).AutoSize = true;
		((Control)label11_UserName).Font = new Font("MS UI Gothic", 9f);
		((Control)label11_UserName).ForeColor = SystemColors.Highlight;
		label11_UserName.ImeMode = (ImeMode)0;
		((Control)label11_UserName).Location = new Point(33, 150);
		((Control)label11_UserName).Name = "label11_UserName";
		((Control)label11_UserName).Size = new Size(62, 12);
		((Control)label11_UserName).TabIndex = 15;
		((Control)label11_UserName).Text = "User Name";
		((Control)label11_FolderName).AutoSize = true;
		((Control)label11_FolderName).Font = new Font("MS UI Gothic", 9f);
		((Control)label11_FolderName).ForeColor = SystemColors.Highlight;
		label11_FolderName.ImeMode = (ImeMode)0;
		((Control)label11_FolderName).Location = new Point(33, 120);
		((Control)label11_FolderName).Name = "label11_FolderName";
		((Control)label11_FolderName).Size = new Size(70, 12);
		((Control)label11_FolderName).TabIndex = 10;
		((Control)label11_FolderName).Text = "Folder Name";
		((Control)label11_FolderPath).AutoSize = true;
		((Control)label11_FolderPath).Font = new Font("MS UI Gothic", 9f);
		((Control)label11_FolderPath).ForeColor = SystemColors.Highlight;
		label11_FolderPath.ImeMode = (ImeMode)0;
		((Control)label11_FolderPath).Location = new Point(33, 90);
		((Control)label11_FolderPath).Name = "label11_FolderPath";
		((Control)label11_FolderPath).Size = new Size(64, 12);
		((Control)label11_FolderPath).TabIndex = 13;
		((Control)label11_FolderPath).Text = "Folder Path";
		((Control)radioButtonCreateFolder).AutoSize = true;
		radioButtonCreateFolder.Checked = true;
		((ButtonBase)radioButtonCreateFolder).ImeMode = (ImeMode)0;
		((Control)radioButtonCreateFolder).Location = new Point(24, 60);
		((Control)radioButtonCreateFolder).Name = "radioButtonCreateFolder";
		((Control)radioButtonCreateFolder).Size = new Size(114, 16);
		((Control)radioButtonCreateFolder).TabIndex = 13;
		radioButtonCreateFolder.TabStop = true;
		((Control)radioButtonCreateFolder).Text = "Create new folder";
		((ButtonBase)radioButtonCreateFolder).UseVisualStyleBackColor = true;
		radioButtonCreateFolder.CheckedChanged += radioButtonCreateFolder_CheckedChanged;
		((Control)label_T1_FolderPath).AutoSize = true;
		((Control)label_T1_FolderPath).Enabled = false;
		((Control)label_T1_FolderPath).Font = new Font("MS UI Gothic", 9f);
		((Control)label_T1_FolderPath).ForeColor = SystemColors.Highlight;
		label_T1_FolderPath.ImeMode = (ImeMode)0;
		((Control)label_T1_FolderPath).Location = new Point(33, 240);
		((Control)label_T1_FolderPath).Name = "label_T1_FolderPath";
		((Control)label_T1_FolderPath).Size = new Size(64, 12);
		((Control)label_T1_FolderPath).TabIndex = 11;
		((Control)label_T1_FolderPath).Text = "Folder Path";
		((Control)label_T1_SharedName).AutoSize = true;
		((Control)label_T1_SharedName).Enabled = false;
		((Control)label_T1_SharedName).Font = new Font("MS UI Gothic", 9f);
		((Control)label_T1_SharedName).ForeColor = SystemColors.Highlight;
		label_T1_SharedName.ImeMode = (ImeMode)0;
		((Control)label_T1_SharedName).Location = new Point(33, 270);
		((Control)label_T1_SharedName).Name = "label_T1_SharedName";
		((Control)label_T1_SharedName).Size = new Size(73, 12);
		((Control)label_T1_SharedName).TabIndex = 11;
		((Control)label_T1_SharedName).Text = "Shared Name";
		((Control)label_T1_UserName).AutoSize = true;
		((Control)label_T1_UserName).Enabled = false;
		((Control)label_T1_UserName).Font = new Font("MS UI Gothic", 9f);
		((Control)label_T1_UserName).ForeColor = SystemColors.Highlight;
		label_T1_UserName.ImeMode = (ImeMode)0;
		((Control)label_T1_UserName).Location = new Point(33, 300);
		((Control)label_T1_UserName).Name = "label_T1_UserName";
		((Control)label_T1_UserName).Size = new Size(62, 12);
		((Control)label_T1_UserName).TabIndex = 15;
		((Control)label_T1_UserName).Text = "User Name";
		((Control)label_T1_SelectMessage).AutoSize = true;
		((Control)label_T1_SelectMessage).Enabled = false;
		((Control)label_T1_SelectMessage).Font = new Font("MS UI Gothic", 9f);
		label_T1_SelectMessage.ImeMode = (ImeMode)0;
		((Control)label_T1_SelectMessage).Location = new Point(33, 330);
		((Control)label_T1_SelectMessage).Name = "label_T1_SelectMessage";
		((Control)label_T1_SelectMessage).Size = new Size(73, 12);
		((Control)label_T1_SelectMessage).TabIndex = 11;
		((Control)label_T1_SelectMessage).Text = "Select Folder";
		((Control)label_T1_CreateMessage).AutoSize = true;
		((Control)label_T1_CreateMessage).Font = new Font("MS UI Gothic", 9f);
		label_T1_CreateMessage.ImeMode = (ImeMode)0;
		((Control)label_T1_CreateMessage).Location = new Point(33, 180);
		((Control)label_T1_CreateMessage).Name = "label_T1_CreateMessage";
		((Control)label_T1_CreateMessage).Size = new Size(75, 12);
		((Control)label_T1_CreateMessage).TabIndex = 11;
		((Control)label_T1_CreateMessage).Text = "Create Folder";
		((Control)btn_T1_SelectFolder).AutoSize = true;
		((Control)btn_T1_SelectFolder).Enabled = false;
		((Control)btn_T1_SelectFolder).Font = new Font("MS UI Gothic", 9f);
		((ButtonBase)btn_T1_SelectFolder).ImeMode = (ImeMode)0;
		((Control)btn_T1_SelectFolder).Location = new Point(571, 240);
		((Control)btn_T1_SelectFolder).Name = "btn_T1_SelectFolder";
		((Control)btn_T1_SelectFolder).Size = new Size(55, 22);
		((Control)btn_T1_SelectFolder).TabIndex = 5;
		((Control)btn_T1_SelectFolder).Text = "参照";
		((ButtonBase)btn_T1_SelectFolder).UseVisualStyleBackColor = true;
		((Control)btn_T1_SelectFolder).Click += btn_T1_SelectFolder_Click;
		((Control)textBox_T1_FolderPath).Enabled = false;
		((Control)textBox_T1_FolderPath).Font = new Font("MS UI Gothic", 9f);
		((Control)textBox_T1_FolderPath).Location = new Point(164, 240);
		((Control)textBox_T1_FolderPath).Name = "textBox_T1_FolderPath";
		((Control)textBox_T1_FolderPath).Size = new Size(400, 19);
		((Control)textBox_T1_FolderPath).TabIndex = 4;
		((Control)textBox_T1_FolderPath).Enter += textBox_T1_FolderPath_Enter;
		((Control)textBox_T1_FolderPath).Leave += textBox_T1_FolderPath_Leave;
		((Control)textBox_T1_SharedName).Enabled = false;
		((Control)textBox_T1_SharedName).Font = new Font("MS UI Gothic", 9f);
		((Control)textBox_T1_SharedName).Location = new Point(164, 270);
		((Control)textBox_T1_SharedName).Name = "textBox_T1_SharedName";
		((Control)textBox_T1_SharedName).Size = new Size(460, 19);
		((Control)textBox_T1_SharedName).TabIndex = 4;
		((Control)textBox_T1_SharedName).Enter += textBox_T1_SharedName_Enter;
		((Control)textBox_T1_SharedName).Leave += textBox_T1_SharedName_Leave;
		comboBox_T1_UserName.DropDownStyle = (ComboBoxStyle)2;
		((Control)comboBox_T1_UserName).Enabled = false;
		((ListControl)comboBox_T1_UserName).FormattingEnabled = true;
		((Control)comboBox_T1_UserName).Location = new Point(164, 300);
		((Control)comboBox_T1_UserName).Name = "comboBox_T1_UserName";
		((Control)comboBox_T1_UserName).Size = new Size(460, 20);
		((Control)comboBox_T1_UserName).TabIndex = 4;
		((Control)radioButtonSelectFolder).AutoSize = true;
		((ButtonBase)radioButtonSelectFolder).ImeMode = (ImeMode)0;
		((Control)radioButtonSelectFolder).Location = new Point(24, 210);
		((Control)radioButtonSelectFolder).Name = "radioButtonSelectFolder";
		((Control)radioButtonSelectFolder).Size = new Size(88, 16);
		((Control)radioButtonSelectFolder).TabIndex = 13;
		radioButtonSelectFolder.TabStop = true;
		((Control)radioButtonSelectFolder).Text = "Select folder";
		((ButtonBase)radioButtonSelectFolder).UseVisualStyleBackColor = true;
		radioButtonSelectFolder.CheckedChanged += radioButtonCreateFolder_CheckedChanged;
		((Control)tabPage2).Controls.Add((Control)(object)comboBoxSendPath);
		((Control)tabPage2).Controls.Add((Control)(object)label12_PasswordConfirm);
		((Control)tabPage2).Controls.Add((Control)(object)textBoxPasswordConfirm);
		((Control)tabPage2).Controls.Add((Control)(object)btnHeadLine);
		((Control)tabPage2).Controls.Add((Control)(object)linkLabelFolderSend);
		((Control)tabPage2).Controls.Add((Control)(object)btnConnectTest);
		((Control)tabPage2).Controls.Add((Control)(object)label12_Password);
		((Control)tabPage2).Controls.Add((Control)(object)label12_UserName);
		((Control)tabPage2).Controls.Add((Control)(object)label12_Path);
		((Control)tabPage2).Controls.Add((Control)(object)label12_Destination);
		((Control)tabPage2).Controls.Add((Control)(object)label12_Machine);
		((Control)tabPage2).Controls.Add((Control)(object)label12_Folder);
		((Control)tabPage2).Controls.Add((Control)(object)linkLabelHelp);
		((Control)tabPage2).Controls.Add((Control)(object)comboBoxFolder);
		((Control)tabPage2).Controls.Add((Control)(object)label12_GuideMessage);
		((Control)tabPage2).Controls.Add((Control)(object)label12_comment);
		((Control)tabPage2).Controls.Add((Control)(object)btnAdd);
		((Control)tabPage2).Controls.Add((Control)(object)textBoxPassword);
		((Control)tabPage2).Controls.Add((Control)(object)textBoxDestination);
		((Control)tabPage2).Controls.Add((Control)(object)comboBoxPCUserName);
		((Control)tabPage2).Controls.Add((Control)(object)machineSelectControl);
		tabPage2.Location = new Point(4, 22);
		((Control)tabPage2).Name = "tabPage2";
		((Control)tabPage2).Padding = new Padding(3);
		((Control)tabPage2).Size = new Size(652, 621);
		tabPage2.TabIndex = 1;
		((Control)tabPage2).Text = "Add Destination";
		tabPage2.UseVisualStyleBackColor = true;
		comboBoxSendPath.DropDownStyle = (ComboBoxStyle)2;
		((ListControl)comboBoxSendPath).FormattingEnabled = true;
		((Control)comboBoxSendPath).Location = new Point(164, 233);
		((Control)comboBoxSendPath).Name = "comboBoxSendPath";
		((Control)comboBoxSendPath).Size = new Size(459, 20);
		((Control)comboBoxSendPath).TabIndex = 43;
		((Control)label12_PasswordConfirm).AutoSize = true;
		((Control)label12_PasswordConfirm).Font = new Font("MS UI Gothic", 9f);
		((Control)label12_PasswordConfirm).ForeColor = SystemColors.Highlight;
		label12_PasswordConfirm.ImeMode = (ImeMode)0;
		((Control)label12_PasswordConfirm).Location = new Point(33, 205);
		((Control)label12_PasswordConfirm).Name = "label12_PasswordConfirm";
		((Control)label12_PasswordConfirm).Size = new Size(102, 12);
		((Control)label12_PasswordConfirm).TabIndex = 42;
		((Control)label12_PasswordConfirm).Text = "Password(Confirm)";
		((Control)textBoxPasswordConfirm).Location = new Point(164, 202);
		((Control)textBoxPasswordConfirm).Name = "textBoxPasswordConfirm";
		textBoxPasswordConfirm.PasswordChar = '*';
		((Control)textBoxPasswordConfirm).Size = new Size(460, 19);
		((Control)textBoxPasswordConfirm).TabIndex = 10;
		((Control)textBoxPasswordConfirm).Enter += textBoxPasswordConfirm_Enter;
		((Control)textBoxPasswordConfirm).Leave += textBoxPasswordConfirm_Leave;
		((Control)btnHeadLine).AutoSize = true;
		((ButtonBase)btnHeadLine).ImeMode = (ImeMode)0;
		((Control)btnHeadLine).Location = new Point(510, 50);
		((Control)btnHeadLine).Name = "btnHeadLine";
		((Control)btnHeadLine).Size = new Size(114, 23);
		((Control)btnHeadLine).TabIndex = 6;
		((Control)btnHeadLine).Text = "Index";
		((ButtonBase)btnHeadLine).UseVisualStyleBackColor = true;
		((Control)btnHeadLine).Click += buttonHeadLine_Click;
		((Control)linkLabelFolderSend).AutoSize = true;
		((Control)linkLabelFolderSend).Font = new Font("MS UI Gothic", 9f);
		((Label)linkLabelFolderSend).ImeMode = (ImeMode)0;
		((Control)linkLabelFolderSend).Location = new Point(35, 576);
		((Control)linkLabelFolderSend).Name = "linkLabelFolderSend";
		((Control)linkLabelFolderSend).Size = new Size(144, 12);
		((Control)linkLabelFolderSend).TabIndex = 17;
		linkLabelFolderSend.TabStop = true;
		((Control)linkLabelFolderSend).Text = "How to send data to folder.";
		linkLabelFolderSend.LinkClicked += new LinkLabelLinkClickedEventHandler(linkLabelFolderSend_LinkClicked);
		((Control)btnConnectTest).AutoSize = true;
		((ButtonBase)btnConnectTest).ImeMode = (ImeMode)0;
		((Control)btnConnectTest).Location = new Point(492, 489);
		((Control)btnConnectTest).Name = "btnConnectTest";
		((Control)btnConnectTest).Size = new Size(114, 23);
		((Control)btnConnectTest).TabIndex = 14;
		((Control)btnConnectTest).Text = "Com. Test";
		((ButtonBase)btnConnectTest).UseVisualStyleBackColor = true;
		((Control)btnConnectTest).Click += buttonConnectTest_Click;
		((Control)label12_Password).AutoSize = true;
		((Control)label12_Password).Font = new Font("MS UI Gothic", 9f);
		((Control)label12_Password).ForeColor = SystemColors.Highlight;
		label12_Password.ImeMode = (ImeMode)0;
		((Control)label12_Password).Location = new Point(33, 175);
		((Control)label12_Password).Name = "label12_Password";
		((Control)label12_Password).Size = new Size(54, 12);
		((Control)label12_Password).TabIndex = 37;
		((Control)label12_Password).Text = "Password";
		((Control)label12_UserName).AutoSize = true;
		((Control)label12_UserName).Font = new Font("MS UI Gothic", 9f);
		((Control)label12_UserName).ForeColor = SystemColors.Highlight;
		label12_UserName.ImeMode = (ImeMode)0;
		((Control)label12_UserName).Location = new Point(33, 145);
		((Control)label12_UserName).Name = "label12_UserName";
		((Control)label12_UserName).Size = new Size(62, 12);
		((Control)label12_UserName).TabIndex = 36;
		((Control)label12_UserName).Text = "User Name";
		((Control)label12_Path).AutoSize = true;
		((Control)label12_Path).Font = new Font("MS UI Gothic", 9f);
		((Control)label12_Path).ForeColor = SystemColors.Highlight;
		label12_Path.ImeMode = (ImeMode)0;
		((Control)label12_Path).Location = new Point(33, 235);
		((Control)label12_Path).Name = "label12_Path";
		((Control)label12_Path).Size = new Size(28, 12);
		((Control)label12_Path).TabIndex = 35;
		((Control)label12_Path).Text = "Path";
		((Control)label12_Destination).AutoSize = true;
		((Control)label12_Destination).Font = new Font("MS UI Gothic", 9f);
		((Control)label12_Destination).ForeColor = SystemColors.Highlight;
		label12_Destination.ImeMode = (ImeMode)0;
		((Control)label12_Destination).Location = new Point(33, 55);
		((Control)label12_Destination).Name = "label12_Destination";
		((Control)label12_Destination).Size = new Size(63, 12);
		((Control)label12_Destination).TabIndex = 34;
		((Control)label12_Destination).Text = "Destination";
		((Control)label12_Machine).AutoSize = true;
		((Control)label12_Machine).Font = new Font("MS UI Gothic", 9f);
		((Control)label12_Machine).ForeColor = SystemColors.Highlight;
		label12_Machine.ImeMode = (ImeMode)0;
		((Control)label12_Machine).Location = new Point(33, 265);
		((Control)label12_Machine).Name = "label12_Machine";
		((Control)label12_Machine).Size = new Size(47, 12);
		((Control)label12_Machine).TabIndex = 33;
		((Control)label12_Machine).Text = "Machine";
		((Control)label12_Folder).AutoSize = true;
		((Control)label12_Folder).Font = new Font("MS UI Gothic", 9f);
		((Control)label12_Folder).ForeColor = SystemColors.Highlight;
		label12_Folder.ImeMode = (ImeMode)0;
		((Control)label12_Folder).Location = new Point(33, 85);
		((Control)label12_Folder).Name = "label12_Folder";
		((Control)label12_Folder).Size = new Size(37, 12);
		((Control)label12_Folder).TabIndex = 31;
		((Control)label12_Folder).Text = "Folder";
		((Control)linkLabelHelp).AutoSize = true;
		((Label)linkLabelHelp).ImeMode = (ImeMode)0;
		linkLabelHelp.LinkColor = Color.Red;
		((Control)linkLabelHelp).Location = new Point(35, 602);
		((Control)linkLabelHelp).Name = "linkLabelHelp";
		((Control)linkLabelHelp).Size = new Size(226, 12);
		((Control)linkLabelHelp).TabIndex = 18;
		linkLabelHelp.TabStop = true;
		((Control)linkLabelHelp).Text = "Direct regist procedure on panel if it failed.";
		linkLabelHelp.LinkClicked += new LinkLabelLinkClickedEventHandler(linkLabelHelp_LinkClicked);
		comboBoxFolder.DropDownStyle = (ComboBoxStyle)2;
		((ListControl)comboBoxFolder).FormattingEnabled = true;
		((Control)comboBoxFolder).Location = new Point(164, 83);
		((Control)comboBoxFolder).Name = "comboBoxFolder";
		((Control)comboBoxFolder).Size = new Size(460, 20);
		comboBoxFolder.Sorted = true;
		((Control)comboBoxFolder).TabIndex = 7;
		comboBoxFolder.SelectedIndexChanged += comboBoxFolder_SelectedIndexChanged;
		((Control)label12_GuideMessage).AutoSize = true;
		((Control)label12_GuideMessage).Font = new Font("MS UI Gothic", 9f);
		label12_GuideMessage.ImeMode = (ImeMode)0;
		((Control)label12_GuideMessage).Location = new Point(33, 106);
		((Control)label12_GuideMessage).Name = "label12_GuideMessage";
		((Control)label12_GuideMessage).Size = new Size(72, 12);
		((Control)label12_GuideMessage).TabIndex = 26;
		((Control)label12_GuideMessage).Text = "Select folder.";
		((Control)label12_comment).AutoSize = true;
		((Control)label12_comment).Font = new Font("MS UI Gothic", 9f);
		label12_comment.ImeMode = (ImeMode)0;
		((Control)label12_comment).Location = new Point(24, 26);
		((Control)label12_comment).Name = "label12_comment";
		((Control)label12_comment).Size = new Size(131, 12);
		((Control)label12_comment).TabIndex = 21;
		((Control)label12_comment).Text = "Regist folder to machine";
		((Control)btnAdd).Font = new Font("MS UI Gothic", 11f, (FontStyle)1);
		((ButtonBase)btnAdd).ImeMode = (ImeMode)0;
		((Control)btnAdd).Location = new Point(35, 522);
		((Control)btnAdd).Name = "btnAdd";
		((Control)btnAdd).Size = new Size(591, 34);
		((Control)btnAdd).TabIndex = 16;
		((Control)btnAdd).Text = "Add";
		((ButtonBase)btnAdd).UseVisualStyleBackColor = true;
		((Control)btnAdd).Click += buttonSend_Click;
		((Control)textBoxPassword).Location = new Point(164, 171);
		((Control)textBoxPassword).Name = "textBoxPassword";
		textBoxPassword.PasswordChar = '*';
		((Control)textBoxPassword).Size = new Size(460, 19);
		((Control)textBoxPassword).TabIndex = 9;
		((Control)textBoxPassword).Enter += textBoxPassword_Enter;
		((Control)textBoxPassword).Leave += textBoxPassword_Leave;
		((Control)textBoxDestination).Location = new Point(164, 52);
		((Control)textBoxDestination).Name = "textBoxDestination";
		((Control)textBoxDestination).Size = new Size(340, 19);
		((Control)textBoxDestination).TabIndex = 5;
		((Control)textBoxDestination).Enter += textBoxSendFolderName_Enter;
		((Control)textBoxDestination).Leave += textBoxSendFolderName_Leave;
		comboBoxPCUserName.DropDownStyle = (ComboBoxStyle)2;
		((ListControl)comboBoxPCUserName).FormattingEnabled = true;
		((Control)comboBoxPCUserName).Location = new Point(164, 139);
		((Control)comboBoxPCUserName).Name = "comboBoxPCUserName";
		((Control)comboBoxPCUserName).Size = new Size(460, 20);
		((Control)comboBoxPCUserName).TabIndex = 8;
		((Control)comboBoxPCUserName).Enter += comboBoxPCUser_Enter;
		((Control)comboBoxPCUserName).Leave += comboBoxPCUser_Leave;
		((Control)machineSelectControl).Location = new Point(164, 265);
		((Control)machineSelectControl).Name = "machineSelectControl";
		((Control)machineSelectControl).Size = new Size(442, 222);
		((Control)machineSelectControl).TabIndex = 12;
		machineSelectControl.SearchButtonClicked += machineSelectControl_SearchButtonClicked;
		((Control)label11_GuideMessage).AutoSize = true;
		((Control)label11_GuideMessage).Font = new Font("MS UI Gothic", 9f);
		label11_GuideMessage.ImeMode = (ImeMode)0;
		((Control)label11_GuideMessage).Location = new Point(33, 330);
		((Control)label11_GuideMessage).Name = "label11_GuideMessage";
		((Control)label11_GuideMessage).Size = new Size(187, 12);
		((Control)label11_GuideMessage).TabIndex = 24;
		((Control)label11_GuideMessage).Text = "Select user name for access folder.";
		((ContainerControl)this).AutoScaleDimensions = new SizeF(6f, 12f);
		((ContainerControl)this).AutoScaleMode = (AutoScaleMode)1;
		((Form)this).ClientSize = new Size(689, 678);
		((Control)this).Controls.Add((Control)(object)tabControlCustom);
		((Control)this).Controls.Add((Control)(object)statusStripFolder);
		((Form)this).FormBorderStyle = (FormBorderStyle)1;
		((Form)this).Icon = (Icon)componentResourceManager.GetObject("$this.Icon");
		((Form)this).MaximizeBox = false;
		((Form)this).Menu = mainMenu1;
		((Form)this).MinimizeBox = false;
		((Control)this).Name = "FormMain";
		((Form)this).StartPosition = (FormStartPosition)4;
		((Control)statusStripFolder).ResumeLayout(false);
		((Control)statusStripFolder).PerformLayout();
		((Control)tabControlCustom).ResumeLayout(false);
		((Control)tabPage1).ResumeLayout(false);
		((Control)tabPage1).PerformLayout();
		((Control)tabPage2).ResumeLayout(false);
		((Control)tabPage2).PerformLayout();
		((Control)this).ResumeLayout(false);
		((Control)this).PerformLayout();
	}

	private void InitializeComponent_MultiLang()
	{
		//IL_0022: Unknown result type (might be due to invalid IL or missing references)
		//IL_002c: Expected O, but got Unknown
		//IL_002d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0037: Expected O, but got Unknown
		//IL_0038: Unknown result type (might be due to invalid IL or missing references)
		//IL_0042: Expected O, but got Unknown
		//IL_0043: Unknown result type (might be due to invalid IL or missing references)
		//IL_004d: Expected O, but got Unknown
		//IL_004e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0058: Expected O, but got Unknown
		//IL_0059: Unknown result type (might be due to invalid IL or missing references)
		//IL_0063: Expected O, but got Unknown
		//IL_0064: Unknown result type (might be due to invalid IL or missing references)
		//IL_006e: Expected O, but got Unknown
		//IL_006f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0079: Expected O, but got Unknown
		//IL_007a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0084: Expected O, but got Unknown
		//IL_0085: Unknown result type (might be due to invalid IL or missing references)
		//IL_008f: Expected O, but got Unknown
		//IL_0090: Unknown result type (might be due to invalid IL or missing references)
		//IL_009a: Expected O, but got Unknown
		//IL_009b: Unknown result type (might be due to invalid IL or missing references)
		//IL_00a5: Expected O, but got Unknown
		//IL_00a6: Unknown result type (might be due to invalid IL or missing references)
		//IL_00b0: Expected O, but got Unknown
		//IL_00b1: Unknown result type (might be due to invalid IL or missing references)
		//IL_00bb: Expected O, but got Unknown
		//IL_00bc: Unknown result type (might be due to invalid IL or missing references)
		//IL_00c6: Expected O, but got Unknown
		//IL_00c7: Unknown result type (might be due to invalid IL or missing references)
		//IL_00d1: Expected O, but got Unknown
		//IL_00d2: Unknown result type (might be due to invalid IL or missing references)
		//IL_00dc: Expected O, but got Unknown
		//IL_00dd: Unknown result type (might be due to invalid IL or missing references)
		//IL_00e7: Expected O, but got Unknown
		//IL_00e8: Unknown result type (might be due to invalid IL or missing references)
		//IL_00f2: Expected O, but got Unknown
		//IL_00f3: Unknown result type (might be due to invalid IL or missing references)
		//IL_00fd: Expected O, but got Unknown
		//IL_00fe: Unknown result type (might be due to invalid IL or missing references)
		//IL_0108: Expected O, but got Unknown
		//IL_0109: Unknown result type (might be due to invalid IL or missing references)
		//IL_0113: Expected O, but got Unknown
		//IL_0114: Unknown result type (might be due to invalid IL or missing references)
		//IL_011e: Expected O, but got Unknown
		//IL_011f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0129: Expected O, but got Unknown
		//IL_012a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0134: Expected O, but got Unknown
		//IL_0135: Unknown result type (might be due to invalid IL or missing references)
		//IL_013f: Expected O, but got Unknown
		//IL_0140: Unknown result type (might be due to invalid IL or missing references)
		//IL_014a: Expected O, but got Unknown
		//IL_014b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0155: Expected O, but got Unknown
		//IL_0156: Unknown result type (might be due to invalid IL or missing references)
		//IL_0160: Expected O, but got Unknown
		//IL_0161: Unknown result type (might be due to invalid IL or missing references)
		//IL_016b: Expected O, but got Unknown
		//IL_016c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0176: Expected O, but got Unknown
		//IL_0177: Unknown result type (might be due to invalid IL or missing references)
		//IL_0181: Expected O, but got Unknown
		//IL_0182: Unknown result type (might be due to invalid IL or missing references)
		//IL_018c: Expected O, but got Unknown
		//IL_018d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0197: Expected O, but got Unknown
		//IL_0198: Unknown result type (might be due to invalid IL or missing references)
		//IL_01a2: Expected O, but got Unknown
		//IL_01a3: Unknown result type (might be due to invalid IL or missing references)
		//IL_01ad: Expected O, but got Unknown
		//IL_01ae: Unknown result type (might be due to invalid IL or missing references)
		//IL_01b8: Expected O, but got Unknown
		//IL_01b9: Unknown result type (might be due to invalid IL or missing references)
		//IL_01c3: Expected O, but got Unknown
		//IL_01c4: Unknown result type (might be due to invalid IL or missing references)
		//IL_01ce: Expected O, but got Unknown
		//IL_01cf: Unknown result type (might be due to invalid IL or missing references)
		//IL_01d9: Expected O, but got Unknown
		//IL_01da: Unknown result type (might be due to invalid IL or missing references)
		//IL_01e4: Expected O, but got Unknown
		//IL_01e5: Unknown result type (might be due to invalid IL or missing references)
		//IL_01ef: Expected O, but got Unknown
		//IL_01f0: Unknown result type (might be due to invalid IL or missing references)
		//IL_01fa: Expected O, but got Unknown
		//IL_01fb: Unknown result type (might be due to invalid IL or missing references)
		//IL_0205: Expected O, but got Unknown
		//IL_0206: Unknown result type (might be due to invalid IL or missing references)
		//IL_0210: Expected O, but got Unknown
		//IL_0211: Unknown result type (might be due to invalid IL or missing references)
		//IL_021b: Expected O, but got Unknown
		//IL_021c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0226: Expected O, but got Unknown
		//IL_0227: Unknown result type (might be due to invalid IL or missing references)
		//IL_0231: Expected O, but got Unknown
		//IL_0232: Unknown result type (might be due to invalid IL or missing references)
		//IL_023c: Expected O, but got Unknown
		//IL_023d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0247: Expected O, but got Unknown
		//IL_0248: Unknown result type (might be due to invalid IL or missing references)
		//IL_0252: Expected O, but got Unknown
		//IL_0253: Unknown result type (might be due to invalid IL or missing references)
		//IL_025d: Expected O, but got Unknown
		//IL_025e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0268: Expected O, but got Unknown
		//IL_026f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0279: Expected O, but got Unknown
		//IL_0522: Unknown result type (might be due to invalid IL or missing references)
		//IL_052c: Expected O, but got Unknown
		//IL_0791: Unknown result type (might be due to invalid IL or missing references)
		//IL_07f9: Unknown result type (might be due to invalid IL or missing references)
		//IL_0803: Expected O, but got Unknown
		//IL_0886: Unknown result type (might be due to invalid IL or missing references)
		//IL_0890: Expected O, but got Unknown
		//IL_0932: Unknown result type (might be due to invalid IL or missing references)
		//IL_093c: Expected O, but got Unknown
		//IL_0b1b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0b25: Expected O, but got Unknown
		//IL_0bb1: Unknown result type (might be due to invalid IL or missing references)
		//IL_0bbb: Expected O, but got Unknown
		//IL_0cb8: Unknown result type (might be due to invalid IL or missing references)
		//IL_0cc2: Expected O, but got Unknown
		//IL_0d52: Unknown result type (might be due to invalid IL or missing references)
		//IL_0d5c: Expected O, but got Unknown
		//IL_0dff: Unknown result type (might be due to invalid IL or missing references)
		//IL_0e09: Expected O, but got Unknown
		//IL_0e99: Unknown result type (might be due to invalid IL or missing references)
		//IL_0ea3: Expected O, but got Unknown
		//IL_0f46: Unknown result type (might be due to invalid IL or missing references)
		//IL_0f50: Expected O, but got Unknown
		//IL_0fec: Unknown result type (might be due to invalid IL or missing references)
		//IL_0ff6: Expected O, but got Unknown
		//IL_1090: Unknown result type (might be due to invalid IL or missing references)
		//IL_109a: Expected O, but got Unknown
		//IL_12a4: Unknown result type (might be due to invalid IL or missing references)
		//IL_12ae: Expected O, but got Unknown
		//IL_133e: Unknown result type (might be due to invalid IL or missing references)
		//IL_1348: Expected O, but got Unknown
		//IL_13d5: Unknown result type (might be due to invalid IL or missing references)
		//IL_13df: Expected O, but got Unknown
		//IL_1648: Unknown result type (might be due to invalid IL or missing references)
		//IL_1716: Unknown result type (might be due to invalid IL or missing references)
		//IL_1720: Expected O, but got Unknown
		//IL_18ce: Unknown result type (might be due to invalid IL or missing references)
		//IL_18d8: Expected O, but got Unknown
		//IL_1958: Unknown result type (might be due to invalid IL or missing references)
		//IL_1962: Expected O, but got Unknown
		//IL_1a17: Unknown result type (might be due to invalid IL or missing references)
		//IL_1a21: Expected O, but got Unknown
		//IL_1ab1: Unknown result type (might be due to invalid IL or missing references)
		//IL_1abb: Expected O, but got Unknown
		//IL_1b4b: Unknown result type (might be due to invalid IL or missing references)
		//IL_1b55: Expected O, but got Unknown
		//IL_1be5: Unknown result type (might be due to invalid IL or missing references)
		//IL_1bef: Expected O, but got Unknown
		//IL_1c7c: Unknown result type (might be due to invalid IL or missing references)
		//IL_1c86: Expected O, but got Unknown
		//IL_1d16: Unknown result type (might be due to invalid IL or missing references)
		//IL_1d20: Expected O, but got Unknown
		//IL_1e2d: Unknown result type (might be due to invalid IL or missing references)
		//IL_1e37: Expected O, but got Unknown
		//IL_1ed8: Unknown result type (might be due to invalid IL or missing references)
		//IL_1ee2: Expected O, but got Unknown
		//IL_1f5f: Unknown result type (might be due to invalid IL or missing references)
		//IL_1f69: Expected O, but got Unknown
		//IL_1fde: Unknown result type (might be due to invalid IL or missing references)
		//IL_1fe8: Expected O, but got Unknown
		//IL_22d4: Unknown result type (might be due to invalid IL or missing references)
		//IL_22de: Expected O, but got Unknown
		components = new Container();
		ComponentResourceManager componentResourceManager = new ComponentResourceManager(typeof(FormMain));
		mainMenu1 = new MainMenu(components);
		menuItemFile = new MenuItem();
		menuItemExit = new MenuItem();
		menuItemSecurity = new MenuItem();
		menuItemVersion = new MenuItem();
		menuItemClose = new MenuItem();
		statusStripFolder = new StatusStrip();
		toolStripStatusLabelProgress = new ToolStripStatusLabel();
		toolStripStatusLabelWork = new ToolStripStatusLabel();
		tabControlCustom = new TabControl();
		tabPage1 = new TabPage();
		radioButtonCreateFolder = new RadioButton();
		label_T1_FolderPath = new Label();
		label_T1_SharedName = new Label();
		label_T1_UserName = new Label();
		label_T1_SelectMessage = new Label();
		label_T1_CreateMessage = new Label();
		btn_T1_SelectFolder = new Button();
		textBox_T1_FolderPath = new TextBox();
		textBox_T1_SharedName = new TextBox();
		comboBox_T1_UserName = new ComboBox();
		radioButtonSelectFolder = new RadioButton();
		label11_GuideMessage = new Label();
		btnSelectFolder = new Button();
		label11_comment = new Label();
		btnCreateFolder = new Button();
		textBoxFolderName = new TextBox();
		textBoxFolderPath = new TextBox();
		comboBoxUserName = new ComboBox();
		label11_UserName = new Label();
		label11_FolderName = new Label();
		label11_FolderPath = new Label();
		tabPage2 = new TabPage();
		comboBoxSendPath = new ComboBox();
		label12_PasswordConfirm = new Label();
		textBoxPasswordConfirm = new TextBox();
		btnHeadLine = new Button();
		linkLabelFolderSend = new LinkLabel();
		btnConnectTest = new Button();
		label12_Password = new Label();
		label12_UserName = new Label();
		label12_Path = new Label();
		label12_Destination = new Label();
		label12_Machine = new Label();
		label12_Folder = new Label();
		linkLabelHelp = new LinkLabel();
		comboBoxFolder = new ComboBox();
		label12_GuideMessage = new Label();
		label12_comment = new Label();
		btnAdd = new Button();
		textBoxPassword = new TextBox();
		textBoxDestination = new TextBox();
		comboBoxPCUserName = new ComboBox();
		toolTipPath = new ToolTip(components);
		((Control)statusStripFolder).SuspendLayout();
		((Control)tabControlCustom).SuspendLayout();
		((Control)tabPage1).SuspendLayout();
		((Control)tabPage2).SuspendLayout();
		((Control)this).SuspendLayout();
		machineSelectControl = new MachineSelectControl("");
		((Menu)mainMenu1).MenuItems.AddRange((MenuItem[])(object)new MenuItem[4] { menuItemFile, menuItemSecurity, menuItemVersion, menuItemClose });
		menuItemFile.Index = 0;
		((Menu)menuItemFile).MenuItems.AddRange((MenuItem[])(object)new MenuItem[1] { menuItemExit });
		menuItemFile.Text = "File(&F)";
		menuItemExit.Index = 0;
		menuItemExit.Text = "Close(&E)";
		menuItemExit.Click += menuItemExit_Click;
		menuItemSecurity.Index = 1;
		menuItemSecurity.Text = "Security(&S)";
		menuItemSecurity.Click += menuItemSetup_Click;
		menuItemVersion.Index = 2;
		menuItemVersion.Text = "Version(&H)";
		menuItemVersion.Click += menuItemVersion_Click;
		menuItemClose.Index = 3;
		menuItemClose.Text = "Close(&X)";
		menuItemClose.Click += menuItemClose_Click;
		((ToolStrip)statusStripFolder).Items.AddRange((ToolStripItem[])(object)new ToolStripItem[2]
		{
			(ToolStripItem)toolStripStatusLabelProgress,
			(ToolStripItem)toolStripStatusLabelWork
		});
		((Control)statusStripFolder).Location = new Point(0, 484);
		((Control)statusStripFolder).Name = "statusStripFolder";
		((Control)statusStripFolder).Size = new Size(679, 22);
		((Control)statusStripFolder).TabIndex = 9;
		((Control)statusStripFolder).Text = "statusStrip1";
		((ToolStripItem)toolStripStatusLabelProgress).Name = "toolStripStatusLabelProgress";
		((ToolStripItem)toolStripStatusLabelProgress).Size = new Size(61, 17);
		((ToolStripItem)toolStripStatusLabelProgress).Text = "Progress : ";
		((ToolStripItem)toolStripStatusLabelWork).Name = "toolStripStatusLabelWork";
		((ToolStripItem)toolStripStatusLabelWork).Size = new Size(19, 17);
		((ToolStripItem)toolStripStatusLabelWork).Text = "\u3000";
		((Control)tabControlCustom).Controls.Add((Control)(object)tabPage1);
		((Control)tabControlCustom).Controls.Add((Control)(object)tabPage2);
		((Control)tabControlCustom).Font = new Font("MS UI Gothic", 9f);
		((Control)tabControlCustom).Location = new Point(14, 5);
		((Control)tabControlCustom).Name = "tabControlCustom";
		tabControlCustom.SelectedIndex = 0;
		((Control)tabControlCustom).Size = new Size(780, 647);
		((Control)tabControlCustom).TabIndex = 10;
		tabControlCustom.SelectedIndexChanged += tabControlCustom_SelectedIndexChanged;
		((Control)tabPage1).Controls.Add((Control)(object)label11_GuideMessage);
		((Control)tabPage1).Controls.Add((Control)(object)btnSelectFolder);
		((Control)tabPage1).Controls.Add((Control)(object)label11_comment);
		((Control)tabPage1).Controls.Add((Control)(object)btnCreateFolder);
		((Control)tabPage1).Controls.Add((Control)(object)textBoxFolderName);
		((Control)tabPage1).Controls.Add((Control)(object)textBoxFolderPath);
		((Control)tabPage1).Controls.Add((Control)(object)comboBoxUserName);
		((Control)tabPage1).Controls.Add((Control)(object)label11_UserName);
		((Control)tabPage1).Controls.Add((Control)(object)label11_FolderName);
		((Control)tabPage1).Controls.Add((Control)(object)label11_FolderPath);
		((Control)tabPage1).Controls.Add((Control)(object)radioButtonCreateFolder);
		((Control)tabPage1).Controls.Add((Control)(object)label_T1_FolderPath);
		((Control)tabPage1).Controls.Add((Control)(object)label_T1_SharedName);
		((Control)tabPage1).Controls.Add((Control)(object)label_T1_UserName);
		((Control)tabPage1).Controls.Add((Control)(object)label_T1_SelectMessage);
		((Control)tabPage1).Controls.Add((Control)(object)label_T1_CreateMessage);
		((Control)tabPage1).Controls.Add((Control)(object)btn_T1_SelectFolder);
		((Control)tabPage1).Controls.Add((Control)(object)textBox_T1_FolderPath);
		((Control)tabPage1).Controls.Add((Control)(object)textBox_T1_SharedName);
		((Control)tabPage1).Controls.Add((Control)(object)comboBox_T1_UserName);
		((Control)tabPage1).Controls.Add((Control)(object)radioButtonSelectFolder);
		tabPage1.Location = new Point(4, 22);
		((Control)tabPage1).Name = "tabPage1";
		((Control)tabPage1).Padding = new Padding(3);
		((Control)tabPage1).Size = new Size(792, 621);
		tabPage1.TabIndex = 0;
		((Control)tabPage1).Text = "Create Folder";
		tabPage1.UseVisualStyleBackColor = true;
		((Control)label11_GuideMessage).AutoSize = true;
		((Control)label11_GuideMessage).Font = new Font("MS UI Gothic", 9f);
		label11_GuideMessage.ImeMode = (ImeMode)0;
		((Control)label11_GuideMessage).Location = new Point(33, 330);
		((Control)label11_GuideMessage).Name = "label11_GuideMessage";
		((Control)label11_GuideMessage).Size = new Size(187, 12);
		((Control)label11_GuideMessage).TabIndex = 24;
		((Control)label11_GuideMessage).Text = "Select user name for access folder.";
		((Control)btnSelectFolder).AutoSize = true;
		((Control)btnSelectFolder).Font = new Font("MS UI Gothic", 9f);
		((ButtonBase)btnSelectFolder).ImeMode = (ImeMode)0;
		((Control)btnSelectFolder).Location = new Point(621, 90);
		((Control)btnSelectFolder).Name = "btnSelectFolder";
		((Control)btnSelectFolder).Size = new Size(103, 21);
		((Control)btnSelectFolder).TabIndex = 3;
		((Control)btnSelectFolder).Text = "Refer";
		((ButtonBase)btnSelectFolder).UseVisualStyleBackColor = true;
		((Control)btnSelectFolder).Click += buttonSelectFolder_Click;
		((Control)label11_comment).AutoSize = true;
		((Control)label11_comment).Font = new Font("MS UI Gothic", 9f);
		label11_comment.ImeMode = (ImeMode)0;
		((Control)label11_comment).Location = new Point(24, 26);
		((Control)label11_comment).Name = "label11_comment";
		((Control)label11_comment).Size = new Size(283, 12);
		((Control)label11_comment).TabIndex = 17;
		((Control)label11_comment).Text = "Create folder at computer to sink scanned documents.";
		((Control)radioButtonCreateFolder).AutoSize = true;
		radioButtonCreateFolder.Checked = true;
		((ButtonBase)radioButtonCreateFolder).ImeMode = (ImeMode)0;
		((Control)radioButtonCreateFolder).Location = new Point(24, 60);
		((Control)radioButtonCreateFolder).Name = "radioButtonCreateFolder";
		((Control)radioButtonCreateFolder).Size = new Size(114, 16);
		((Control)radioButtonCreateFolder).TabIndex = 13;
		radioButtonCreateFolder.TabStop = true;
		((Control)radioButtonCreateFolder).Text = "Create new folder";
		((ButtonBase)radioButtonCreateFolder).UseVisualStyleBackColor = true;
		radioButtonCreateFolder.CheckedChanged += radioButtonCreateFolder_CheckedChanged;
		((Control)radioButtonSelectFolder).AutoSize = true;
		radioButtonSelectFolder.Checked = false;
		((ButtonBase)radioButtonSelectFolder).ImeMode = (ImeMode)0;
		((Control)radioButtonSelectFolder).Location = new Point(24, 210);
		((Control)radioButtonSelectFolder).Name = "radioButtonSelectFolder";
		((Control)radioButtonSelectFolder).Size = new Size(114, 16);
		((Control)radioButtonSelectFolder).TabIndex = 13;
		radioButtonSelectFolder.TabStop = true;
		((Control)radioButtonSelectFolder).Text = "Select folder";
		((ButtonBase)radioButtonSelectFolder).UseVisualStyleBackColor = true;
		radioButtonSelectFolder.CheckedChanged += radioButtonCreateFolder_CheckedChanged;
		((Control)label_T1_SelectMessage).Enabled = false;
		((Control)label_T1_SelectMessage).AutoSize = true;
		((Control)label_T1_SelectMessage).Font = new Font("MS UI Gothic", 9f);
		label_T1_SelectMessage.ImeMode = (ImeMode)0;
		((Control)label_T1_SelectMessage).Location = new Point(33, 330);
		((Control)label_T1_SelectMessage).Name = "label_T1_SelectMessage";
		((Control)label_T1_SelectMessage).Size = new Size(64, 12);
		((Control)label_T1_SelectMessage).TabIndex = 11;
		((Control)label_T1_SelectMessage).Text = "Select Folder";
		((Control)label_T1_CreateMessage).Enabled = true;
		((Control)label_T1_CreateMessage).AutoSize = true;
		((Control)label_T1_CreateMessage).Font = new Font("MS UI Gothic", 9f);
		label_T1_CreateMessage.ImeMode = (ImeMode)0;
		((Control)label_T1_CreateMessage).Location = new Point(33, 180);
		((Control)label_T1_CreateMessage).Name = "label_T1_CreateMessage";
		((Control)label_T1_CreateMessage).Size = new Size(64, 12);
		((Control)label_T1_CreateMessage).TabIndex = 11;
		((Control)label_T1_CreateMessage).Text = "Create Folder";
		((Control)comboBox_T1_UserName).Enabled = false;
		comboBox_T1_UserName.DropDownStyle = (ComboBoxStyle)2;
		((ListControl)comboBox_T1_UserName).FormattingEnabled = true;
		((Control)comboBox_T1_UserName).Location = new Point(264, 300);
		((Control)comboBox_T1_UserName).Name = "comboBox_T1_UserName";
		((Control)comboBox_T1_UserName).Size = new Size(460, 20);
		((Control)comboBox_T1_UserName).TabIndex = 4;
		((Control)label_T1_UserName).AutoSize = true;
		((Control)label_T1_UserName).Enabled = false;
		((Control)label_T1_UserName).Font = new Font("MS UI Gothic", 9f);
		label_T1_UserName.ImeMode = (ImeMode)0;
		((Control)label_T1_UserName).ForeColor = SystemColors.Highlight;
		((Control)label_T1_UserName).Location = new Point(33, 300);
		((Control)label_T1_UserName).Name = "label_T1_UserName";
		((Control)label_T1_UserName).Size = new Size(62, 12);
		((Control)label_T1_UserName).TabIndex = 15;
		((Control)label_T1_UserName).Text = "User Name";
		((Control)textBox_T1_SharedName).Enabled = false;
		((Control)textBox_T1_SharedName).Font = new Font("MS UI Gothic", 9f);
		((Control)textBox_T1_SharedName).Location = new Point(264, 270);
		((Control)textBox_T1_SharedName).Name = "textBox_T1_SharedName";
		((Control)textBox_T1_SharedName).Size = new Size(460, 19);
		((Control)textBox_T1_SharedName).TabIndex = 4;
		((Control)textBox_T1_SharedName).Enter += textBox_T1_SharedName_Enter;
		((Control)textBox_T1_SharedName).Leave += textBox_T1_SharedName_Leave;
		((Control)label_T1_SharedName).Enabled = false;
		((Control)label_T1_SharedName).AutoSize = true;
		((Control)label_T1_SharedName).Font = new Font("MS UI Gothic", 9f);
		label_T1_SharedName.ImeMode = (ImeMode)0;
		((Control)label_T1_SharedName).ForeColor = SystemColors.Highlight;
		((Control)label_T1_SharedName).Location = new Point(33, 270);
		((Control)label_T1_SharedName).Name = "label_T1_SharedName";
		((Control)label_T1_SharedName).Size = new Size(64, 12);
		((Control)label_T1_SharedName).TabIndex = 11;
		((Control)label_T1_SharedName).Text = "Shared Name";
		((Control)textBox_T1_FolderPath).Enabled = false;
		((Control)textBox_T1_FolderPath).Font = new Font("MS UI Gothic", 9f);
		((Control)textBox_T1_FolderPath).Location = new Point(264, 240);
		((Control)textBox_T1_FolderPath).Name = "textBoxFolderPath";
		((Control)textBox_T1_FolderPath).Size = new Size(350, 19);
		((Control)textBox_T1_FolderPath).TabIndex = 4;
		((Control)textBox_T1_FolderPath).Enter += textBox_T1_FolderPath_Enter;
		((Control)textBox_T1_FolderPath).Leave += textBox_T1_FolderPath_Leave;
		((Control)label_T1_FolderPath).Enabled = false;
		((Control)label_T1_FolderPath).AutoSize = true;
		((Control)label_T1_FolderPath).Font = new Font("MS UI Gothic", 9f);
		((Control)label_T1_FolderPath).ForeColor = SystemColors.Highlight;
		label_T1_FolderPath.ImeMode = (ImeMode)0;
		((Control)label_T1_FolderPath).Location = new Point(33, 240);
		((Control)label_T1_FolderPath).Name = "label_T1_FolderPath";
		((Control)label_T1_FolderPath).Size = new Size(64, 12);
		((Control)label_T1_FolderPath).TabIndex = 11;
		((Control)label_T1_FolderPath).Text = "Folder Path";
		((Control)btn_T1_SelectFolder).AutoSize = true;
		((Control)btn_T1_SelectFolder).Enabled = false;
		((Control)btn_T1_SelectFolder).Font = new Font("MS UI Gothic", 9f);
		((ButtonBase)btn_T1_SelectFolder).ImeMode = (ImeMode)0;
		((Control)btn_T1_SelectFolder).Location = new Point(621, 240);
		((Control)btn_T1_SelectFolder).Name = "btn_T1_SelectFolder";
		((Control)btn_T1_SelectFolder).Size = new Size(105, 22);
		((Control)btn_T1_SelectFolder).TabIndex = 5;
		((Control)btn_T1_SelectFolder).Text = "参照";
		((ButtonBase)btn_T1_SelectFolder).UseVisualStyleBackColor = true;
		((Control)btn_T1_SelectFolder).Click += btn_T1_SelectFolder_Click;
		((Control)btnCreateFolder).Font = new Font("MS UI Gothic", 11f, (FontStyle)1);
		((ButtonBase)btnCreateFolder).ImeMode = (ImeMode)0;
		((Control)btnCreateFolder).Location = new Point(33, 400);
		((Control)btnCreateFolder).Name = "btnCreateFolder";
		((Control)btnCreateFolder).Size = new Size(688, 34);
		((Control)btnCreateFolder).TabIndex = 5;
		((Control)btnCreateFolder).Text = "Create";
		((ButtonBase)btnCreateFolder).UseVisualStyleBackColor = true;
		((Control)btnCreateFolder).Click += buttonCreateFolder_Click;
		((Control)textBoxFolderName).Location = new Point(264, 120);
		((Control)textBoxFolderName).Name = "textBoxFolderName";
		((Control)textBoxFolderName).Size = new Size(460, 19);
		((Control)textBoxFolderName).TabIndex = 1;
		((Control)textBoxFolderName).Text = "ScanDoc";
		((Control)textBoxFolderName).Enter += textBoxFolderName_Enter;
		((Control)textBoxFolderName).Leave += textBoxFolderName_Leave;
		((Control)textBoxFolderPath).Location = new Point(264, 90);
		((Control)textBoxFolderPath).Name = "textBoxFolderPath";
		((Control)textBoxFolderPath).Size = new Size(350, 19);
		((Control)textBoxFolderPath).TabIndex = 2;
		((Control)textBoxFolderPath).Enter += textBoxFolderPath_Enter;
		((Control)textBoxFolderPath).Leave += textBoxFolderPath_Leave;
		comboBoxUserName.DropDownStyle = (ComboBoxStyle)2;
		((ListControl)comboBoxUserName).FormattingEnabled = true;
		((Control)comboBoxUserName).Location = new Point(264, 150);
		((Control)comboBoxUserName).Name = "comboBoxUserName";
		((Control)comboBoxUserName).Size = new Size(460, 20);
		((Control)comboBoxUserName).TabIndex = 4;
		((Control)label11_UserName).AutoSize = true;
		((Control)label11_UserName).Font = new Font("MS UI Gothic", 9f);
		((Control)label11_UserName).ForeColor = SystemColors.Highlight;
		label11_UserName.ImeMode = (ImeMode)0;
		((Control)label11_UserName).Location = new Point(33, 150);
		((Control)label11_UserName).Name = "label11_UserName";
		((Control)label11_UserName).Size = new Size(62, 12);
		((Control)label11_UserName).TabIndex = 15;
		((Control)label11_UserName).Text = "User Name";
		((Control)label11_FolderName).AutoSize = true;
		((Control)label11_FolderName).Font = new Font("MS UI Gothic", 9f);
		((Control)label11_FolderName).ForeColor = SystemColors.Highlight;
		label11_FolderName.ImeMode = (ImeMode)0;
		((Control)label11_FolderName).Location = new Point(33, 120);
		((Control)label11_FolderName).Name = "label11_FolderName";
		((Control)label11_FolderName).Size = new Size(70, 12);
		((Control)label11_FolderName).TabIndex = 10;
		((Control)label11_FolderName).Text = "Folder Name";
		((Control)label11_FolderPath).AutoSize = true;
		((Control)label11_FolderPath).Font = new Font("MS UI Gothic", 9f);
		((Control)label11_FolderPath).ForeColor = SystemColors.Highlight;
		label11_FolderPath.ImeMode = (ImeMode)0;
		((Control)label11_FolderPath).Location = new Point(33, 90);
		((Control)label11_FolderPath).Name = "label11_FolderPath";
		((Control)label11_FolderPath).Size = new Size(64, 12);
		((Control)label11_FolderPath).TabIndex = 13;
		((Control)label11_FolderPath).Text = "Folder Path";
		((Control)tabPage2).Controls.Add((Control)(object)comboBoxSendPath);
		((Control)tabPage2).Controls.Add((Control)(object)label12_PasswordConfirm);
		((Control)tabPage2).Controls.Add((Control)(object)textBoxPasswordConfirm);
		((Control)tabPage2).Controls.Add((Control)(object)btnHeadLine);
		((Control)tabPage2).Controls.Add((Control)(object)linkLabelFolderSend);
		((Control)tabPage2).Controls.Add((Control)(object)btnConnectTest);
		((Control)tabPage2).Controls.Add((Control)(object)label12_Password);
		((Control)tabPage2).Controls.Add((Control)(object)label12_UserName);
		((Control)tabPage2).Controls.Add((Control)(object)label12_Path);
		((Control)tabPage2).Controls.Add((Control)(object)label12_Destination);
		((Control)tabPage2).Controls.Add((Control)(object)label12_Machine);
		((Control)tabPage2).Controls.Add((Control)(object)label12_Folder);
		((Control)tabPage2).Controls.Add((Control)(object)linkLabelHelp);
		((Control)tabPage2).Controls.Add((Control)(object)comboBoxFolder);
		((Control)tabPage2).Controls.Add((Control)(object)label12_GuideMessage);
		((Control)tabPage2).Controls.Add((Control)(object)label12_comment);
		((Control)tabPage2).Controls.Add((Control)(object)btnAdd);
		((Control)tabPage2).Controls.Add((Control)(object)textBoxPassword);
		((Control)tabPage2).Controls.Add((Control)(object)textBoxDestination);
		((Control)tabPage2).Controls.Add((Control)(object)comboBoxPCUserName);
		((Control)tabPage2).Controls.Add((Control)(object)machineSelectControl);
		tabPage2.Location = new Point(4, 22);
		((Control)tabPage2).Name = "tabPage2";
		((Control)tabPage2).Padding = new Padding(3);
		((Control)tabPage2).Size = new Size(792, 621);
		tabPage2.TabIndex = 1;
		((Control)tabPage2).Text = "Add Destination";
		tabPage2.UseVisualStyleBackColor = true;
		comboBoxSendPath.DropDownStyle = (ComboBoxStyle)2;
		((ListControl)comboBoxSendPath).FormattingEnabled = true;
		((Control)comboBoxSendPath).Location = new Point(264, 233);
		((Control)comboBoxSendPath).Name = "comboBoxSendPath";
		((Control)comboBoxSendPath).Size = new Size(479, 20);
		((Control)comboBoxSendPath).TabIndex = 43;
		((Control)label12_PasswordConfirm).AutoSize = true;
		((Control)label12_PasswordConfirm).Font = new Font("MS UI Gothic", 9f);
		((Control)label12_PasswordConfirm).ForeColor = SystemColors.Highlight;
		label12_PasswordConfirm.ImeMode = (ImeMode)0;
		((Control)label12_PasswordConfirm).Location = new Point(33, 205);
		((Control)label12_PasswordConfirm).Name = "label12_PasswordConfirm";
		((Control)label12_PasswordConfirm).Size = new Size(102, 12);
		((Control)label12_PasswordConfirm).TabIndex = 42;
		((Control)label12_PasswordConfirm).Text = "Password(Confirm)";
		((Control)textBoxPasswordConfirm).Location = new Point(264, 202);
		((Control)textBoxPasswordConfirm).Name = "textBoxPasswordConfirm";
		textBoxPasswordConfirm.PasswordChar = '*';
		((Control)textBoxPasswordConfirm).Size = new Size(480, 19);
		((Control)textBoxPasswordConfirm).TabIndex = 10;
		((Control)textBoxPasswordConfirm).Enter += textBoxPasswordConfirm_Enter;
		((Control)textBoxPasswordConfirm).Leave += textBoxPasswordConfirm_Leave;
		((Control)btnHeadLine).AutoSize = true;
		((ButtonBase)btnHeadLine).ImeMode = (ImeMode)0;
		((Control)btnHeadLine).Location = new Point(610, 50);
		((Control)btnHeadLine).Name = "btnHeadLine";
		((Control)btnHeadLine).Size = new Size(134, 23);
		((Control)btnHeadLine).TabIndex = 6;
		((Control)btnHeadLine).Text = "Index";
		((ButtonBase)btnHeadLine).UseVisualStyleBackColor = true;
		((Control)btnHeadLine).Click += buttonHeadLine_Click;
		((Control)linkLabelFolderSend).AutoSize = true;
		((Control)linkLabelFolderSend).Font = new Font("MS UI Gothic", 9f);
		((Label)linkLabelFolderSend).ImeMode = (ImeMode)0;
		((Control)linkLabelFolderSend).Location = new Point(33, 576);
		((Control)linkLabelFolderSend).Name = "linkLabelFolderSend";
		((Control)linkLabelFolderSend).Size = new Size(144, 12);
		((Control)linkLabelFolderSend).TabIndex = 17;
		linkLabelFolderSend.TabStop = true;
		((Control)linkLabelFolderSend).Text = "How to send data to folder.";
		linkLabelFolderSend.LinkClicked += new LinkLabelLinkClickedEventHandler(linkLabelFolderSend_LinkClicked);
		((Control)btnConnectTest).AutoSize = true;
		((ButtonBase)btnConnectTest).ImeMode = (ImeMode)0;
		((Control)btnConnectTest).Location = new Point(610, 489);
		((Control)btnConnectTest).Name = "btnConnectTest";
		((Control)btnConnectTest).Size = new Size(134, 23);
		((Control)btnConnectTest).TabIndex = 14;
		((Control)btnConnectTest).Text = "Com. Test";
		((ButtonBase)btnConnectTest).UseVisualStyleBackColor = true;
		((Control)btnConnectTest).Click += buttonConnectTest_Click;
		((Control)label12_Password).AutoSize = true;
		((Control)label12_Password).Font = new Font("MS UI Gothic", 9f);
		((Control)label12_Password).ForeColor = SystemColors.Highlight;
		label12_Password.ImeMode = (ImeMode)0;
		((Control)label12_Password).Location = new Point(33, 175);
		((Control)label12_Password).Name = "label12_Password";
		((Control)label12_Password).Size = new Size(54, 12);
		((Control)label12_Password).TabIndex = 37;
		((Control)label12_Password).Text = "Password";
		((Control)label12_UserName).AutoSize = true;
		((Control)label12_UserName).Font = new Font("MS UI Gothic", 9f);
		((Control)label12_UserName).ForeColor = SystemColors.Highlight;
		label12_UserName.ImeMode = (ImeMode)0;
		((Control)label12_UserName).Location = new Point(33, 145);
		((Control)label12_UserName).Name = "label12_UserName";
		((Control)label12_UserName).Size = new Size(62, 12);
		((Control)label12_UserName).TabIndex = 36;
		((Control)label12_UserName).Text = "User Name";
		((Control)label12_Path).AutoSize = true;
		((Control)label12_Path).Font = new Font("MS UI Gothic", 9f);
		((Control)label12_Path).ForeColor = SystemColors.Highlight;
		label12_Path.ImeMode = (ImeMode)0;
		((Control)label12_Path).Location = new Point(33, 235);
		((Control)label12_Path).Name = "label12_Path";
		((Control)label12_Path).Size = new Size(28, 12);
		((Control)label12_Path).TabIndex = 35;
		((Control)label12_Path).Text = "Path";
		((Control)label12_Destination).AutoSize = true;
		((Control)label12_Destination).Font = new Font("MS UI Gothic", 9f);
		((Control)label12_Destination).ForeColor = SystemColors.Highlight;
		label12_Destination.ImeMode = (ImeMode)0;
		((Control)label12_Destination).Location = new Point(33, 55);
		((Control)label12_Destination).Name = "label12_Destination";
		((Control)label12_Destination).Size = new Size(63, 12);
		((Control)label12_Destination).TabIndex = 34;
		((Control)label12_Destination).Text = "Destination";
		((Control)label12_Machine).AutoSize = true;
		((Control)label12_Machine).Font = new Font("MS UI Gothic", 9f);
		((Control)label12_Machine).ForeColor = SystemColors.Highlight;
		label12_Machine.ImeMode = (ImeMode)0;
		((Control)label12_Machine).Location = new Point(33, 265);
		((Control)label12_Machine).Name = "label12_Machine";
		((Control)label12_Machine).Size = new Size(47, 12);
		((Control)label12_Machine).TabIndex = 33;
		((Control)label12_Machine).Text = "Machine";
		((Control)label12_Folder).AutoSize = true;
		((Control)label12_Folder).Font = new Font("MS UI Gothic", 9f);
		((Control)label12_Folder).ForeColor = SystemColors.Highlight;
		label12_Folder.ImeMode = (ImeMode)0;
		((Control)label12_Folder).Location = new Point(33, 85);
		((Control)label12_Folder).Name = "label12_Folder";
		((Control)label12_Folder).Size = new Size(37, 12);
		((Control)label12_Folder).TabIndex = 31;
		((Control)label12_Folder).Text = "Folder";
		((Control)linkLabelHelp).AutoSize = true;
		((Label)linkLabelHelp).ImeMode = (ImeMode)0;
		linkLabelHelp.LinkColor = Color.Red;
		((Control)linkLabelHelp).Location = new Point(33, 602);
		((Control)linkLabelHelp).Name = "linkLabelHelp";
		((Control)linkLabelHelp).Size = new Size(226, 12);
		((Control)linkLabelHelp).TabIndex = 18;
		linkLabelHelp.TabStop = true;
		((Control)linkLabelHelp).Text = "Direct regist procedure on panel if it failed.";
		linkLabelHelp.LinkClicked += new LinkLabelLinkClickedEventHandler(linkLabelHelp_LinkClicked);
		comboBoxFolder.DropDownStyle = (ComboBoxStyle)2;
		((ListControl)comboBoxFolder).FormattingEnabled = true;
		((Control)comboBoxFolder).Location = new Point(264, 83);
		((Control)comboBoxFolder).Name = "comboBoxFolder";
		((Control)comboBoxFolder).Size = new Size(480, 20);
		comboBoxFolder.Sorted = true;
		((Control)comboBoxFolder).TabIndex = 7;
		comboBoxFolder.SelectedIndexChanged += comboBoxFolder_SelectedIndexChanged;
		((Control)label12_GuideMessage).AutoSize = true;
		((Control)label12_GuideMessage).Font = new Font("MS UI Gothic", 9f);
		label12_GuideMessage.ImeMode = (ImeMode)0;
		((Control)label12_GuideMessage).Location = new Point(33, 106);
		((Control)label12_GuideMessage).Name = "label12_GuideMessage";
		((Control)label12_GuideMessage).Size = new Size(72, 12);
		((Control)label12_GuideMessage).TabIndex = 26;
		((Control)label12_GuideMessage).Text = "Select folder.";
		((Control)label12_comment).AutoSize = true;
		((Control)label12_comment).Font = new Font("MS UI Gothic", 9f);
		label12_comment.ImeMode = (ImeMode)0;
		((Control)label12_comment).Location = new Point(24, 26);
		((Control)label12_comment).Name = "label12_comment";
		((Control)label12_comment).Size = new Size(131, 12);
		((Control)label12_comment).TabIndex = 21;
		((Control)label12_comment).Text = "Regist folder to machine";
		((Control)btnAdd).Font = new Font("MS UI Gothic", 11f, (FontStyle)1);
		((ButtonBase)btnAdd).ImeMode = (ImeMode)0;
		((Control)btnAdd).Location = new Point(33, 522);
		((Control)btnAdd).Name = "btnAdd";
		((Control)btnAdd).Size = new Size(711, 34);
		((Control)btnAdd).TabIndex = 16;
		((Control)btnAdd).Text = "Add";
		((ButtonBase)btnAdd).UseVisualStyleBackColor = true;
		((Control)btnAdd).Click += buttonSend_Click;
		((Control)textBoxPassword).Location = new Point(264, 171);
		((Control)textBoxPassword).Name = "textBoxPassword";
		textBoxPassword.PasswordChar = '*';
		((Control)textBoxPassword).Size = new Size(480, 19);
		((Control)textBoxPassword).TabIndex = 9;
		((Control)textBoxPassword).Enter += textBoxPassword_Enter;
		((Control)textBoxPassword).Leave += textBoxPassword_Leave;
		((Control)textBoxDestination).Location = new Point(264, 52);
		((Control)textBoxDestination).Name = "textBoxDestination";
		((Control)textBoxDestination).Size = new Size(340, 19);
		((Control)textBoxDestination).TabIndex = 5;
		((Control)textBoxDestination).Enter += textBoxSendFolderName_Enter;
		((Control)textBoxDestination).Leave += textBoxSendFolderName_Leave;
		comboBoxPCUserName.DropDownStyle = (ComboBoxStyle)2;
		((ListControl)comboBoxPCUserName).FormattingEnabled = true;
		((Control)comboBoxPCUserName).Location = new Point(264, 139);
		((Control)comboBoxPCUserName).Name = "comboBoxPCUserName";
		((Control)comboBoxPCUserName).Size = new Size(480, 20);
		((Control)comboBoxPCUserName).TabIndex = 8;
		((Control)comboBoxPCUserName).Enter += comboBoxPCUser_Enter;
		((Control)comboBoxPCUserName).Leave += comboBoxPCUser_Leave;
		((Control)machineSelectControl).Location = new Point(256, 265);
		((Control)machineSelectControl).Name = "machineSelectControl";
		((Control)machineSelectControl).Size = new Size(492, 222);
		((Control)machineSelectControl).TabIndex = 12;
		machineSelectControl.SearchButtonClicked += machineSelectControl_SearchButtonClicked;
		((ContainerControl)this).AutoScaleDimensions = new SizeF(6f, 12f);
		((ContainerControl)this).AutoScaleMode = (AutoScaleMode)1;
		((Form)this).ClientSize = new Size(809, 678);
		((Control)this).Controls.Add((Control)(object)tabControlCustom);
		((Control)this).Controls.Add((Control)(object)statusStripFolder);
		((Form)this).FormBorderStyle = (FormBorderStyle)1;
		((Form)this).Icon = (Icon)componentResourceManager.GetObject("$this.Icon");
		((Form)this).MaximizeBox = false;
		((Form)this).Menu = mainMenu1;
		((Form)this).MinimizeBox = false;
		((Control)this).Name = "FormMain";
		((Form)this).StartPosition = (FormStartPosition)4;
		((Control)statusStripFolder).ResumeLayout(false);
		((Control)statusStripFolder).PerformLayout();
		((Control)tabControlCustom).ResumeLayout(false);
		((Control)tabPage1).ResumeLayout(false);
		((Control)tabPage1).PerformLayout();
		((Control)tabPage2).ResumeLayout(false);
		((Control)tabPage2).PerformLayout();
		((Control)this).ResumeLayout(false);
		((Control)this).PerformLayout();
	}
}
