using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Linq;
using System.Management;
using System.Net;
using System.Net.NetworkInformation;
using System.Reflection;
using System.Text;
using System.Windows.Forms;
using CreateFolder.Properties;
using Microsoft.TeamFoundation.Build.Common;
using Microsoft.TeamFoundation.Common;
using log4net;

namespace CreateFolder;

public class FormPCInfo : Form
{
	private enum ServerType
	{
		DNS,
		WINS,
		GATEWAY,
		ST_NOSTATE
	}

	private static readonly ILog LOG = LogManager.GetLogger(MethodBase.GetCurrentMethod().DeclaringType);

	private string computerName = string.Empty;

	private string ipAddress = string.Empty;

	private string subnetMask = string.Empty;

	private string gateWay = string.Empty;

	private string fDHCP = string.Empty;

	private string fullComputerName = string.Empty;

	private string workGroup = string.Empty;

	private string logonUserName = string.Empty;

	private string fSMB = string.Empty;

	private string statusFireWall = string.Empty;

	private static FormPCInfo f = null;

	private string machineLang = string.Empty;

	private IContainer components;

	private Button buttonClose;

	private Label label1;

	private RichTextBox richTextBoxPCInfo;

	public string ComputerName
	{
		get
		{
			return computerName;
		}
		private set
		{
			computerName = value;
			SetFullComputerName(value, WorkGroup);
		}
	}

	public string IPAddress
	{
		get
		{
			return ipAddress;
		}
		private set
		{
			ipAddress = value;
		}
	}

	public string SubNetMask
	{
		get
		{
			return subnetMask;
		}
		private set
		{
			subnetMask = value;
		}
	}

	public string GateWay
	{
		get
		{
			return gateWay;
		}
		private set
		{
			gateWay = value;
		}
	}

	public string DHCP
	{
		get
		{
			return fDHCP;
		}
		private set
		{
			fDHCP = value;
		}
	}

	public string FullComputerName
	{
		get
		{
			return fullComputerName;
		}
		private set
		{
			fullComputerName = value;
		}
	}

	public string WorkGroup
	{
		get
		{
			return workGroup;
		}
		private set
		{
			workGroup = value;
			SetFullComputerName(ComputerName, value);
		}
	}

	public string LogonUserName
	{
		get
		{
			return logonUserName;
		}
		private set
		{
			logonUserName = value;
		}
	}

	public string SMB
	{
		get
		{
			return fSMB;
		}
		private set
		{
			fSMB = value;
		}
	}

	public string StatusFireWall
	{
		get
		{
			return statusFireWall;
		}
		private set
		{
			statusFireWall = value;
		}
	}

	private FormPCInfo(string lang)
	{
		InitializeComponent();
		machineLang = lang;
		Control[] allControls = CreateFolderUtil.GetAllControls((Control)(object)this);
		CreateFolderUtil.ResetFontToControl(((object)this).GetType().Name, allControls);
		((Control)this).Text = Resources.ITEM_COMPUTER_ENVIRONMENTS;
		((Control)buttonClose).Text = Resources.ITEM_BUTTON_BACK;
	}

	public static FormPCInfo GetFormPCInfo(string lang)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		if (f == null)
		{
			f = new FormPCInfo(lang);
		}
		f.GetPCInfo();
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return f;
	}

	private void GetPCInfo()
	{
		//IL_0049: Unknown result type (might be due to invalid IL or missing references)
		//IL_0050: Expected O, but got Unknown
		//IL_00c4: Unknown result type (might be due to invalid IL or missing references)
		//IL_00cb: Expected O, but got Unknown
		//IL_0266: Unknown result type (might be due to invalid IL or missing references)
		//IL_026b: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		((Control)richTextBoxPCInfo).Text = string.Empty;
		StringBuilder stringBuilder = new StringBuilder();
		ManagementObjectEnumerator enumerator = WmiManager.WMIGetter("SELECT * FROM Win32_OperatingSystem").GetEnumerator();
		try
		{
			while (enumerator.MoveNext())
			{
				ManagementObject val = (ManagementObject)enumerator.Current;
				ComputerName = (((ManagementBaseObject)val)["CSName"] ?? string.Empty) as string;
				stringBuilder.AppendFormat(Resources.TXT_PC_INFO_01 + "\t\t\t : {0}\n", ComputerName);
			}
		}
		finally
		{
			((IDisposable)enumerator)?.Dispose();
		}
		ManagementObjectCollection obj = WmiManager.WMIGetter("SELECT * FROM Win32_NetworkAdapterConfiguration");
		uint num = uint.MaxValue;
		int num2 = 0;
		enumerator = obj.GetEnumerator();
		try
		{
			while (enumerator.MoveNext())
			{
				ManagementObject val2 = (ManagementObject)enumerator.Current;
				if ((uint)(((ManagementBaseObject)val2)["IPConnectionMetric"] ?? ((object)uint.MaxValue)) < num)
				{
					IPAddress = GetStrConvertedArray(((ManagementBaseObject)val2)["IPAddress"], 0);
					SubNetMask = GetStrConvertedArray(((ManagementBaseObject)val2)["IPSubnet"], 0);
					GateWay = GetStrConvertedArray(((ManagementBaseObject)val2)["DefaultIPGateway"], 0);
					Console.WriteLine("MACAddr = " + ((ManagementBaseObject)val2)["MACAddress"]);
					if ((((ManagementBaseObject)val2)["DHCPEnabled"] ?? string.Empty).ToString() == "True")
					{
						DHCP = Resources.ENABLED;
					}
					else
					{
						DHCP = Resources.DISABLED;
					}
					num2++;
					string arg = ((num2 > 1) ? ("[" + num2 + "]") : "   ");
					stringBuilder.AppendFormat(Resources.TXT_MACHINE_INFO_03_13 + "{0}\t\t\t : {1}\n", arg, IPAddress);
					stringBuilder.AppendFormat(Resources.TXT_MACHINE_INFO_04_13 + "{0}\t\t\t : {1}\n", arg, SubNetMask);
					stringBuilder.AppendFormat(Resources.TXT_MACHINE_INFO_05_13 + "{0}\t\t\t : {1}\n", arg, GateWay);
					stringBuilder.AppendFormat(Resources.TXT_PC_INFO_05 + "{0}\t\t\t\t : {1}\n", arg, DHCP);
				}
			}
		}
		finally
		{
			((IDisposable)enumerator)?.Dispose();
		}
		enumerator = WmiManager.WMIGetter("SELECT * FROM Win32_ComputerSystem").GetEnumerator();
		try
		{
			while (enumerator.MoveNext())
			{
				ManagementObject val3 = (ManagementObject)enumerator.Current;
				object obj2 = ((ManagementBaseObject)val3)["Domain"];
				object obj3 = ((ManagementBaseObject)val3)["Workgroup"];
				WorkGroup = ((obj2 != null) ? obj2 : obj3) as string;
				LogonUserName = WmiManager.GetUserName() ?? string.Empty;
				string arg2 = ((obj2 != null) ? (ComputerName + "." + WorkGroup) : ComputerName);
				stringBuilder.AppendFormat(Resources.TXT_PC_INFO_06 + "\t\t : {0}\n", arg2);
				stringBuilder.AppendFormat(Resources.ITEM_GROUP_NAME + "\t\t\t : {0}\n", WorkGroup);
				stringBuilder.AppendFormat(Resources.TXT_PC_INFO_08 + "\t\t\t : {0}\n", LogonUserName);
			}
		}
		finally
		{
			((IDisposable)enumerator)?.Dispose();
		}
		PowerShellManager powerShellManager = new PowerShellManager();
		SMB = powerShellManager.GetSMBStatus();
		StatusFireWall = GetStatusFireWall();
		stringBuilder.AppendFormat("{0}\t\t : {1}\n", Resources.TXT_PC_INFO_09, SMB);
		stringBuilder.AppendFormat("{0}\t\t : {1}\n", Resources.TXT_MACHINE_INFO_10_13, getServerAddress(ServerType.WINS));
		stringBuilder.AppendFormat("{0}\t\t : {1}\n", Resources.TXT_MACHINE_INFO_13_13, getServerAddress(ServerType.DNS));
		stringBuilder.AppendFormat("{0}\t : {1}\n", Resources.TXT_PC_INFO_12, StatusFireWall);
		((Control)richTextBoxPCInfo).Text = stringBuilder.ToString();
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	private string GetStrConvertedArray(object obj, int index)
	{
		if (obj == null)
		{
			return string.Empty;
		}
		string[] array = obj as string[];
		if (array.Count() < index)
		{
			return string.Empty;
		}
		return array[index];
	}

	private string GetStatusFireWall()
	{
		if (!new FormSetup(machineLang).getPortState((NET_FW_RULE_DIRECTION_)1, 445, (NET_FW_IP_PROTOCOL_)6))
		{
			return Resources.DO_NOT;
		}
		return Resources.DO_DO;
	}

	private void SetFullComputerName(string computerName, string domainName)
	{
		FullComputerName = computerName + "." + domainName;
	}

	private void buttonClose_Click(object sender, EventArgs e)
	{
		((Control)this).Visible = false;
	}

	private string getServerAddress(ServerType serverType)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		string text = string.Empty;
		try
		{
			NetworkInterface[] allNetworkInterfaces = NetworkInterface.GetAllNetworkInterfaces();
			int num = 0;
			if (num < allNetworkInterfaces.Length)
			{
				NetworkInterface networkInterface = allNetworkInterfaces[num];
				if (networkInterface.OperationalStatus == OperationalStatus.Up && networkInterface.NetworkInterfaceType != NetworkInterfaceType.Loopback && networkInterface.NetworkInterfaceType != NetworkInterfaceType.Tunnel)
				{
					Console.WriteLine("接続名:{0}", networkInterface.Name);
					Console.WriteLine("説明:{0}", networkInterface.Description);
					Console.WriteLine("種類:{0}", networkInterface.NetworkInterfaceType);
					Console.WriteLine("速度:{0}", networkInterface.Speed);
					Console.WriteLine("MAC(物理)アドレス:{0}", networkInterface.GetPhysicalAddress());
					LOG.DebugFormat("{0}：接続名:{1}", (object)MethodBase.GetCurrentMethod().Name, (object)networkInterface.Name);
					LOG.DebugFormat("{0}：説明:{1}", (object)MethodBase.GetCurrentMethod().Name, (object)networkInterface.Description);
					LOG.DebugFormat("{0}：種類:{1}", (object)MethodBase.GetCurrentMethod().Name, (object)networkInterface.NetworkInterfaceType);
					LOG.DebugFormat("{0}：速度:{1}", (object)MethodBase.GetCurrentMethod().Name, (object)networkInterface.Speed);
					LOG.DebugFormat("{0}：MAC(物理)アドレス:{1}", (object)MethodBase.GetCurrentMethod().Name, (object)networkInterface.GetPhysicalAddress());
					IPInterfaceProperties iPProperties = networkInterface.GetIPProperties();
					if (iPProperties != null)
					{
						switch (serverType)
						{
						case ServerType.DNS:
						{
							using (IEnumerator<IPAddress> enumerator2 = iPProperties.DnsAddresses.GetEnumerator())
							{
								if (enumerator2.MoveNext())
								{
									IPAddress current3 = enumerator2.Current;
									Console.WriteLine("DNS:{0}", current3.ToString());
									LOG.DebugFormat("{0}：DNS:{1}", (object)MethodBase.GetCurrentMethod().Name, (object)current3.ToString());
									text = current3.ToString();
								}
							}
							break;
						}
						case ServerType.WINS:
						{
							using (IEnumerator<IPAddress> enumerator2 = iPProperties.WinsServersAddresses.GetEnumerator())
							{
								if (enumerator2.MoveNext())
								{
									IPAddress current2 = enumerator2.Current;
									Console.WriteLine("WINS:{0}", current2.ToString());
									LOG.DebugFormat("{0}：WINS:{1}", (object)MethodBase.GetCurrentMethod().Name, (object)current2.ToString());
									text = current2.ToString();
								}
							}
							break;
						}
						case ServerType.GATEWAY:
						{
							using (IEnumerator<GatewayIPAddressInformation> enumerator = iPProperties.GatewayAddresses.GetEnumerator())
							{
								if (enumerator.MoveNext())
								{
									GatewayIPAddressInformation current = enumerator.Current;
									Console.WriteLine("GATEWAY:{0}", current.Address);
									LOG.DebugFormat("{0}：GATEWAY:{1}", (object)MethodBase.GetCurrentMethod().Name, (object)current.Address);
									text = current.Address.ToString();
								}
							}
							break;
						}
						default:
							LOG.ErrorFormat("{0}：Parameter Not Found :{1}", (object)MethodBase.GetCurrentMethod().Name, (object)serverType);
							break;
						}
					}
				}
			}
		}
		catch (Exception ex)
		{
			LOG.ErrorFormat("{0}：！！！ Server情報取得処理でエラー  \n" + ex.ToString() + "\n*******************************", (object)MethodBase.GetCurrentMethod().Name);
		}
		if (text.Length < 1)
		{
			text = "-";
		}
		LOG.DebugFormat("{0}：end serverAddr = {1}", (object)MethodBase.GetCurrentMethod().Name, (object)text);
		return text;
	}

	protected override void Dispose(bool disposing)
	{
		if (disposing && components != null)
		{
			components.Dispose();
		}
		((Form)this).Dispose(disposing);
	}

	private void InitializeComponent()
	{
		//IL_0011: Unknown result type (might be due to invalid IL or missing references)
		//IL_001b: Expected O, but got Unknown
		//IL_001c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0026: Expected O, but got Unknown
		//IL_0027: Unknown result type (might be due to invalid IL or missing references)
		//IL_0031: Expected O, but got Unknown
		//IL_0208: Unknown result type (might be due to invalid IL or missing references)
		//IL_0212: Expected O, but got Unknown
		ComponentResourceManager componentResourceManager = new ComponentResourceManager(typeof(FormPCInfo));
		buttonClose = new Button();
		label1 = new Label();
		richTextBoxPCInfo = new RichTextBox();
		((Control)this).SuspendLayout();
		((Control)buttonClose).AutoSize = true;
		((Control)buttonClose).Location = new Point(12, 281);
		((Control)buttonClose).Name = "buttonClose";
		((Control)buttonClose).Size = new Size(75, 23);
		((Control)buttonClose).TabIndex = 0;
		((Control)buttonClose).Text = "Back";
		((ButtonBase)buttonClose).UseVisualStyleBackColor = true;
		((Control)buttonClose).Click += buttonClose_Click;
		((Control)label1).Anchor = (AnchorStyles)13;
		label1.BorderStyle = (BorderStyle)2;
		((Control)label1).Location = new Point(12, 274);
		((Control)label1).Name = "label1";
		((Control)label1).Size = new Size(474, 1);
		((Control)label1).TabIndex = 1;
		((Control)richTextBoxPCInfo).BackColor = SystemColors.Control;
		((Control)richTextBoxPCInfo).Location = new Point(12, 14);
		((Control)richTextBoxPCInfo).Name = "richTextBoxPCInfo";
		((Control)richTextBoxPCInfo).Size = new Size(471, 248);
		((Control)richTextBoxPCInfo).TabIndex = 24;
		((Control)richTextBoxPCInfo).Text = "";
		((ContainerControl)this).AutoScaleDimensions = new SizeF(6f, 12f);
		((ContainerControl)this).AutoScaleMode = (AutoScaleMode)1;
		((Control)this).AutoSize = true;
		((Form)this).ClientSize = new Size(498, 316);
		((Control)this).Controls.Add((Control)(object)richTextBoxPCInfo);
		((Control)this).Controls.Add((Control)(object)label1);
		((Control)this).Controls.Add((Control)(object)buttonClose);
		((Form)this).FormBorderStyle = (FormBorderStyle)3;
		((Form)this).Icon = (Icon)componentResourceManager.GetObject("$this.Icon");
		((Form)this).MaximizeBox = false;
		((Form)this).MinimizeBox = false;
		((Control)this).Name = "FormPCInfo";
		((Form)this).StartPosition = (FormStartPosition)4;
		((Control)this).Text = "Computer Info";
		((Control)this).ResumeLayout(false);
		((Control)this).PerformLayout();
	}
}
