using System;
using System.Collections;
using System.Collections.Generic;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Management;
using System.Reflection;
using System.Windows.Forms;
using CreateFolder.Properties;
using Microsoft.TeamFoundation.Build.Common;
using Microsoft.TeamFoundation.Common;
using log4net;

namespace CreateFolder;

public class FormSetup : Form
{
	private static bool smbOpened = false;

	private static bool blankPasswordAllowed = false;

	private static bool isDomain = false;

	private Dictionary<int, string> profileType2 = new Dictionary<int, string>
	{
		{ 1, "DOMAIN" },
		{ 2, "PRIVATE" },
		{ 4, "PUBLIC" },
		{
			int.MaxValue,
			"ALL"
		}
	};

	private Dictionary<int, string> protocolName = new Dictionary<int, string>
	{
		{ 6, "TCP" },
		{ 17, "UDP" },
		{ 256, "ANY" }
	};

	private Dictionary<NET_FW_RULE_DIRECTION_, string> direction = new Dictionary<NET_FW_RULE_DIRECTION_, string>
	{
		{
			(NET_FW_RULE_DIRECTION_)1,
			"NET_FW_RULE_DIR_IN"
		},
		{
			(NET_FW_RULE_DIRECTION_)2,
			"NET_FW_RULE_DIR_OUT"
		},
		{
			(NET_FW_RULE_DIRECTION_)3,
			"NET_FW_RULE_DIR_MAX"
		}
	};

	private Dictionary<NET_FW_ACTION_, string> action = new Dictionary<NET_FW_ACTION_, string>
	{
		{
			(NET_FW_ACTION_)1,
			"NET_FW_ACTION_ALLOW"
		},
		{
			(NET_FW_ACTION_)0,
			"NET_FW_ACTION_BLOCK"
		},
		{
			(NET_FW_ACTION_)2,
			"NET_FW_ACTION_MAX"
		}
	};

	private static readonly ILog LOG = LogManager.GetLogger(MethodBase.GetCurrentMethod().DeclaringType);

	private IContainer components;

	private Label labelPasswordWarning;

	private Button buttonClose;

	private Panel panel3;

	private GroupBox groupBoxGroup;

	private RadioButton radioButtonWork;

	private RadioButton radioButtonDomain;

	private GroupBox groupBoxShared;

	private RadioButton radioButtonSharedON;

	private RadioButton radioButtonSharedOFF;

	private Label labelLoginUserName;

	private Label labelUserCaption;

	private Label labelGroupName;

	private Label labelMessage;

	private GroupBox groupBoxPasswordDesabled;

	private Label labelSharedWarning;

	private Button buttonEnter;

	private GroupBox groupBoxMessage;

	private Label label_WarningMessage;

	private Label labelNonPasswordWarning;

	private Button buttonNonPasswordConfig;

	private Label labelSharingWarning;

	private Label labelSharingInfo;

	public static bool SmbOpened
	{
		get
		{
			return smbOpened;
		}
		set
		{
			smbOpened = value;
		}
	}

	public static bool BlankPasswordAllowed
	{
		get
		{
			return blankPasswordAllowed;
		}
		set
		{
			blankPasswordAllowed = value;
		}
	}

	public FormSetup(string lang)
	{
		if (lang.Equals("ja") || lang.Equals("en"))
		{
			InitializeComponent();
		}
		else
		{
			InitializeComponent_MultiLang();
		}
		((Control)labelGroupName).Text = string.Empty;
		((Control)labelLoginUserName).Text = string.Empty;
		((Control)labelSharedWarning).Text = string.Empty;
		((Control)labelPasswordWarning).Text = string.Empty;
		Control[] allControls = CreateFolderUtil.GetAllControls((Control)(object)this);
		CreateFolderUtil.ResetFontToControl(((object)this).GetType().Name, allControls);
		((Control)this).Text = Resources.SECURITY_DLG_CAPTION;
		((Control)groupBoxShared).Text = Resources.FORM_SETUP_GROUP_TITLE1;
		((Control)groupBoxPasswordDesabled).Text = Resources.FORM_SETUP_GROUP_TITLE2;
		((Control)groupBoxMessage).Text = Resources.FORM_SETUP_GROUP_TITLE3;
		((Control)groupBoxGroup).Text = Resources.GROUP_THIS_PC_BELONGING;
		((Control)radioButtonSharedON).Text = Resources.DO_DO;
		((Control)radioButtonSharedOFF).Text = Resources.DO_NOT;
		((Control)radioButtonDomain).Text = Resources.PC_GROUP_DOMAIN;
		((Control)radioButtonWork).Text = Resources.PC_GROUP_WORKGROUP;
		((Control)buttonNonPasswordConfig).Text = Resources.BUTTON_AGREE;
		((Control)buttonEnter).Text = Resources.ITEM_BUTTON_SET;
		((Control)buttonClose).Text = Resources.BUTTON_CLOSE;
		((Control)label_WarningMessage).Text = $"{Resources.SECURITY_WARNING_MESSAGE_01}\n{Resources.SECURITY_WARNING_MESSAGE_02}";
		((Control)labelNonPasswordWarning).Text = $"{Resources.SECURITY_WARNING_NON_PASSWORD_MESSAGE_01}\n{Resources.SECURITY_WARNING_NON_PASSWORD_MESSAGE_02}";
		((Control)labelSharingInfo).Text = $"{Resources.SECURITY_WARNING_NON_PASSWORD_MESSAGE_03}\n{Resources.SECURITY_WARNING_NON_PASSWORD_MESSAGE_04}";
		((Control)labelSharingWarning).Text = $"{Resources.SECURITY_AGREEMENT_01}\n{Resources.SECURITY_AGREEMENT_02}\n{Resources.SECURITY_AGREEMENT_03}";
		setLabelString();
	}

	private void buttonClose_Click(object sender, EventArgs e)
	{
		((Form)this).Close();
	}

	private void setLabelString()
	{
		//IL_004c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0051: Unknown result type (might be due to invalid IL or missing references)
		//IL_005c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0062: Expected O, but got Unknown
		//IL_006e: Expected O, but got Unknown
		//IL_0069: Unknown result type (might be due to invalid IL or missing references)
		//IL_006f: Expected O, but got Unknown
		//IL_008a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0091: Expected O, but got Unknown
		LOG.InfoFormat("{0}： start", (object)MethodBase.GetCurrentMethod().Name);
		((Control)labelMessage).Text = Resources.LABEL_MSG_NO_PASS_WARNING_1_3 + Resources.LABEL_MSG_NO_PASS_WARNING_2_3 + Resources.LABEL_MSG_NO_PASS_WARNING_3_3;
		ManagementScope val = new ManagementScope("\\\\" + Environment.MachineName + "\\root\\cimv2");
		val.Connect();
		ObjectQuery val2 = new ObjectQuery("SELECT * FROM Win32_ComputerSystem");
		_ = string.Empty;
		ManagementObjectSearcher val3 = new ManagementObjectSearcher(val, val2);
		try
		{
			ManagementObjectCollection val4 = val3.Get();
			try
			{
				ManagementObjectEnumerator enumerator = val4.GetEnumerator();
				try
				{
					while (enumerator.MoveNext())
					{
						ManagementObject val5 = (ManagementObject)enumerator.Current;
						string empty = string.Empty;
						if (((ManagementBaseObject)val5)["Workgroup"] == null)
						{
							if (((ManagementBaseObject)val5)["Domain"] == null)
							{
								((Control)labelGroupName).Text = "";
							}
							else
							{
								((Control)labelGroupName).Text = ((ManagementBaseObject)val5)["Domain"].ToString();
							}
							isDomain = true;
							radioButtonDomain.Checked = true;
							((Control)labelPasswordWarning).Text = Resources.FORM_SETUP_SET_PASSWORD_FOR_PC_BELONGING_DOMAIN;
						}
						else
						{
							isDomain = false;
							((Control)labelPasswordWarning).Text = $"{Resources.ALERT_NO_PASSWORD_PROTECTED_TEXT_01}\n{Resources.ALERT_NO_PASSWORD_PROTECTED_TEXT_02}";
							((Control)labelGroupName).Text = ((ManagementBaseObject)val5)["Workgroup"].ToString();
							((Control)labelGroupName).Text = empty;
							radioButtonWork.Checked = true;
						}
						((Control)labelMessage).Text = string.Empty;
						((Control)buttonNonPasswordConfig).Visible = !isDomain;
						((Control)labelNonPasswordWarning).Visible = !isDomain;
						((Control)labelSharingInfo).Visible = !isDomain;
						((Control)labelSharingWarning).Visible = !isDomain;
					}
				}
				finally
				{
					((IDisposable)enumerator)?.Dispose();
				}
			}
			finally
			{
				((IDisposable)val4)?.Dispose();
			}
		}
		finally
		{
			((IDisposable)val3)?.Dispose();
		}
		((Control)labelLoginUserName).Text = Environment.UserName;
		bool portState = getPortState((NET_FW_RULE_DIRECTION_)1, 445, (NET_FW_IP_PROTOCOL_)6);
		radioButtonSharedON.Checked = portState;
		radioButtonSharedOFF.Checked = !portState;
		checkButtonEnter();
	}

	public void OpenPort(NET_FW_RULE_DIRECTION_ io, int portNo, NET_FW_IP_PROTOCOL_ protocol)
	{
		//IL_004a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0050: Expected O, but got Unknown
		//IL_0067: Unknown result type (might be due to invalid IL or missing references)
		//IL_006d: Expected O, but got Unknown
		//IL_0126: Unknown result type (might be due to invalid IL or missing references)
		//IL_0127: Invalid comparison between I4 and Unknown
		//IL_0133: Unknown result type (might be due to invalid IL or missing references)
		//IL_0160: Unknown result type (might be due to invalid IL or missing references)
		//IL_0165: Unknown result type (might be due to invalid IL or missing references)
		//IL_0150: Unknown result type (might be due to invalid IL or missing references)
		//IL_01a4: Unknown result type (might be due to invalid IL or missing references)
		//IL_01a9: Unknown result type (might be due to invalid IL or missing references)
		//IL_01d1: Unknown result type (might be due to invalid IL or missing references)
		//IL_01fd: Unknown result type (might be due to invalid IL or missing references)
		//IL_01ff: Unknown result type (might be due to invalid IL or missing references)
		//IL_0217: Unknown result type (might be due to invalid IL or missing references)
		LOG.InfoFormat("{0}： start", (object)MethodBase.GetCurrentMethod().Name);
		SmbOpened = false;
		LOG.InfoFormat("  portNo : {0}", (object)portNo);
		_ = string.Empty;
		INetFwPolicy2 val = (INetFwPolicy2)Activator.CreateInstance(Type.GetTypeFromProgID("HNetCfg.FwPolicy2", throwOnError: false));
		foreach (INetFwRule item in (IEnumerable)val.Rules)
		{
			INetFwRule val2 = item;
			LOG.InfoFormat("  ======================================= Firewall rules", new object[0]);
			LOG.InfoFormat("    name : {0}", (object)val2.Name);
			LOG.InfoFormat("    ApplicationName : {0}", (object)val2.ApplicationName);
			LOG.InfoFormat("    serviceName : {0}", (object)val2.serviceName);
			LOG.InfoFormat("    Profiles : {0}", (object)val2.Profiles);
			if (protocolName.ContainsKey(val2.Protocol))
			{
				LOG.InfoFormat("    Protocol : {0}", (object)protocolName[val2.Protocol]);
				_ = protocolName[val2.Protocol];
			}
			if (val2.Protocol != (int)protocol)
			{
				continue;
			}
			if (direction.ContainsKey(val2.Direction))
			{
				LOG.InfoFormat("    Direction : {0}", (object)direction[val2.Direction]);
			}
			if (val2.Direction != io)
			{
				continue;
			}
			LOG.InfoFormat("    Description : {0}", (object)val2.Description);
			if (val2.Description == null || val2.Description.IndexOf(portNo.ToString()) < 0)
			{
				continue;
			}
			NET_FW_ACTION_ val3 = val2.Action;
			if ((val2.Profiles & val.CurrentProfileTypes) == 0 && val2.Profiles != int.MaxValue)
			{
				continue;
			}
			LOG.InfoFormat("  BEFORE Action : {0}", (object)val2.Action);
			if (radioButtonSharedOFF.Checked)
			{
				val2.Action = (NET_FW_ACTION_)0;
			}
			else
			{
				val2.Action = (NET_FW_ACTION_)1;
				if (val3 != val2.Action)
				{
					SmbOpened = true;
				}
			}
			LOG.InfoFormat("  AFTER Action : {0}", (object)val2.Action);
			val2.Enabled = true;
		}
		LOG.InfoFormat("{0}： end", (object)MethodBase.GetCurrentMethod().Name);
	}

	public bool checkOpenPort(NET_FW_RULE_DIRECTION_ io, int portNo, NET_FW_IP_PROTOCOL_ protocol, bool showDlgFlg)
	{
		//IL_0031: Unknown result type (might be due to invalid IL or missing references)
		//IL_0037: Expected O, but got Unknown
		//IL_007f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0086: Expected O, but got Unknown
		//IL_0168: Unknown result type (might be due to invalid IL or missing references)
		//IL_0169: Invalid comparison between I4 and Unknown
		//IL_018d: Unknown result type (might be due to invalid IL or missing references)
		//IL_01bc: Unknown result type (might be due to invalid IL or missing references)
		//IL_01c1: Unknown result type (might be due to invalid IL or missing references)
		//IL_01ab: Unknown result type (might be due to invalid IL or missing references)
		//IL_0298: Unknown result type (might be due to invalid IL or missing references)
		//IL_02b6: Unknown result type (might be due to invalid IL or missing references)
		//IL_0332: Unknown result type (might be due to invalid IL or missing references)
		//IL_0371: Unknown result type (might be due to invalid IL or missing references)
		//IL_03fb: Unknown result type (might be due to invalid IL or missing references)
		//IL_03fe: Invalid comparison between Unknown and I4
		//IL_03d6: Unknown result type (might be due to invalid IL or missing references)
		//IL_03db: Unknown result type (might be due to invalid IL or missing references)
		//IL_03df: Unknown result type (might be due to invalid IL or missing references)
		//IL_03e2: Invalid comparison between Unknown and I4
		//IL_03b5: Unknown result type (might be due to invalid IL or missing references)
		//IL_03b8: Invalid comparison between Unknown and I4
		//IL_0390: Unknown result type (might be due to invalid IL or missing references)
		//IL_0395: Unknown result type (might be due to invalid IL or missing references)
		//IL_0399: Unknown result type (might be due to invalid IL or missing references)
		//IL_039c: Invalid comparison between Unknown and I4
		LOG.InfoFormat("{0}： start", (object)MethodBase.GetCurrentMethod().Name);
		bool result = true;
		_ = string.Empty;
		INetFwPolicy2 val = (INetFwPolicy2)Activator.CreateInstance(Type.GetTypeFromProgID("HNetCfg.FwPolicy2", throwOnError: false));
		LOG.InfoFormat("  ======================================================", new object[0]);
		LOG.InfoFormat("  fwPolicy2.CurrentProfileTypes : {0}", (object)val.CurrentProfileTypes);
		INetFwRules rules = val.Rules;
		bool flag = false;
		foreach (INetFwRule item in (IEnumerable)rules)
		{
			INetFwRule val2 = item;
			LOG.InfoFormat("  ======================================= Firewall rules", new object[0]);
			LOG.InfoFormat("    name : {0}", (object)val2.Name);
			LOG.InfoFormat("    ApplicationName : {0}", (object)val2.ApplicationName);
			LOG.InfoFormat("    serviceName : {0}", (object)val2.serviceName);
			LOG.InfoFormat("    Profiles : {0}", (object)val2.Profiles);
			if ((val2.Profiles & val.CurrentProfileTypes) == 0 && val2.Profiles != int.MaxValue)
			{
				continue;
			}
			if (protocolName.ContainsKey(val2.Protocol))
			{
				LOG.InfoFormat("    Protocol : {0}", (object)protocolName[val2.Protocol]);
				_ = protocolName[val2.Protocol];
			}
			if (val2.Protocol != (int)protocol)
			{
				LOG.InfoFormat("  continue PROTOCOL", new object[0]);
				continue;
			}
			if (direction.ContainsKey(val2.Direction))
			{
				LOG.InfoFormat("    Direction : {0}", (object)direction[val2.Direction]);
			}
			if (val2.Direction != io)
			{
				LOG.InfoFormat("  continue DIRECTION", new object[0]);
				continue;
			}
			LOG.InfoFormat("    Description : {0}", (object)val2.Description);
			if (val2.Description == null || val2.Description.IndexOf(portNo.ToString()) < 0)
			{
				LOG.InfoFormat("  continue DISCRIPTION", new object[0]);
				if (val2.Description != null)
				{
					LOG.InfoFormat("  continue Index = {0}", (object)val2.Description.IndexOf(portNo.ToString()));
					LOG.InfoFormat("  continue portNo = {0} ", (object)portNo);
				}
				continue;
			}
			LOG.InfoFormat("    Enabled : {0}", (object)val2.Enabled);
			if (action.ContainsKey(val2.Action))
			{
				LOG.InfoFormat("    Action : {0}", (object)action[val2.Action]);
			}
			LOG.InfoFormat("    Edge : {0}", (object)val2.EdgeTraversal);
			LOG.InfoFormat("    Grouping : {0}", (object)val2.Grouping);
			LOG.InfoFormat("    InterfaceTypes : {0}", (object)val2.InterfaceTypes);
			if (val2.Interfaces != null)
			{
				LOG.InfoFormat("    Interfaces : {0}", (object)val2.Interfaces.ToString());
			}
			_ = val2.Action;
			string aLERT_NO_PASSWORD_CAPTION = Resources.ALERT_NO_PASSWORD_CAPTION;
			string text = Resources.RESTRICTED_CONNECTION_BY_WIN_FW_1_4 + Resources.RESTRICTED_CONNECTION_BY_WIN_FW_2_4 + Resources.RESTRICTED_CONNECTION_BY_WIN_FW_3_4 + Resources.RESTRICTED_CONNECTION_BY_WIN_FW_4_4;
			string text2 = Resources.DISABLED_SETTING_BLOCK_FOR_SENDING_FOLDER_1_3 + Resources.DISABLED_SETTING_BLOCK_FOR_SENDING_FOLDER_2_3 + Resources.DISABLED_SETTING_BLOCK_FOR_SENDING_FOLDER_3_3;
			DialogResult val3 = (DialogResult)0;
			if (radioButtonSharedOFF.Checked)
			{
				if (!flag && showDlgFlg)
				{
					val3 = MessageBox.Show(text, aLERT_NO_PASSWORD_CAPTION, (MessageBoxButtons)1, (MessageBoxIcon)64);
					flag = true;
					if ((int)val3 == 2)
					{
						LOG.InfoFormat("  USER SELECT CANCEL", new object[0]);
						result = false;
					}
				}
				if ((int)val3 == 1)
				{
					result = true;
				}
				else if (!showDlgFlg)
				{
					result = false;
				}
				continue;
			}
			if (!flag && showDlgFlg)
			{
				val3 = MessageBox.Show(text2, aLERT_NO_PASSWORD_CAPTION, (MessageBoxButtons)1, (MessageBoxIcon)64);
				flag = true;
				if ((int)val3 == 2)
				{
					LOG.InfoFormat("  USER SELECT CANCEL", new object[0]);
					result = false;
				}
			}
			if ((int)val3 == 1)
			{
				result = true;
			}
			else if (!showDlgFlg)
			{
				result = true;
			}
		}
		LOG.InfoFormat("{0}： end", (object)MethodBase.GetCurrentMethod().Name);
		return result;
	}

	public bool getPortState(NET_FW_RULE_DIRECTION_ io, int portNo, NET_FW_IP_PROTOCOL_ protocol)
	{
		//IL_0033: Unknown result type (might be due to invalid IL or missing references)
		//IL_0039: Expected O, but got Unknown
		//IL_00c3: Unknown result type (might be due to invalid IL or missing references)
		//IL_00ca: Expected O, but got Unknown
		//IL_0196: Unknown result type (might be due to invalid IL or missing references)
		//IL_0197: Invalid comparison between I4 and Unknown
		//IL_01a4: Unknown result type (might be due to invalid IL or missing references)
		//IL_01d3: Unknown result type (might be due to invalid IL or missing references)
		//IL_01d8: Unknown result type (might be due to invalid IL or missing references)
		//IL_01c2: Unknown result type (might be due to invalid IL or missing references)
		//IL_023c: Unknown result type (might be due to invalid IL or missing references)
		//IL_025a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0276: Unknown result type (might be due to invalid IL or missing references)
		LOG.InfoFormat("{0}： start", (object)MethodBase.GetCurrentMethod().Name);
		bool flag = true;
		bool flag2 = false;
		_ = string.Empty;
		INetFwPolicy2 val = (INetFwPolicy2)Activator.CreateInstance(Type.GetTypeFromProgID("HNetCfg.FwPolicy2", throwOnError: false));
		LOG.InfoFormat("  －－－－－－－－－－－－－－－－－－－－－－－－－", new object[0]);
		int num = val.CurrentProfileTypes;
		if (!profileType2.ContainsKey(num))
		{
			LOG.ErrorFormat("    Current Type not found. currentType = {0}. set public", (object)num);
			num = 4;
		}
		LOG.InfoFormat("    Current Type : {0}", (object)profileType2[num]);
		LOG.InfoFormat("  －－－－－－－－－－－－－－－－－－－－－－－－－", new object[0]);
		foreach (INetFwRule item in (IEnumerable)val.Rules)
		{
			INetFwRule val2 = item;
			LOG.InfoFormat("  ======================================= Firewall rules", new object[0]);
			LOG.InfoFormat("    name : {0}", (object)val2.Name);
			LOG.InfoFormat("    ApplicationName : {0}", (object)val2.ApplicationName);
			LOG.InfoFormat("    serviceName : {0}", (object)val2.serviceName);
			LOG.InfoFormat("    Profiles : {0}  Current Profile Types : {1}", (object)val2.Profiles, (object)val.CurrentProfileTypes);
			if ((val2.Profiles & val.CurrentProfileTypes) == 0 && val2.Profiles != int.MaxValue)
			{
				continue;
			}
			if (protocolName.ContainsKey(val2.Protocol))
			{
				_ = protocolName[val2.Protocol];
			}
			if (val2.Protocol != (int)protocol)
			{
				continue;
			}
			if (direction.ContainsKey(val2.Direction))
			{
				LOG.InfoFormat("    Direction : {0}", (object)direction[val2.Direction]);
			}
			if (val2.Direction != io)
			{
				continue;
			}
			LOG.InfoFormat("    Description : {0}", (object)val2.Description);
			if (val2.Description == null || val2.Description.IndexOf(portNo.ToString()) < 0)
			{
				continue;
			}
			LOG.InfoFormat("    Enabled : {0}", (object)val2.Enabled);
			if (action.ContainsKey(val2.Action))
			{
				LOG.InfoFormat("    Action : {0}", (object)action[val2.Action]);
			}
			if (val2.Enabled)
			{
				flag2 = true;
				if ((int)val2.Action == 0)
				{
					flag = false;
					break;
				}
			}
			LOG.InfoFormat("    Edge : {0}", (object)val2.EdgeTraversal);
			LOG.InfoFormat("    InterfaceTypes : {0}, CurrentTypeName : {1}", (object)val2.InterfaceTypes, (object)profileType2[num]);
			LOG.InfoFormat("    Grouping : {0}", (object)val2.Grouping);
			if (val2.Interfaces != null)
			{
				LOG.InfoFormat("    Interfaces : {0}", (object)val2.Interfaces.ToString());
			}
		}
		LOG.InfoFormat("{0}： end", (object)MethodBase.GetCurrentMethod().Name);
		return flag2 && flag;
	}

	private void buttonEnter_Click(object sender, EventArgs e)
	{
		//IL_0051: Unknown result type (might be due to invalid IL or missing references)
		//IL_0086: Invalid comparison between Unknown and I4
		((Control)buttonEnter).Enabled = false;
		try
		{
			DialogResult val = MessageBox.Show(Resources.CONFIRM_IMPLEMENT_SETTING_SECURE + "\n" + Resources.SETTING_CONTENTS + "\n" + setMessagePCGroup() + setMessageSMBReceive(), Resources.CONFIRM_SECURITY_SETTING_CAPTION, (MessageBoxButtons)4, (MessageBoxIcon)32);
			LOG.InfoFormat("{0}：\n********************************\n以下の内容で設定しますか？\n\n" + setMessagePCGroup() + setMessageSMBReceive() + "\n********************************\n", (object)MethodBase.GetCurrentMethod().Name);
			if ((int)val == 7)
			{
				LOG.InfoFormat("{0}：設定項目確認 No Selected… \n", (object)MethodBase.GetCurrentMethod().Name);
				Application.DoEvents();
				return;
			}
			LOG.InfoFormat("{0}：共有フォルダー作成確認 Yes Selected… \n", (object)MethodBase.GetCurrentMethod().Name);
			string text = ((Control)labelMessage).Text;
			string arg = string.Empty;
			string arg2 = string.Empty;
			if (radioButtonDomain.Checked && ((Control)radioButtonDomain).Enabled)
			{
				arg = Resources.SET_PC_GROUP_TO_DOMAIN;
			}
			else if (radioButtonWork.Checked && ((Control)radioButtonWork).Enabled)
			{
				arg = Resources.SET_PC_GROUP_TO_WORKGROUP;
			}
			if (radioButtonSharedON.Checked && ((Control)radioButtonSharedON).Enabled)
			{
				arg2 = Resources.ENABLE_FIREWALL_LIMITATION;
			}
			else if (radioButtonSharedOFF.Checked && ((Control)radioButtonSharedOFF).Enabled)
			{
				arg2 = Resources.DISABLE_FIREWALL_LIMITATION;
			}
			OpenPort((NET_FW_RULE_DIRECTION_)1, 445, (NET_FW_IP_PROTOCOL_)6);
			((Control)labelMessage).Text = $"{arg}\n{arg2}\n{text}";
		}
		catch (Exception ex)
		{
			((Control)labelMessage).Text = Resources.FOLDER_SHARING_SETUP_FAILED_MSG_1_4 + Resources.FOLDER_SHARING_SETUP_FAILED_MSG_2_4;
			LOG.ErrorFormat("{0}： フォルダ共有設定でエラー発生\n" + ex.ToString(), (object)MethodBase.GetCurrentMethod().Name);
		}
		finally
		{
			((Control)buttonEnter).Enabled = true;
			checkButtonEnter();
		}
	}

	public bool isPCDomain()
	{
		return radioButtonDomain.Checked;
	}

	public void enableSMB()
	{
		if (getPortState((NET_FW_RULE_DIRECTION_)1, 445, (NET_FW_IP_PROTOCOL_)6))
		{
			((Control)radioButtonSharedON).Enabled = false;
			((Control)radioButtonSharedOFF).Enabled = false;
			return;
		}
		radioButtonSharedON.Checked = true;
		radioButtonSharedOFF.Checked = false;
		((Control)radioButtonSharedON).Enabled = false;
		((Control)radioButtonSharedOFF).Enabled = false;
		OpenPort((NET_FW_RULE_DIRECTION_)1, 445, (NET_FW_IP_PROTOCOL_)6);
	}

	public bool checkEnableSMB(bool showDlgFlg = true)
	{
		bool flag = false;
		if (getPortState((NET_FW_RULE_DIRECTION_)1, 445, (NET_FW_IP_PROTOCOL_)6))
		{
			radioButtonSharedON.Checked = true;
			radioButtonSharedOFF.Checked = false;
			((Control)radioButtonSharedON).Enabled = false;
			((Control)radioButtonSharedOFF).Enabled = false;
			return true;
		}
		radioButtonSharedON.Checked = false;
		radioButtonSharedOFF.Checked = true;
		((Control)radioButtonSharedON).Enabled = false;
		((Control)radioButtonSharedOFF).Enabled = false;
		return checkOpenPort((NET_FW_RULE_DIRECTION_)1, 445, (NET_FW_IP_PROTOCOL_)6, showDlgFlg);
	}

	private string setMessagePCGroup()
	{
		string result = string.Empty;
		if (((Control)radioButtonDomain).Enabled && ((Control)radioButtonWork).Enabled)
		{
			string empty = string.Empty;
			result = string.Concat(str2: radioButtonDomain.Checked ? Resources.PC_GROUP_DOMAIN : ((!radioButtonWork.Checked) ? Resources.DO_NOT_SET : Resources.PC_GROUP_WORKGROUP), str0: "  ", str1: Resources.GROUP_THIS_PC_BELONGING, str3: "\n");
		}
		return result;
	}

	private string setMessageSMBReceive()
	{
		string result = string.Empty;
		if (((Control)radioButtonSharedON).Enabled && ((Control)radioButtonSharedOFF).Enabled)
		{
			string empty = string.Empty;
			result = string.Concat(str1: radioButtonSharedON.Checked ? Resources.DO_DO : ((!radioButtonSharedOFF.Checked) ? Resources.DO_NOT_SET : Resources.DO_NOT), str0: Resources.STATE_RELEASING_CONNECTION_RESTRICTION_SHARE_FOLDER, str2: "\n");
		}
		return result;
	}

	private void checkButtonEnter()
	{
		if (!((Control)radioButtonDomain).Enabled && !((Control)radioButtonWork).Enabled && !((Control)radioButtonSharedON).Enabled && !((Control)radioButtonSharedOFF).Enabled)
		{
			((Control)buttonEnter).Enabled = false;
		}
	}

	private void buttonNonPasswordConfig_Click(object sender, EventArgs e)
	{
		//IL_0120: Unknown result type (might be due to invalid IL or missing references)
		LOG.InfoFormat("{0}：パスワード保護共有呼び出し", (object)MethodBase.GetCurrentMethod().Name);
		try
		{
			Process.Start(new ProcessStartInfo
			{
				FileName = "control.exe",
				Arguments = "/name Microsoft.NetworkAndSharingCenter /page Advanced",
				UseShellExecute = true
			});
		}
		catch (Exception ex)
		{
			LOG.ErrorFormat("{0}：パスワード保護共有呼び出しでエラー Exception = {1}", (object)MethodBase.GetCurrentMethod().Name, (object)ex.ToString());
		}
		CustomDialogBox customDialogBox = new CustomDialogBox();
		customDialogBox.SetIcon(SystemIcons.Exclamation);
		customDialogBox.SetMessageBoxSize(550, 430);
		customDialogBox.SetHangingIndent(0);
		customDialogBox.SetMesages($"\n{Resources.SECURITY_DIALOG_MESSAGE_11}\n\n");
		customDialogBox.SetUnderLineMode(sw: true);
		customDialogBox.SetMesages($"{Resources.SECURITY_DIALOG_MESSAGE_12}\n");
		customDialogBox.SetUnderLineMode(sw: false);
		customDialogBox.SetHangingIndent(40);
		customDialogBox.SetMesages($" {Resources.SECURITY_DIALOG_MESSAGE_13}\n {Resources.SECURITY_DIALOG_MESSAGE_14}\n {Resources.SECURITY_DIALOG_MESSAGE_15}\n {Resources.SECURITY_DIALOG_MESSAGE_16}\n {Resources.SECURITY_DIALOG_MESSAGE_17}\n {Resources.SECURITY_DIALOG_MESSAGE_18}\n");
		customDialogBox.HideAgreeButton();
		customDialogBox.ResizeWindow();
		((Form)customDialogBox).ShowDialog();
		LOG.InfoFormat("{0}：パスワード保護共有呼び出し終了", (object)MethodBase.GetCurrentMethod().Name);
	}

	protected override void Dispose(bool disposing)
	{
		if (disposing && components != null)
		{
			components.Dispose();
		}
		((Form)this).Dispose(disposing);
	}

	private void InitializeComponent()
	{
		//IL_0011: Unknown result type (might be due to invalid IL or missing references)
		//IL_001b: Expected O, but got Unknown
		//IL_001c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0026: Expected O, but got Unknown
		//IL_0027: Unknown result type (might be due to invalid IL or missing references)
		//IL_0031: Expected O, but got Unknown
		//IL_0032: Unknown result type (might be due to invalid IL or missing references)
		//IL_003c: Expected O, but got Unknown
		//IL_003d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0047: Expected O, but got Unknown
		//IL_0048: Unknown result type (might be due to invalid IL or missing references)
		//IL_0052: Expected O, but got Unknown
		//IL_0053: Unknown result type (might be due to invalid IL or missing references)
		//IL_005d: Expected O, but got Unknown
		//IL_005e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0068: Expected O, but got Unknown
		//IL_0069: Unknown result type (might be due to invalid IL or missing references)
		//IL_0073: Expected O, but got Unknown
		//IL_0074: Unknown result type (might be due to invalid IL or missing references)
		//IL_007e: Expected O, but got Unknown
		//IL_007f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0089: Expected O, but got Unknown
		//IL_008a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0094: Expected O, but got Unknown
		//IL_0095: Unknown result type (might be due to invalid IL or missing references)
		//IL_009f: Expected O, but got Unknown
		//IL_00a0: Unknown result type (might be due to invalid IL or missing references)
		//IL_00aa: Expected O, but got Unknown
		//IL_00ab: Unknown result type (might be due to invalid IL or missing references)
		//IL_00b5: Expected O, but got Unknown
		//IL_00b6: Unknown result type (might be due to invalid IL or missing references)
		//IL_00c0: Expected O, but got Unknown
		//IL_00c1: Unknown result type (might be due to invalid IL or missing references)
		//IL_00cb: Expected O, but got Unknown
		//IL_00cc: Unknown result type (might be due to invalid IL or missing references)
		//IL_00d6: Expected O, but got Unknown
		//IL_00d7: Unknown result type (might be due to invalid IL or missing references)
		//IL_00e1: Expected O, but got Unknown
		//IL_00e2: Unknown result type (might be due to invalid IL or missing references)
		//IL_00ec: Expected O, but got Unknown
		//IL_00ed: Unknown result type (might be due to invalid IL or missing references)
		//IL_00f7: Expected O, but got Unknown
		//IL_00f8: Unknown result type (might be due to invalid IL or missing references)
		//IL_0102: Expected O, but got Unknown
		//IL_0ce0: Unknown result type (might be due to invalid IL or missing references)
		//IL_0cea: Expected O, but got Unknown
		ComponentResourceManager componentResourceManager = new ComponentResourceManager(typeof(FormSetup));
		labelPasswordWarning = new Label();
		buttonClose = new Button();
		panel3 = new Panel();
		label_WarningMessage = new Label();
		groupBoxMessage = new GroupBox();
		labelMessage = new Label();
		groupBoxPasswordDesabled = new GroupBox();
		labelSharingWarning = new Label();
		labelSharingInfo = new Label();
		labelNonPasswordWarning = new Label();
		buttonNonPasswordConfig = new Button();
		labelSharedWarning = new Label();
		groupBoxShared = new GroupBox();
		radioButtonSharedON = new RadioButton();
		radioButtonSharedOFF = new RadioButton();
		labelGroupName = new Label();
		labelLoginUserName = new Label();
		labelUserCaption = new Label();
		groupBoxGroup = new GroupBox();
		radioButtonWork = new RadioButton();
		radioButtonDomain = new RadioButton();
		buttonEnter = new Button();
		((Control)panel3).SuspendLayout();
		((Control)groupBoxMessage).SuspendLayout();
		((Control)groupBoxPasswordDesabled).SuspendLayout();
		((Control)groupBoxShared).SuspendLayout();
		((Control)groupBoxGroup).SuspendLayout();
		((Control)this).SuspendLayout();
		((Control)labelPasswordWarning).AutoSize = true;
		((Control)labelPasswordWarning).Location = new Point(14, 24);
		((Control)labelPasswordWarning).Name = "labelPasswordWarning";
		((Control)labelPasswordWarning).Size = new Size(109, 12);
		((Control)labelPasswordWarning).TabIndex = 1;
		((Control)labelPasswordWarning).Text = "Security recommend";
		((ButtonBase)buttonClose).ImeMode = (ImeMode)0;
		((Control)buttonClose).Location = new Point(434, 518);
		((Control)buttonClose).Name = "buttonClose";
		((Control)buttonClose).Size = new Size(85, 35);
		((Control)buttonClose).TabIndex = 6;
		((Control)buttonClose).Text = "Close";
		((ButtonBase)buttonClose).UseVisualStyleBackColor = true;
		((Control)buttonClose).Click += buttonClose_Click;
		((Control)panel3).Controls.Add((Control)(object)label_WarningMessage);
		((Control)panel3).Controls.Add((Control)(object)groupBoxMessage);
		((Control)panel3).Controls.Add((Control)(object)groupBoxPasswordDesabled);
		((Control)panel3).Controls.Add((Control)(object)labelSharedWarning);
		((Control)panel3).Controls.Add((Control)(object)groupBoxShared);
		((Control)panel3).Controls.Add((Control)(object)labelGroupName);
		((Control)panel3).Controls.Add((Control)(object)labelLoginUserName);
		((Control)panel3).Controls.Add((Control)(object)labelUserCaption);
		((Control)panel3).Location = new Point(14, 12);
		((Control)panel3).Name = "panel3";
		((Control)panel3).Size = new Size(509, 493);
		((Control)panel3).TabIndex = 7;
		((Control)label_WarningMessage).AutoSize = true;
		((Control)label_WarningMessage).Location = new Point(22, 67);
		((Control)label_WarningMessage).Name = "label_WarningMessage";
		((Control)label_WarningMessage).Size = new Size(91, 12);
		((Control)label_WarningMessage).TabIndex = 15;
		((Control)label_WarningMessage).Text = "Security Warning";
		((Control)groupBoxMessage).Controls.Add((Control)(object)labelMessage);
		((Control)groupBoxMessage).Location = new Point(21, 378);
		((Control)groupBoxMessage).Name = "groupBoxMessage";
		((Control)groupBoxMessage).Size = new Size(473, 86);
		((Control)groupBoxMessage).TabIndex = 14;
		groupBoxMessage.TabStop = false;
		((Control)groupBoxMessage).Text = "Message";
		((Control)labelMessage).Location = new Point(11, 16);
		((Control)labelMessage).Name = "labelMessage";
		((Control)labelMessage).Size = new Size(452, 59);
		((Control)labelMessage).TabIndex = 13;
		((Control)labelMessage).Text = "label2";
		((Control)groupBoxPasswordDesabled).Controls.Add((Control)(object)labelSharingWarning);
		((Control)groupBoxPasswordDesabled).Controls.Add((Control)(object)labelSharingInfo);
		((Control)groupBoxPasswordDesabled).Controls.Add((Control)(object)labelNonPasswordWarning);
		((Control)groupBoxPasswordDesabled).Controls.Add((Control)(object)buttonNonPasswordConfig);
		((Control)groupBoxPasswordDesabled).Controls.Add((Control)(object)labelPasswordWarning);
		((Control)groupBoxPasswordDesabled).Location = new Point(21, 121);
		((Control)groupBoxPasswordDesabled).Name = "groupBoxPasswordDesabled";
		((Control)groupBoxPasswordDesabled).Size = new Size(473, 244);
		((Control)groupBoxPasswordDesabled).TabIndex = 12;
		groupBoxPasswordDesabled.TabStop = false;
		((Control)groupBoxPasswordDesabled).Text = "No password agreements";
		((Control)labelSharingWarning).AutoSize = true;
		((Control)labelSharingWarning).Location = new Point(14, 147);
		((Control)labelSharingWarning).Name = "labelSharingWarning";
		((Control)labelSharingWarning).Size = new Size(110, 12);
		((Control)labelSharingWarning).TabIndex = 5;
		((Control)labelSharingWarning).Text = "Security agreements";
		((Control)labelSharingInfo).AutoSize = true;
		((Control)labelSharingInfo).Location = new Point(14, 106);
		((Control)labelSharingInfo).Name = "labelSharingInfo";
		((Control)labelSharingInfo).Size = new Size(152, 12);
		((Control)labelSharingInfo).TabIndex = 4;
		((Control)labelSharingInfo).Text = "Non password warning detail";
		((Control)labelNonPasswordWarning).AutoSize = true;
		((Control)labelNonPasswordWarning).Location = new Point(14, 70);
		((Control)labelNonPasswordWarning).Name = "labelNonPasswordWarning";
		((Control)labelNonPasswordWarning).Size = new Size(120, 12);
		((Control)labelNonPasswordWarning).TabIndex = 3;
		((Control)labelNonPasswordWarning).Text = "Non password warning";
		((Control)buttonNonPasswordConfig).AutoSize = true;
		((Control)buttonNonPasswordConfig).Location = new Point(363, 205);
		((Control)buttonNonPasswordConfig).Name = "buttonNonPasswordConfig";
		((Control)buttonNonPasswordConfig).Size = new Size(100, 23);
		((Control)buttonNonPasswordConfig).TabIndex = 2;
		((Control)buttonNonPasswordConfig).Text = "Apply";
		((ButtonBase)buttonNonPasswordConfig).UseVisualStyleBackColor = true;
		((Control)buttonNonPasswordConfig).Click += buttonNonPasswordConfig_Click;
		((Control)labelSharedWarning).AutoSize = true;
		((Control)labelSharedWarning).Location = new Point(470, 41);
		((Control)labelSharedWarning).Name = "labelSharedWarning";
		((Control)labelSharedWarning).Size = new Size(35, 12);
		((Control)labelSharedWarning).TabIndex = 11;
		((Control)labelSharedWarning).Text = "label5";
		((Control)labelSharedWarning).Visible = false;
		((Control)groupBoxShared).Controls.Add((Control)(object)radioButtonSharedON);
		((Control)groupBoxShared).Controls.Add((Control)(object)radioButtonSharedOFF);
		((Control)groupBoxShared).Location = new Point(21, 19);
		((Control)groupBoxShared).Name = "groupBoxShared";
		((Control)groupBoxShared).Size = new Size(356, 45);
		((Control)groupBoxShared).TabIndex = 9;
		groupBoxShared.TabStop = false;
		((Control)groupBoxShared).Text = "Windows Firewal Limitation";
		((Control)radioButtonSharedON).AutoSize = true;
		((Control)radioButtonSharedON).Location = new Point(12, 18);
		((Control)radioButtonSharedON).Name = "radioButtonSharedON";
		((Control)radioButtonSharedON).Size = new Size(42, 16);
		((Control)radioButtonSharedON).TabIndex = 8;
		radioButtonSharedON.TabStop = true;
		((Control)radioButtonSharedON).Text = "Yes";
		((ButtonBase)radioButtonSharedON).UseVisualStyleBackColor = true;
		((Control)radioButtonSharedOFF).AutoSize = true;
		((ButtonBase)radioButtonSharedOFF).ImeMode = (ImeMode)0;
		((Control)radioButtonSharedOFF).Location = new Point(173, 18);
		((Control)radioButtonSharedOFF).Name = "radioButtonSharedOFF";
		((Control)radioButtonSharedOFF).Size = new Size(37, 16);
		((Control)radioButtonSharedOFF).TabIndex = 7;
		radioButtonSharedOFF.TabStop = true;
		((Control)radioButtonSharedOFF).Text = "No";
		((ButtonBase)radioButtonSharedOFF).UseVisualStyleBackColor = true;
		((Control)labelGroupName).AutoSize = true;
		((Control)labelGroupName).Location = new Point(404, 21);
		((Control)labelGroupName).Name = "labelGroupName";
		((Control)labelGroupName).Size = new Size(35, 12);
		((Control)labelGroupName).TabIndex = 3;
		((Control)labelGroupName).Text = "label4";
		((Control)labelGroupName).Visible = false;
		((Control)labelLoginUserName).AutoSize = true;
		((Control)labelLoginUserName).Location = new Point(404, 40);
		((Control)labelLoginUserName).Name = "labelLoginUserName";
		((Control)labelLoginUserName).Size = new Size(35, 12);
		((Control)labelLoginUserName).TabIndex = 5;
		((Control)labelLoginUserName).Text = "label5";
		((Control)labelLoginUserName).Visible = false;
		((Control)labelUserCaption).AutoSize = true;
		((Control)labelUserCaption).Location = new Point(303, 40);
		((Control)labelUserCaption).Name = "labelUserCaption";
		((Control)labelUserCaption).Size = new Size(63, 12);
		((Control)labelUserCaption).TabIndex = 4;
		((Control)labelUserCaption).Text = "ユーザー名：";
		((Control)labelUserCaption).Visible = false;
		((Control)groupBoxGroup).Controls.Add((Control)(object)radioButtonWork);
		((Control)groupBoxGroup).Controls.Add((Control)(object)radioButtonDomain);
		((Control)groupBoxGroup).Location = new Point(35, 511);
		((Control)groupBoxGroup).Name = "groupBoxGroup";
		((Control)groupBoxGroup).Size = new Size(198, 48);
		((Control)groupBoxGroup).TabIndex = 10;
		groupBoxGroup.TabStop = false;
		((Control)groupBoxGroup).Text = "Group";
		((Control)groupBoxGroup).Visible = false;
		((Control)radioButtonWork).AutoSize = true;
		((Control)radioButtonWork).Enabled = false;
		((Control)radioButtonWork).Location = new Point(90, 24);
		((Control)radioButtonWork).Name = "radioButtonWork";
		((Control)radioButtonWork).Size = new Size(78, 16);
		((Control)radioButtonWork).TabIndex = 1;
		radioButtonWork.TabStop = true;
		((Control)radioButtonWork).Text = "WorkGroup";
		((ButtonBase)radioButtonWork).UseVisualStyleBackColor = true;
		((Control)radioButtonDomain).AutoSize = true;
		((Control)radioButtonDomain).Enabled = false;
		((Control)radioButtonDomain).Location = new Point(19, 24);
		((Control)radioButtonDomain).Name = "radioButtonDomain";
		((Control)radioButtonDomain).Size = new Size(61, 16);
		((Control)radioButtonDomain).TabIndex = 0;
		radioButtonDomain.TabStop = true;
		((Control)radioButtonDomain).Text = "Domain";
		((ButtonBase)radioButtonDomain).UseVisualStyleBackColor = true;
		((ButtonBase)buttonEnter).ImeMode = (ImeMode)0;
		((Control)buttonEnter).Location = new Point(337, 518);
		((Control)buttonEnter).Name = "buttonEnter";
		((Control)buttonEnter).Size = new Size(91, 35);
		((Control)buttonEnter).TabIndex = 8;
		((Control)buttonEnter).Text = "OK";
		((ButtonBase)buttonEnter).UseVisualStyleBackColor = true;
		((Control)buttonEnter).Click += buttonEnter_Click;
		((ContainerControl)this).AutoScaleDimensions = new SizeF(6f, 12f);
		((ContainerControl)this).AutoScaleMode = (AutoScaleMode)1;
		((Form)this).ClientSize = new Size(535, 597);
		((Control)this).Controls.Add((Control)(object)buttonEnter);
		((Control)this).Controls.Add((Control)(object)panel3);
		((Control)this).Controls.Add((Control)(object)buttonClose);
		((Control)this).Controls.Add((Control)(object)groupBoxGroup);
		((Form)this).FormBorderStyle = (FormBorderStyle)3;
		((Form)this).Icon = (Icon)componentResourceManager.GetObject("$this.Icon");
		((Form)this).MaximizeBox = false;
		((Form)this).MinimizeBox = false;
		((Control)this).Name = "FormSetup";
		((Form)this).StartPosition = (FormStartPosition)4;
		((Control)this).Text = "Security Settings";
		((Control)panel3).ResumeLayout(false);
		((Control)panel3).PerformLayout();
		((Control)groupBoxMessage).ResumeLayout(false);
		((Control)groupBoxPasswordDesabled).ResumeLayout(false);
		((Control)groupBoxPasswordDesabled).PerformLayout();
		((Control)groupBoxShared).ResumeLayout(false);
		((Control)groupBoxShared).PerformLayout();
		((Control)groupBoxGroup).ResumeLayout(false);
		((Control)groupBoxGroup).PerformLayout();
		((Control)this).ResumeLayout(false);
	}

	private void InitializeComponent_MultiLang()
	{
		//IL_0011: Unknown result type (might be due to invalid IL or missing references)
		//IL_001b: Expected O, but got Unknown
		//IL_001c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0026: Expected O, but got Unknown
		//IL_0027: Unknown result type (might be due to invalid IL or missing references)
		//IL_0031: Expected O, but got Unknown
		//IL_0032: Unknown result type (might be due to invalid IL or missing references)
		//IL_003c: Expected O, but got Unknown
		//IL_003d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0047: Expected O, but got Unknown
		//IL_0048: Unknown result type (might be due to invalid IL or missing references)
		//IL_0052: Expected O, but got Unknown
		//IL_0053: Unknown result type (might be due to invalid IL or missing references)
		//IL_005d: Expected O, but got Unknown
		//IL_005e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0068: Expected O, but got Unknown
		//IL_0069: Unknown result type (might be due to invalid IL or missing references)
		//IL_0073: Expected O, but got Unknown
		//IL_0074: Unknown result type (might be due to invalid IL or missing references)
		//IL_007e: Expected O, but got Unknown
		//IL_007f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0089: Expected O, but got Unknown
		//IL_008a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0094: Expected O, but got Unknown
		//IL_0095: Unknown result type (might be due to invalid IL or missing references)
		//IL_009f: Expected O, but got Unknown
		//IL_00a0: Unknown result type (might be due to invalid IL or missing references)
		//IL_00aa: Expected O, but got Unknown
		//IL_00ab: Unknown result type (might be due to invalid IL or missing references)
		//IL_00b5: Expected O, but got Unknown
		//IL_00b6: Unknown result type (might be due to invalid IL or missing references)
		//IL_00c0: Expected O, but got Unknown
		//IL_00c1: Unknown result type (might be due to invalid IL or missing references)
		//IL_00cb: Expected O, but got Unknown
		//IL_00cc: Unknown result type (might be due to invalid IL or missing references)
		//IL_00d6: Expected O, but got Unknown
		//IL_00d7: Unknown result type (might be due to invalid IL or missing references)
		//IL_00e1: Expected O, but got Unknown
		//IL_00e2: Unknown result type (might be due to invalid IL or missing references)
		//IL_00ec: Expected O, but got Unknown
		//IL_00ed: Unknown result type (might be due to invalid IL or missing references)
		//IL_00f7: Expected O, but got Unknown
		//IL_00f8: Unknown result type (might be due to invalid IL or missing references)
		//IL_0102: Expected O, but got Unknown
		//IL_0ce3: Unknown result type (might be due to invalid IL or missing references)
		//IL_0ced: Expected O, but got Unknown
		ComponentResourceManager componentResourceManager = new ComponentResourceManager(typeof(FormSetup));
		labelPasswordWarning = new Label();
		buttonClose = new Button();
		panel3 = new Panel();
		label_WarningMessage = new Label();
		groupBoxMessage = new GroupBox();
		labelMessage = new Label();
		groupBoxPasswordDesabled = new GroupBox();
		labelSharingWarning = new Label();
		labelSharingInfo = new Label();
		labelNonPasswordWarning = new Label();
		buttonNonPasswordConfig = new Button();
		labelSharedWarning = new Label();
		groupBoxShared = new GroupBox();
		radioButtonSharedON = new RadioButton();
		radioButtonSharedOFF = new RadioButton();
		labelGroupName = new Label();
		labelLoginUserName = new Label();
		labelUserCaption = new Label();
		groupBoxGroup = new GroupBox();
		radioButtonWork = new RadioButton();
		radioButtonDomain = new RadioButton();
		buttonEnter = new Button();
		((Control)panel3).SuspendLayout();
		((Control)groupBoxMessage).SuspendLayout();
		((Control)groupBoxPasswordDesabled).SuspendLayout();
		((Control)groupBoxShared).SuspendLayout();
		((Control)groupBoxGroup).SuspendLayout();
		((Control)this).SuspendLayout();
		((Control)labelPasswordWarning).AutoSize = true;
		((Control)labelPasswordWarning).Location = new Point(14, 24);
		((Control)labelPasswordWarning).Name = "labelPasswordWarning";
		((Control)labelPasswordWarning).Size = new Size(109, 12);
		((Control)labelPasswordWarning).TabIndex = 1;
		((Control)labelPasswordWarning).Text = "Security recommend";
		((ButtonBase)buttonClose).ImeMode = (ImeMode)0;
		((Control)buttonClose).Location = new Point(434, 538);
		((Control)buttonClose).Name = "buttonClose";
		((Control)buttonClose).Size = new Size(85, 35);
		((Control)buttonClose).TabIndex = 6;
		((Control)buttonClose).Text = "Close";
		((ButtonBase)buttonClose).UseVisualStyleBackColor = true;
		((Control)buttonClose).Click += buttonClose_Click;
		((Control)panel3).Controls.Add((Control)(object)label_WarningMessage);
		((Control)panel3).Controls.Add((Control)(object)groupBoxMessage);
		((Control)panel3).Controls.Add((Control)(object)groupBoxPasswordDesabled);
		((Control)panel3).Controls.Add((Control)(object)labelSharedWarning);
		((Control)panel3).Controls.Add((Control)(object)groupBoxShared);
		((Control)panel3).Controls.Add((Control)(object)labelGroupName);
		((Control)panel3).Controls.Add((Control)(object)labelLoginUserName);
		((Control)panel3).Controls.Add((Control)(object)labelUserCaption);
		((Control)panel3).Location = new Point(14, 12);
		((Control)panel3).Name = "panel3";
		((Control)panel3).Size = new Size(509, 513);
		((Control)panel3).TabIndex = 7;
		((Control)label_WarningMessage).AutoSize = true;
		((Control)label_WarningMessage).Location = new Point(22, 87);
		((Control)label_WarningMessage).Name = "label_WarningMessage";
		((Control)label_WarningMessage).Size = new Size(91, 12);
		((Control)label_WarningMessage).TabIndex = 15;
		((Control)label_WarningMessage).Text = "Security Warning";
		((Control)groupBoxMessage).Controls.Add((Control)(object)labelMessage);
		((Control)groupBoxMessage).Location = new Point(21, 398);
		((Control)groupBoxMessage).Name = "groupBoxMessage";
		((Control)groupBoxMessage).Size = new Size(473, 86);
		((Control)groupBoxMessage).TabIndex = 14;
		groupBoxMessage.TabStop = false;
		((Control)groupBoxMessage).Text = "Message";
		((Control)labelMessage).Location = new Point(11, 16);
		((Control)labelMessage).Name = "labelMessage";
		((Control)labelMessage).Size = new Size(452, 59);
		((Control)labelMessage).TabIndex = 13;
		((Control)labelMessage).Text = "label2";
		((Control)groupBoxPasswordDesabled).Controls.Add((Control)(object)labelSharingWarning);
		((Control)groupBoxPasswordDesabled).Controls.Add((Control)(object)labelSharingInfo);
		((Control)groupBoxPasswordDesabled).Controls.Add((Control)(object)labelNonPasswordWarning);
		((Control)groupBoxPasswordDesabled).Controls.Add((Control)(object)buttonNonPasswordConfig);
		((Control)groupBoxPasswordDesabled).Controls.Add((Control)(object)labelPasswordWarning);
		((Control)groupBoxPasswordDesabled).Location = new Point(21, 141);
		((Control)groupBoxPasswordDesabled).Name = "groupBoxPasswordDesabled";
		((Control)groupBoxPasswordDesabled).Size = new Size(473, 244);
		((Control)groupBoxPasswordDesabled).TabIndex = 12;
		groupBoxPasswordDesabled.TabStop = false;
		((Control)groupBoxPasswordDesabled).Text = "No password agreements";
		((Control)labelSharingWarning).AutoSize = true;
		((Control)labelSharingWarning).Location = new Point(14, 147);
		((Control)labelSharingWarning).Name = "labelSharingWarning";
		((Control)labelSharingWarning).Size = new Size(110, 12);
		((Control)labelSharingWarning).TabIndex = 5;
		((Control)labelSharingWarning).Text = "Security agreements";
		((Control)labelSharingInfo).AutoSize = true;
		((Control)labelSharingInfo).Location = new Point(14, 106);
		((Control)labelSharingInfo).Name = "labelSharingInfo";
		((Control)labelSharingInfo).Size = new Size(152, 12);
		((Control)labelSharingInfo).TabIndex = 4;
		((Control)labelSharingInfo).Text = "Non password warning detail";
		((Control)labelNonPasswordWarning).AutoSize = true;
		((Control)labelNonPasswordWarning).Location = new Point(14, 70);
		((Control)labelNonPasswordWarning).Name = "labelNonPasswordWarning";
		((Control)labelNonPasswordWarning).Size = new Size(120, 12);
		((Control)labelNonPasswordWarning).TabIndex = 3;
		((Control)labelNonPasswordWarning).Text = "Non password warning";
		((Control)buttonNonPasswordConfig).AutoSize = true;
		((Control)buttonNonPasswordConfig).Location = new Point(363, 205);
		((Control)buttonNonPasswordConfig).Name = "buttonNonPasswordConfig";
		((Control)buttonNonPasswordConfig).Size = new Size(100, 23);
		((Control)buttonNonPasswordConfig).TabIndex = 2;
		((Control)buttonNonPasswordConfig).Text = "Apply";
		((ButtonBase)buttonNonPasswordConfig).UseVisualStyleBackColor = true;
		((Control)buttonNonPasswordConfig).Click += buttonNonPasswordConfig_Click;
		((Control)labelSharedWarning).AutoSize = true;
		((Control)labelSharedWarning).Location = new Point(470, 41);
		((Control)labelSharedWarning).Name = "labelSharedWarning";
		((Control)labelSharedWarning).Size = new Size(35, 12);
		((Control)labelSharedWarning).TabIndex = 11;
		((Control)labelSharedWarning).Text = "label5";
		((Control)labelSharedWarning).Visible = false;
		((Control)groupBoxShared).Controls.Add((Control)(object)radioButtonSharedON);
		((Control)groupBoxShared).Controls.Add((Control)(object)radioButtonSharedOFF);
		((Control)groupBoxShared).Location = new Point(21, 19);
		((Control)groupBoxShared).Name = "groupBoxShared";
		((Control)groupBoxShared).Size = new Size(356, 65);
		((Control)groupBoxShared).TabIndex = 9;
		groupBoxShared.TabStop = false;
		((Control)groupBoxShared).Text = "Windows Firewal Limitation";
		((Control)radioButtonSharedON).AutoSize = true;
		((Control)radioButtonSharedON).Location = new Point(12, 38);
		((Control)radioButtonSharedON).Name = "radioButtonSharedON";
		((Control)radioButtonSharedON).Size = new Size(42, 16);
		((Control)radioButtonSharedON).TabIndex = 8;
		radioButtonSharedON.TabStop = true;
		((Control)radioButtonSharedON).Text = "Yes";
		((ButtonBase)radioButtonSharedON).UseVisualStyleBackColor = true;
		((Control)radioButtonSharedOFF).AutoSize = true;
		((ButtonBase)radioButtonSharedOFF).ImeMode = (ImeMode)0;
		((Control)radioButtonSharedOFF).Location = new Point(173, 38);
		((Control)radioButtonSharedOFF).Name = "radioButtonSharedOFF";
		((Control)radioButtonSharedOFF).Size = new Size(37, 16);
		((Control)radioButtonSharedOFF).TabIndex = 7;
		radioButtonSharedOFF.TabStop = true;
		((Control)radioButtonSharedOFF).Text = "No";
		((ButtonBase)radioButtonSharedOFF).UseVisualStyleBackColor = true;
		((Control)labelGroupName).AutoSize = true;
		((Control)labelGroupName).Location = new Point(404, 41);
		((Control)labelGroupName).Name = "labelGroupName";
		((Control)labelGroupName).Size = new Size(35, 12);
		((Control)labelGroupName).TabIndex = 3;
		((Control)labelGroupName).Text = "label4";
		((Control)labelGroupName).Visible = false;
		((Control)labelLoginUserName).AutoSize = true;
		((Control)labelLoginUserName).Location = new Point(404, 60);
		((Control)labelLoginUserName).Name = "labelLoginUserName";
		((Control)labelLoginUserName).Size = new Size(35, 12);
		((Control)labelLoginUserName).TabIndex = 5;
		((Control)labelLoginUserName).Text = "label5";
		((Control)labelLoginUserName).Visible = false;
		((Control)labelUserCaption).AutoSize = true;
		((Control)labelUserCaption).Location = new Point(303, 60);
		((Control)labelUserCaption).Name = "labelUserCaption";
		((Control)labelUserCaption).Size = new Size(63, 12);
		((Control)labelUserCaption).TabIndex = 4;
		((Control)labelUserCaption).Text = "ユーザー名：";
		((Control)labelUserCaption).Visible = false;
		((Control)groupBoxGroup).Controls.Add((Control)(object)radioButtonWork);
		((Control)groupBoxGroup).Controls.Add((Control)(object)radioButtonDomain);
		((Control)groupBoxGroup).Location = new Point(35, 531);
		((Control)groupBoxGroup).Name = "groupBoxGroup";
		((Control)groupBoxGroup).Size = new Size(198, 48);
		((Control)groupBoxGroup).TabIndex = 10;
		groupBoxGroup.TabStop = false;
		((Control)groupBoxGroup).Text = "Group";
		((Control)groupBoxGroup).Visible = false;
		((Control)radioButtonWork).AutoSize = true;
		((Control)radioButtonWork).Enabled = false;
		((Control)radioButtonWork).Location = new Point(90, 24);
		((Control)radioButtonWork).Name = "radioButtonWork";
		((Control)radioButtonWork).Size = new Size(78, 16);
		((Control)radioButtonWork).TabIndex = 1;
		radioButtonWork.TabStop = true;
		((Control)radioButtonWork).Text = "WorkGroup";
		((ButtonBase)radioButtonWork).UseVisualStyleBackColor = true;
		((Control)radioButtonDomain).AutoSize = true;
		((Control)radioButtonDomain).Enabled = false;
		((Control)radioButtonDomain).Location = new Point(19, 24);
		((Control)radioButtonDomain).Name = "radioButtonDomain";
		((Control)radioButtonDomain).Size = new Size(61, 16);
		((Control)radioButtonDomain).TabIndex = 0;
		radioButtonDomain.TabStop = true;
		((Control)radioButtonDomain).Text = "Domain";
		((ButtonBase)radioButtonDomain).UseVisualStyleBackColor = true;
		((ButtonBase)buttonEnter).ImeMode = (ImeMode)0;
		((Control)buttonEnter).Location = new Point(337, 538);
		((Control)buttonEnter).Name = "buttonEnter";
		((Control)buttonEnter).Size = new Size(91, 35);
		((Control)buttonEnter).TabIndex = 8;
		((Control)buttonEnter).Text = "OK";
		((ButtonBase)buttonEnter).UseVisualStyleBackColor = true;
		((Control)buttonEnter).Click += buttonEnter_Click;
		((ContainerControl)this).AutoScaleDimensions = new SizeF(6f, 12f);
		((ContainerControl)this).AutoScaleMode = (AutoScaleMode)1;
		((Form)this).ClientSize = new Size(535, 617);
		((Control)this).Controls.Add((Control)(object)buttonEnter);
		((Control)this).Controls.Add((Control)(object)panel3);
		((Control)this).Controls.Add((Control)(object)buttonClose);
		((Control)this).Controls.Add((Control)(object)groupBoxGroup);
		((Form)this).FormBorderStyle = (FormBorderStyle)3;
		((Form)this).Icon = (Icon)componentResourceManager.GetObject("$this.Icon");
		((Form)this).MaximizeBox = false;
		((Form)this).MinimizeBox = false;
		((Control)this).Name = "FormSetup";
		((Form)this).StartPosition = (FormStartPosition)4;
		((Control)this).Text = "Security Settings";
		((Control)panel3).ResumeLayout(false);
		((Control)panel3).PerformLayout();
		((Control)groupBoxMessage).ResumeLayout(false);
		((Control)groupBoxPasswordDesabled).ResumeLayout(false);
		((Control)groupBoxPasswordDesabled).PerformLayout();
		((Control)groupBoxShared).ResumeLayout(false);
		((Control)groupBoxShared).PerformLayout();
		((Control)groupBoxGroup).ResumeLayout(false);
		((Control)groupBoxGroup).PerformLayout();
		((Control)this).ResumeLayout(false);
	}
}
