using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.Specialized;
using System.Globalization;
using System.IO;
using System.Linq;
using System.Net;
using System.Net.Http;
using System.Net.Security;
using System.Reflection;
using System.Security.Cryptography.X509Certificates;
using System.Text;
using System.Text.RegularExpressions;
using System.Threading.Tasks;
using System.Web;
using System.Windows.Forms;
using CreateFolder.Properties;
using HtmlAgilityPack;
using log4net;

namespace CreateFolder;

public class MachineControl
{
	private enum GET_ADDRESSBOOK_MODE
	{
		FULL,
		NUMBER_ITEM_SPECIFIED,
		GET_NUM_OF_USERS
	}

	public enum ADDRESSBOOK_ITEM
	{
		REGISTRATION_NUMBER,
		NAME,
		INDEX,
		DATE_LAST_USED,
		FOLDER,
		KEY_CODE
	}

	public enum PRIMAX_MACHINE_CONTROL_RESULT
	{
		SUCCESS,
		ABORT,
		RESETTING,
		PW_RESETTING,
		ADD_DUPLICATE,
		ADD_OVER,
		ERROR
	}

	public enum PRIMAX_HEX_ENCODINGT
	{
		UTF16,
		SJIS
	}

	public enum PRIMAX_INPUT_ITEM
	{
		DESTINATION_NAME,
		USER_NAME,
		PASSWORD,
		FOLDER_NAME,
		FOLDER_PATH
	}

	private static readonly ILog LOG = LogManager.GetLogger(MethodBase.GetCurrentMethod().DeclaringType);

	private string machineLang = string.Empty;

	private string protocol = string.Empty;

	private object displayLabel;

	private ProgressBar progress;

	private string baseAddressStr = string.Empty;

	private object machineInfoRichTextBox;

	private readonly string URI_FORMAT_BASE_ADDRESS = "{0}://{1}/";

	private readonly string URI_FORMAT_AUTHFORM = "{0}web/guest/{1}/websys/webArch/authForm.cgi";

	private readonly string URI_FORMAT_MAINFRAME = "{0}web/guest/{1}/websys/webArch/mainFrame.cgi";

	private readonly string URI_FORMAT_LOGIN = "{0}web/guest/{1}/websys/webArch/login.cgi";

	private readonly string URI_FORMAT_ADDR_LIST = "{0}web/entry/{1}/address/adrsList.cgi";

	private readonly string URI_FORMAT_ADDR_LIST_MODEIN_LALL = "?modeIn=LALL";

	private readonly string URI_FORMAT_ADDR_LIST_MODEIN_LIST = "?modeIn=LIST";

	private readonly string URI_FORMAT_ADDR_LIST_LOAD_ENTRY = "{0}web/entry/{1}/address/adrsListLoadEntry.cgi?_={2}&listCountIn={3}&getCountIn={4}";

	private readonly string URI_FORMAT_ADDR_GET_USER = "{0}web/entry/{1}/address/address/adrsGetUser.cgi";

	private readonly string URI_FORMAT_ADDR_EDIT_PASSWD = "{0}web/entry/{1}/address/adrsEditPassword.cgi";

	private readonly string URI_FORMAT_ADDR_SET_USER = "{0}web/entry/{1}/address/adrsSetUser.cgi";

	private readonly string URI_FORMAT_GET_ADMIN_AUTH = "{0}web/entry/{1}/websys/config/getAdminAuthenticationManager.cgi";

	private readonly string URI_FORMAT_CONFIGURATION = "{0}://{1}/web/guest/{2}/websys/status/configuration.cgi";

	private readonly string URI_FORMAT_GETTCP = "{0}://{1}/web/guest/{2}/websys/netw/getTcp.cgi";

	private readonly string URI_FORMAT_GETSMB = "{0}://{1}/web/guest/{2}/websys/netw/getSmb.cgi";

	private readonly string URI_FORMAT_POSTSMB = "{0}://{1}/web/entry/{2}/websys/netw/setSmb.cgi";

	private readonly string URI_FORMAT_ENTRYSMBGET = "{0}://{1}/web/entry/{2}/websys/netw/getSmb.cgi";

	private readonly string URI_FORMAT_FIRMWARE_UPDATE = "{0}://{1}/web/entry/{2}/websys/config/webFirmwareUpdate.cgi";

	private readonly string URI_FORMAT_GET_USER_WIZARD = "{0}web/entry/{1}/address/adrsGetUserWizard.cgi";

	private readonly string URI_FORMAT_SET_USER_WIZARD = "{0}web/entry/{1}/address/adrsSetUserWizard.cgi";

	private readonly string URI_FORMAT_LOGOUT = "{0}web/entry/{1}/websys/webArch/logout.cgi";

	private string URI_FORMAT_MAINTENANCE = "{0}web/entry/{1}/address/adrsMaintenance.cgi?mode=BACKUP&wimToken={2}";

	private string URI_FORMAT_SET_MAINTENANCE = "{0}web/entry/{1}/address/adrsSetMainte.cgi";

	private readonly int ADDRESSBOOK_LINES_PER_PAGE_NORM = 20;

	private readonly string ADDRESSBOOK_PWD_CHG_ON = "ACCOUNTPWD_ON_RB";

	private readonly string ADDRESSBOOK_PWD_CHG_OFF = "ACCOUNTPWD_OFF_RB";

	private Dictionary<int, string> columnList = new Dictionary<int, string>();

	private Dictionary<string, string> searchForList = new Dictionary<string, string>();

	private readonly string ADDRESSBOOK_HEADER = "adrsListShowHeaders";

	private readonly string ADDRESSBOOK_HEADER_FOLDER = "FOLDER_LH";

	private List<string> wimAddressbookDisplayItems = new List<string>();

	private int progressValue;

	private int progressMaxValue;

	private static Dictionary<string, Account> adminAccounts = new Dictionary<string, Account>();

	public static string REGISTRATION_NUMBER_PASS = "pass";

	public static string REGISTRATION_NUMBER_INUSE = "inuse";

	private static HttpClient client = null;

	private static CookieContainer cookieContainer = null;

	private string wimToken = string.Empty;

	private readonly string XPATH_ADDR_LIST_ALL = "//*/div[@id='ReportListArea']/div[1]/div[1]/table[@class='adTable mgn-B1e']/tbody[1]";

	private readonly string XPATH_ADDR_LIST_NUM_LIMITATION = "//*/form[@name='mainForm']/table[1]/tr[4]/td[1]/table[1]/tr[2]/td[1]/table[1]/tr[1]/td[1]/table[1]/tr[1]";

	private readonly string XPATH_ADDR_LIST_TITLE_ALL = "div/a";

	private readonly string XPATH_ADDR_LIST_TITLE_NUM_LIMITATION = "table/tr/td/table/tr/td/div/font";

	private readonly string XPATH_ADDRESSBOOK_TITLE = "//*/div[@class='listTitle']/font";

	private readonly string XPATH_ADDRESSBOOK_SERACH_FILTERED = "//*/table[@class='reportListCommon']/tr";

	private readonly string XPATH_SERACH_FILTER = "//*/select[@name='searchItemIn']";

	private readonly string XPATH_NUM_USERS = "//*/span[@id='span_numOfUsers']";

	private readonly string XPATH_NUM_GROUPS = "//*/span[@id='span_numOfGroups']";

	private readonly string XPATH_WIM_TOKEN = "//*/form[@name='commandForm']/input";

	private readonly string XPATH_WIM_TOKEN_LIST_ALL = "//*/form[@name='listAllForm']/input";

	private readonly string XPATH_WIM_CURRENT_PAGE = "//*/form[@name='mainForm']/table[1]/tr[4]/td[1]/table[1]/tr[1]/td[1]/table[1]/tr[1]/td[1]/table[1]/tr[1]/td[5]";

	private readonly string XPATH_WIM_CONFIG_MACHINE_NAME = "//table/tr[@class='staticProp']/td[4]";

	private readonly string XPATH_WIM_RESULT_VALUE = "//*/form[@name='basicForm']/input[@name='returnValue']";

	private readonly string XPATH_WIM_MAIN_FORM = "//*/form[@name='mainForm']";

	private readonly string XPATH_WIM_ERROR_MESSAGE = "../form//*/tr[@class='responseMessage']/td";

	private readonly string XPATH_WIM_ERROR_MESSAGE_2 = "//body//*/tr[@class='responseMessage']/td";

	private readonly string XPATH_WIM_AUTOLOGOUT = "//*/form[@name='form1']/input[@name='messageID']";

	private readonly string XPATH_WIM_ERROR_MESSAGE_TABLE = "//*/body/*/div[@id='parentFrame']/input";

	private string XPATH_WIM_MAINTENANCE_HIDDEN_FORM = "//*/form[@name='setForm']/input[@type='hidden']";

	private string XPATH_WIM_MAINTENANCE_AUTO_DELETE = "//*[@name='autoDeleteSettingIn']";

	private string XPATH_WIM_MAINTENANCE_DISP_ITEM_LIST = "//*[@id='dispHeaderBox']";

	private string WIM_RETURN_VALUE_BUSY = "BUSY";

	private string WIM_RETURN_VALUE_SUCCESS = "SUCCESS";

	private string WIM_RETURN_VALUE_SESSIONFULL = "SESSIONFULL";

	private string WIM_RETURN_VALUE_SEARCHRESULTEXCEED = "SEARCHRESULTEXCEED";

	private string WIM_RETURN_VALUE_SEARCHWORDTOOLONG = "SEARCHWORDTOOLONG";

	private List<WimError> wimErrorTable = new List<WimError>();

	private bool stop_addressbook_collection;

	private int dummyRegistrationNo;

	private readonly Dictionary<string, ADDRESSBOOK_ITEM> addressBookTitle = new Dictionary<string, ADDRESSBOOK_ITEM>
	{
		{
			Resources.ADDRESSBOOK_REGISTRATION_NO_NAME,
			ADDRESSBOOK_ITEM.REGISTRATION_NUMBER
		},
		{
			Resources.ADDRESSBOOK_NAME,
			ADDRESSBOOK_ITEM.NAME
		},
		{
			Resources.ADDRESSBOOK_INDEX_NAME,
			ADDRESSBOOK_ITEM.INDEX
		},
		{
			Resources.ADDRESSBOOK_DATE_LAST_USED,
			ADDRESSBOOK_ITEM.DATE_LAST_USED
		},
		{
			Resources.ADDRESSBOOK_FOLDER,
			ADDRESSBOOK_ITEM.FOLDER
		}
	};

	private string displayMachineName = string.Empty;

	private readonly string PRIMAX_URI_HOME_STATUS = "{0}://{1}/main.asp{2}";

	private readonly string PRIMAX_URI_HOME_EQUIPMENTINFO = "{0}://{1}/machinei.asp{2}";

	private readonly string PRIMAX_URI_NETWORKSETTINGS_DSN = "{0}://{1}/emaildns.asp{2}";

	private readonly string PRIMAX_URI_NETWORKSETTINGS_NETWORKINFO = "{0}://{1}/card.asp{2}";

	private bool primaxModel;

	private bool primaxUnicode;

	private readonly string PRIMAX_URI_FOLDER_DESTINATION = "{0}://{1}/pcentry.asp?NULL";

	private readonly string PRIMAX_URI_PROFILE_ADD = "{0}://{1}/form/profileAdd";

	private List<string[]> convLatinaList = new List<string[]>
	{
		new string[3] { "Œ", "%u0152", "&#338;" },
		new string[3] { "œ", "%u0153", "&#339;" }
	};

	private readonly string PRIMAX_GET_ADDRESS_BOOK = "{0}://{1}/scanpc.asp";

	private readonly string PRIMAX_GET_ADDRESS_BOOK_INFO = "{0}://{1}/pcentry.asp?{2}&2&?";

	private readonly string PRIMAX_URI_QUICKSCAN = "{0}://{1}/quickscan.asp";

	private List<string> ngCharListForDestName = new List<string> { "~" };

	public string DisplayMachineName => displayMachineName;

	public MachineControl(string lang)
	{
		machineLang = lang;
		if (client == null)
		{
			createHttpClientInstance();
		}
	}

	public async Task<MACHINE_CONTROL_RESULT> executeWimConnect(SettingItemsSetupAddress setting, object displayLabelObject, ProgressBar progressBar, int steps = 9, object machineInfoTextBoxObject = null, bool registNoCheckOnly = false)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		displayLabel = displayLabelObject;
		progress = progressBar;
		if (setting.addressName != null && setting.registrationNo == 0)
		{
			steps--;
		}
		if (setting.firstFlg)
		{
			progressValue = 0;
			progressMaxValue = steps;
		}
		machineInfoRichTextBox = machineInfoTextBoxObject;
		if (setting.firstFlg)
		{
			if (progress != null)
			{
				progress.Maximum = progressMaxValue;
			}
			updateProgressBar(Resources.PROGRESS_MESSAGE_1);
		}
		if (setting.httpsFlg)
		{
			protocol = "https";
			ServicePointManager.SecurityProtocol = SecurityProtocolType.Tls11 | SecurityProtocolType.Tls12;
		}
		else
		{
			protocol = "http";
		}
		baseAddressStr = string.Format(URI_FORMAT_BASE_ADDRESS, protocol, setting.host);
		try
		{
			return await connectAndLogin(client, setting, registNoCheckOnly);
		}
		catch (HttpRequestException ex)
		{
			LOG.InfoFormat("\n例外発生!", new object[0]);
			for (Exception ex2 = ex; ex2 != null; ex2 = ex2.InnerException)
			{
				LOG.InfoFormat("例外メッセージ EX: {0} ", (object)ex2.Message);
			}
			throw;
		}
		catch (TaskCanceledException ex3)
		{
			LOG.InfoFormat("\nタイムアウト!", new object[0]);
			LOG.InfoFormat("例外メッセージ TCE: {0} ", (object)ex3.Message);
			throw;
		}
		catch (ArgumentException ex4)
		{
			LOG.InfoFormat("例外メッセージ AE: {0} ", (object)ex4.Message);
			throw;
		}
		catch (Exception ex5)
		{
			LOG.InfoFormat("例外メッセージ EXP: {0} ", (object)ex5.Message);
			throw;
		}
		finally
		{
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		}
	}

	public async Task<string[]> executeSetupAddress(SettingItemsSetupAddress setting, bool registNoCheckOnly = false)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		try
		{
			if (setting.registrationNo > 0)
			{
				if (await checkRegistrationNumberInUse(client, setting, cookieContainer))
				{
					updateProgressBar(Resources.REGISTRATION_NUMBER_INUSE, firstFlag: false);
					return new string[1] { REGISTRATION_NUMBER_INUSE };
				}
				if (registNoCheckOnly)
				{
					return new string[1] { REGISTRATION_NUMBER_PASS };
				}
			}
			HttpResponseMessage obj = await getAddressAll(client, GET_ADDRESSBOOK_MODE.FULL);
			string result = obj.Content.ReadAsStringAsync().Result;
			Uri uri = new Uri(baseAddressStr);
			foreach (string item in obj.Headers.GetValues("Set-Cookie").ToList())
			{
				if (item.ToString().IndexOf("risessionid") != -1)
				{
					cookieContainer.Add(uri, new Cookie("risessionid", item.Split('=', ';')[1], "/"));
					break;
				}
			}
			string text = "name=\"wimToken\" value=\"";
			int num = result.IndexOf(text) + text.Length;
			int num2 = result.IndexOf("\"", num);
			string wimStr = result.Substring(num, num2 - num);
			LOG.InfoFormat("wimToken:" + wimStr, new object[0]);
			await getAddressList(client, wimStr, ADDRESSBOOK_LINES_PER_PAGE_NORM);
			result = (await getRegistNo(client, wimStr)).Content.ReadAsStringAsync().Result;
			string text2 = "name=\"entryIndexIn\" value=\"";
			num = result.IndexOf(text2) + text2.Length;
			num2 = result.IndexOf("\"", num);
			string entryIndexInStr = ((setting.registrationNo > 0) ? setting.registrationNo.ToString() : result.Substring(num, num2 - num));
			if (!string.IsNullOrEmpty(setting.authPassword))
			{
				await setPassword(client, setting, wimStr);
			}
			return await setAddressBook(client, setting, wimStr, entryIndexInStr);
		}
		catch (HttpRequestException ex)
		{
			LOG.InfoFormat("\n例外発生!", new object[0]);
			for (Exception ex2 = ex; ex2 != null; ex2 = ex2.InnerException)
			{
				LOG.InfoFormat("例外メッセージ EX: {0} ", (object)ex2.Message);
			}
			throw;
		}
		catch (TaskCanceledException ex3)
		{
			LOG.InfoFormat("\nタイムアウト!", new object[0]);
			LOG.InfoFormat("例外メッセージ TCE: {0} ", (object)ex3.Message);
			throw;
		}
		catch (ArgumentException ex4)
		{
			LOG.InfoFormat("例外メッセージ AE: {0} ", (object)ex4.Message);
			throw;
		}
		catch (Exception ex5)
		{
			LOG.InfoFormat("例外メッセージ EXP: {0} ", (object)ex5.Message);
			throw;
		}
	}

	private async Task<HttpResponseMessage> getAsync(string jobName, HttpClient client, string uri)
	{
		int cntNG = 0;
		int MAXNG = 5;
		HttpResponseMessage response = null;
		while (cntNG < MAXNG)
		{
			try
			{
				response = await client.GetAsync(uri);
			}
			catch (TaskCanceledException ex)
			{
				cntNG++;
				LOG.InfoFormat("\nタイムアウト!\u3000リトライ {0} 回数＝ {1}", (object)jobName, (object)cntNG);
				LOG.InfoFormat("例外メッセージ TCE: {0} ", (object)ex.Message);
				if (cntNG >= MAXNG)
				{
					LOG.InfoFormat("\nリトライアウト!", new object[0]);
					throw;
				}
				continue;
			}
			break;
		}
		return response;
	}

	private async Task<MACHINE_CONTROL_RESULT> wimInitialConnection(HttpClient client, bool firstFlag)
	{
		string text = string.Format(URI_FORMAT_MAINFRAME, baseAddressStr, machineLang);
		LOG.InfoFormat("{0}：WIM 01.初回接続 リクエスト:{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)text);
		if (firstFlag)
		{
			updateProgressBar(Resources.PROGRESS_MESSAGE_1);
		}
		string result = (await postAsync("初回接続！", client, text)).Content.ReadAsStringAsync().Result;
		LOG.InfoFormat("{0}：WIM 01.初回接続 レスポンス:\n{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)result);
		checkWimErrorExist(result);
		return MACHINE_CONTROL_RESULT.SUCCESS;
	}

	private async Task<HttpResponseMessage> winLogin(HttpClient client, SettingItemsSetupAddress setting)
	{
		Base64String base64String = new Base64String("shift_jis");
		string value = base64String.Encode(setting.adminName);
		string value2 = base64String.Encode(setting.passwd);
		string text = string.Empty;
		Dictionary<string, string> dictionary = new Dictionary<string, string>
		{
			{ "userid_work", "" },
			{ "userid", value },
			{ "password_work", "" },
			{ "password", value2 }
		};
		foreach (KeyValuePair<string, string> item in dictionary)
		{
			text += $"\n    {item.Key}:****";
		}
		string text2 = string.Format(URI_FORMAT_LOGIN, baseAddressStr, machineLang);
		LOG.InfoFormat("{0}：WIM 02.ログイン リクエスト:\nURI:{1}\nBODY:{2}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)text2, (object)text);
		if (setting.firstFlg)
		{
			updateProgressBar(Resources.PROGRESS_MESSAGE_1);
		}
		HttpResponseMessage obj = await postAsync("ログイン！", client, text2, dictionary);
		string result = obj.Content.ReadAsStringAsync().Result;
		LOG.InfoFormat("{0}：WIM 02.ログイン レスポンス:\n{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)result);
		checkWimErrorExist(result);
		string text3 = "<tr class=\"responseMessage\">";
		string value3 = "</td>";
		if (result != null && result.IndexOf(text3) != -1)
		{
			_ = string.Empty;
			int num = result.IndexOf(text3);
			string text4 = result.Substring(num + text3.Length);
			num = text4.IndexOf(">");
			string text5 = text4.Substring(num + 1);
			text5 = text5[..text5.IndexOf(value3)];
			text5 = removaTag(text5);
			LOG.InfoFormat("WIM ログインエラー :{0}", (object)text5);
			string message = ((text5.IndexOf(Resources.ERR_MSG_WIM_BUSY) <= 0) ? text5 : Resources.LOGIN_ERROR_MSG_2_5);
			throw new Exception(message);
		}
		return obj;
	}

	private async Task<bool> checkAdminAuth(HttpClient client)
	{
		string text = string.Format(URI_FORMAT_GET_ADMIN_AUTH, baseAddressStr, machineLang);
		LOG.InfoFormat("{0}：WIM 02-01.機器管理者認証調査 リクエスト:{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)text);
		string result = (await postAsync("機器管理者認証調査！", client, text)).Content.ReadAsStringAsync().Result;
		LOG.InfoFormat("{0}：WIM 02-01.機器管理者認証調査 レスポンス:\n{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)result);
		checkWimErrorExist(result);
		string value = "<input ";
		string value2 = "name=\"isMachineAuthentication\"";
		string value3 = "checked";
		string text2 = string.Empty;
		bool result2 = false;
		int num = result.IndexOf(value2);
		if (num > 0)
		{
			num = result.LastIndexOf(value, num);
			if (num > 0)
			{
				int num2 = result.IndexOf(">", num);
				if (num2 > 0)
				{
					text2 = result.Substring(num, num2 - num + 1);
				}
			}
		}
		if (!string.IsNullOrEmpty(text2))
		{
			result2 = text2.Contains(value3);
		}
		return result2;
	}

	private async Task<MACHINE_CONTROL_RESULT> retryWithAuthentication(SettingItemsSetupAddress setting, bool registNoCheckOnly)
	{
		LOG.InfoFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		LOG.InfoFormat("{0}：認証情報の入力", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		FormAdminAuthConfirm formAdminAuthConfirm = new FormAdminAuthConfirm();
		formAdminAuthConfirm.setMsg(setting.firstFlg);
		((Form)formAdminAuthConfirm).StartPosition = (FormStartPosition)4;
		((Form)formAdminAuthConfirm).ShowDialog();
		if ((int)((Form)formAdminAuthConfirm).DialogResult == 1)
		{
			createHttpClientInstance();
			SettingItemsSetupAddress settingItemsSetupAddress = setting.Clone();
			settingItemsSetupAddress.adminName = formAdminAuthConfirm.getAuthUser();
			settingItemsSetupAddress.passwd = formAdminAuthConfirm.getAuthPass();
			settingItemsSetupAddress.firstFlg = false;
			return await executeWimConnect(settingItemsSetupAddress, displayLabel, progress, 0, machineInfoRichTextBox, registNoCheckOnly);
		}
		updateProgressBar(Resources.TEXT_STOP_EXECUTE, firstFlag: true, numeric: false);
		return MACHINE_CONTROL_RESULT.ABORT;
	}

	private async Task<HttpResponseMessage> getAddressAll(HttpClient client, GET_ADDRESSBOOK_MODE mode)
	{
		LOG.InfoFormat("{0}：start mode:{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)mode);
		string text = string.Format(URI_FORMAT_ADDR_LIST, baseAddressStr, machineLang);
		switch (mode)
		{
		case GET_ADDRESSBOOK_MODE.NUMBER_ITEM_SPECIFIED:
			text += URI_FORMAT_ADDR_LIST_MODEIN_LIST;
			break;
		case GET_ADDRESSBOOK_MODE.GET_NUM_OF_USERS:
			text += URI_FORMAT_ADDR_LIST_MODEIN_LALL;
			break;
		default:
			updateProgressBar(Resources.PROGRESS_MESSAGE_3);
			text += URI_FORMAT_ADDR_LIST_MODEIN_LALL;
			break;
		}
		LOG.InfoFormat("{0}：WIM 03.登録No取得 リクエスト:{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)text);
		HttpResponseMessage obj = await getAsync("登録No取得！", client, text);
		string result = obj.Content.ReadAsStringAsync().Result;
		LOG.InfoFormat("{0}：WIM 03.登録No取得 レスポンス:\n{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)result);
		createWimErrorTable(result);
		checkWimErrorExist(result);
		LOG.InfoFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		return obj;
	}

	private async Task<HttpResponseMessage> getAddressList(HttpClient client, string wimStr, int linesPerPage, int page = 1)
	{
		LOG.InfoFormat("{0}：start page:{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)page);
		string text = string.Format(URI_FORMAT_ADDR_LIST_LOAD_ENTRY, baseAddressStr, machineLang, wimStr, linesPerPage, page);
		LOG.InfoFormat("{0}：WIM 04.リストを取得 リクエスト:" + text, (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		updateProgressBar(Resources.ADDRESSBOOK_READING);
		HttpResponseMessage obj = await getAsync("リストを取得！", client, text);
		string result = obj.Content.ReadAsStringAsync().Result;
		LOG.InfoFormat("{0}：WIM 04.リストを取得 レスポンス:\n{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)result);
		checkWimErrorExist(result);
		LOG.InfoFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		return obj;
	}

	private async Task<HttpResponseMessage> getAddressListFiltered(HttpClient client, int getLines, int totalLines, int pageNum, string searchWay, string searchData, Dictionary<string, Dictionary<ADDRESSBOOK_ITEM, string>> addressBookTable)
	{
		string text = string.Format(URI_FORMAT_ADDR_LIST, baseAddressStr, machineLang);
		LOG.InfoFormat("{0}：start WIM 04.リストを取得 リクエスト:" + text, (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		string value = string.Empty;
		foreach (KeyValuePair<string, string> searchFor in searchForList)
		{
			if (string.Equals(searchWay, searchFor.Value))
			{
				value = searchFor.Key;
				break;
			}
		}
		string value2 = ((pageNum == 1) ? "0" : pageNum.ToString());
		string value3 = ((pageNum == 1) ? "INPUT" : string.Empty);
		updateProgressBar(Resources.ADDRESSBOOK_READING);
		Dictionary<string, string> dictionary = new Dictionary<string, string>();
		dictionary.Add("wimToken", wimToken);
		dictionary.Add("mode", "LIST");
		dictionary.Add("pageSpecifiedIn", "true");
		dictionary.Add("pageNumberIn", value2);
		dictionary.Add("searchSpecifyModeIn", value3);
		dictionary.Add("outputSpecifyModeIn", "");
		dictionary.Add("entryIndexIn", "");
		dictionary.Add("entryNameIn", "");
		dictionary.Add("entryFilterIn", "ALL_O");
		dictionary.Add("searchItemIn", value);
		dictionary.Add("searchDataIn", searchData);
		dictionary.Add("pages", "");
		dictionary.Add("listCountIn", getLines.ToString());
		dictionary.Add("totalCount", totalLines.ToString());
		dictionary.Add("offset", "0");
		if (addressBookTable.Count == 0)
		{
			for (int i = 1; i <= getLines; i++)
			{
				dictionary.Add($"{i:D5}", "1");
			}
		}
		else
		{
			foreach (KeyValuePair<string, Dictionary<ADDRESSBOOK_ITEM, string>> item in addressBookTable)
			{
				dictionary.Add(item.Key, "1");
			}
		}
		KeyValuePair<string, string>[] content = dictionary.ToArray();
		HttpResponseMessage obj = await postAsync("リストを取得！", client, text, content);
		string result = obj.Content.ReadAsStringAsync().Result;
		LOG.InfoFormat("{0}：WIM 04.リストを取得 レスポンス:\n{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)result);
		checkWimErrorExist(result);
		LOG.InfoFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		return obj;
	}

	public async Task<HttpResponseMessage> getAddressListFirstpage()
	{
		string text = string.Format(URI_FORMAT_ADDR_LIST, baseAddressStr, machineLang);
		LOG.InfoFormat("{0}：start リストを取得 リクエスト:" + text, (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		updateProgressBar(Resources.ADDRESSBOOK_READING);
		KeyValuePair<string, string>[] content = new Dictionary<string, string>
		{
			{ "wimToken", wimToken },
			{ "mode", "LIST" },
			{ "pageSpecifiedIn", "false" },
			{ "pageNumberIn", "0" },
			{ "searchSpecifyModeIn", "NONE" },
			{ "outputSpecifyModeIn", "" },
			{ "entryIndexIn", "" },
			{ "entryNameIn", "" }
		}.ToArray();
		HttpResponseMessage obj = await postAsync("リストを取得！", client, text, content);
		string result = obj.Content.ReadAsStringAsync().Result;
		LOG.InfoFormat("{0}：リストを取得 レスポンス:\n{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)result);
		checkWimErrorExist(result);
		LOG.InfoFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		return obj;
	}

	private async Task<HttpResponseMessage> getRegistNo(HttpClient client, string wimStr)
	{
		Dictionary<string, string> dictionary = new Dictionary<string, string>
		{
			{ "mode", "ADDUSER" },
			{ "outputSpecifyModeIn", "DEFAULT" },
			{ "wimToken", wimStr }
		};
		string text = string.Empty;
		foreach (KeyValuePair<string, string> item in dictionary)
		{
			text += $"\n    {item.Key}:{item.Value}";
		}
		string text2 = string.Format(URI_FORMAT_ADDR_GET_USER, baseAddressStr, machineLang);
		LOG.InfoFormat("{0}：WIM 05.アドレス帳登録番号取得 リクエスト:\nURI:{1}\nBODY:{2}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)text2, (object)text);
		updateProgressBar(Resources.PROGRESS_MESSAGE_3);
		HttpResponseMessage obj = await postAsync("アドレス帳登録番号取得！", client, text2, dictionary);
		string result = obj.Content.ReadAsStringAsync().Result;
		LOG.InfoFormat("{0}：WIM 05.アドレス帳登録番号取得  レスポンス:\n{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)result);
		checkWimErrorExist(result);
		return obj;
	}

	private async Task<HttpResponseMessage> setPassword(HttpClient client, SettingItemsSetupAddress setting, string wimStr)
	{
		string value = new Base64String("shift_jis").Encode(setting.authPassword);
		Dictionary<string, string> content = new Dictionary<string, string>
		{
			{ "mode", "ADDUSER" },
			{ "kind", "FOLDER" },
			{ "inputSpecifyMode", "FIX" },
			{ "outputSpecifyModeIn", "" },
			{ "wimToken", wimStr },
			{ "wayFrom", "adrsEditPassword.cgi?inputSpecifyMode=NONE" },
			{ "wayTo", "adrsGetUser.cgi#AUTH_INFO_C?outputSpecifyModeIn=SETTINGS" },
			{ "pageSpecifiedIn", "" },
			{ "pageNumberIn", "" },
			{ "passwordInwk", "" },
			{ "passwordIn", value },
			{ "passwordConfirmInwk", "" },
			{ "passwordConfirmIn", value }
		};
		string text = string.Format(URI_FORMAT_ADDR_EDIT_PASSWD, baseAddressStr, machineLang);
		LOG.InfoFormat("{0}：WIM 06.パスワード設定 リクエスト:\nURI:{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)text);
		updateProgressBar(Resources.PROGRESS_MESSAGE_3);
		HttpResponseMessage obj = await postAsync("パスワード設定！", client, text, content);
		string result = obj.Content.ReadAsStringAsync().Result;
		LOG.InfoFormat("{0}：WIM 06.パスワード設定 レスポンス:\n{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)result);
		checkWimErrorExist(result);
		return obj;
	}

	private async Task<string[]> setAddressBook(HttpClient client, SettingItemsSetupAddress setting, string wimStr, string entryIndexInStr)
	{
		KeyValuePair<string, string>[] content = new KeyValuePair<string, string>[33]
		{
			new KeyValuePair<string, string>("inputSpecifyModeIn", "WRITE"),
			new KeyValuePair<string, string>("listUpdateIn", "UPDATE"),
			new KeyValuePair<string, string>("wimToken", wimStr),
			new KeyValuePair<string, string>("mode", "ADDUSER"),
			new KeyValuePair<string, string>("pageSpecifiedIn", ""),
			new KeyValuePair<string, string>("pageNumberIn", ""),
			new KeyValuePair<string, string>("searchSpecifyModeIn", ""),
			new KeyValuePair<string, string>("outputSpecifyModeIn", ""),
			new KeyValuePair<string, string>("inputSpecifyModeIn", ""),
			new KeyValuePair<string, string>("wayFrom", "adrsGetUser.cgi?outputSpecifyModeIn=SETTINGS"),
			new KeyValuePair<string, string>("wayTo", "adrsList.cgi"),
			new KeyValuePair<string, string>("isSelfPasswordEditMode", "false"),
			new KeyValuePair<string, string>("entryIndexIn", entryIndexInStr),
			new KeyValuePair<string, string>("entryNameIn", setting.addressName),
			new KeyValuePair<string, string>("entryReadNameIn", ""),
			new KeyValuePair<string, string>("entryDisplayNameIn", setting.addressName),
			new KeyValuePair<string, string>("priorityIn", "5"),
			new KeyValuePair<string, string>("entryTagInfoIn", (setting.headlineIndex1 + 1).ToString()),
			new KeyValuePair<string, string>("entryTagInfoIn", (setting.headlineIndex2 + 1).ToString()),
			new KeyValuePair<string, string>("entryTagInfoIn", (setting.headlineIndex3 + 1).ToString()),
			new KeyValuePair<string, string>("entryTagInfoIn", setting.regularHeadingIndex.ToString()),
			new KeyValuePair<string, string>("userCodeIn", ""),
			new KeyValuePair<string, string>("smtpAuthAccountIn", "AUTH_SYSTEM_O"),
			new KeyValuePair<string, string>("folderAuthAccountIn", "AUTH_ASSIGNMENT_O"),
			new KeyValuePair<string, string>("folderAuthUserNameIn", setting.authUserName),
			new KeyValuePair<string, string>("ldapAuthAccountIn", "AUTH_SYSTEM_O"),
			new KeyValuePair<string, string>("entryUseIn", "ENTRYUSE_TO_O"),
			new KeyValuePair<string, string>("faxDestIn", ""),
			new KeyValuePair<string, string>("mailAddressIn", ""),
			new KeyValuePair<string, string>("isCertificateExist", "false"),
			new KeyValuePair<string, string>("isEncryptAlways", "false"),
			new KeyValuePair<string, string>("folderProtocolIn", "SMB_O"),
			new KeyValuePair<string, string>("folderPathNameIn", setting.folderPath)
		};
		updateProgressBar(Resources.PROGRESS_MESSAGE_3);
		string text = string.Format(URI_FORMAT_ADDR_SET_USER, baseAddressStr, machineLang);
		LOG.InfoFormat("{0}：WIM アドレス帳登録 07.リクエスト:\nURI:{1}\nwimStr:{2}\nentryIndexInStr:{3}\naddressName:{4}\nauthUserName:{5}\nfolderPath:{6}", new object[7]
		{
			MethodBase.GetCurrentMethod().DeclaringType.Name,
			text,
			wimStr,
			entryIndexInStr,
			setting.addressName,
			setting.authUserName,
			setting.folderPath
		});
		string result = (await postAsync("アドレス帳登録！", client, text, content)).Content.ReadAsStringAsync().Result;
		LOG.InfoFormat("{0}：WIM 07.アドレス帳登録 レスポンス:\n{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)result);
		checkWimErrorExist(result);
		string text2 = "<tr class=\"responseMessage\">";
		string value = "</tr>";
		if (result != null && result.IndexOf(text2) != -1)
		{
			int num = result.IndexOf(text2);
			string text3 = result.Substring(num + text2.Length);
			string text4 = text3;
			text3 = text3[..text3.IndexOf(value)];
			text3 = removaTag(text3);
			num = text4.IndexOf(text2);
			text4 = text4.Substring(num + text2.Length);
			text4 = text4[..text4.IndexOf(value)];
			text4 = removaTag(text4);
			LOG.InfoFormat("WIM アドレス帳登録 " + text3 + ":" + text4, new object[0]);
			text3 = ((text4.IndexOf(Resources.ERR_MSG_WIM_BUSY) <= 0) ? text4 : Resources.LOGIN_ERROR_MSG_2_5);
			throw new Exception(text3);
		}
		return result.Split(new char[1] { ',' });
	}

	private async Task<HttpResponseMessage> postAsync(string jobName, HttpClient client, string uri, KeyValuePair<string, string>[] content)
	{
		HttpContent httpContent = new FormUrlEncodedContent(content);
		return await postAsyncCommon(jobName, client, uri, httpContent);
	}

	private async Task<HttpResponseMessage> postAsync(string jobName, HttpClient client, string uri, Dictionary<string, string> content = null)
	{
		HttpContent httpContent = null;
		if (content != null)
		{
			httpContent = new FormUrlEncodedContent(content);
		}
		return await postAsyncCommon(jobName, client, uri, httpContent);
	}

	private async Task<HttpResponseMessage> postAsyncCommon(string jobName, HttpClient client, string uri, HttpContent httpContent)
	{
		int cntNG = 0;
		int MAXNG = 5;
		HttpResponseMessage response = null;
		while (cntNG < MAXNG)
		{
			try
			{
				response = await client.PostAsync(uri, httpContent);
			}
			catch (TaskCanceledException ex)
			{
				cntNG++;
				LOG.InfoFormat("\nタイムアウト!\u3000リトライ {0} 回数＝ {1}", (object)jobName, (object)cntNG);
				LOG.InfoFormat("例外メッセージ TCE: {0} ", (object)ex.Message);
				if (cntNG >= MAXNG)
				{
					LOG.InfoFormat("\nリトライアウト!", new object[0]);
					throw;
				}
				continue;
			}
			break;
		}
		return response;
	}

	private void updateProgressBar(string progressMessage, bool firstFlag = true, bool numeric = true)
	{
		//IL_0075: Unknown result type (might be due to invalid IL or missing references)
		//IL_00ab: Unknown result type (might be due to invalid IL or missing references)
		//IL_0098: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("updateProgressBar:\n progressMessage:{0}\n firstFlag:{1}\n numeric：{2}\n", (object)progressMessage, (object)firstFlag, (object)numeric);
		if (progressValue < progressMaxValue)
		{
			progressValue++;
		}
		if (!firstFlag)
		{
			return;
		}
		if (numeric)
		{
			progressMessage += $"({progressValue}/{progressMaxValue})";
		}
		if (machineInfoRichTextBox != null)
		{
			((Control)(RichTextBox)machineInfoRichTextBox).Text = progressMessage;
		}
		else if (displayLabel != null)
		{
			if (progress == null)
			{
				((ToolStripItem)(ToolStripLabel)displayLabel).Text = progressMessage;
			}
			else
			{
				((Control)(Label)displayLabel).Text = progressMessage;
				progress.Value = progressValue;
			}
		}
		LOG.DebugFormat("Progress Message: {0}", (object)progressMessage);
		LOG.DebugFormat("updateProgressBar end", new object[0]);
	}

	private bool OnRemoteCertificateValidationCallback(object sender, X509Certificate certificate, X509Chain chain, SslPolicyErrors sslPolicyErrors)
	{
		return true;
	}

	private string removaTag(string value)
	{
		string[] array = new string[8] { "<td nowrap align=\"left\" width=\"40\">", "<img src=\"/images/messageIconE.gif\" alt=\"\">", "<td nowrap align=\"left\" height=\"32\">", "<td align=\"left\" valign=\"top\">", "<td>", "</td>", "<br>", "<br/>" };
		string text = value;
		for (int i = 0; i < array.Length; i++)
		{
			text = text.Replace(array[i], "");
		}
		return text;
	}

	public async Task<Hashtable> GetMFPInfo(SettingItemsSetupAddress info, RichTextBox rt)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		((Control)rt).Text = string.Empty;
		protocol = (info.httpsFlg ? "https" : "http");
		try
		{
			if (await executeWimConnect(info, null, null, 6, rt) != 0)
			{
				return null;
			}
			updateProgressBar(Resources.TXT_MACHINE_MESSAGE_01);
			string text = string.Format(URI_FORMAT_CONFIGURATION, protocol, info.host, machineLang);
			Console.WriteLine("{0}：WIM Configuration画面を取得 リクエスト:" + text, MethodBase.GetCurrentMethod().DeclaringType.Name);
			HttpResponseMessage httpResponseMessage = await client.GetAsync(text);
			LOG.DebugFormat("{0}：response2(sys) = {1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)httpResponseMessage.Content.ReadAsStringAsync().Result);
			Hashtable mfpSettings = new Hashtable();
			string result = httpResponseMessage.Content.ReadAsStringAsync().Result;
			mfpSettings.Add(FormMFPInfo.KEY.MODELNAME, ReadHtmlConfirmSetting(result, Resources.WIM_ITEM_MODEL_NAME));
			mfpSettings.Add(FormMFPInfo.KEY.SYSTEMCOPY, ReadHtmlConfirmSetting(result, Resources.WIM_ITEM_SYSTEM_COPY));
			mfpSettings.Add(FormMFPInfo.KEY.NETWORKSUPPORT, ReadHtmlConfirmSetting(result, Resources.WIM_ITEM_NETWORK_SUPPORT));
			mfpSettings.Add(FormMFPInfo.KEY.WEBSUPPORT, ReadHtmlConfirmSetting(result, Resources.WIM_ITEM_WEB_SUPPORT));
			LOG.DebugFormat("{0}：modelName = {1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, mfpSettings[FormMFPInfo.KEY.MODELNAME]);
			updateProgressBar(Resources.TXT_MACHINE_MESSAGE_01);
			text = string.Format(URI_FORMAT_GETTCP, protocol, info.host, machineLang);
			Console.WriteLine("{0}：WIM IPv4画面を取得 リクエスト:" + text, MethodBase.GetCurrentMethod().DeclaringType.Name);
			httpResponseMessage = await client.GetAsync(text);
			LOG.DebugFormat("{0}：response3(ip) = {1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)httpResponseMessage.Content.ReadAsStringAsync().Result);
			result = httpResponseMessage.Content.ReadAsStringAsync().Result;
			mfpSettings.Add(FormMFPInfo.KEY.NETBIOSNAME, ReadHtmlConfirmSetting(result, Resources.WIM_ITEM_NETBIOS_NAME));
			mfpSettings.Add(FormMFPInfo.KEY.IPV4ADRESS, ReadHtmlConfirmSetting(result, Resources.WIM_ITEM_IPV4_ADDRESS));
			mfpSettings.Add(FormMFPInfo.KEY.SUBNETMASK, ReadHtmlConfirmSetting(result, Resources.TXT_MACHINE_INFO_04_13));
			mfpSettings.Add(FormMFPInfo.KEY.GATEWAY, ReadHtmlConfirmSetting(result, Resources.WIM_ITEM_DEFAULT_GATEWAY));
			mfpSettings.Add(FormMFPInfo.KEY.PRIMARYWINS, ReadHtmlConfirmSetting(result, Resources.WIM_ITEM_PRIMARY_WINS_SERVER));
			mfpSettings.Add(FormMFPInfo.KEY.SECONDARYWINS, ReadHtmlConfirmSetting(result, Resources.WIN_ITEM_SECONDARY_WINS_SERVER));
			mfpSettings.Add(FormMFPInfo.KEY.DNS1, ReadHtmlConfirmSetting(result, Resources.WIM_ITEM_DNS_SERVER + "1"));
			mfpSettings.Add(FormMFPInfo.KEY.DNS2, ReadHtmlConfirmSetting(result, Resources.WIM_ITEM_DNS_SERVER + "2"));
			mfpSettings.Add(FormMFPInfo.KEY.DNS3, ReadHtmlConfirmSetting(result, Resources.WIM_ITEM_DNS_SERVER + "3"));
			updateProgressBar(Resources.TXT_MACHINE_MESSAGE_01);
			text = string.Format(URI_FORMAT_GETSMB, protocol, info.host, machineLang);
			Console.WriteLine("{0}：WIM SMB画面を取得 リクエスト:" + text, MethodBase.GetCurrentMethod().DeclaringType.Name);
			httpResponseMessage = await client.GetAsync(text);
			LOG.DebugFormat("{0}：response4 = {1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)httpResponseMessage.Content.ReadAsStringAsync().Result);
			result = httpResponseMessage.Content.ReadAsStringAsync().Result;
			mfpSettings.Add(FormMFPInfo.KEY.SMBENABLE, ReadHtmlConfirmSetting(result, Resources.WIM_ITEM_SMB));
			mfpSettings.Add(FormMFPInfo.KEY.SMBPORT, ReadHtmlConfirmSetting(result, Resources.WIM_ITEM_SMB_PORT_NO));
			string text2 = ReadHtmlConfirmSetting(result, Resources.WIM_ITEM_SMB_V2V3);
			string text3 = ReadHtmlConfirmSetting(result, Resources.WIM_ITEM_SMB_AUTH_LEVEL);
			bool flag = false;
			if (text2.Equals("") && !text3.Equals(""))
			{
				flag = true;
			}
			if (flag)
			{
				mfpSettings.Add(FormMFPInfo.KEY.SMBVERSION, Resources.WIM_LABEL_SMB_V2V3_ON);
				mfpSettings.Add(FormMFPInfo.KEY.SMBAUTHLEVEL, text3);
			}
			else
			{
				mfpSettings.Add(FormMFPInfo.KEY.SMBVERSION, text2);
			}
			updateProgressBar(Resources.TXT_MACHINE_MESSAGE_01);
			text = string.Format(URI_FORMAT_FIRMWARE_UPDATE, protocol, info.host, machineLang);
			Console.WriteLine("{0}：WIM ファームウェアアップデート画面を取得 リクエスト:" + text, MethodBase.GetCurrentMethod().DeclaringType.Name);
			httpResponseMessage = await client.GetAsync(text);
			LOG.DebugFormat("{0}：response5 = {1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)httpResponseMessage.Content.ReadAsStringAsync().Result);
			result = httpResponseMessage.Content.ReadAsStringAsync().Result;
			mfpSettings.Add(FormMFPInfo.KEY.SCANNER, ReadHtmlConfirmSetting(result, Resources.WIM_ITEM_SCANNER));
			mfpSettings.Add(FormMFPInfo.KEY.ANIMATION, ReadHtmlConfirmSetting(result, Resources.WIM_ITEM_ANIMATION));
			return mfpSettings;
		}
		catch (HttpRequestException ex)
		{
			Console.WriteLine("\n例外発生!");
			for (Exception ex2 = ex; ex2 != null; ex2 = ex2.InnerException)
			{
				Console.WriteLine("例外メッセージ: {0} ", ex2.Message);
			}
			throw;
		}
		catch (TaskCanceledException ex3)
		{
			Console.WriteLine("\nタイムアウト!");
			Console.WriteLine("例外メッセージ: {0} ", ex3.Message);
			throw;
		}
		catch (ArgumentException ex4)
		{
			Console.WriteLine("例外メッセージ: {0} ", ex4.Message);
			throw;
		}
		catch (Exception ex5)
		{
			Console.WriteLine(ex5.ToString());
			throw;
		}
	}

	private string ReadHtmlConfirmSetting(string response, string key)
	{
		LOG.DebugFormat("{0}：HTMLからの情報収集開始:[{1}]", (object)MethodBase.GetCurrentMethod().Name, (object)key);
		Regex regex = new Regex("<td .*>(" + key + ".*)</td>", RegexOptions.IgnoreCase);
		Regex regex2 = new Regex("<td nowrap.*>(.*)</td>", RegexOptions.IgnoreCase);
		StringReader stringReader = new StringReader(response);
		string text = string.Empty;
		bool flag = false;
		while (stringReader.Peek() > -1)
		{
			string input = stringReader.ReadLine();
			Match match = regex.Match(input);
			if (!flag)
			{
				flag = match.Success;
				continue;
			}
			Match match2 = regex2.Match(input);
			if (!match2.Success || match2.Groups[1].Value.Equals(":"))
			{
				continue;
			}
			text = match2.Groups[1].Value.TrimEnd(new char[0]);
			break;
		}
		LOG.DebugFormat("{0}：HTMLからの情報収集終了:[{1}]", (object)MethodBase.GetCurrentMethod().Name, (object)text);
		return text;
	}

	private void createWimErrorTable(string resultData)
	{
		//IL_001f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0024: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0} start", (object)MethodBase.GetCurrentMethod().Name);
		_ = string.Empty;
		HtmlDocument val = new HtmlDocument();
		val.LoadHtml(resultData);
		HtmlNodeCollection val2 = val.DocumentNode.SelectNodes(XPATH_WIM_ERROR_MESSAGE_TABLE);
		if (val2 != null)
		{
			wimErrorTable.Clear();
			foreach (HtmlNode item in (IEnumerable<HtmlNode>)val2)
			{
				WimError wimError = new WimError();
				wimError.id = item.Attributes["id"].Value;
				wimError.message = item.Attributes["value"].Value.Replace("<br />", "\n");
				switch (wimError.id.Last())
				{
				case 'E':
					wimError.kind = WIM_MESSAGE_KIND.ERROR;
					break;
				case 'G':
					wimError.kind = WIM_MESSAGE_KIND.GUIDANCE;
					break;
				case 'T':
					wimError.kind = WIM_MESSAGE_KIND.STATUS;
					break;
				default:
					wimError.kind = WIM_MESSAGE_KIND.INFORMATION;
					break;
				}
				wimErrorTable.Add(wimError);
			}
		}
		LOG.DebugFormat("{0} end", (object)MethodBase.GetCurrentMethod().Name);
	}

	public WimError checkWimErrorCode(HttpResponseMessage response)
	{
		string[] array = response.Content.ReadAsStringAsync().Result.Replace("[", "").Replace("]", "").Split(new char[1] { ',' });
		int result = 0;
		int.TryParse(array[0], out result);
		WimError wimError = wimErrorTable[result];
		if (array.Length > 1)
		{
			wimError.errPoint = array[1];
		}
		return wimError;
	}

	private void checkWimErrorExist(string resultData)
	{
		//IL_001f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0025: Expected O, but got Unknown
		LOG.DebugFormat("{0} start", (object)MethodBase.GetCurrentMethod().Name);
		string text = string.Empty;
		HtmlDocument val = new HtmlDocument();
		val.LoadHtml(resultData);
		HtmlNodeCollection val2 = val.DocumentNode.SelectNodes(XPATH_WIM_RESULT_VALUE);
		if (val2 != null)
		{
			string value = val2[0].Attributes["value"].Value;
			if (string.Equals(WIM_RETURN_VALUE_SUCCESS, value))
			{
				LOG.DebugFormat("{0} end", (object)MethodBase.GetCurrentMethod().Name);
				return;
			}
			if (string.Equals(WIM_RETURN_VALUE_SESSIONFULL, value))
			{
				text = Resources.ERR_MSG_WIM_ERROR;
			}
			else if (string.Equals(WIM_RETURN_VALUE_SEARCHRESULTEXCEED, value))
			{
				text = $"{Resources.ERR_MSG_WIM_SEARCH_FULL}\n\n{Resources.ERR_MSG_WIM_SEARCH_RETRY}";
			}
			else if (string.Equals(WIM_RETURN_VALUE_SEARCHWORDTOOLONG, value))
			{
				text = $"{Resources.ERR_MSG_WIM_SEARCH_WORD_TOO_LONG}\n\n{Resources.ERR_MSG_WIM_SEARCH_RETRY}";
			}
			else if (string.Equals(WIM_RETURN_VALUE_BUSY, value))
			{
				text = Resources.LOGIN_ERROR_MSG_2_5;
			}
		}
		string empty = string.Empty;
		val2 = val.DocumentNode.SelectNodes(XPATH_WIM_MAIN_FORM);
		val2 = ((val2 == null) ? val.DocumentNode.SelectNodes(XPATH_WIM_ERROR_MESSAGE) : val2[0].SelectNodes(XPATH_WIM_ERROR_MESSAGE));
		if (val2 == null)
		{
			val2 = val.DocumentNode.SelectNodes(XPATH_WIM_AUTOLOGOUT);
			if (val2 == null)
			{
				val2 = val.DocumentNode.SelectNodes(XPATH_WIM_ERROR_MESSAGE_2);
				if (val2 == null)
				{
					LOG.DebugFormat("{0} end. No responseMessage element.", (object)MethodBase.GetCurrentMethod().Name);
					return;
				}
				empty = val2[0].InnerText;
				if (empty.Contains(Resources.ERR_MSG_WIM_ADDRESSBOOK_UPDATE))
				{
					text = $"{Resources.ERR_MSG_WIM_ADDRESSBOOK_UPDATE}\n{Resources.ERR_MSG_SEARCH_RETRY}";
				}
				else if (empty.Contains(Resources.ERR_MSG_WIM_BUSY))
				{
					text = Resources.LOGIN_ERROR_MSG_2_5;
				}
			}
			else
			{
				empty = val2[0].Attributes["value"].Value;
			}
		}
		else
		{
			empty = val2[0].InnerText;
			if (string.IsNullOrEmpty(empty))
			{
				LOG.DebugFormat("{0} end. No error message.", (object)MethodBase.GetCurrentMethod().Name);
				return;
			}
		}
		if (string.IsNullOrEmpty(text))
		{
			text = Resources.ERR_MSG_WIM_ERROR_DISCONNECTED;
			LOG.DebugFormat("{0} Disconnect", (object)MethodBase.GetCurrentMethod().Name);
		}
		empty = empty.Replace("<br>", "\n");
		empty = empty.Replace("<br/>", "\n");
		empty = empty.Replace("<br />", "\n");
		LOG.InfoFormat(empty, new object[0]);
		empty = $"{Resources.WIM_ERROR_DETECT}{text}";
		LOG.DebugFormat("{0} end\n{1}", (object)MethodBase.GetCurrentMethod().Name, (object)text);
		throw new Exception(empty);
	}

	private async Task<MACHINE_CONTROL_RESULT> connectAndLogin(HttpClient client, SettingItemsSetupAddress setting, bool registNoCheckOnly)
	{
		LOG.DebugFormat("{0}:start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		MACHINE_CONTROL_RESULT mACHINE_CONTROL_RESULT = await wimInitialConnection(client, setting.firstFlg);
		if (mACHINE_CONTROL_RESULT != 0)
		{
			return mACHINE_CONTROL_RESULT;
		}
		if (stop_addressbook_collection)
		{
			LOG.DebugFormat("{0}:中断", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			return MACHINE_CONTROL_RESULT.ABORT;
		}
		bool accountValid = adminAccounts.ContainsKey(setting.host);
		if (accountValid)
		{
			Account account = adminAccounts[setting.host];
			setting.adminName = account.adminName;
			setting.passwd = account.passwd;
		}
		HttpResponseMessage response = await winLogin(client, setting);
		if (stop_addressbook_collection)
		{
			LOG.DebugFormat("{0}:中断", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			return MACHINE_CONTROL_RESULT.ABORT;
		}
		string result = response.Content.ReadAsStringAsync().Result;
		if (result != null && result.IndexOf("alert") != -1)
		{
			LOG.InfoFormat("{0}：認証エラー", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			if (accountValid)
			{
				adminAccounts.Remove(setting.host);
			}
			return await retryWithAuthentication(setting, registNoCheckOnly);
		}
		if (!accountValid)
		{
			bool flag = false;
			if (setting.firstFlg)
			{
				flag = await checkAdminAuth(client);
			}
			if (stop_addressbook_collection)
			{
				LOG.DebugFormat("{0}:中断", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
				return MACHINE_CONTROL_RESULT.ABORT;
			}
			if (flag)
			{
				LOG.InfoFormat("{0}：機器管理者認証が有効", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
				return await retryWithAuthentication(setting, registNoCheckOnly);
			}
		}
		if (!setting.firstFlg)
		{
			if (adminAccounts.ContainsKey(setting.host))
			{
				adminAccounts.Remove(setting.host);
			}
			Account account2 = new Account();
			account2.adminName = setting.adminName;
			account2.passwd = setting.passwd;
			adminAccounts.Add(setting.host, account2);
		}
		IEnumerable<string> values = response.Headers.GetValues("Set-Cookie");
		client.DefaultRequestHeaders.Add("Cookie", values);
		LOG.DebugFormat("{0}:end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		return MACHINE_CONTROL_RESULT.SUCCESS;
	}

	private void createHttpClientInstance()
	{
		//IL_001e: Unknown result type (might be due to invalid IL or missing references)
		//IL_002d: Unknown result type (might be due to invalid IL or missing references)
		//IL_003f: Unknown result type (might be due to invalid IL or missing references)
		//IL_004a: Expected O, but got Unknown
		//IL_004a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0051: Expected O, but got Unknown
		//IL_0051: Unknown result type (might be due to invalid IL or missing references)
		//IL_0058: Expected O, but got Unknown
		//IL_006e: Expected O, but got Unknown
		LOG.DebugFormat("{0}:start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		WebRequestHandler val = new WebRequestHandler();
		cookieContainer = new CookieContainer();
		val.ServerCertificateValidationCallback = OnRemoteCertificateValidationCallback;
		((HttpClientHandler)val).CookieContainer = cookieContainer;
		((HttpClientHandler)val).AllowAutoRedirect = true;
		((HttpClientHandler)val).UseCookies = true;
		if (client != null)
		{
			client.Dispose();
		}
		client = new HttpClient((HttpMessageHandler)val);
		client.DefaultRequestHeaders.Add("User-Agent", "Wget/1.11.3");
		client.DefaultRequestHeaders.Add("Accept", "*/*");
		client.DefaultRequestHeaders.Add("Connection", "Keep-Alive");
		client.Timeout = TimeSpan.FromSeconds(short.Parse(Settings.Default.httpTimeout));
		new HttpClientHandler().UseCookies = false;
		LOG.DebugFormat("{0}:end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
	}

	public void Dispose()
	{
		if (client != null)
		{
			client.Dispose();
		}
		client = null;
		cookieContainer = null;
	}

	private async Task<bool> checkRegistrationNumberInUse(HttpClient client, SettingItemsSetupAddress setting, CookieContainer cookieContainer)
	{
		HttpResponseMessage obj = await getAddressAll(client, GET_ADDRESSBOOK_MODE.NUMBER_ITEM_SPECIFIED);
		string result = obj.Content.ReadAsStringAsync().Result;
		HtmlDocument val = new HtmlDocument();
		val.LoadHtml(result);
		Uri uri = new Uri(baseAddressStr);
		List<string> list = obj.Headers.GetValues("Set-Cookie").ToList();
		updateProgressBar(Resources.PROGRESS_MESSAGE_2);
		foreach (string item in list)
		{
			if (item.ToString().IndexOf("risessionid") != -1)
			{
				cookieContainer.Add(uri, new Cookie("risessionid", item.Split('=', ';')[1], "/"));
				break;
			}
		}
		string value = htmlSelectNodes(val, XPATH_WIM_TOKEN)[0].Attributes["value"].Value;
		LOG.InfoFormat("wimToken:{0}", (object)value);
		string registeredUsers = getRegisteredUsers(result);
		LOG.InfoFormat("{0}：numOfUsers:{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)registeredUsers);
		Dictionary<string, string> content = new Dictionary<string, string>
		{
			{ "wimToken", value },
			{ "mode", "LIST" },
			{ "pageSpecifiedIn", "true" },
			{ "pageNumberIn", "0" },
			{ "searchSpecifyModeIn", "INPUT" },
			{ "outputSpecifyModeIn", "" },
			{ "entryIndexIn", "" },
			{ "entryNameIn", "" },
			{ "entryFilterIn", "ALL_0" },
			{ "searchItemIn", "SEARCH_INDEX_O" },
			{
				"searchDataIn",
				setting.registrationNo.ToString("00000")
			},
			{ "pages", "" },
			{ "listCountIn", "5" },
			{ "totalCount", registeredUsers },
			{ "offset", "0" },
			{ "00001", "1" },
			{ "00002", "1" },
			{ "00003", "1" },
			{ "00004", "1" },
			{ "00005", "1" }
		};
		bool inUse;
		try
		{
			string uri2 = string.Format(URI_FORMAT_ADDR_LIST, baseAddressStr, machineLang);
			result = (await postAsync("登録番号検索", client, uri2, content)).Content.ReadAsStringAsync().Result;
			LOG.InfoFormat("{0}：検索結果：\n{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)result);
			string text = "name=\"totalCount\" value=\"";
			int num = result.IndexOf(text) + text.Length;
			int num2 = result.IndexOf("\"", num);
			string text2 = result.Substring(num, num2 - num);
			inUse = !string.Equals(text2, "0");
			LOG.InfoFormat("{0}：totalCountStr:{1} InUse:{2}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)text2, (object)inUse);
			if (inUse)
			{
				string text3 = $"{Resources.ASK_IF_RESUNDANT_REGISTRATION_NUMBER_01}\n{Resources.ASK_IF_RESUNDANT_REGISTRATION_NUMBER_02}\n\n{Resources.ASK_IF_RESUNDANT_REGISTRATION_NUMBER_03}\n{Resources.ASK_IF_RESUNDANT_REGISTRATION_NUMBER_04}\n";
				if ((int)new CustomizableMessageBox
				{
					ButtonText = 
					{
						Yes = Resources.BUTTON_REVICE,
						No = Resources.BUTTON_CONTINUE
					}
				}.Show(text3, Resources.SET_REGISTRATION_NUMBER_CAPTION, (MessageBoxButtons)4, (MessageBoxIcon)48) == 7)
				{
					setting.registrationNo = 0;
					inUse = false;
				}
			}
		}
		catch (TaskCanceledException)
		{
			throw;
		}
		catch (Exception)
		{
			throw;
		}
		return inUse;
	}

	public COMMUNICATION_ERROR_CODE communicateConfirm(string host, bool showErrorDialog = true)
	{
		//IL_0055: Unknown result type (might be due to invalid IL or missing references)
		//IL_00df: Unknown result type (might be due to invalid IL or missing references)
		COMMUNICATION_ERROR_CODE cOMMUNICATION_ERROR_CODE = COMMUNICATION_ERROR_CODE.ERROR;
		COMMUNICATION_ERROR_ONE cOMMUNICATION_ERROR_ONE = communicateConfirm(host, "http");
		if (cOMMUNICATION_ERROR_ONE == COMMUNICATION_ERROR_ONE.SUCCESS)
		{
			cOMMUNICATION_ERROR_CODE |= COMMUNICATION_ERROR_CODE.HTTP_ONLY;
		}
		if (cOMMUNICATION_ERROR_ONE != COMMUNICATION_ERROR_ONE.NOT_SUPPORT)
		{
			cOMMUNICATION_ERROR_ONE = communicateConfirm(host, "https");
			if (cOMMUNICATION_ERROR_ONE == COMMUNICATION_ERROR_ONE.SUCCESS)
			{
				cOMMUNICATION_ERROR_CODE |= COMMUNICATION_ERROR_CODE.HTTPS_ONLY;
			}
		}
		if (cOMMUNICATION_ERROR_ONE == COMMUNICATION_ERROR_ONE.NOT_SUPPORT)
		{
			if (showErrorDialog)
			{
				StringBuilder stringBuilder = new StringBuilder();
				stringBuilder.AppendLine(Resources.MACHINE_NOT_SUPPORTED);
				MessageBox.Show(stringBuilder.ToString(), Resources.ERR_TITLE_MACHINE_NOT_SUPPORT, (MessageBoxButtons)0, (MessageBoxIcon)16);
			}
			LOG.InfoFormat("{0}：サポート対象ではありません。：{1}\n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)host);
			cOMMUNICATION_ERROR_CODE = COMMUNICATION_ERROR_CODE.NOT_SUPPORT;
		}
		if (cOMMUNICATION_ERROR_CODE == COMMUNICATION_ERROR_CODE.ERROR)
		{
			if (showErrorDialog)
			{
				StringBuilder stringBuilder2 = new StringBuilder();
				stringBuilder2.AppendLine(Resources.CANT_CONNECT_MACHINE_ERROR_TEXT_1_5);
				stringBuilder2.AppendLine(Resources.CANT_CONNECT_MACHINE_ERROR_TEXT_6_5);
				stringBuilder2.AppendLine(Resources.CANT_CONNECT_MACHINE_ERROR_TEXT_2_5);
				stringBuilder2.AppendLine(Resources.CANT_CONNECT_MACHINE_ERROR_TEXT_3_5);
				stringBuilder2.AppendLine(Resources.CANT_CONNECT_MACHINE_ERROR_TEXT_4_5);
				stringBuilder2.AppendLine(Resources.CANT_CONNECT_MACHINE_ERROR_TEXT_5_5);
				MessageBox.Show(stringBuilder2.ToString(), Resources.ERR_TITLE_MACHINE_CONNECT, (MessageBoxButtons)0, (MessageBoxIcon)16);
			}
			LOG.InfoFormat("{0}：機器に接続できません。：{1}\n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)host);
		}
		return cOMMUNICATION_ERROR_CODE;
	}

	private COMMUNICATION_ERROR_ONE communicateConfirm(string host, string protocol)
	{
		LOG.DebugFormat("{0}：start ({1}://{2})", (object)MethodBase.GetCurrentMethod().Name, (object)protocol, (object)host);
		COMMUNICATION_ERROR_ONE cOMMUNICATION_ERROR_ONE = COMMUNICATION_ERROR_ONE.ERROR;
		string requestUriString = string.Format(URI_FORMAT_CONFIGURATION, protocol, host, machineLang);
		if (primaxModel)
		{
			requestUriString = string.Format(PRIMAX_URI_HOME_STATUS, protocol, host, getLangCmd());
		}
		if (protocol.Equals("https"))
		{
			ServicePointManager.SecurityProtocol = SecurityProtocolType.Tls11 | SecurityProtocolType.Tls12;
			ServicePointManager.ServerCertificateValidationCallback = OnRemoteCertificateValidationCallback;
		}
		HttpWebRequest httpWebRequest = (HttpWebRequest)WebRequest.Create(requestUriString);
		try
		{
			int timeout = int.Parse(Settings.Default.httpTimeout) * 1000;
			httpWebRequest.Timeout = timeout;
		}
		catch (Exception ex)
		{
			LOG.InfoFormat("timeout値の設定エラー:[{0}] {1}", (object)Settings.Default.httpTimeout, (object)ex.ToString());
		}
		HttpWebResponse httpWebResponse = null;
		try
		{
			httpWebResponse = (HttpWebResponse)httpWebRequest.GetResponse();
			LOG.DebugFormat("Uri:{0} HttpStatusCode:{1} Description:{2}", (object)httpWebResponse.ResponseUri, (object)httpWebResponse.StatusCode, (object)httpWebResponse.StatusDescription);
			cOMMUNICATION_ERROR_ONE = ((!checkMachineSupported(httpWebResponse)) ? COMMUNICATION_ERROR_ONE.NOT_SUPPORT : COMMUNICATION_ERROR_ONE.SUCCESS);
			cOMMUNICATION_ERROR_ONE = COMMUNICATION_ERROR_ONE.SUCCESS;
		}
		catch (WebException ex2)
		{
			if (ex2.Status == WebExceptionStatus.ProtocolError)
			{
				HttpWebResponse httpWebResponse2 = (HttpWebResponse)ex2.Response;
				LOG.ErrorFormat("Uri:{0} HttpStatusCode:{1} Description{2}", (object)httpWebResponse2.ResponseUri, (object)httpWebResponse2.StatusCode, (object)httpWebResponse2.StatusDescription);
			}
			LOG.Error((object)ex2.Message);
		}
		finally
		{
			httpWebResponse?.Close();
			LOG.DebugFormat("{0}：end {1}", (object)MethodBase.GetCurrentMethod().Name, (object)cOMMUNICATION_ERROR_ONE);
		}
		return cOMMUNICATION_ERROR_ONE;
	}

	private bool checkMachineSupported(HttpWebResponse webres)
	{
		//IL_0024: Unknown result type (might be due to invalid IL or missing references)
		//IL_002a: Expected O, but got Unknown
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		displayMachineName = string.Empty;
		HtmlDocument val = new HtmlDocument();
		using (Stream stream = webres.GetResponseStream())
		{
			string text = new StreamReader(stream).ReadToEnd();
			val.LoadHtml(text);
			LOG.DebugFormat("Response:{0}", (object)text);
		}
		HtmlNodeCollection val2 = val.DocumentNode.SelectNodes(XPATH_WIM_CONFIG_MACHINE_NAME);
		string text2 = ((val2 == null) ? "UNKNOWN" : val2[0].InnerText);
		LOG.DebugFormat("{0}：machine name:[{1}]", (object)MethodBase.GetCurrentMethod().Name, (object)text2);
		if (text2.Contains("IPSiO"))
		{
			LOG.DebugFormat("{0}：Not supported.(Printer)", (object)MethodBase.GetCurrentMethod().Name);
			return false;
		}
		displayMachineName = $"RICOH {text2}";
		bool flag = false;
		StringEnumerator enumerator = Settings.Default.machineSupported.GetEnumerator();
		try
		{
			while (enumerator.MoveNext())
			{
				string current = enumerator.Current;
				flag = text2.Contains(current);
				if (flag)
				{
					LOG.DebugFormat("{0}：supported found:[{1}]", (object)MethodBase.GetCurrentMethod().Name, (object)current);
					break;
				}
			}
		}
		finally
		{
			if (enumerator is IDisposable disposable)
			{
				disposable.Dispose();
			}
		}
		LOG.DebugFormat("{0}：end supported:{1}", (object)MethodBase.GetCurrentMethod().Name, (object)flag);
		return true;
	}

	private string getRegisteredUsers(string resStr)
	{
		string text = "<td nowrap>";
		string text2 = "</td>";
		string text3 = $"{text}{Resources.WIM_ITEM_REGISTERED_USERS}{text2}";
		int num = resStr.IndexOf(text3);
		if (num < 0)
		{
			throw new Exception("ユーザー数が見つかりません");
		}
		num = resStr.IndexOf(text, num + text3.Length);
		if (num < 0)
		{
			throw new Exception("ユーザーの登録数が見つかりません");
		}
		num += text.Length;
		int num2 = resStr.IndexOf(text2, num);
		return resStr.Substring(num, num2 - num);
	}

	public async Task<string> getAddressBookTotalLines(SettingItemsSetupAddress info)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		string resultMsg = string.Empty;
		try
		{
			MACHINE_CONTROL_RESULT mACHINE_CONTROL_RESULT = await executeWimConnect(info, null, null);
			if (mACHINE_CONTROL_RESULT != 0)
			{
				LOG.DebugFormat("{0}:初回接続＆ログイン失敗", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
				return mACHINE_CONTROL_RESULT.ToString();
			}
			HttpResponseMessage httpResponseMessage = await getAddressAll(client, GET_ADDRESSBOOK_MODE.GET_NUM_OF_USERS);
			if (stop_addressbook_collection)
			{
				LOG.DebugFormat("{0}:中断", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
				return MACHINE_CONTROL_RESULT.ABORT.ToString();
			}
			string result = httpResponseMessage.Content.ReadAsStringAsync().Result;
			HtmlDocument val = new HtmlDocument();
			val.LoadHtml(result);
			string value = htmlSelectNodes(val, XPATH_WIM_TOKEN_LIST_ALL)[0].Attributes["value"].Value;
			LOG.InfoFormat("wimToken:{0}", (object)value);
			wimToken = value;
			Uri uri = new Uri(baseAddressStr);
			foreach (string item in httpResponseMessage.Headers.GetValues("Set-Cookie").ToList())
			{
				if (item.ToString().IndexOf("risessionid") != -1)
				{
					cookieContainer.Add(uri, new Cookie("risessionid", item.Split('=', ';')[1], "/"));
					break;
				}
			}
			int totalLines = getRegistrationNumber(val);
			if (!createColumnList(val, fullMode: true))
			{
				LOG.InfoFormat("{0}：WIMにフォルダー欄が無いので追加します。", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
				if (!(await getWimDisplayItem()))
				{
					await changeDisplayItem(addFolder: true);
					httpResponseMessage = await getAddressAll(client, GET_ADDRESSBOOK_MODE.GET_NUM_OF_USERS);
					if (stop_addressbook_collection)
					{
						LOG.DebugFormat("{0}:中断", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
						return MACHINE_CONTROL_RESULT.ABORT.ToString();
					}
					result = httpResponseMessage.Content.ReadAsStringAsync().Result;
					val = new HtmlDocument();
					val.LoadHtml(result);
					createColumnList(val, fullMode: true);
				}
			}
			return totalLines.ToString();
		}
		catch (HttpRequestException ex)
		{
			LOG.InfoFormat("\n例外発生!", new object[0]);
			for (Exception ex2 = ex; ex2 != null; ex2 = ex2.InnerException)
			{
				LOG.InfoFormat("例外メッセージ EX: {0} ", (object)ex2.Message);
			}
			resultMsg = ex.Message;
		}
		catch (TaskCanceledException ex3)
		{
			LOG.InfoFormat("\nタイムアウト!", new object[0]);
			LOG.InfoFormat("例外メッセージ TCE: {0} ", (object)ex3.Message);
			resultMsg = ex3.Message;
		}
		catch (ArgumentException ex4)
		{
			LOG.InfoFormat("例外メッセージ AE: {0} ", (object)ex4.Message);
			resultMsg = ex4.Message;
		}
		catch (Exception ex5)
		{
			LOG.InfoFormat("例外メッセージ EXP: {0} ", (object)ex5.Message);
			resultMsg = ex5.Message;
			if (resultMsg.Contains(Resources.WIM_ERROR_DETECT))
			{
				resultMsg = resultMsg.Substring(Resources.WIM_ERROR_DETECT.Length);
			}
		}
		finally
		{
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		}
		return resultMsg;
	}

	public async Task<string> getAddressBook(int getLines, int page, Dictionary<string, Dictionary<ADDRESSBOOK_ITEM, string>> addressBookTable)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		string errMsg = string.Empty;
		try
		{
			string result = (await getAddressList(client, wimToken, getLines, page)).Content.ReadAsStringAsync().Result;
			parseToRecord(result, addressBookTable);
		}
		catch (HttpRequestException ex)
		{
			LOG.InfoFormat("\n例外発生!", new object[0]);
			for (Exception ex2 = ex; ex2 != null; ex2 = ex2.InnerException)
			{
				LOG.InfoFormat("例外メッセージ EX: {0} ", (object)ex2.Message);
			}
			errMsg = ex.Message;
		}
		catch (TaskCanceledException ex3)
		{
			LOG.InfoFormat("\nタイムアウト!", new object[0]);
			LOG.InfoFormat("例外メッセージ TCE: {0} ", (object)ex3.Message);
			errMsg = ex3.Message;
		}
		catch (ArgumentException ex4)
		{
			LOG.InfoFormat("例外メッセージ AE: {0} ", (object)ex4.Message);
			errMsg = ex4.Message;
		}
		catch (Exception ex5)
		{
			LOG.InfoFormat("例外メッセージ EXP: {0} ", (object)ex5.Message);
			errMsg = ex5.Message;
			if (errMsg.Contains(Resources.WIM_ERROR_DETECT))
			{
				errMsg = errMsg.Substring(Resources.WIM_ERROR_DETECT.Length);
			}
		}
		return errMsg;
	}

	public async Task<string> getAddressBookFilteredTotalLines(SettingItemsSetupAddress info)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		_ = string.Empty;
		string text;
		try
		{
			int totalLines = 0;
			text = await getAddressBookTotalLines(info);
			if (!int.TryParse(text, out totalLines))
			{
				if (string.Equals(text, MACHINE_CONTROL_RESULT.ABORT.ToString()) || string.Equals(text, MACHINE_CONTROL_RESULT.ERROR.ToString()))
				{
					text = string.Empty;
				}
			}
			else
			{
				HttpResponseMessage httpResponseMessage = await getAddressAll(client, GET_ADDRESSBOOK_MODE.NUMBER_ITEM_SPECIFIED);
				if (stop_addressbook_collection)
				{
					LOG.DebugFormat("{0}:中断", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
					text = string.Empty;
				}
				else
				{
					string result = httpResponseMessage.Content.ReadAsStringAsync().Result;
					HtmlDocument val = new HtmlDocument();
					val.LoadHtml(result);
					createSearchForList(val);
					string value = htmlSelectNodes(val, XPATH_WIM_TOKEN)[0].Attributes["value"].Value;
					LOG.InfoFormat("wimToken:{0}", (object)value);
					wimToken = value;
					text = totalLines.ToString();
				}
			}
		}
		catch (HttpRequestException ex)
		{
			LOG.InfoFormat("\n例外発生!", new object[0]);
			for (Exception ex2 = ex; ex2 != null; ex2 = ex2.InnerException)
			{
				LOG.InfoFormat("例外メッセージ EX: {0} ", (object)ex2.Message);
			}
			text = ex.Message;
		}
		catch (TaskCanceledException ex3)
		{
			LOG.InfoFormat("\nタイムアウト!", new object[0]);
			LOG.InfoFormat("例外メッセージ TCE: {0} ", (object)ex3.Message);
			text = ex3.Message;
		}
		catch (ArgumentException ex4)
		{
			LOG.InfoFormat("例外メッセージ AE: {0} ", (object)ex4.Message);
			text = ex4.Message;
		}
		catch (Exception ex5)
		{
			LOG.InfoFormat("例外メッセージ EXP: {0} ", (object)ex5.Message);
			text = ex5.Message;
			if (text.Contains(Resources.WIM_ERROR_DETECT))
			{
				text = text.Substring(Resources.WIM_ERROR_DETECT.Length);
			}
		}
		return text;
	}

	public async Task<string> getAddressBookFilteredOnePage(int getLines, int page, int totalLines, Dictionary<string, Dictionary<ADDRESSBOOK_ITEM, string>> addressBookTable, string serchWay, string searchData)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		string resultMsg = string.Empty;
		try
		{
			string result = (await getAddressListFiltered(client, getLines, totalLines, page, serchWay, searchData, addressBookTable)).Content.ReadAsStringAsync().Result;
			HtmlDocument val = new HtmlDocument();
			val.LoadHtml(result);
			addressBookTable.Clear();
			if (!parseHtmlToRecord(val, addressBookTable) || stop_addressbook_collection)
			{
				LOG.DebugFormat("{0}:中断", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
				return string.Empty;
			}
			return getCurrentPage(val);
		}
		catch (HttpRequestException ex)
		{
			LOG.InfoFormat("\n例外発生!", new object[0]);
			for (Exception ex2 = ex; ex2 != null; ex2 = ex2.InnerException)
			{
				LOG.InfoFormat("例外メッセージ EX: {0} ", (object)ex2.Message);
			}
			resultMsg = ex.Message;
		}
		catch (TaskCanceledException ex3)
		{
			LOG.InfoFormat("\nタイムアウト!", new object[0]);
			LOG.InfoFormat("例外メッセージ TCE: {0} ", (object)ex3.Message);
			resultMsg = ex3.Message;
		}
		catch (ArgumentException ex4)
		{
			LOG.InfoFormat("例外メッセージ AE: {0} ", (object)ex4.Message);
			resultMsg = ex4.Message;
		}
		catch (Exception ex5)
		{
			LOG.InfoFormat("例外メッセージ EXP: {0} ", (object)ex5.Message);
			resultMsg = ex5.Message;
			if (resultMsg.Contains(Resources.WIM_ERROR_DETECT))
			{
				resultMsg = resultMsg.Substring(Resources.WIM_ERROR_DETECT.Length);
			}
		}
		finally
		{
			LOG.InfoFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		}
		return resultMsg;
	}

	public void stopAddressbookCollection(bool state = true)
	{
		stop_addressbook_collection = state;
		LOG.DebugFormat("{0}:中断フラグ{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)(state ? "セット" : "リセット"));
	}

	private async Task<HttpResponseMessage> getAddressBookInfo(HttpClient client, string regNo)
	{
		string text = string.Format(URI_FORMAT_GET_USER_WIZARD, baseAddressStr, machineLang);
		LOG.InfoFormat("{0}：WIM 03.ユーザー情報取得 リクエスト:{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)text);
		Dictionary<string, string> content = new Dictionary<string, string>
		{
			{ "mode", "MODUSER" },
			{ "outputSpecifyModeIn", "PROGRAMMED" },
			{ "entryIndexIn", regNo },
			{ "wimToken", wimToken }
		};
		HttpResponseMessage obj = await postAsync("ユーザー情報取得！", client, text, content);
		string result = obj.Content.ReadAsStringAsync().Result;
		LOG.InfoFormat("{0}：WIM 03.登録No取得 レスポンス:\n{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)result);
		checkWimErrorExist(result);
		return obj;
	}

	public async Task<string> getAddressBookInfoXml(SettingItemsSetupAddress info, string regNo)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		try
		{
			return (await getAddressBookInfo(client, regNo)).Content.ReadAsStringAsync().Result;
		}
		catch (HttpRequestException ex)
		{
			LOG.InfoFormat("\n例外発生!", new object[0]);
			for (Exception ex2 = ex; ex2 != null; ex2 = ex2.InnerException)
			{
				LOG.InfoFormat("例外メッセージ EX: {0} ", (object)ex2.Message);
			}
			throw;
		}
		catch (TaskCanceledException ex3)
		{
			LOG.InfoFormat("\nタイムアウト!", new object[0]);
			LOG.InfoFormat("例外メッセージ TCE: {0} ", (object)ex3.Message);
			throw;
		}
		catch (ArgumentException ex4)
		{
			LOG.InfoFormat("例外メッセージ AE: {0} ", (object)ex4.Message);
			throw;
		}
		catch (Exception ex5)
		{
			LOG.InfoFormat("例外メッセージ EXP: {0} ", (object)ex5.Message);
			throw;
		}
		finally
		{
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		}
	}

	public async Task<HttpResponseMessage> setAddressbookBase(SettingItemsSetupAddress info)
	{
		string text = string.Format(URI_FORMAT_SET_USER_WIZARD, baseAddressStr, machineLang);
		LOG.InfoFormat("{0}：WIM ユーザー情報更新（基本情報）リクエスト:{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)text);
		KeyValuePair<string, string>[] array = new KeyValuePair<string, string>[11]
		{
			new KeyValuePair<string, string>("mode", "MODUSER"),
			new KeyValuePair<string, string>("step", "BASE"),
			new KeyValuePair<string, string>("wimToken", wimToken),
			new KeyValuePair<string, string>("entryIndexIn", $"{info.registrationNo:D5}"),
			new KeyValuePair<string, string>("entryNameIn", info.addressName),
			new KeyValuePair<string, string>("entryReadNameIn", info.readName),
			new KeyValuePair<string, string>("entryDisplayNameIn", info.displayName),
			new KeyValuePair<string, string>("entryTagInfoIn", info.headlineIndex1.ToString()),
			new KeyValuePair<string, string>("entryTagInfoIn", info.headlineIndex2.ToString()),
			new KeyValuePair<string, string>("entryTagInfoIn", info.headlineIndex3.ToString()),
			new KeyValuePair<string, string>("entryTagInfoIn", info.regularHeadingIndex.ToString())
		};
		string text2 = string.Empty;
		KeyValuePair<string, string>[] array2 = array;
		for (int i = 0; i < array2.Length; i++)
		{
			KeyValuePair<string, string> keyValuePair = array2[i];
			text2 += $"{keyValuePair.Key}={keyValuePair.Value} ";
		}
		LOG.InfoFormat("Option:{0}", (object)text2);
		HttpResponseMessage httpResponseMessage = await postAsync("ユーザー基本情報更新！", client, text, array);
		string result = httpResponseMessage.Content.ReadAsStringAsync().Result;
		LOG.DebugFormat("ユーザー基本情報更新 レスポンス [ {0} ]\n{1}", (object)httpResponseMessage.StatusCode, (object)result);
		checkWimErrorExist(result);
		return httpResponseMessage;
	}

	public async Task<HttpResponseMessage> setAddressbookFolder(SettingItemsSetupAddress info)
	{
		string text = string.Format(URI_FORMAT_SET_USER_WIZARD, baseAddressStr, machineLang);
		LOG.InfoFormat("{0}：WIM ユーザー情報更新（フォルダーあて先）リクエスト:{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)text);
		Dictionary<string, string> dictionary = new Dictionary<string, string>
		{
			{ "mode", "MODUSER" },
			{ "step", "FOLDER" },
			{ "wimToken", wimToken },
			{ "folderProtocolIn", "SMB_O" },
			{ "folderPortNoIn", "21" },
			{
				"folderServerNameIn",
				string.Empty
			},
			{ "folderPathNameIn", info.folderPath },
			{ "folderCharCodeIn", "ASCII_O" },
			{ "folderAuthUserNameIn", info.authUserName }
		};
		string text2 = string.Empty;
		foreach (KeyValuePair<string, string> item in dictionary)
		{
			text2 += $"{item.Key}={item.Value} ";
		}
		LOG.InfoFormat("Option:{0}", (object)text2);
		if (string.IsNullOrEmpty(info.authPassword))
		{
			dictionary.Add("folderPasswordUpdateIn", ADDRESSBOOK_PWD_CHG_OFF);
		}
		else
		{
			string value = new Base64String("shift_jis").Encode(info.authPassword);
			dictionary.Add("folderPasswordUpdateIn", ADDRESSBOOK_PWD_CHG_ON);
			dictionary.Add("wk_folderPasswordIn", string.Empty);
			dictionary.Add("folderPasswordIn", value);
			dictionary.Add("wk_folderPasswordConfirmIn", string.Empty);
			dictionary.Add("folderPasswordConfirmIn", value);
		}
		HttpResponseMessage httpResponseMessage = await postAsync("ユーザーフォルダーあて先情報更新！", client, text, dictionary);
		string result = httpResponseMessage.Content.ReadAsStringAsync().Result;
		LOG.DebugFormat("ユーザーフォルダーあて先情報更新 レスポンス [ {0} ]\n{1}", (object)httpResponseMessage.StatusCode, (object)result);
		checkWimErrorExist(result);
		return httpResponseMessage;
	}

	public async Task<Dictionary<string, Dictionary<ADDRESSBOOK_ITEM, string>>> setAddressbookGo()
	{
		Dictionary<string, Dictionary<ADDRESSBOOK_ITEM, string>> addressBookTable = new Dictionary<string, Dictionary<ADDRESSBOOK_ITEM, string>>();
		string text = string.Format(URI_FORMAT_SET_USER_WIZARD, baseAddressStr, machineLang);
		LOG.InfoFormat("{0}：WIM ユーザー情報更新（設定実行）リクエスト:{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)text);
		KeyValuePair<string, string>[] array = new KeyValuePair<string, string>[5]
		{
			new KeyValuePair<string, string>("mode", "MODUSER"),
			new KeyValuePair<string, string>("wimToken", wimToken),
			new KeyValuePair<string, string>("stepListIn", "BASE"),
			new KeyValuePair<string, string>("stepListIn", "FOLDER"),
			new KeyValuePair<string, string>("step", "CONFIRM")
		};
		string text2 = string.Empty;
		KeyValuePair<string, string>[] array2 = array;
		for (int i = 0; i < array2.Length; i++)
		{
			KeyValuePair<string, string> keyValuePair = array2[i];
			text2 += $"{keyValuePair.Key}={keyValuePair.Value} ";
		}
		LOG.InfoFormat("Option:{0}", (object)text2);
		HttpResponseMessage httpResponseMessage = await postAsync("ユーザー情報更新！", client, text, array);
		LOG.DebugFormat("WIM ユーザー情報更新（設定実行）レスポンス [ {0} ]\n{1}", (object)httpResponseMessage.StatusCode, (object)httpResponseMessage.Content.ReadAsStringAsync().Result);
		if (httpResponseMessage.StatusCode == HttpStatusCode.OK)
		{
			string result = httpResponseMessage.Content.ReadAsStringAsync().Result;
			checkWimErrorExist(result);
			parseToRecord(result, addressBookTable, singleLine: true);
		}
		return addressBookTable;
	}

	private int getRegistrationNumber(HtmlDocument htmlDoc)
	{
		LOG.InfoFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		int.TryParse(htmlSelectNodes(htmlDoc, XPATH_NUM_USERS)[0].InnerText, out var result);
		int.TryParse(htmlSelectNodes(htmlDoc, XPATH_NUM_GROUPS)[0].InnerText, out var result2);
		LOG.InfoFormat("{0}：end {1} users, {2} groups", (object)MethodBase.GetCurrentMethod().Name, (object)result, (object)result2);
		return result + result2;
	}

	private string getCurrentPage(HtmlDocument htmlDoc)
	{
		return htmlSelectNodes(htmlDoc, XPATH_WIM_CURRENT_PAGE)[0].InnerText;
	}

	private bool createColumnList(HtmlDocument htmlDoc, bool fullMode)
	{
		LOG.InfoFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		string xpath = (fullMode ? XPATH_ADDR_LIST_ALL : XPATH_ADDR_LIST_NUM_LIMITATION);
		string a = (fullMode ? "th" : "td");
		string text = (fullMode ? XPATH_ADDR_LIST_TITLE_ALL : XPATH_ADDR_LIST_TITLE_NUM_LIMITATION);
		int num = 0;
		columnList.Clear();
		foreach (HtmlNode item in (IEnumerable<HtmlNode>)htmlSelectNodes(htmlDoc, xpath)[0].ChildNodes)
		{
			if (string.Equals(a, item.Name))
			{
				HtmlNode val = item.SelectSingleNode(text);
				if (val != null)
				{
					columnList.Add(num, val.InnerText);
					LOG.InfoFormat("{0}:{1}", (object)num, (object)val.InnerText);
				}
				num++;
			}
		}
		LOG.InfoFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return columnList.ContainsValue(Resources.ADDRESSBOOK_FOLDER);
	}

	private async Task<bool> getWimDisplayItem()
	{
		LOG.InfoFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		try
		{
			string text = string.Format(URI_FORMAT_MAINTENANCE, baseAddressStr, machineLang, wimToken);
			LOG.InfoFormat("{0}：メンテナンス リクエスト:{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)text);
			string result = (await getAsync("メンテナンス", client, text)).Content.ReadAsStringAsync().Result;
			LOG.InfoFormat("{0}：メンテナンス レスポンス:\n{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)result);
			HtmlDocument val = new HtmlDocument();
			val.LoadHtml(result);
			HtmlNodeCollection val2 = val.DocumentNode.SelectNodes(XPATH_WIM_MAINTENANCE_HIDDEN_FORM);
			if (val2 != null)
			{
				foreach (HtmlNode item in (IEnumerable<HtmlNode>)val2)
				{
					wimAddressbookDisplayItems.Add(item.Attributes["name"].Value);
					wimAddressbookDisplayItems.Add(item.Attributes["value"].Value);
				}
			}
			val2 = val.DocumentNode.SelectNodes(XPATH_WIM_MAINTENANCE_AUTO_DELETE);
			if (val2 != null)
			{
				foreach (HtmlNode item2 in (IEnumerable<HtmlNode>)val2)
				{
					if (item2.Attributes.Contains("checked"))
					{
						wimAddressbookDisplayItems.Add(item2.Attributes["name"].Value);
						wimAddressbookDisplayItems.Add(item2.Attributes["value"].Value);
						break;
					}
				}
			}
			val2 = val.DocumentNode.SelectNodes(XPATH_WIM_MAINTENANCE_DISP_ITEM_LIST);
			if (val2 != null)
			{
				foreach (HtmlNode item3 in (IEnumerable<HtmlNode>)val2[0].ChildNodes)
				{
					if (string.Equals(item3.Name, "li") && item3.Attributes.Contains("class"))
					{
						wimAddressbookDisplayItems.Add(ADDRESSBOOK_HEADER);
						wimAddressbookDisplayItems.Add(item3.Attributes["id"].Value);
					}
				}
			}
			if (wimAddressbookDisplayItems.Contains(ADDRESSBOOK_HEADER_FOLDER))
			{
				wimAddressbookDisplayItems.Clear();
			}
		}
		catch (Exception ex)
		{
			LOG.DebugFormat("{0}：例外メッセージ EX: {1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)ex.ToString());
			throw;
		}
		bool flag = wimAddressbookDisplayItems.Count == 0;
		LOG.InfoFormat("{0}：end フォルダー{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)(flag ? "あり" : "なし"));
		return flag;
	}

	private async Task<bool> changeDisplayItem(bool addFolder)
	{
		LOG.InfoFormat("{0}：start [{1}]", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)(addFolder ? "addFolder" : "reset"));
		int num = wimAddressbookDisplayItems.Count / 2;
		if (addFolder)
		{
			num++;
		}
		KeyValuePair<string, string>[] array = new KeyValuePair<string, string>[num];
		string text = string.Empty;
		int num2 = 0;
		foreach (string wimAddressbookDisplayItem in wimAddressbookDisplayItems)
		{
			if (string.IsNullOrEmpty(text))
			{
				text = wimAddressbookDisplayItem;
				continue;
			}
			array[num2++] = new KeyValuePair<string, string>(text, wimAddressbookDisplayItem);
			text = string.Empty;
		}
		if (addFolder)
		{
			array[num2] = new KeyValuePair<string, string>(ADDRESSBOOK_HEADER, ADDRESSBOOK_HEADER_FOLDER);
			LOG.InfoFormat("{0}：add folder", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		}
		string text2 = string.Format(URI_FORMAT_SET_MAINTENANCE, baseAddressStr, machineLang);
		LOG.DebugFormat("メンテナンス リクエスト {0}", (object)text2);
		HttpResponseMessage httpResponseMessage = await postAsync("", client, text2, array);
		LOG.DebugFormat("メンテナンス レスポンス [ {0} ]\n{1}", (object)httpResponseMessage.StatusCode, (object)httpResponseMessage.Content.ReadAsStringAsync().Result);
		string result = httpResponseMessage.Content.ReadAsStringAsync().Result;
		checkWimErrorExist(result);
		LOG.InfoFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		return true;
	}

	private void createSearchForList(HtmlDocument htmlDoc)
	{
		LOG.InfoFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		searchForList.Clear();
		foreach (HtmlNode item in (IEnumerable<HtmlNode>)htmlSelectNodes(htmlDoc, XPATH_SERACH_FILTER)[0].ChildNodes)
		{
			if (string.Equals("option", item.Name))
			{
				searchForList.Add(item.Attributes["value"].Value, item.InnerText);
			}
		}
		LOG.InfoFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	private void parseToRecord(string addressData, Dictionary<string, Dictionary<ADDRESSBOOK_ITEM, string>> addressBookTable, bool singleLine = false)
	{
		LOG.InfoFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		addressData = addressData.Substring(2, addressData.Length - 4);
		string[] separator = new string[1] { "],[" };
		string[] array = addressData.Split(separator, StringSplitOptions.None);
		string[] array2 = new string[12];
		int num = 0;
		int num2 = 0;
		int num3 = 0;
		string text = ",";
		string text2 = "','";
		int num4 = 2;
		string[] array3 = array;
		foreach (string text3 in array3)
		{
			num = 0;
			num2 = 0;
			num3 = 0;
			for (int j = 0; j < columnList.Count + 1; j++)
			{
				if (j < num4)
				{
					num2 = text3.IndexOf(text, num);
					num3 = text.Length;
				}
				else
				{
					num2 = text3.IndexOf(text2, num);
					if (num2 == -1)
					{
						num2 = text3.Length - 1;
						num3 = 0;
					}
					else
					{
						num3 = text2.Length;
					}
				}
				array2[j] = text3.Substring(num, num2 - num);
				num = num2 + num3;
			}
			if (array2.Length < 4)
			{
				LOG.DebugFormat("{0}：too few items {1}", (object)MethodBase.GetCurrentMethod().Name, (object)array2.Length);
			}
			string text4 = string.Empty;
			_ = string.Empty;
			Dictionary<ADDRESSBOOK_ITEM, string> dictionary = new Dictionary<ADDRESSBOOK_ITEM, string>();
			foreach (KeyValuePair<int, string> column in columnList)
			{
				string value = column.Value;
				if (string.Equals(value, Resources.ADDRESSBOOK_REGISTRATION_NO_NAME))
				{
					text4 = peelUserString(array2[column.Key]);
				}
				else if (string.Equals(value, Resources.ADDRESSBOOK_NAME))
				{
					dictionary.Add(ADDRESSBOOK_ITEM.NAME, peelUserString(array2[column.Key]));
				}
				else if (string.Equals(value, Resources.ADDRESSBOOK_INDEX_NAME))
				{
					dictionary.Add(ADDRESSBOOK_ITEM.INDEX, peelUserString(array2[column.Key]));
				}
				else if (string.Equals(value, Resources.ADDRESSBOOK_DATE_LAST_USED))
				{
					int num5 = array2[column.Key].IndexOf("#");
					string value2 = string.Empty;
					if (num5 >= 0)
					{
						value2 = peelUserString(array2[column.Key]);
						value2 = value2.Substring(value2.IndexOf("#") + 1);
					}
					dictionary.Add(ADDRESSBOOK_ITEM.DATE_LAST_USED, value2);
				}
				else if (string.Equals(value, Resources.ADDRESSBOOK_FOLDER) && array2.Length > column.Key)
				{
					string text5 = array2[column.Key].TrimStart(new char[1] { '\'' }).TrimEnd(new char[1] { '\'' });
					dictionary.Add(ADDRESSBOOK_ITEM.FOLDER, text5.Replace("\\\\", "\\"));
				}
			}
			if (string.IsNullOrEmpty(text4))
			{
				text4 = $"*{dummyRegistrationNo++}";
			}
			if (addressBookTable.ContainsKey(text4))
			{
				string text6 = $"重複する項目が見つかりました。スキップします。\n{text4}:";
				foreach (KeyValuePair<ADDRESSBOOK_ITEM, string> item in dictionary)
				{
					text6 += $", {item.Key}:{item.Value}";
				}
				LOG.Debug((object)text6);
			}
			else
			{
				addressBookTable.Add(text4, dictionary);
				if (singleLine)
				{
					break;
				}
			}
		}
		LOG.InfoFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	private string peelUserString(string targetStr)
	{
		return targetStr.TrimStart(new char[1] { '\'' }).TrimEnd(new char[1] { '\'' }).Replace("\\'", "'")
			.Replace("\\\\", "\\");
	}

	private bool parseHtmlToRecord(HtmlDocument htmlDoc, Dictionary<string, Dictionary<ADDRESSBOOK_ITEM, string>> addressBookTable)
	{
		LOG.InfoFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		string text = string.Empty;
		List<string> list = new List<string>();
		try
		{
			foreach (HtmlNode item in (IEnumerable<HtmlNode>)htmlSelectNodes(htmlDoc, XPATH_ADDRESSBOOK_TITLE))
			{
				list.Add(item.InnerText);
			}
			foreach (HtmlNode item2 in (IEnumerable<HtmlNode>)htmlSelectNodes(htmlDoc, XPATH_ADDRESSBOOK_SERACH_FILTERED))
			{
				if (item2.HasAttributes)
				{
					continue;
				}
				int num = 0;
				Dictionary<ADDRESSBOOK_ITEM, string> dictionary = new Dictionary<ADDRESSBOOK_ITEM, string>();
				foreach (HtmlNode item3 in (IEnumerable<HtmlNode>)item2.SelectNodes("td"))
				{
					string key = list[num++];
					if (addressBookTitle.ContainsKey(key))
					{
						switch (addressBookTitle[key])
						{
						case ADDRESSBOOK_ITEM.REGISTRATION_NUMBER:
							text = item3.InnerText;
							break;
						case ADDRESSBOOK_ITEM.NAME:
							dictionary.Add(ADDRESSBOOK_ITEM.NAME, item3.InnerText);
							break;
						case ADDRESSBOOK_ITEM.INDEX:
						{
							string value = ((item3.InnerText.IndexOf("---") > 0) ? string.Empty : item3.InnerText);
							dictionary.Add(ADDRESSBOOK_ITEM.INDEX, value);
							break;
						}
						case ADDRESSBOOK_ITEM.DATE_LAST_USED:
							dictionary.Add(ADDRESSBOOK_ITEM.DATE_LAST_USED, item3.InnerText);
							break;
						case ADDRESSBOOK_ITEM.FOLDER:
						{
							string text2 = ((item3.InnerText.IndexOf("---") > 0) ? string.Empty : item3.InnerText);
							dictionary.Add(ADDRESSBOOK_ITEM.FOLDER, text2.Replace("\\\\", "\\"));
							break;
						}
						}
					}
				}
				if (string.IsNullOrEmpty(text))
				{
					text = $"*{dummyRegistrationNo++}";
				}
				addressBookTable.Add(text, dictionary);
			}
		}
		catch (Exception ex)
		{
			LOG.InfoFormat("例外メッセージ EXP: {0} ", (object)ex.Message);
			throw;
		}
		finally
		{
			LOG.InfoFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		}
		return true;
	}

	private HtmlNodeCollection htmlSelectNodes(HtmlDocument htmlDoc, string xpath)
	{
		LOG.InfoFormat("{0}：start xpath:{1}", (object)MethodBase.GetCurrentMethod().Name, (object)xpath);
		HtmlNodeCollection val = htmlDoc.DocumentNode.SelectNodes(xpath);
		if (val == null || val.Count <= 0)
		{
			LOG.ErrorFormat("機器から受信したHTMLデータのxPath検索が失敗しました。\nxPath:{0}", (object)xpath);
			throw new Exception(Resources.ERR_MSG_FATAL);
		}
		LOG.InfoFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return val;
	}

	public async Task<HttpResponseMessage> winLogout()
	{
		string text = string.Format(URI_FORMAT_LOGOUT, baseAddressStr, machineLang);
		LOG.InfoFormat("{0}：start WIM 02.ログアウト リクエスト:\nURI:{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)text);
		HttpResponseMessage obj = await getAsync("ログアウト！", client, text);
		createHttpClientInstance();
		string result = obj.Content.ReadAsStringAsync().Result;
		LOG.InfoFormat("{0}：WIM 02.ログアウト レスポンス:\n{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)result);
		LOG.InfoFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		return obj;
	}

	public async Task<bool> goBackWimAddressbookDisplayItems()
	{
		if (wimAddressbookDisplayItems.Count > 0)
		{
			await changeDisplayItem(addFolder: false);
			wimAddressbookDisplayItems.Clear();
		}
		return true;
	}

	public async Task<Hashtable> GetMFPByHTTPtoPrimax(SettingItemsSetupAddress info)
	{
		LOG.InfoFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		string lang = getLangCmd();
		protocol = (info.httpsFlg ? "https" : "http");
		string uri = string.Format(PRIMAX_URI_HOME_STATUS, protocol, info.host, lang);
		string text = await getRetHtml(uri);
		if (string.IsNullOrEmpty(text))
		{
			LOG.InfoFormat("{0}：end => Not ModelName", (object)MethodBase.GetCurrentMethod().Name);
			return null;
		}
		string key = "//*[@class=\"modelName\"]";
		string modelName = getHtmlItem(text, key);
		uri = string.Format(PRIMAX_URI_NETWORKSETTINGS_DSN, protocol, info.host, lang);
		text = await getRetHtml(uri);
		key = "//*[@name=\"dns5\"]";
		string netBiosNm = getHtmlItem(text, key);
		key = "//*[@name=\"dns1\"]";
		string htmlItem = getHtmlItem(text, key);
		key = "//*[@name=\"dns12\"]";
		string htmlItem2 = getHtmlItem(text, key);
		key = "//*[@name=\"dns13\"]";
		string htmlItem3 = getHtmlItem(text, key);
		key = "//*[@name=\"dns14\"]";
		string htmlItem4 = getHtmlItem(text, key);
		string dns1 = htmlItem + "." + htmlItem2 + "." + htmlItem3 + "." + htmlItem4;
		key = "//*[@name=\"dns2\"]";
		string htmlItem5 = getHtmlItem(text, key);
		key = "//*[@name=\"dns22\"]";
		string htmlItem6 = getHtmlItem(text, key);
		key = "//*[@name=\"dns23\"]";
		string htmlItem7 = getHtmlItem(text, key);
		key = "//*[@name=\"dns24\"]";
		string htmlItem8 = getHtmlItem(text, key);
		string dns2 = htmlItem5 + "." + htmlItem6 + "." + htmlItem7 + "." + htmlItem8;
		uri = string.Format(PRIMAX_URI_NETWORKSETTINGS_NETWORKINFO, protocol, info.host, lang);
		text = await getRetHtml(uri);
		key = "//*[@name=\"D5\"]";
		string htmlItem9 = getHtmlItem(text, key);
		key = "//*[@name=\"D6\"]";
		string htmlItem10 = getHtmlItem(text, key);
		key = "//*[@name=\"D7\"]";
		string htmlItem11 = getHtmlItem(text, key);
		key = "//*[@name=\"D8\"]";
		string htmlItem12 = getHtmlItem(text, key);
		string ipAddr = htmlItem9 + "." + htmlItem10 + "." + htmlItem11 + "." + htmlItem12;
		key = "//*[@name=\"D9\"]";
		string htmlItem13 = getHtmlItem(text, key);
		key = "//*[@name=\"D10\"]";
		string htmlItem14 = getHtmlItem(text, key);
		key = "//*[@name=\"D11\"]";
		string htmlItem15 = getHtmlItem(text, key);
		key = "//*[@name=\"D12\"]";
		string htmlItem16 = getHtmlItem(text, key);
		string subMask = htmlItem13 + "." + htmlItem14 + "." + htmlItem15 + "." + htmlItem16;
		key = "//*[@name=\"D13\"]";
		string htmlItem17 = getHtmlItem(text, key);
		key = "//*[@name=\"D14\"]";
		string htmlItem18 = getHtmlItem(text, key);
		key = "//*[@name=\"D15\"]";
		string htmlItem19 = getHtmlItem(text, key);
		key = "//*[@name=\"D16\"]";
		string htmlItem20 = getHtmlItem(text, key);
		string gateway = htmlItem17 + "." + htmlItem18 + "." + htmlItem19 + "." + htmlItem20;
		uri = string.Format(PRIMAX_URI_HOME_EQUIPMENTINFO, protocol, info.host, lang);
		text = await getRetHtml(uri);
		string targetJp = "ファームウェアバージョン";
		string targetEn = "Firmware Version";
		string httmlIndexOfItem = getHttmlIndexOfItem(text, targetJp, targetEn, 8);
		Hashtable result = new Hashtable
		{
			{
				FormMFPInfo.KEY.MODELNAME,
				modelName
			},
			{
				FormMFPInfo.KEY.SYSTEMCOPY,
				httmlIndexOfItem
			},
			{
				FormMFPInfo.KEY.NETWORKSUPPORT,
				""
			},
			{
				FormMFPInfo.KEY.WEBSUPPORT,
				""
			},
			{
				FormMFPInfo.KEY.NETBIOSNAME,
				netBiosNm
			},
			{
				FormMFPInfo.KEY.IPV4ADRESS,
				ipAddr
			},
			{
				FormMFPInfo.KEY.SUBNETMASK,
				subMask
			},
			{
				FormMFPInfo.KEY.GATEWAY,
				gateway
			},
			{
				FormMFPInfo.KEY.PRIMARYWINS,
				""
			},
			{
				FormMFPInfo.KEY.SECONDARYWINS,
				""
			},
			{
				FormMFPInfo.KEY.DNS1,
				dns1
			},
			{
				FormMFPInfo.KEY.DNS2,
				dns2
			},
			{
				FormMFPInfo.KEY.DNS3,
				""
			},
			{
				FormMFPInfo.KEY.SMBENABLE,
				""
			},
			{
				FormMFPInfo.KEY.SMBPORT,
				""
			},
			{
				FormMFPInfo.KEY.SMBVERSION,
				""
			},
			{
				FormMFPInfo.KEY.SMBAUTHLEVEL,
				""
			},
			{
				FormMFPInfo.KEY.SCANNER,
				""
			},
			{
				FormMFPInfo.KEY.ANIMATION,
				""
			},
			{
				FormMFPInfo.KEY.ST_NOSTATE,
				""
			}
		};
		LOG.InfoFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return result;
	}

	private string getLangCmd()
	{
		string text = "";
		if ("ja".Equals(machineLang))
		{
			return "?Lang=ja";
		}
		return "?Lang=en-us";
	}

	private async Task<string> getRetHtml(string uri)
	{
		LOG.InfoFormat("URI：{0}", (object)uri);
		string result = "";
		using HttpClient httpClient = new HttpClient();
		httpClient.DefaultRequestHeaders.Add("User-Agent", "Wget/1.11.3");
		httpClient.DefaultRequestHeaders.Add("Accept-Language", "utf-8");
		httpClient.Timeout = TimeSpan.FromSeconds(short.Parse(Settings.Default.httpTimeout));
		try
		{
			HttpResponseMessage obj = await httpClient.GetAsync(uri);
			obj.EnsureSuccessStatusCode();
			Encoding enc = Encoding.GetEncoding("shift_jis");
			using (Stream stream = await obj.Content.ReadAsStreamAsync())
			{
				using TextReader reader = new StreamReader(stream, enc, detectEncodingFromByteOrderMarks: true);
				result = await reader.ReadToEndAsync();
			}
			return result;
		}
		catch (HttpRequestException ex)
		{
			Console.WriteLine("\n例外発生!");
			for (Exception ex2 = ex; ex2 != null; ex2 = ex2.InnerException)
			{
				Console.WriteLine("例外メッセージ: {0} ", ex2.Message);
			}
			throw;
		}
		catch (TaskCanceledException ex3)
		{
			Console.WriteLine("\nタイムアウト!");
			Console.WriteLine("例外メッセージ: {0} ", ex3.Message);
			throw;
		}
		catch (ArgumentException ex4)
		{
			Console.WriteLine("例外メッセージ: {0} ", ex4.Message);
			throw;
		}
		catch (Exception ex5)
		{
			Console.WriteLine(ex5.ToString());
			throw;
		}
	}

	private string getHtmlItem(string retHtml, string key)
	{
		//IL_000e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0013: Unknown result type (might be due to invalid IL or missing references)
		if (string.IsNullOrEmpty(retHtml))
		{
			return "";
		}
		HtmlDocument val = new HtmlDocument();
		val.LoadHtml(retHtml);
		HtmlNode val2 = val.DocumentNode.SelectSingleNode(key);
		string text = ((val2 == null) ? "Error, not found" : val2.InnerHtml);
		if (string.IsNullOrEmpty(text))
		{
			foreach (HtmlAttribute item in (IEnumerable<HtmlAttribute>)val2.Attributes)
			{
				if ("VALUE".Equals(item.Name.ToString().ToUpper()))
				{
					text = item.Value;
					return text;
				}
			}
		}
		return text;
	}

	private string getHttmlIndexOfItem(string retHtml, string targetJp, string targetEn, int upCnt)
	{
		List<string> retHtmlToList = getRetHtmlToList(retHtml);
		string item = targetJp;
		if (!"ja".Equals(machineLang))
		{
			item = targetEn;
		}
		string result = "";
		int num = retHtmlToList.IndexOf(item);
		if (num >= 0)
		{
			result = retHtmlToList[num + upCnt];
		}
		return result;
	}

	public void SetPrimaxModel(bool flg)
	{
		primaxModel = flg;
	}

	public void SetPrimaxUnicode(bool flg)
	{
		primaxUnicode = flg;
	}

	public async Task<PRIMAX_MACHINE_CONTROL_RESULT> executeSetupAddressToPrimax(SettingItemsSetupAddress info, string oldEntryName = "", string passwordChange = "0")
	{
		LOG.DebugFormat("{0}：start ({1})", (object)MethodBase.GetCurrentMethod().Name, (object)info.host);
		string text = info.registrationNo.ToString();
		if (info.registrationNo == 0)
		{
			text = "";
		}
		protocol = (info.httpsFlg ? "https" : "http");
		string text2 = info.addressName.Trim();
		string text3 = info.passwd.Trim();
		string text4 = info.adminName.Trim();
		string[] array = info.folderPath.Split(new char[1] { '\\' });
		string text5 = array[2].Trim();
		string text6 = array[3].Trim();
		string[] array2 = info.authUserName.Split(new char[1] { '\\' });
		string text7 = array2[0].Trim();
		string text8 = array2[1].Trim();
		string text9 = "0";
		if (info.firstFlg || (!info.firstFlg && "1".Equals(passwordChange)))
		{
			text9 = "1";
		}
		string text10 = "";
		string text11 = "";
		string text12 = protocol + "%3A%2F%2F" + info.host + "%2Fpcentry.asp%3FNULL";
		if (!info.firstFlg)
		{
			text10 = "upd=0&";
			oldEntryName = oldEntryName.Trim();
			text11 = ((!primaxUnicode) ? oldEntryName : convToUnicode(oldEntryName));
			text12 = protocol + "%3A%2F%2F" + info.host + "%2Fpcentry.asp%3F" + oldEntryName + "%262%26";
		}
		_ = string.Empty;
		string text13 = ((!primaxUnicode) ? convHexString(text2, PRIMAX_HEX_ENCODINGT.UTF16) : convToUnicode(text2));
		string s = "type=2&Density=3&reqdestname=" + text13 + "&name1=" + convHexString(text2, PRIMAX_HEX_ENCODINGT.SJIS) + "&history=" + text12 + "&ifEdit=" + text9 + "&normal=1&Forwarding=&SMBPW=" + text3 + "&" + text10 + "oldname=" + text11 + "&QuickDial=" + text + "&reqdestname2=" + convHexString(text2, PRIMAX_HEX_ENCODINGT.SJIS) + "&reqpcname=" + text5 + "&reqpcfolder=" + text6 + "&DomainName=" + text7 + "&uname=" + text8 + "&pword=" + text3 + "&pcdir=&pcsender=&fileformatcolor=1&fileformat=2&Original=0&docSize=3&unit=0&widthmm=210&lengthmm=297&widthinch1=8&widthinch2=50&lengthinch1=11&lengthinch2=00&resolution=4&admin=" + text4;
		HttpWebResponse httpWebResponse = null;
		StreamReader streamReader = null;
		PRIMAX_MACHINE_CONTROL_RESULT pRIMAX_MACHINE_CONTROL_RESULT = PRIMAX_MACHINE_CONTROL_RESULT.ERROR;
		try
		{
			byte[] bytes = Encoding.ASCII.GetBytes(s);
			WebRequest webRequest = WebRequest.Create(string.Format(PRIMAX_URI_PROFILE_ADD, protocol, info.host));
			webRequest.Method = "POST";
			webRequest.ContentType = "application/x-www-form-urlencoded";
			webRequest.ContentLength = bytes.Length;
			Stream requestStream = webRequest.GetRequestStream();
			requestStream.Write(bytes, 0, bytes.Length);
			requestStream.Close();
			httpWebResponse = (HttpWebResponse)webRequest.GetResponse();
			streamReader = new StreamReader(webRequest.GetResponse().GetResponseStream(), Encoding.UTF8);
			string text14 = streamReader.ReadToEnd();
			if (!"OK".Equals(httpWebResponse.StatusCode.ToString()))
			{
				pRIMAX_MACHINE_CONTROL_RESULT = PRIMAX_MACHINE_CONTROL_RESULT.ERROR;
				LOG.DebugFormat("{0}：end {1} StatusCode:{2}", (object)MethodBase.GetCurrentMethod().Name, (object)pRIMAX_MACHINE_CONTROL_RESULT, (object)httpWebResponse.StatusCode);
				return pRIMAX_MACHINE_CONTROL_RESULT;
			}
			string value = "パスワードが正しくありません。";
			string value2 = "Wrong Password";
			if (text14.IndexOf(value) >= 0 || text14.IndexOf(value2) >= 0)
			{
				pRIMAX_MACHINE_CONTROL_RESULT = PRIMAX_MACHINE_CONTROL_RESULT.PW_RESETTING;
				LOG.DebugFormat("{0}：end {1}", (object)MethodBase.GetCurrentMethod().Name, (object)pRIMAX_MACHINE_CONTROL_RESULT);
				return pRIMAX_MACHINE_CONTROL_RESULT;
			}
			string value3 = "入力された宛先はすでに存在しています。";
			string value4 = "The destination has already existed.";
			if (text14.IndexOf(value3) >= 0 || text14.IndexOf(value4) >= 0)
			{
				pRIMAX_MACHINE_CONTROL_RESULT = PRIMAX_MACHINE_CONTROL_RESULT.ADD_DUPLICATE;
				LOG.DebugFormat("{0}：end {1}", (object)MethodBase.GetCurrentMethod().Name, (object)pRIMAX_MACHINE_CONTROL_RESULT);
				return pRIMAX_MACHINE_CONTROL_RESULT;
			}
			string value5 = "これ以上宛先を登録できません。";
			string value6 = "Cannot program more destinations.";
			if (text14.IndexOf(value5) >= 0 || text14.IndexOf(value6) >= 0)
			{
				pRIMAX_MACHINE_CONTROL_RESULT = PRIMAX_MACHINE_CONTROL_RESULT.ADD_OVER;
				LOG.DebugFormat("{0}：end {1}", (object)MethodBase.GetCurrentMethod().Name, (object)pRIMAX_MACHINE_CONTROL_RESULT);
				return pRIMAX_MACHINE_CONTROL_RESULT;
			}
			pRIMAX_MACHINE_CONTROL_RESULT = PRIMAX_MACHINE_CONTROL_RESULT.SUCCESS;
		}
		catch (WebException ex)
		{
			if (ex.Status == WebExceptionStatus.ProtocolError)
			{
				HttpWebResponse httpWebResponse2 = (HttpWebResponse)ex.Response;
				LOG.ErrorFormat("Uri:{0} HttpStatusCode:{1} Description{2}", (object)httpWebResponse2.ResponseUri, (object)httpWebResponse2.StatusCode, (object)httpWebResponse2.StatusDescription);
			}
			LOG.Error((object)ex.Message);
			pRIMAX_MACHINE_CONTROL_RESULT = PRIMAX_MACHINE_CONTROL_RESULT.ERROR;
		}
		finally
		{
			httpWebResponse?.Close();
			streamReader?.Close();
			LOG.DebugFormat("{0}：end {1}", (object)MethodBase.GetCurrentMethod().Name, (object)pRIMAX_MACHINE_CONTROL_RESULT);
		}
		return pRIMAX_MACHINE_CONTROL_RESULT;
	}

	public string convHexString(string text, PRIMAX_HEX_ENCODINGT enc)
	{
		string text2 = "";
		Encoding encoding = Encoding.GetEncoding("Shift_JIS");
		Encoding encoding2 = Encoding.GetEncoding("utf-16BE");
		Regex regex = new Regex("[｡-ﾟ]");
		Regex regex2 = new Regex("[#$%&']");
		Regex regex3 = new Regex("[ŒœÃÄÅÆÇÉÑÕÖØÜßàáâãäæçèéêëìíîïñòóôõöøùúûüÿ]");
		Regex regex4 = new Regex("[Œœ]");
		bool flag = true;
		for (int i = 0; i < text.Length; i++)
		{
			string text3 = text.Substring(i, 1);
			if (Encoding.GetEncoding("shift_jis").GetByteCount(text3) != 1)
			{
				return null;
			}
			bool num = regex3.IsMatch(text3);
			flag = regex4.IsMatch(text3);
			if (num)
			{
				if (flag)
				{
					for (int j = 0; j < convLatinaList.Count; j++)
					{
						if (convLatinaList[j][0].Equals(text3))
						{
							if (enc == PRIMAX_HEX_ENCODINGT.UTF16)
							{
								text2 += convLatinaList[j][1];
								break;
							}
							if (PRIMAX_HEX_ENCODINGT.SJIS == enc)
							{
								text2 += convLatinaList[j][2];
								break;
							}
							return null;
						}
					}
					continue;
				}
				string text4 = HttpUtility.UrlEncode(text3, encoding2);
				if (enc == PRIMAX_HEX_ENCODINGT.UTF16)
				{
					text4 = text4.Replace("%00%", "");
					text2 = text2 + "%25" + text4.ToUpper();
					continue;
				}
				if (PRIMAX_HEX_ENCODINGT.SJIS != enc)
				{
					return null;
				}
				text4 = text4.Replace("%00%", "");
				text2 = text2 + "%26%23" + int.Parse(text4, NumberStyles.HexNumber) + ";";
			}
			else if (regex.IsMatch(text3))
			{
				if (enc == PRIMAX_HEX_ENCODINGT.UTF16)
				{
					text2 = text2 + "%25u" + convToUnicode(text3).Replace("%U", "");
					continue;
				}
				if (PRIMAX_HEX_ENCODINGT.SJIS != enc)
				{
					return null;
				}
				text2 += HttpUtility.UrlEncode(text3, encoding);
			}
			else if (regex2.IsMatch(text3))
			{
				if (enc == PRIMAX_HEX_ENCODINGT.UTF16)
				{
					string text5 = BitConverter.ToString(Encoding.Default.GetBytes(text3));
					text2 = text2 + "%25" + text5;
					continue;
				}
				if (PRIMAX_HEX_ENCODINGT.SJIS != enc)
				{
					return null;
				}
				text2 += HttpUtility.UrlEncode(text3, encoding);
			}
			else
			{
				text2 += text3;
			}
		}
		return text2;
	}

	private List<string> getRetHtmlToList(string retHtml)
	{
		string text = retHtml.Replace("\t", "");
		List<string> list = new List<string>();
		char[] separator = new char[2] { '<', '>' };
		string[] array = text.Split(separator);
		for (int i = 0; i < array.Length; i++)
		{
			_ = array[i];
			if (array[i].Replace(" ", "").Replace("\u3000", "").Replace("\r\n", "")
				.Length != 0)
			{
				list.Add(array[i]);
			}
		}
		return list;
	}

	public async Task<string> getPrimaxAddressBook(SettingItemsSetupAddress info, Dictionary<string, Dictionary<ADDRESSBOOK_ITEM, string>> addressBookTable, List<OneTouchKeyInfo> oneTouchKeyInfo)
	{
		string registNum = "";
		protocol = (info.httpsFlg ? "https" : "http");
		string uri = string.Format(PRIMAX_GET_ADDRESS_BOOK, protocol, info.host);
		try
		{
			addressBookTable.Clear();
			List<string[]> primaxAddressBookToSort = getPrimaxAddressBookToSort(await getRetHtml(uri), oneTouchKeyInfo);
			for (int i = 0; i < primaxAddressBookToSort.Count; i++)
			{
				Dictionary<ADDRESSBOOK_ITEM, string> dictionary = new Dictionary<ADDRESSBOOK_ITEM, string>();
				dictionary.Add(ADDRESSBOOK_ITEM.REGISTRATION_NUMBER, primaxAddressBookToSort[i][0]);
				dictionary.Add(ADDRESSBOOK_ITEM.NAME, primaxAddressBookToSort[i][1]);
				dictionary.Add(ADDRESSBOOK_ITEM.INDEX, "-");
				dictionary.Add(ADDRESSBOOK_ITEM.DATE_LAST_USED, "-");
				dictionary.Add(ADDRESSBOOK_ITEM.FOLDER, primaxAddressBookToSort[i][2]);
				dictionary.Add(ADDRESSBOOK_ITEM.KEY_CODE, primaxAddressBookToSort[i][3]);
				string key = (i + 1).ToString();
				addressBookTable.Add(key, dictionary);
			}
		}
		catch (HttpRequestException ex)
		{
			registNum = ex.Message;
		}
		catch (TaskCanceledException ex2)
		{
			registNum = ex2.Message;
		}
		catch (ArgumentException ex3)
		{
			registNum = ex3.Message;
		}
		catch (Exception ex4)
		{
			registNum = ex4.Message;
			if (registNum.Contains(Resources.WIM_ERROR_DETECT))
			{
				registNum = registNum.Substring(Resources.WIM_ERROR_DETECT.Length);
			}
		}
		return registNum;
	}

	public async Task<List<string[]>> getPrimaxAddressList(bool httpsFlg, string host, List<OneTouchKeyInfo> oneTouchKeyInfo)
	{
		protocol = (httpsFlg ? "https" : "http");
		string uri = string.Format(PRIMAX_GET_ADDRESS_BOOK, protocol, host);
		return getPrimaxAddressBookToSort(await getRetHtml(uri), oneTouchKeyInfo);
	}

	private List<string[]> getPrimaxAddressBookToSort(string retHtml, List<OneTouchKeyInfo> oneTouchKeyInfo)
	{
		List<string> retHtmlToList = getRetHtmlToList(retHtml);
		string[] array = null;
		List<string[]> list = new List<string[]>();
		List<string[]> list2 = new List<string[]>();
		List<string> list3 = new List<string>();
		for (int i = 0; i < retHtmlToList.Count; i++)
		{
			if (retHtmlToList[i].ToString().IndexOf("profName") < 0)
			{
				continue;
			}
			string utf = retHtmlToList[i + 3].ToString();
			string text = retHtmlToList[i + 9].ToString();
			int startIndex = 26;
			int length = retHtmlToList[i].ToString().Substring(startIndex).IndexOf("'");
			string text2 = retHtmlToList[i].ToString().Substring(startIndex, length);
			string text3 = convUtf16String(utf);
			string text4 = "-";
			for (int j = 0; j < oneTouchKeyInfo.Count; j++)
			{
				if (text3.Equals(oneTouchKeyInfo[j].name))
				{
					text4 = oneTouchKeyInfo[j].no.ToString();
					break;
				}
			}
			array = new string[4] { "", "", "", "" };
			array[0] = text4;
			array[1] = text3;
			array[2] = text;
			array[3] = text2;
			list.Add(array);
			list3.Add(array[1]);
		}
		list3.Sort();
		int num = 0;
		for (int k = 0; k < list3.Count; k++)
		{
			for (int l = 0; l < list.Count; l++)
			{
				if (list3[k].Equals(list[l][1]))
				{
					num++;
					array = new string[4] { "", "", "", "" };
					array[0] = list[l][0];
					array[1] = list[l][1];
					array[2] = list[l][2];
					array[3] = list[l][3];
					list2.Add(array);
				}
			}
		}
		return list2;
	}

	private string convUtf16String(string utf16)
	{
		string text = "";
		string[] array = utf16.Split(new char[1] { ';' });
		if (primaxUnicode)
		{
			text = convFromUnicode(utf16);
		}
		else
		{
			for (int i = 0; i < array.Length; i++)
			{
				if (!string.IsNullOrEmpty(array[i]))
				{
					if (array[i].Equals("&nbsp"))
					{
						array[i] = array[i].Replace("&nbsp", "&#32");
					}
					text += (char)int.Parse(array[i].Replace("&#", ""));
				}
			}
		}
		return text;
	}

	public async Task<Dictionary<AddressBookListControl.ADDRESSBOOK_LIST_ITEM, string>> getPrimaxAddressBookInfo(SettingItemsSetupAddress info, string reqdestname, string keycode)
	{
		_ = string.Empty;
		string arg;
		if (primaxUnicode)
		{
			arg = convToUnicode(reqdestname);
		}
		else
		{
			if (keycode.Equals(""))
			{
				return null;
			}
			arg = keycode;
		}
		protocol = (info.httpsFlg ? "https" : "http");
		string uri = string.Format(PRIMAX_GET_ADDRESS_BOOK_INFO, protocol, info.host, arg);
		string retHtml = await getRetHtml(uri);
		string key = "//*[@name=\"reqdestname2\"]";
		string htmlItem = getHtmlItem(retHtml, key);
		htmlItem = convUtf16String(htmlItem);
		key = "//*[@name=\"reqpcname\"]";
		string htmlItem2 = getHtmlItem(retHtml, key);
		key = "//*[@name=\"reqpcfolder\"]";
		string htmlItem3 = getHtmlItem(retHtml, key);
		key = "//*[@name=\"DomainName\"]";
		string htmlItem4 = getHtmlItem(retHtml, key);
		key = "//*[@name=\"uname\"]";
		string htmlItem5 = getHtmlItem(retHtml, key);
		string value = "\\\\" + htmlItem2 + "\\" + htmlItem3;
		string value2 = htmlItem4 + "\\" + htmlItem5;
		return new Dictionary<AddressBookListControl.ADDRESSBOOK_LIST_ITEM, string>
		{
			{
				AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX,
				"0"
			},
			{
				AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_NAME,
				htmlItem
			},
			{
				AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX_NAME,
				""
			},
			{
				AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_DISPLAY_NAME,
				""
			},
			{
				AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_1,
				""
			},
			{
				AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_2,
				""
			},
			{
				AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_3,
				""
			},
			{
				AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_FREQ,
				""
			},
			{
				AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PROTOCOL,
				""
			},
			{
				AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PORT_NO,
				""
			},
			{
				AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PATH_NAME,
				value
			},
			{
				AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_CHAR_CODE,
				""
			},
			{
				AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_AUTH_USER_NAME,
				value2
			},
			{
				AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PASSWORD_CHANGE,
				""
			},
			{
				AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PASSWORD,
				""
			},
			{
				AddressBookListControl.ADDRESSBOOK_LIST_ITEM.KEY_CODE,
				keycode
			}
		};
	}

	public async Task<List<OneTouchKeyInfo>> getPrimaxOneTouchKeyInfo(bool thhpsFlg, string ipAddr)
	{
		Encoding sjisEnc = Encoding.GetEncoding("Shift_JIS");
		List<OneTouchKeyInfo> oneTouchKeyInfo = new List<OneTouchKeyInfo>();
		protocol = (thhpsFlg ? "https" : "http");
		string uri = string.Format(PRIMAX_URI_QUICKSCAN, protocol, ipAddr);
		List<string> retHtmlToList = getRetHtmlToList(await getRetHtml(uri));
		for (int i = 0; i < retHtmlToList.Count; i++)
		{
			if (retHtmlToList[i].ToString().IndexOf("profName") < 0)
			{
				continue;
			}
			string s = retHtmlToList[i + 3].ToString();
			string text = retHtmlToList[i].ToString();
			char c = '"';
			string text2 = "";
			int num = text.IndexOf("value=\"");
			if (num >= 0)
			{
				for (int j = num + 7; j < text.Length; j++)
				{
					char c2 = text[j];
					if (c == c2)
					{
						break;
					}
					text2 += text[j];
				}
			}
			string text3 = "";
			if (!string.IsNullOrEmpty(text2))
			{
				if (primaxUnicode)
				{
					text3 = convFromUnicode(text2);
				}
				else
				{
					string[] array = text2.Split(new char[1] { '%' });
					for (int k = 1; k < array.Length; k++)
					{
						int num2 = Convert.ToInt32(array[k], 16);
						string @string = sjisEnc.GetString(new byte[1] { (byte)num2 });
						text3 += @string;
					}
				}
			}
			OneTouchKeyInfo oneTouchKeyInfo2 = new OneTouchKeyInfo();
			oneTouchKeyInfo2.no = int.Parse(s);
			oneTouchKeyInfo2.name = text3;
			oneTouchKeyInfo.Add(oneTouchKeyInfo2);
		}
		return oneTouchKeyInfo;
	}

	private string convFromUnicode(string input)
	{
		string text = input;
		string pattern = "&#x(?<head>[0-9A-Fa-f]{2})(?<tail>[0-9A-Fa-f]{2});";
		string pattern2 = "&#x(?<head>[0-9A-Fa-f]{2});";
		Regex regex = new Regex("%U(?<head>[0-9A-Fa-f]{2})(?<tail>[0-9A-Fa-f]{2})");
		Regex regex2 = new Regex(pattern);
		Regex regex3 = new Regex(pattern2);
		Match match = regex.Match(text);
		Match match2 = regex2.Match(text);
		Match match3 = regex3.Match(text);
		if (!match.Success && !match2.Success && !match3.Success)
		{
			return text;
		}
		while (match.Success || match2.Success || match3.Success)
		{
			string empty = string.Empty;
			Match match4;
			if (match.Success)
			{
				match4 = match;
				byte[] bytes = new byte[2]
				{
					Convert.ToByte(match4.Groups["tail"].Value, 16),
					Convert.ToByte(match4.Groups["head"].Value, 16)
				};
				empty = new UnicodeEncoding().GetString(bytes);
			}
			else if (match2.Success)
			{
				match4 = match2;
				byte[] bytes = new byte[2]
				{
					Convert.ToByte(match4.Groups["tail"].Value, 16),
					Convert.ToByte(match4.Groups["head"].Value, 16)
				};
				empty = new UnicodeEncoding().GetString(bytes);
			}
			else
			{
				match4 = match3;
				byte[] bytes = new byte[1] { Convert.ToByte(match3.Groups["head"].Value, 16) };
				string text2 = empty;
				char c = (char)bytes[0];
				empty = text2 + c;
			}
			text = text.Replace(match4.Value, empty);
			match = regex.Match(text);
			match2 = regex2.Match(text);
			match3 = regex3.Match(text);
		}
		return text;
	}

	public string convToUnicode(string input_string)
	{
		Encoding bigEndianUnicode = Encoding.BigEndianUnicode;
		Encoding encoding = Encoding.GetEncoding("Shift_JIS");
		string text = string.Empty;
		try
		{
			byte[] bytes = Encoding.GetEncoding("shift_jis").GetBytes(input_string);
			byte[] array = Encoding.Convert(encoding, bigEndianUnicode, bytes);
			int num = 0;
			for (num = 0; num < array.Length; num++)
			{
				if (num % 2 == 0)
				{
					text += "%U";
				}
				text = ((array[num] != 0) ? (text + BitConverter.ToString(array, num, 1)) : (text + "00"));
			}
		}
		catch (Exception)
		{
			text = null;
		}
		return text;
	}

	public bool checkDestNameChar(string text)
	{
		bool result = true;
		for (int i = 0; i < text.Length; i++)
		{
			string text2 = text.Substring(i, 1);
			if (Encoding.GetEncoding("shift_jis").GetByteCount(text2) != 1)
			{
				return result;
			}
			for (int j = 0; j < ngCharListForDestName.Count; j++)
			{
				if (text2.Equals(ngCharListForDestName[j]))
				{
					result = false;
					break;
				}
			}
		}
		return result;
	}

	public bool checkDestNameCharUnicode(string text)
	{
		return !new Regex("[”’～、。￥「」‘]").IsMatch(text);
	}

	public async Task<Hashtable> GetMFPSMBInfo(SettingItemsSetupAddress info)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		protocol = (info.httpsFlg ? "https" : "http");
		try
		{
			MACHINE_CONTROL_RESULT mACHINE_CONTROL_RESULT = await executeWimConnect(info, null, null, 6);
			if (mACHINE_CONTROL_RESULT != 0)
			{
				LOG.InfoFormat("MFP:SMBv2v3設定確認前初回接続&ログイン失敗:{0}", (object)mACHINE_CONTROL_RESULT);
				LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
				return null;
			}
			Hashtable mfpSettings = new Hashtable();
			updateProgressBar(Resources.TXT_MACHINE_MESSAGE_01);
			string text = string.Format(URI_FORMAT_ENTRYSMBGET, protocol, info.host, machineLang);
			Console.WriteLine("{0}：WIM SMB画面を取得 リクエスト:" + text, MethodBase.GetCurrentMethod().DeclaringType.Name);
			HttpResponseMessage httpResponseMessage = await client.GetAsync(text);
			LOG.DebugFormat("{0}：response4 = {1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)httpResponseMessage.Content.ReadAsStringAsync().Result);
			string result = httpResponseMessage.Content.ReadAsStringAsync().Result;
			string key = "name=\"smb\" value=\"";
			mfpSettings.Add(FormMFPInfo.KEY.SMBENABLE, getHTMLKeyValueRadioButton(result, key));
			key = "name=\"smbPortNo\" value=\"";
			mfpSettings.Add(FormMFPInfo.KEY.SMBPORT, getHTMLKeyValueRadioButton(result, key));
			key = "name=\"smbv2v3\" value=\"";
			string hTMLKeyValueRadioButton = getHTMLKeyValueRadioButton(result, key);
			key = "name=\"smbAuthLevel\"";
			string hTMLKeyValueListBox = getHTMLKeyValueListBox(result, key);
			bool flag = false;
			key = "name=\"nbns\" value=\"";
			string hTMLKeyValueRadioButton2 = getHTMLKeyValueRadioButton(result, key);
			key = "name=\"nbnsTimeout\" value=\"";
			string hTMLKeyValue = getHTMLKeyValue(result, key);
			bool flag2 = false;
			key = "name=\"smbv3FuncExpansion\" value=\"";
			getHTMLKeyValueRadioButton(result, key);
			string hTMLKeyValueRadioButton3 = getHTMLKeyValueRadioButton(result, key);
			bool flag3 = false;
			if (!hTMLKeyValueRadioButton2.Equals(""))
			{
				flag2 = true;
			}
			if (hTMLKeyValueRadioButton.Equals("") && !hTMLKeyValueListBox.Equals(""))
			{
				flag = true;
			}
			if (!hTMLKeyValueRadioButton3.Equals(""))
			{
				flag3 = true;
			}
			if (flag)
			{
				mfpSettings.Add(FormMFPInfo.KEY.SMBVERSION, "true");
				mfpSettings.Add(FormMFPInfo.KEY.SMBAUTHLEVEL, hTMLKeyValueListBox);
			}
			else
			{
				mfpSettings.Add(FormMFPInfo.KEY.SMBVERSION, hTMLKeyValueRadioButton);
			}
			if (flag2)
			{
				mfpSettings.Add(FormMFPInfo.KEY.NBNS, hTMLKeyValueRadioButton2);
				mfpSettings.Add(FormMFPInfo.KEY.NBNSTIMEOUT, hTMLKeyValue);
			}
			if (flag3)
			{
				mfpSettings.Add(FormMFPInfo.KEY.SMBV3FUNC, hTMLKeyValueRadioButton3);
			}
			LOG.DebugFormat("mfpSettingsResult:{0}：", (object)mfpSettings.ToString());
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
			return mfpSettings;
		}
		catch (HttpRequestException ex)
		{
			Console.WriteLine("\n例外発生!");
			for (Exception ex2 = ex; ex2 != null; ex2 = ex2.InnerException)
			{
				Console.WriteLine("例外メッセージ: {0} ", ex2.Message);
			}
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
			throw;
		}
		catch (TaskCanceledException ex3)
		{
			Console.WriteLine("\nタイムアウト!");
			Console.WriteLine("例外メッセージ: {0} ", ex3.Message);
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
			throw;
		}
		catch (ArgumentException ex4)
		{
			Console.WriteLine("例外メッセージ: {0} ", ex4.Message);
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
			throw;
		}
		catch (Exception ex5)
		{
			Console.WriteLine(ex5.ToString());
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
			throw;
		}
		finally
		{
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		}
	}

	public async Task<string> executeSetupSMB(SettingItemsSetupAddress info, bool enable)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		protocol = (info.httpsFlg ? "https" : "http");
		try
		{
			MACHINE_CONTROL_RESULT mACHINE_CONTROL_RESULT = await executeWimConnect(info, null, null, 6);
			if (mACHINE_CONTROL_RESULT != 0)
			{
				LOG.DebugFormat("WimconnectFail：{0}", (object)mACHINE_CONTROL_RESULT);
				LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
				return null;
			}
			updateProgressBar(Resources.TXT_MACHINE_MESSAGE_01);
			string text = string.Format(URI_FORMAT_ENTRYSMBGET, protocol, info.host, machineLang);
			Console.WriteLine("{0}：WIM SMB画面を取得 リクエスト:" + text, MethodBase.GetCurrentMethod().DeclaringType.Name);
			HttpResponseMessage httpResponseMessage = await client.GetAsync(text);
			LOG.DebugFormat("{0}：response4 = {1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)httpResponseMessage.Content.ReadAsStringAsync().Result);
			Uri uri = new Uri(baseAddressStr);
			foreach (string item in httpResponseMessage.Headers.GetValues("Set-Cookie").ToList())
			{
				if (item.ToString().IndexOf("risessionid") != -1)
				{
					cookieContainer.Add(uri, new Cookie("risessionid", item.Split('=', ';')[1], "/"));
					break;
				}
			}
			string result = httpResponseMessage.Content.ReadAsStringAsync().Result;
			LOG.DebugFormat("GetSMBParam:{0}", (object)result);
			string key = "name=\"wimToken\" value=\"";
			string hTMLKeyValue = getHTMLKeyValue(result, key);
			key = "name=\"accessConf\" value=\"";
			string hTMLKeyValue2 = getHTMLKeyValue(result, key);
			key = "name=\"smb\" value=\"";
			string hTMLKeyValueRadioButton = getHTMLKeyValueRadioButton(result, key);
			key = "name=\"workgroupName\" value=\"";
			string hTMLKeyValue3 = getHTMLKeyValue(result, key);
			key = "name=\"computerName\" value=\"";
			string hTMLKeyValue4 = getHTMLKeyValue(result, key);
			key = "name=\"comment\" value=\"";
			string hTMLKeyValue5 = getHTMLKeyValue(result, key);
			key = "name=\"smbPortNo\" value=\"";
			string hTMLKeyValueRadioButton2 = getHTMLKeyValueRadioButton(result, key);
			string text2 = (enable ? "true" : "false");
			key = "name=\"nbns\" value=\"";
			string hTMLKeyValueRadioButton3 = getHTMLKeyValueRadioButton(result, key);
			key = "name=\"nbnsTimeout\" value=\"";
			string hTMLKeyValue6 = getHTMLKeyValue(result, key);
			key = "name=\"smbAuthLevel\"";
			string hTMLKeyValueListBox = getHTMLKeyValueListBox(result, key);
			key = "name=\"smbv3FuncExpansion\" value=\"";
			string hTMLKeyValueRadioButton4 = getHTMLKeyValueRadioButton(result, key);
			Dictionary<string, string> dictionary = new Dictionary<string, string>
			{
				{ "wimToken", hTMLKeyValue },
				{ "accessConf", hTMLKeyValue2 },
				{ "smb", hTMLKeyValueRadioButton },
				{ "workgroupName", hTMLKeyValue3 },
				{ "computerName", hTMLKeyValue4 },
				{ "comment", hTMLKeyValue5 },
				{ "smbPortNo", hTMLKeyValueRadioButton2 },
				{ "smbv2v3", text2 }
			};
			if (!hTMLKeyValueRadioButton3.Equals(""))
			{
				dictionary.Add("nbns", hTMLKeyValueRadioButton3);
			}
			if (!hTMLKeyValue6.Equals(""))
			{
				dictionary.Add("nbnsTimeout", hTMLKeyValue6);
			}
			if (!hTMLKeyValueListBox.Equals(""))
			{
				dictionary.Add("smbAuthLevel", hTMLKeyValueListBox);
			}
			if (!hTMLKeyValueRadioButton4.Equals("") && text2.Equals("true"))
			{
				dictionary.Add("smbv3FuncExpansion", hTMLKeyValueRadioButton4);
			}
			string text3 = string.Format(URI_FORMAT_POSTSMB, protocol, info.host, machineLang);
			LOG.DebugFormat("posturl:{0}", (object)text3);
			httpResponseMessage = await postAsync("SMB情報更新!", client, text3, dictionary);
			string result2 = httpResponseMessage.Content.ReadAsStringAsync().Result;
			LOG.DebugFormat("postResponse:{0}", (object)result2);
			if (!"OK".Equals(httpResponseMessage.StatusCode.ToString()))
			{
				LOG.DebugFormat("{0}：end {1} StatusCode:{2}", (object)MethodBase.GetCurrentMethod().Name, (object)"error", (object)httpResponseMessage.StatusCode);
			}
			else
			{
				LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
			}
			return result2;
		}
		catch (WebException ex)
		{
			if (ex.Status == WebExceptionStatus.ProtocolError)
			{
				HttpWebResponse httpWebResponse = (HttpWebResponse)ex.Response;
				LOG.ErrorFormat("Uri:{0} HttpStatusCode:{1} Description{2}", (object)httpWebResponse.ResponseUri, (object)httpWebResponse.StatusCode, (object)httpWebResponse.StatusDescription);
			}
			LOG.Error((object)ex.Message);
		}
		catch (TaskCanceledException ex2)
		{
			Console.WriteLine("\nタイムアウト!");
			Console.WriteLine("例外メッセージ: {0} ", ex2.Message);
			throw;
		}
		catch (ArgumentException ex3)
		{
			Console.WriteLine("例外メッセージ: {0} ", ex3.Message);
			throw;
		}
		catch (Exception ex4)
		{
			Console.WriteLine(ex4.ToString());
			throw;
		}
		finally
		{
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		}
		return "";
	}

	private string getHTMLKeyValue(string rethtml, string key)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		int num = rethtml.IndexOf(key) + key.Length;
		if (num < key.Length)
		{
			return "";
		}
		int num2 = rethtml.IndexOf("\"", num);
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return rethtml.Substring(num, num2 - num);
	}

	private string getHTMLKeyValueRadioButton(string rethtml, string key)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		int num = rethtml.IndexOf(key) + key.Length;
		if (num < key.Length)
		{
			return "";
		}
		int startIndex = rethtml.IndexOf("checked", num);
		int num2 = rethtml.LastIndexOf(key, startIndex) + key.Length;
		int num3 = rethtml.IndexOf("\"", num2);
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return rethtml.Substring(num2, num3 - num2);
	}

	private string getHTMLKeyValueListBox(string rethtml, string key)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		int num = rethtml.IndexOf(key) + key.Length;
		if (num < key.Length)
		{
			return "";
		}
		int startIndex = rethtml.IndexOf("selected", num);
		string text = "option value=\"";
		int num2 = rethtml.LastIndexOf(text, startIndex) + text.Length;
		int num3 = rethtml.IndexOf("\"", num2);
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return rethtml.Substring(num2, num3 - num2);
	}

	public async Task<bool> checkUserAdminPermission(SettingItemsSetupAddress info)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		bool ret = false;
		try
		{
			MACHINE_CONTROL_RESULT mACHINE_CONTROL_RESULT = await executeWimConnect(info, null, null, 6);
			if (mACHINE_CONTROL_RESULT != 0)
			{
				LOG.InfoFormat("MFP:ユーザー管理者権限確認前初回接続&ログイン失敗:{0}", (object)mACHINE_CONTROL_RESULT);
				LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
				return ret;
			}
			string text = string.Format(URI_FORMAT_ADDR_LIST, baseAddressStr, machineLang);
			text += URI_FORMAT_ADDR_LIST_MODEIN_LIST;
			HttpResponseMessage httpResponseMessage = await getAsync("ユーザー権限確認のHTML取得", client, text);
			string result = httpResponseMessage.Content.ReadAsStringAsync().Result;
			string lOGIN_USER_PERMISSION_CHECK = Resources.LOGIN_USER_PERMISSION_CHECK;
			if (result.IndexOf(lOGIN_USER_PERMISSION_CHECK) > 0)
			{
				LOG.DebugFormat("ユーザー管理者権限なし", new object[0]);
				MessageBox.Show(Resources.MSG_USER_PERMISSTION_ERROR, Resources.CONFIRM, (MessageBoxButtons)0, (MessageBoxIcon)0);
			}
			else
			{
				ret = true;
				LOG.DebugFormat("ユーザー管理者権限あり", new object[0]);
			}
			Uri uri = new Uri(baseAddressStr);
			foreach (string item in httpResponseMessage.Headers.GetValues("Set-Cookie").ToList())
			{
				if (item.ToString().IndexOf("risessionid") != -1)
				{
					cookieContainer.Add(uri, new Cookie("risessionid", item.Split('=', ';')[1], "/"));
					break;
				}
			}
		}
		catch (TaskCanceledException ex)
		{
			Console.WriteLine("\nタイムアウト!");
			Console.WriteLine("例外メッセージ: {0} ", ex.Message);
			throw;
		}
		catch (ArgumentException ex2)
		{
			Console.WriteLine("例外メッセージ: {0} ", ex2.Message);
			throw;
		}
		catch (Exception ex3)
		{
			Console.WriteLine(ex3.ToString());
			throw;
		}
		finally
		{
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		}
		return ret;
	}

	public async Task<bool> checkMachineAdminPermission(SettingItemsSetupAddress info)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		bool ret = false;
		try
		{
			MACHINE_CONTROL_RESULT mACHINE_CONTROL_RESULT = await executeWimConnect(info, null, null, 6);
			if (mACHINE_CONTROL_RESULT != 0)
			{
				LOG.InfoFormat("MFP:機器管理者権限確認前初回接続&ログイン失敗:{0}", (object)mACHINE_CONTROL_RESULT);
				LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
				return ret;
			}
			string text = string.Format(URI_FORMAT_ENTRYSMBGET, protocol, info.host, machineLang);
			Console.WriteLine("{0}：WIM SMB画面を取得 リクエスト:" + text, MethodBase.GetCurrentMethod().DeclaringType.Name);
			HttpResponseMessage httpResponseMessage = await client.GetAsync(text);
			LOG.DebugFormat("{0}：response4 = {1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)httpResponseMessage.Content.ReadAsStringAsync().Result);
			string result = httpResponseMessage.Content.ReadAsStringAsync().Result;
			string value = "<input type=\"radio\"";
			if (result.IndexOf(value) > 0)
			{
				ret = true;
				LOG.DebugFormat("機器管理者権限あり", new object[0]);
			}
			else
			{
				MessageBox.Show(Resources.MSG_NETWORK_PERMISSION_ERROR, Resources.CONFIRM, (MessageBoxButtons)0, (MessageBoxIcon)0);
				LOG.DebugFormat("機器管理者権限なし", new object[0]);
			}
			Uri uri = new Uri(baseAddressStr);
			foreach (string item in httpResponseMessage.Headers.GetValues("Set-Cookie").ToList())
			{
				if (item.ToString().IndexOf("risessionid") != -1)
				{
					cookieContainer.Add(uri, new Cookie("risessionid", item.Split('=', ';')[1], "/"));
					break;
				}
			}
		}
		catch (TaskCanceledException ex)
		{
			Console.WriteLine("\nタイムアウト!");
			Console.WriteLine("例外メッセージ: {0} ", ex.Message);
			throw;
		}
		catch (ArgumentException ex2)
		{
			Console.WriteLine("例外メッセージ: {0} ", ex2.Message);
			throw;
		}
		catch (Exception ex3)
		{
			Console.WriteLine(ex3.ToString());
			throw;
		}
		finally
		{
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		}
		return ret;
	}

	public void retryLoginState(string host, string loginUser)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		if (adminAccounts.ContainsKey(host))
		{
			if (adminAccounts[host].passwd.Equals(""))
			{
				adminAccounts[host].passwd = "hogehoe";
			}
			else
			{
				adminAccounts[host].passwd = "";
			}
		}
		else
		{
			Account account = new Account();
			account.adminName = loginUser;
			account.passwd = "hogehoe";
			adminAccounts.Add(host, account);
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}
}
