using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Net;
using System.Reflection;
using System.Threading.Tasks;
using System.Windows.Forms;
using CreateFolder.Properties;
using log4net;

namespace CreateFolder;

public class MachineSelectControl : UserControl
{
	public enum ADDRESS_FORM
	{
		IP,
		NAME
	}

	private delegate void SetMachineListDelegate(List<string> machineInfoList);

	private static readonly ILog LOG = LogManager.GetLogger(MethodBase.GetCurrentMethod().DeclaringType);

	private string hostName = string.Empty;

	private static readonly int IPAddressMax = 255;

	private static readonly string IPAddressMaxStr = "255";

	private List<TextBox> textBoxes;

	private int listViewSelectedIndex = -1;

	private readonly int LISTVIEW_NUM_COLUMNS = 2;

	private string machineLang = string.Empty;

	private IContainer components;

	private Label labelMFP_Found;

	private Label labelMFP_Info;

	private Button buttonMachineInfoUpdate;

	private LinkLabel linkLabelIP;

	private Button buttonSeach;

	private TextBox textBox4;

	private TextBox textBox3;

	private TextBox textBox2;

	private TextBox textBox1;

	private Label label4;

	private Label label3;

	private Label label2;

	private RadioButton radioButtonIPAddress;

	private ListView listViewMFPList;

	private RadioButton radioButtonMFPSelect;

	[Browsable(true)]
	public event ControlEnableEventHandler SearchButtonClicked;

	public MachineSelectControl(string lang)
	{
		//IL_0059: Unknown result type (might be due to invalid IL or missing references)
		//IL_005f: Expected O, but got Unknown
		//IL_00ad: Unknown result type (might be due to invalid IL or missing references)
		//IL_00b3: Expected O, but got Unknown
		if (lang.Equals("ja") || lang.Equals("en"))
		{
			InitializeComponent();
		}
		else
		{
			InitializeComponent_MultiLang();
		}
		machineLang = lang;
		ColumnHeader val = new ColumnHeader();
		val.Text = Resources.ITEM_MACHINE_NAME;
		val.TextAlign = (HorizontalAlignment)0;
		if (machineLang.Equals("ja") || machineLang.Equals("en"))
		{
			val.Width = 218;
		}
		else
		{
			val.Width = 248;
		}
		ColumnHeader val2 = new ColumnHeader();
		val2.Text = Resources.TXT_MACHINE_INFO_03_13;
		val2.TextAlign = (HorizontalAlignment)0;
		if (machineLang.Equals("ja") || machineLang.Equals("en"))
		{
			val2.Width = 196;
		}
		else
		{
			val2.Width = 216;
		}
		listViewMFPList.Columns.Add(val);
		listViewMFPList.Columns.Add(val2);
		((Control)linkLabelIP).Text = Resources.FIND_IP_ADDRESS_LINK;
		((Control)labelMFP_Info).Text = Resources.TXT_SELECT_MACHINE_INFO_03;
		((Control)radioButtonMFPSelect).Text = Resources.TXT_SELECT_MACHINE_INFO_01;
		((Control)radioButtonIPAddress).Text = Resources.TXT_SELECT_MACHINE_INFO_02;
		((Control)buttonMachineInfoUpdate).Text = Resources.ITEM_BUTTON_UPDATE_LIST;
		((Control)buttonSeach).Text = Resources.ITEM_BUTTON_SEARCH;
		textBoxes = new List<TextBox>();
		textBoxes.Add(textBox1);
		textBoxes.Add(textBox2);
		textBoxes.Add(textBox3);
		textBoxes.Add(textBox4);
	}

	public void initialize()
	{
		radioButtonMFPSelect.Checked = true;
		listViewMFPList.SelectedItems.Clear();
		listViewMFPList.Items.Clear();
		listViewSelectedIndex = -1;
	}

	public void setMachineList(List<string> machineInfoList)
	{
		//IL_0091: Unknown result type (might be due to invalid IL or missing references)
		//IL_009b: Expected O, but got Unknown
		if (((Control)this).InvokeRequired)
		{
			((Control)this).Invoke((Delegate)new SetMachineListDelegate(setMachineList), new object[1] { machineInfoList });
			return;
		}
		string[] array = new string[2];
		_ = string.Empty;
		listViewMFPList.Items.Clear();
		foreach (string machineInfo in machineInfoList)
		{
			string[] array2 = machineInfo.TrimStart(new char[1] { ' ' }).Split('(', ')');
			array[0] = array2[0];
			array[1] = array2[1];
			listViewMFPList.Items.Add(new ListViewItem(array));
		}
	}

	private string getInputIPAddress(bool magOn = true)
	{
		//IL_0125: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		int[] array = new int[4];
		bool flag = true;
		string text = string.Empty;
		string[] array2 = new string[4]
		{
			((Control)textBox1).Text,
			((Control)textBox2).Text,
			((Control)textBox3).Text,
			((Control)textBox4).Text
		};
		for (int i = 0; i < array.Length; i++)
		{
			if (!int.TryParse(array2[i], out array[i]))
			{
				flag = false;
				LOG.DebugFormat("{0}：format error octet{1}: {2}", (object)MethodBase.GetCurrentMethod().Name, (object)i, (object)array[i]);
			}
		}
		if (flag)
		{
			IPAddress address = null;
			text = $"{array[0]}.{array[1]}.{array[2]}.{array[3]}";
			flag = IPAddress.TryParse(text, out address);
		}
		if (!flag)
		{
			if (magOn)
			{
				MessageBox.Show(Resources.ERR_SET_ILLEGAL_FORMAT_1_2 + "\n" + Resources.ERR_SET_ILLEGAL_FORMAT_2_2, Resources.ERR_SET_ILLEGAL_FORMAT_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
				LOG.DebugFormat("{0}：format error tempIpAddr: {1} : {2}.{3}.{4}.{5}", new object[6]
				{
					MethodBase.GetCurrentMethod().Name,
					text,
					array2[0],
					array2[1],
					array2[2],
					array2[3]
				});
			}
			text = string.Empty;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return text;
	}

	public Dictionary<ADDRESS_FORM, string> getSelectedAddress(bool msgOn = true)
	{
		Dictionary<ADDRESS_FORM, string> dictionary = new Dictionary<ADDRESS_FORM, string>();
		string text = string.Empty;
		string empty = string.Empty;
		if (radioButtonIPAddress.Checked)
		{
			text = getInputIPAddress(msgOn);
			if (!string.IsNullOrEmpty(text) && !string.IsNullOrEmpty(hostName))
			{
				empty = $"{hostName} ({text})";
				dictionary.Add(ADDRESS_FORM.NAME, empty);
			}
		}
		else if (listViewMFPList.SelectedItems.Count > 0)
		{
			ListViewSubItemCollection subItems = listViewMFPList.SelectedItems[0].SubItems;
			text = subItems[1].Text;
			empty = $"{subItems[0].Text} ({text})";
			dictionary.Add(ADDRESS_FORM.NAME, empty);
		}
		dictionary.Add(ADDRESS_FORM.IP, text);
		return dictionary;
	}

	public void setBackDisplayName(string displayName)
	{
		if (radioButtonIPAddress.Checked && string.IsNullOrEmpty(((Control)labelMFP_Found).Text))
		{
			((Control)labelMFP_Found).Text = displayName;
		}
	}

	private void textBox_KeyPress(object sender, KeyPressEventArgs e)
	{
		//IL_0013: Unknown result type (might be due to invalid IL or missing references)
		//IL_001e: Expected O, but got Unknown
		if (e.KeyChar == '.')
		{
			e.Handled = true;
			TextBox val = nextTextBox((TextBox)sender, direction: true);
			if (val != null)
			{
				((Control)val).Focus();
			}
			else
			{
				((Control)buttonSeach).Focus();
			}
		}
		if ((e.KeyChar < '0' || '9' < e.KeyChar) && e.KeyChar != '\b')
		{
			e.Handled = true;
		}
	}

	private void textBox_KeyDown(object sender, KeyEventArgs e)
	{
		//IL_0001: Unknown result type (might be due to invalid IL or missing references)
		//IL_0007: Expected O, but got Unknown
		//IL_001b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0022: Invalid comparison between Unknown and I4
		//IL_004a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0051: Invalid comparison between Unknown and I4
		TextBox val = (TextBox)sender;
		int selectionStart = ((TextBoxBase)val).SelectionStart;
		int length = ((Control)val).Text.Length;
		if ((int)e.KeyData == 39 && selectionStart == length)
		{
			TextBox val2 = nextTextBox(val, direction: true);
			if (val2 != null)
			{
				((Control)val2).Focus();
			}
			else
			{
				((Control)buttonSeach).Focus();
			}
		}
		if ((int)e.KeyData == 37 && selectionStart == 0)
		{
			TextBox val3 = nextTextBox(val, direction: false);
			if (val3 != null)
			{
				((Control)val3).Focus();
			}
		}
	}

	private void textBox_TextChanged(object sender, EventArgs e)
	{
		//IL_001c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0022: Expected O, but got Unknown
		((Control)labelMFP_Found).Text = string.Empty;
		hostName = string.Empty;
		TextBox val = (TextBox)sender;
		if (((Control)val).Text.Length < 3)
		{
			return;
		}
		try
		{
			if (int.Parse(((Control)val).Text) > IPAddressMax)
			{
				((Control)val).Text = IPAddressMaxStr;
			}
		}
		catch (Exception ex)
		{
			LOG.DebugFormat("{0}：Exception {1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)ex.ToString());
			((Control)val).Text = IPAddressMaxStr;
		}
		TextBox val2 = nextTextBox(val, direction: true);
		if (val2 != null)
		{
			((Control)val2).Focus();
		}
		else
		{
			((Control)buttonSeach).Focus();
		}
	}

	private TextBox nextTextBox(TextBox currentTextBox, bool direction)
	{
		TextBox result = null;
		int num = textBoxes.IndexOf(currentTextBox);
		if (num >= 0)
		{
			int num2 = (direction ? (num + 1) : (num - 1));
			if (num2 >= 0 && num2 < textBoxes.Count)
			{
				result = textBoxes[num2];
			}
		}
		return result;
	}

	private void radioButtonMFPSelect_CheckedChanged(object sender, EventArgs e)
	{
		bool @checked = radioButtonMFPSelect.Checked;
		((Control)listViewMFPList).Enabled = @checked;
		((Control)buttonMachineInfoUpdate).Enabled = @checked;
		((Control)textBox1).Enabled = !@checked;
		((Control)textBox2).Enabled = !@checked;
		((Control)textBox3).Enabled = !@checked;
		((Control)textBox4).Enabled = !@checked;
		((Control)label2).Enabled = !@checked;
		((Control)label3).Enabled = !@checked;
		((Control)label4).Enabled = !@checked;
		((Control)buttonSeach).Enabled = !@checked;
		((Control)linkLabelIP).Enabled = !@checked;
		((Control)linkLabelIP).Visible = !@checked;
		((Control)labelMFP_Info).Enabled = !@checked;
		((Control)labelMFP_Info).Visible = !@checked;
		((Control)labelMFP_Found).Enabled = !@checked;
		((Control)labelMFP_Found).Visible = !@checked;
		if (@checked)
		{
			if (listViewSelectedIndex >= 0)
			{
				listViewMFPList.Items[listViewSelectedIndex].Selected = true;
				((Control)listViewMFPList).Focus();
			}
			return;
		}
		if (listViewMFPList.SelectedItems.Count > 0)
		{
			listViewSelectedIndex = listViewMFPList.SelectedItems[0].Index;
			listViewMFPList.SelectedItems.Clear();
		}
		((Control)textBox1).Focus();
	}

	private void buttonSearch_Click(object sender, EventArgs e)
	{
		LOG.DebugFormat("{0} start", (object)MethodBase.GetCurrentMethod().Name);
		((Control)buttonSeach).Enabled = false;
		((Control)textBox4).Enabled = false;
		((Control)textBox3).Enabled = false;
		((Control)textBox2).Enabled = false;
		((Control)textBox1).Enabled = false;
		((Control)radioButtonIPAddress).Enabled = false;
		((Control)radioButtonMFPSelect).Enabled = false;
		((Control)labelMFP_Found).Text = string.Empty;
		try
		{
			Task.Factory.StartNew(delegate
			{
				SearchMachineByIPAddress();
			});
		}
		catch (Exception ex)
		{
			LOG.ErrorFormat("{0}：{1}", (object)MethodBase.GetCurrentMethod().Name, (object)ex);
		}
		LOG.DebugFormat("{0} end", (object)MethodBase.GetCurrentMethod().Name);
	}

	private void SearchMachineByIPAddress()
	{
		//IL_00e8: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		ControlEnableFlag controlEnableFlag = new ControlEnableFlag();
		try
		{
			LOG.DebugFormat("{0} start", (object)MethodBase.GetCurrentMethod().Name);
			((Control)this).Invoke((Delegate)(Action)delegate
			{
				((Control)labelMFP_Found).Text = string.Empty;
				((Control)this).Cursor = Cursors.WaitCursor;
			});
			controlEnableFlag.flag = false;
			this.SearchButtonClicked?.Invoke(this, controlEnableFlag);
			string ipAddrStr = getInputIPAddress();
			if (!string.IsNullOrEmpty(ipAddrStr))
			{
				Task task = Task.Factory.StartNew(delegate
				{
					hostName = GetHostName(ipAddrStr);
				});
				task.Wait();
				while (task.Status != TaskStatus.RanToCompletion)
				{
				}
				string labelMFP = string.Empty;
				if (string.IsNullOrWhiteSpace(hostName))
				{
					labelMFP = ipAddrStr;
					MessageBox.Show(Resources.ERR_MSG_FIND_MACHINE, Resources.ERR_SET_ILLEGAL_FORMAT_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
					LOG.DebugFormat("{0}：Cannot find host name.: {1}", (object)MethodBase.GetCurrentMethod().Name, (object)ipAddrStr);
				}
				else
				{
					labelMFP = $"{hostName} ({ipAddrStr})";
				}
				((Control)this).Invoke((Delegate)(Action)delegate
				{
					((Control)labelMFP_Found).Text = labelMFP;
				});
			}
		}
		catch (Exception ex)
		{
			LOG.ErrorFormat("{0}：{1}", (object)MethodBase.GetCurrentMethod().Name, (object)ex);
		}
		finally
		{
			controlEnableFlag.flag = true;
			this.SearchButtonClicked?.Invoke(this, controlEnableFlag);
			((Control)this).Invoke((Delegate)(Action)delegate
			{
				((Control)buttonSeach).Enabled = true;
				((Control)textBox4).Enabled = true;
				((Control)textBox3).Enabled = true;
				((Control)textBox2).Enabled = true;
				((Control)textBox1).Enabled = true;
				((Control)radioButtonIPAddress).Enabled = true;
				((Control)radioButtonMFPSelect).Enabled = true;
				((Control)this).Cursor = Cursors.Default;
			});
			LOG.DebugFormat("{0} end", (object)MethodBase.GetCurrentMethod().Name);
		}
	}

	private string GetHostName(string ipAddress)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		string hostNameFromIP = FormWizard.GetHostNameFromIP(ipAddress);
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return hostNameFromIP;
	}

	private void buttonMachineInfoUpdate_Click(object sender, EventArgs e)
	{
		LOG.DebugFormat("{0} start", (object)MethodBase.GetCurrentMethod().Name);
		listViewMFPList.SelectedItems.Clear();
		listViewMFPList.Items.Clear();
		listViewSelectedIndex = -1;
		((Control)listViewMFPList).Focus();
		((Control)buttonMachineInfoUpdate).Enabled = false;
		((Control)radioButtonIPAddress).Enabled = false;
		((Control)radioButtonMFPSelect).Enabled = false;
		Task.Factory.StartNew(delegate
		{
			SearchMachines();
		});
		LOG.DebugFormat("{0} end", (object)MethodBase.GetCurrentMethod().Name);
	}

	private void SearchMachines()
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		ControlEnableFlag controlEnableFlag = new ControlEnableFlag();
		try
		{
			LOG.DebugFormat("{0} start", (object)MethodBase.GetCurrentMethod().Name);
			((Control)this).Invoke((Delegate)(Action)delegate
			{
				((Control)labelMFP_Found).Text = string.Empty;
				((Control)this).Cursor = Cursors.WaitCursor;
			});
			controlEnableFlag.flag = false;
			this.SearchButtonClicked?.Invoke(this, controlEnableFlag);
			List<string> mFPList = FormWizard.GetMFPList();
			setMachineList(mFPList);
		}
		catch (Exception ex)
		{
			LOG.ErrorFormat("{0}：{1}", (object)MethodBase.GetCurrentMethod().Name, (object)ex);
		}
		finally
		{
			controlEnableFlag.flag = true;
			this.SearchButtonClicked?.Invoke(this, controlEnableFlag);
			((Control)this).Invoke((Delegate)(Action)delegate
			{
				((Control)buttonMachineInfoUpdate).Enabled = true;
				((Control)radioButtonIPAddress).Enabled = true;
				((Control)radioButtonMFPSelect).Enabled = true;
				((Control)this).Cursor = Cursors.Default;
			});
			LOG.DebugFormat("{0} end", (object)MethodBase.GetCurrentMethod().Name);
		}
	}

	private void linkLabelIP_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
	{
		//IL_0025: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：IP設定手順表示リンク押下", (object)MethodBase.GetCurrentMethod().Name);
		FormHelp formHelp = new FormHelp("help\\HelpIPBase.html");
		((Form)formHelp).ShowDialog((IWin32Window)(object)this);
		((Component)(object)formHelp).Dispose();
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	private void listViewMFPList_DrawColumnHeader(object sender, DrawListViewColumnHeaderEventArgs e)
	{
		//IL_003b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0041: Expected O, but got Unknown
		//IL_0051: Unknown result type (might be due to invalid IL or missing references)
		//IL_005b: Unknown result type (might be due to invalid IL or missing references)
		e.DrawBackground();
		if (e.ColumnIndex >= 0 && e.ColumnIndex < LISTVIEW_NUM_COLUMNS)
		{
			Rectangle bounds = e.Bounds;
			e.Graphics.FillRectangle(Brushes.LightSteelBlue, bounds);
			StringFormat val = new StringFormat();
			val.LineAlignment = (StringAlignment)1;
			val.Trimming = (StringTrimming)3;
			val.FormatFlags = (StringFormatFlags)(val.FormatFlags | 0x1000);
			e.Graphics.DrawString(e.Header.Text, ((Control)listViewMFPList).Font, Brushes.Black, (RectangleF)e.Bounds, val);
			bounds.Size -= ((e.ColumnIndex == LISTVIEW_NUM_COLUMNS - 1) ? new Size(1, 1) : new Size(0, 1));
			e.Graphics.DrawRectangle(Pens.Gray, bounds);
		}
		else
		{
			e.DrawDefault = true;
		}
	}

	private void listViewMFPList_DrawItem(object sender, DrawListViewItemEventArgs e)
	{
		e.DrawDefault = true;
	}

	protected override void Dispose(bool disposing)
	{
		if (disposing && components != null)
		{
			components.Dispose();
		}
		((ContainerControl)this).Dispose(disposing);
	}

	private void InitializeComponent()
	{
		//IL_0001: Unknown result type (might be due to invalid IL or missing references)
		//IL_000b: Expected O, but got Unknown
		//IL_000c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0016: Expected O, but got Unknown
		//IL_0017: Unknown result type (might be due to invalid IL or missing references)
		//IL_0021: Expected O, but got Unknown
		//IL_0022: Unknown result type (might be due to invalid IL or missing references)
		//IL_002c: Expected O, but got Unknown
		//IL_002d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0037: Expected O, but got Unknown
		//IL_0038: Unknown result type (might be due to invalid IL or missing references)
		//IL_0042: Expected O, but got Unknown
		//IL_0043: Unknown result type (might be due to invalid IL or missing references)
		//IL_004d: Expected O, but got Unknown
		//IL_004e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0058: Expected O, but got Unknown
		//IL_0059: Unknown result type (might be due to invalid IL or missing references)
		//IL_0063: Expected O, but got Unknown
		//IL_0064: Unknown result type (might be due to invalid IL or missing references)
		//IL_006e: Expected O, but got Unknown
		//IL_006f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0079: Expected O, but got Unknown
		//IL_007a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0084: Expected O, but got Unknown
		//IL_0085: Unknown result type (might be due to invalid IL or missing references)
		//IL_008f: Expected O, but got Unknown
		//IL_0090: Unknown result type (might be due to invalid IL or missing references)
		//IL_009a: Expected O, but got Unknown
		//IL_009b: Unknown result type (might be due to invalid IL or missing references)
		//IL_00a5: Expected O, but got Unknown
		//IL_0184: Unknown result type (might be due to invalid IL or missing references)
		//IL_018e: Expected O, but got Unknown
		//IL_019b: Unknown result type (might be due to invalid IL or missing references)
		//IL_01a5: Expected O, but got Unknown
		//IL_02a4: Unknown result type (might be due to invalid IL or missing references)
		//IL_02ae: Expected O, but got Unknown
		//IL_035c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0366: Expected O, but got Unknown
		//IL_03d2: Unknown result type (might be due to invalid IL or missing references)
		//IL_03dc: Expected O, but got Unknown
		//IL_0502: Unknown result type (might be due to invalid IL or missing references)
		//IL_050c: Expected O, but got Unknown
		//IL_0519: Unknown result type (might be due to invalid IL or missing references)
		//IL_0523: Expected O, but got Unknown
		//IL_05b3: Unknown result type (might be due to invalid IL or missing references)
		//IL_05bd: Expected O, but got Unknown
		//IL_05ca: Unknown result type (might be due to invalid IL or missing references)
		//IL_05d4: Expected O, but got Unknown
		//IL_0664: Unknown result type (might be due to invalid IL or missing references)
		//IL_066e: Expected O, but got Unknown
		//IL_067b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0685: Expected O, but got Unknown
		//IL_0715: Unknown result type (might be due to invalid IL or missing references)
		//IL_071f: Expected O, but got Unknown
		//IL_072c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0736: Expected O, but got Unknown
		//IL_0753: Unknown result type (might be due to invalid IL or missing references)
		//IL_075d: Expected O, but got Unknown
		//IL_07de: Unknown result type (might be due to invalid IL or missing references)
		//IL_07e8: Expected O, but got Unknown
		//IL_0869: Unknown result type (might be due to invalid IL or missing references)
		//IL_0873: Expected O, but got Unknown
		listViewMFPList = new ListView();
		labelMFP_Found = new Label();
		labelMFP_Info = new Label();
		buttonMachineInfoUpdate = new Button();
		linkLabelIP = new LinkLabel();
		buttonSeach = new Button();
		textBox4 = new TextBox();
		textBox3 = new TextBox();
		textBox2 = new TextBox();
		textBox1 = new TextBox();
		label4 = new Label();
		label3 = new Label();
		label2 = new Label();
		radioButtonIPAddress = new RadioButton();
		radioButtonMFPSelect = new RadioButton();
		((Control)this).SuspendLayout();
		listViewMFPList.AutoArrange = false;
		listViewMFPList.FullRowSelect = true;
		listViewMFPList.GridLines = true;
		listViewMFPList.HeaderStyle = (ColumnHeaderStyle)1;
		listViewMFPList.HideSelection = false;
		((Control)listViewMFPList).Location = new Point(18, 28);
		listViewMFPList.MultiSelect = false;
		((Control)listViewMFPList).Name = "listViewMFPList";
		listViewMFPList.OwnerDraw = true;
		listViewMFPList.ShowGroups = false;
		((Control)listViewMFPList).Size = new Size(418, 82);
		listViewMFPList.Sorting = (SortOrder)1;
		((Control)listViewMFPList).TabIndex = 32;
		listViewMFPList.UseCompatibleStateImageBehavior = false;
		listViewMFPList.View = (View)1;
		listViewMFPList.DrawColumnHeader += new DrawListViewColumnHeaderEventHandler(listViewMFPList_DrawColumnHeader);
		listViewMFPList.DrawItem += new DrawListViewItemEventHandler(listViewMFPList_DrawItem);
		((Control)labelMFP_Found).AutoSize = true;
		((Control)labelMFP_Found).Enabled = false;
		((Control)labelMFP_Found).Location = new Point(107, 207);
		((Control)labelMFP_Found).Name = "labelMFP_Found";
		((Control)labelMFP_Found).Size = new Size(0, 12);
		((Control)labelMFP_Found).TabIndex = 31;
		((Control)labelMFP_Found).Visible = false;
		((Control)labelMFP_Info).AutoSize = true;
		((Control)labelMFP_Info).Enabled = false;
		((Control)labelMFP_Info).Location = new Point(18, 207);
		((Control)labelMFP_Info).Name = "labelMFP_Info";
		((Control)labelMFP_Info).Size = new Size(0, 12);
		((Control)labelMFP_Info).TabIndex = 30;
		((Control)labelMFP_Info).Visible = false;
		((Control)buttonMachineInfoUpdate).Anchor = (AnchorStyles)9;
		((Control)buttonMachineInfoUpdate).AutoSize = true;
		((Control)buttonMachineInfoUpdate).Font = new Font("MS UI Gothic", 9f);
		((ButtonBase)buttonMachineInfoUpdate).ImeMode = (ImeMode)0;
		((Control)buttonMachineInfoUpdate).Location = new Point(322, 2);
		((Control)buttonMachineInfoUpdate).Name = "buttonMachineInfoUpdate";
		((Control)buttonMachineInfoUpdate).Size = new Size(114, 23);
		((Control)buttonMachineInfoUpdate).TabIndex = 20;
		((Control)buttonMachineInfoUpdate).Text = "UpdateList";
		((ButtonBase)buttonMachineInfoUpdate).UseVisualStyleBackColor = true;
		((Control)buttonMachineInfoUpdate).Click += buttonMachineInfoUpdate_Click;
		((Control)linkLabelIP).AutoSize = true;
		((Control)linkLabelIP).Enabled = false;
		((Control)linkLabelIP).Font = new Font("MS UI Gothic", 9f);
		((Label)linkLabelIP).ImeMode = (ImeMode)0;
		((Control)linkLabelIP).Location = new Point(18, 177);
		((Control)linkLabelIP).Name = "linkLabelIP";
		((Control)linkLabelIP).Size = new Size(0, 12);
		((Control)linkLabelIP).TabIndex = 26;
		((Control)linkLabelIP).Visible = false;
		linkLabelIP.LinkClicked += new LinkLabelLinkClickedEventHandler(linkLabelIP_LinkClicked);
		((Control)buttonSeach).AutoSize = true;
		((Control)buttonSeach).Enabled = false;
		((Control)buttonSeach).Location = new Point(163, 144);
		((Control)buttonSeach).Name = "buttonSeach";
		((Control)buttonSeach).Size = new Size(54, 23);
		((Control)buttonSeach).TabIndex = 25;
		((Control)buttonSeach).Text = "Refer";
		((ButtonBase)buttonSeach).UseVisualStyleBackColor = true;
		((Control)buttonSeach).Click += buttonSearch_Click;
		((Control)textBox4).Enabled = false;
		((Control)textBox4).ImeMode = (ImeMode)3;
		((Control)textBox4).Location = new Point(116, 146);
		((Control)textBox4).Name = "textBox4";
		((Control)textBox4).Size = new Size(28, 19);
		((Control)textBox4).TabIndex = 24;
		textBox4.TextAlign = (HorizontalAlignment)1;
		((Control)textBox4).TextChanged += textBox_TextChanged;
		((Control)textBox4).KeyDown += new KeyEventHandler(textBox_KeyDown);
		((Control)textBox4).KeyPress += new KeyPressEventHandler(textBox_KeyPress);
		((Control)textBox3).Enabled = false;
		((Control)textBox3).ImeMode = (ImeMode)3;
		((Control)textBox3).Location = new Point(84, 146);
		((Control)textBox3).Name = "textBox3";
		((Control)textBox3).Size = new Size(28, 19);
		((Control)textBox3).TabIndex = 23;
		textBox3.TextAlign = (HorizontalAlignment)1;
		((Control)textBox3).TextChanged += textBox_TextChanged;
		((Control)textBox3).KeyDown += new KeyEventHandler(textBox_KeyDown);
		((Control)textBox3).KeyPress += new KeyPressEventHandler(textBox_KeyPress);
		((Control)textBox2).Enabled = false;
		((Control)textBox2).ImeMode = (ImeMode)3;
		((Control)textBox2).Location = new Point(52, 146);
		((Control)textBox2).Name = "textBox2";
		((Control)textBox2).Size = new Size(28, 19);
		((Control)textBox2).TabIndex = 22;
		textBox2.TextAlign = (HorizontalAlignment)1;
		((Control)textBox2).TextChanged += textBox_TextChanged;
		((Control)textBox2).KeyDown += new KeyEventHandler(textBox_KeyDown);
		((Control)textBox2).KeyPress += new KeyPressEventHandler(textBox_KeyPress);
		((Control)textBox1).Enabled = false;
		((Control)textBox1).ImeMode = (ImeMode)3;
		((Control)textBox1).Location = new Point(20, 146);
		((Control)textBox1).Name = "textBox1";
		((Control)textBox1).Size = new Size(28, 19);
		((Control)textBox1).TabIndex = 21;
		textBox1.TextAlign = (HorizontalAlignment)1;
		((Control)textBox1).TextChanged += textBox_TextChanged;
		((Control)textBox1).KeyDown += new KeyEventHandler(textBox_KeyDown);
		((Control)textBox1).KeyPress += new KeyPressEventHandler(textBox_KeyPress);
		((Control)label4).AutoSize = true;
		((Control)label4).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		label4.ImeMode = (ImeMode)0;
		((Control)label4).Location = new Point(109, 149);
		((Control)label4).Name = "label4";
		((Control)label4).Size = new Size(12, 16);
		((Control)label4).TabIndex = 29;
		((Control)label4).Text = ".";
		((Control)label3).AutoSize = true;
		((Control)label3).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		label3.ImeMode = (ImeMode)0;
		((Control)label3).Location = new Point(77, 149);
		((Control)label3).Name = "label3";
		((Control)label3).Size = new Size(12, 16);
		((Control)label3).TabIndex = 28;
		((Control)label3).Text = ".";
		((Control)label2).AutoSize = true;
		((Control)label2).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		label2.ImeMode = (ImeMode)0;
		((Control)label2).Location = new Point(45, 149);
		((Control)label2).Name = "label2";
		((Control)label2).Size = new Size(12, 16);
		((Control)label2).TabIndex = 27;
		((Control)label2).Text = ".";
		((Control)radioButtonIPAddress).AutoSize = true;
		((Control)radioButtonIPAddress).Location = new Point(7, 120);
		((Control)radioButtonIPAddress).Name = "radioButtonIPAddress";
		((Control)radioButtonIPAddress).Size = new Size(14, 13);
		((Control)radioButtonIPAddress).TabIndex = 19;
		((ButtonBase)radioButtonIPAddress).UseVisualStyleBackColor = true;
		((Control)radioButtonMFPSelect).AutoSize = true;
		radioButtonMFPSelect.Checked = true;
		((Control)radioButtonMFPSelect).Location = new Point(7, 7);
		((Control)radioButtonMFPSelect).Name = "radioButtonMFPSelect";
		((Control)radioButtonMFPSelect).Size = new Size(14, 13);
		((Control)radioButtonMFPSelect).TabIndex = 18;
		radioButtonMFPSelect.TabStop = true;
		((ButtonBase)radioButtonMFPSelect).UseVisualStyleBackColor = true;
		radioButtonMFPSelect.CheckedChanged += radioButtonMFPSelect_CheckedChanged;
		((ContainerControl)this).AutoScaleMode = (AutoScaleMode)0;
		((Control)this).Controls.Add((Control)(object)listViewMFPList);
		((Control)this).Controls.Add((Control)(object)labelMFP_Found);
		((Control)this).Controls.Add((Control)(object)labelMFP_Info);
		((Control)this).Controls.Add((Control)(object)buttonMachineInfoUpdate);
		((Control)this).Controls.Add((Control)(object)linkLabelIP);
		((Control)this).Controls.Add((Control)(object)buttonSeach);
		((Control)this).Controls.Add((Control)(object)textBox4);
		((Control)this).Controls.Add((Control)(object)textBox3);
		((Control)this).Controls.Add((Control)(object)textBox2);
		((Control)this).Controls.Add((Control)(object)textBox1);
		((Control)this).Controls.Add((Control)(object)label4);
		((Control)this).Controls.Add((Control)(object)label3);
		((Control)this).Controls.Add((Control)(object)label2);
		((Control)this).Controls.Add((Control)(object)radioButtonIPAddress);
		((Control)this).Controls.Add((Control)(object)radioButtonMFPSelect);
		((Control)this).Name = "MachineSelectControl";
		((Control)this).Size = new Size(442, 224);
		((Control)this).ResumeLayout(false);
		((Control)this).PerformLayout();
	}

	private void InitializeComponent_MultiLang()
	{
		//IL_0001: Unknown result type (might be due to invalid IL or missing references)
		//IL_000b: Expected O, but got Unknown
		//IL_000c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0016: Expected O, but got Unknown
		//IL_0017: Unknown result type (might be due to invalid IL or missing references)
		//IL_0021: Expected O, but got Unknown
		//IL_0022: Unknown result type (might be due to invalid IL or missing references)
		//IL_002c: Expected O, but got Unknown
		//IL_002d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0037: Expected O, but got Unknown
		//IL_0038: Unknown result type (might be due to invalid IL or missing references)
		//IL_0042: Expected O, but got Unknown
		//IL_0043: Unknown result type (might be due to invalid IL or missing references)
		//IL_004d: Expected O, but got Unknown
		//IL_004e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0058: Expected O, but got Unknown
		//IL_0059: Unknown result type (might be due to invalid IL or missing references)
		//IL_0063: Expected O, but got Unknown
		//IL_0064: Unknown result type (might be due to invalid IL or missing references)
		//IL_006e: Expected O, but got Unknown
		//IL_006f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0079: Expected O, but got Unknown
		//IL_007a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0084: Expected O, but got Unknown
		//IL_0085: Unknown result type (might be due to invalid IL or missing references)
		//IL_008f: Expected O, but got Unknown
		//IL_0090: Unknown result type (might be due to invalid IL or missing references)
		//IL_009a: Expected O, but got Unknown
		//IL_009b: Unknown result type (might be due to invalid IL or missing references)
		//IL_00a5: Expected O, but got Unknown
		//IL_0184: Unknown result type (might be due to invalid IL or missing references)
		//IL_018e: Expected O, but got Unknown
		//IL_019b: Unknown result type (might be due to invalid IL or missing references)
		//IL_01a5: Expected O, but got Unknown
		//IL_02a4: Unknown result type (might be due to invalid IL or missing references)
		//IL_02ae: Expected O, but got Unknown
		//IL_035c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0366: Expected O, but got Unknown
		//IL_03d2: Unknown result type (might be due to invalid IL or missing references)
		//IL_03dc: Expected O, but got Unknown
		//IL_0502: Unknown result type (might be due to invalid IL or missing references)
		//IL_050c: Expected O, but got Unknown
		//IL_0519: Unknown result type (might be due to invalid IL or missing references)
		//IL_0523: Expected O, but got Unknown
		//IL_05b3: Unknown result type (might be due to invalid IL or missing references)
		//IL_05bd: Expected O, but got Unknown
		//IL_05ca: Unknown result type (might be due to invalid IL or missing references)
		//IL_05d4: Expected O, but got Unknown
		//IL_0664: Unknown result type (might be due to invalid IL or missing references)
		//IL_066e: Expected O, but got Unknown
		//IL_067b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0685: Expected O, but got Unknown
		//IL_0715: Unknown result type (might be due to invalid IL or missing references)
		//IL_071f: Expected O, but got Unknown
		//IL_072c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0736: Expected O, but got Unknown
		//IL_0753: Unknown result type (might be due to invalid IL or missing references)
		//IL_075d: Expected O, but got Unknown
		//IL_07de: Unknown result type (might be due to invalid IL or missing references)
		//IL_07e8: Expected O, but got Unknown
		//IL_0869: Unknown result type (might be due to invalid IL or missing references)
		//IL_0873: Expected O, but got Unknown
		listViewMFPList = new ListView();
		labelMFP_Found = new Label();
		labelMFP_Info = new Label();
		buttonMachineInfoUpdate = new Button();
		linkLabelIP = new LinkLabel();
		buttonSeach = new Button();
		textBox4 = new TextBox();
		textBox3 = new TextBox();
		textBox2 = new TextBox();
		textBox1 = new TextBox();
		label4 = new Label();
		label3 = new Label();
		label2 = new Label();
		radioButtonIPAddress = new RadioButton();
		radioButtonMFPSelect = new RadioButton();
		((Control)this).SuspendLayout();
		listViewMFPList.AutoArrange = false;
		listViewMFPList.FullRowSelect = true;
		listViewMFPList.GridLines = true;
		listViewMFPList.HeaderStyle = (ColumnHeaderStyle)1;
		listViewMFPList.HideSelection = false;
		((Control)listViewMFPList).Location = new Point(18, 28);
		listViewMFPList.MultiSelect = false;
		((Control)listViewMFPList).Name = "listViewMFPList";
		listViewMFPList.OwnerDraw = true;
		listViewMFPList.ShowGroups = false;
		((Control)listViewMFPList).Size = new Size(468, 82);
		listViewMFPList.Sorting = (SortOrder)1;
		((Control)listViewMFPList).TabIndex = 32;
		listViewMFPList.UseCompatibleStateImageBehavior = false;
		listViewMFPList.View = (View)1;
		listViewMFPList.DrawColumnHeader += new DrawListViewColumnHeaderEventHandler(listViewMFPList_DrawColumnHeader);
		listViewMFPList.DrawItem += new DrawListViewItemEventHandler(listViewMFPList_DrawItem);
		((Control)labelMFP_Found).AutoSize = true;
		((Control)labelMFP_Found).Enabled = false;
		((Control)labelMFP_Found).Location = new Point(107, 207);
		((Control)labelMFP_Found).Name = "labelMFP_Found";
		((Control)labelMFP_Found).Size = new Size(0, 12);
		((Control)labelMFP_Found).TabIndex = 31;
		((Control)labelMFP_Found).Visible = false;
		((Control)labelMFP_Info).AutoSize = true;
		((Control)labelMFP_Info).Enabled = false;
		((Control)labelMFP_Info).Location = new Point(18, 207);
		((Control)labelMFP_Info).Name = "labelMFP_Info";
		((Control)labelMFP_Info).Size = new Size(0, 12);
		((Control)labelMFP_Info).TabIndex = 30;
		((Control)labelMFP_Info).Visible = false;
		((Control)buttonMachineInfoUpdate).Anchor = (AnchorStyles)9;
		((Control)buttonMachineInfoUpdate).AutoSize = true;
		((Control)buttonMachineInfoUpdate).Font = new Font("MS UI Gothic", 9f);
		((ButtonBase)buttonMachineInfoUpdate).ImeMode = (ImeMode)0;
		((Control)buttonMachineInfoUpdate).Location = new Point(372, 2);
		((Control)buttonMachineInfoUpdate).Name = "buttonMachineInfoUpdate";
		((Control)buttonMachineInfoUpdate).Size = new Size(114, 23);
		((Control)buttonMachineInfoUpdate).TabIndex = 20;
		((Control)buttonMachineInfoUpdate).Text = "UpdateList";
		((ButtonBase)buttonMachineInfoUpdate).UseVisualStyleBackColor = true;
		((Control)buttonMachineInfoUpdate).Click += buttonMachineInfoUpdate_Click;
		((Control)linkLabelIP).AutoSize = true;
		((Control)linkLabelIP).Enabled = false;
		((Control)linkLabelIP).Font = new Font("MS UI Gothic", 9f);
		((Label)linkLabelIP).ImeMode = (ImeMode)0;
		((Control)linkLabelIP).Location = new Point(18, 177);
		((Control)linkLabelIP).Name = "linkLabelIP";
		((Control)linkLabelIP).Size = new Size(0, 12);
		((Control)linkLabelIP).TabIndex = 26;
		((Control)linkLabelIP).Visible = false;
		linkLabelIP.LinkClicked += new LinkLabelLinkClickedEventHandler(linkLabelIP_LinkClicked);
		((Control)buttonSeach).AutoSize = true;
		((Control)buttonSeach).Enabled = false;
		((Control)buttonSeach).Location = new Point(163, 144);
		((Control)buttonSeach).Name = "buttonSeach";
		((Control)buttonSeach).Size = new Size(54, 23);
		((Control)buttonSeach).TabIndex = 25;
		((Control)buttonSeach).Text = "Refer";
		((ButtonBase)buttonSeach).UseVisualStyleBackColor = true;
		((Control)buttonSeach).Click += buttonSearch_Click;
		((Control)textBox4).Enabled = false;
		((Control)textBox4).ImeMode = (ImeMode)3;
		((Control)textBox4).Location = new Point(116, 146);
		((Control)textBox4).Name = "textBox4";
		((Control)textBox4).Size = new Size(28, 19);
		((Control)textBox4).TabIndex = 24;
		textBox4.TextAlign = (HorizontalAlignment)1;
		((Control)textBox4).TextChanged += textBox_TextChanged;
		((Control)textBox4).KeyDown += new KeyEventHandler(textBox_KeyDown);
		((Control)textBox4).KeyPress += new KeyPressEventHandler(textBox_KeyPress);
		((Control)textBox3).Enabled = false;
		((Control)textBox3).ImeMode = (ImeMode)3;
		((Control)textBox3).Location = new Point(84, 146);
		((Control)textBox3).Name = "textBox3";
		((Control)textBox3).Size = new Size(28, 19);
		((Control)textBox3).TabIndex = 23;
		textBox3.TextAlign = (HorizontalAlignment)1;
		((Control)textBox3).TextChanged += textBox_TextChanged;
		((Control)textBox3).KeyDown += new KeyEventHandler(textBox_KeyDown);
		((Control)textBox3).KeyPress += new KeyPressEventHandler(textBox_KeyPress);
		((Control)textBox2).Enabled = false;
		((Control)textBox2).ImeMode = (ImeMode)3;
		((Control)textBox2).Location = new Point(52, 146);
		((Control)textBox2).Name = "textBox2";
		((Control)textBox2).Size = new Size(28, 19);
		((Control)textBox2).TabIndex = 22;
		textBox2.TextAlign = (HorizontalAlignment)1;
		((Control)textBox2).TextChanged += textBox_TextChanged;
		((Control)textBox2).KeyDown += new KeyEventHandler(textBox_KeyDown);
		((Control)textBox2).KeyPress += new KeyPressEventHandler(textBox_KeyPress);
		((Control)textBox1).Enabled = false;
		((Control)textBox1).ImeMode = (ImeMode)3;
		((Control)textBox1).Location = new Point(20, 146);
		((Control)textBox1).Name = "textBox1";
		((Control)textBox1).Size = new Size(28, 19);
		((Control)textBox1).TabIndex = 21;
		textBox1.TextAlign = (HorizontalAlignment)1;
		((Control)textBox1).TextChanged += textBox_TextChanged;
		((Control)textBox1).KeyDown += new KeyEventHandler(textBox_KeyDown);
		((Control)textBox1).KeyPress += new KeyPressEventHandler(textBox_KeyPress);
		((Control)label4).AutoSize = true;
		((Control)label4).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		label4.ImeMode = (ImeMode)0;
		((Control)label4).Location = new Point(109, 149);
		((Control)label4).Name = "label4";
		((Control)label4).Size = new Size(12, 16);
		((Control)label4).TabIndex = 29;
		((Control)label4).Text = ".";
		((Control)label3).AutoSize = true;
		((Control)label3).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		label3.ImeMode = (ImeMode)0;
		((Control)label3).Location = new Point(77, 149);
		((Control)label3).Name = "label3";
		((Control)label3).Size = new Size(12, 16);
		((Control)label3).TabIndex = 28;
		((Control)label3).Text = ".";
		((Control)label2).AutoSize = true;
		((Control)label2).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		label2.ImeMode = (ImeMode)0;
		((Control)label2).Location = new Point(45, 149);
		((Control)label2).Name = "label2";
		((Control)label2).Size = new Size(12, 16);
		((Control)label2).TabIndex = 27;
		((Control)label2).Text = ".";
		((Control)radioButtonIPAddress).AutoSize = true;
		((Control)radioButtonIPAddress).Location = new Point(7, 120);
		((Control)radioButtonIPAddress).Name = "radioButtonIPAddress";
		((Control)radioButtonIPAddress).Size = new Size(14, 13);
		((Control)radioButtonIPAddress).TabIndex = 19;
		((ButtonBase)radioButtonIPAddress).UseVisualStyleBackColor = true;
		((Control)radioButtonMFPSelect).AutoSize = true;
		radioButtonMFPSelect.Checked = true;
		((Control)radioButtonMFPSelect).Location = new Point(7, 7);
		((Control)radioButtonMFPSelect).Name = "radioButtonMFPSelect";
		((Control)radioButtonMFPSelect).Size = new Size(14, 13);
		((Control)radioButtonMFPSelect).TabIndex = 18;
		radioButtonMFPSelect.TabStop = true;
		((ButtonBase)radioButtonMFPSelect).UseVisualStyleBackColor = true;
		radioButtonMFPSelect.CheckedChanged += radioButtonMFPSelect_CheckedChanged;
		((ContainerControl)this).AutoScaleMode = (AutoScaleMode)0;
		((Control)this).Controls.Add((Control)(object)listViewMFPList);
		((Control)this).Controls.Add((Control)(object)labelMFP_Found);
		((Control)this).Controls.Add((Control)(object)labelMFP_Info);
		((Control)this).Controls.Add((Control)(object)buttonMachineInfoUpdate);
		((Control)this).Controls.Add((Control)(object)linkLabelIP);
		((Control)this).Controls.Add((Control)(object)buttonSeach);
		((Control)this).Controls.Add((Control)(object)textBox4);
		((Control)this).Controls.Add((Control)(object)textBox3);
		((Control)this).Controls.Add((Control)(object)textBox2);
		((Control)this).Controls.Add((Control)(object)textBox1);
		((Control)this).Controls.Add((Control)(object)label4);
		((Control)this).Controls.Add((Control)(object)label3);
		((Control)this).Controls.Add((Control)(object)label2);
		((Control)this).Controls.Add((Control)(object)radioButtonIPAddress);
		((Control)this).Controls.Add((Control)(object)radioButtonMFPSelect);
		((Control)this).Name = "MachineSelectControl";
		((Control)this).Size = new Size(492, 224);
		((Control)this).ResumeLayout(false);
		((Control)this).PerformLayout();
	}
}
