using System;
using System.Diagnostics;
using System.IO;
using System.Reflection;
using CreateFolder.Properties;
using log4net;

namespace CreateFolder;

internal class PowerShellManager
{
	private static readonly ILog LOG = LogManager.GetLogger(MethodBase.GetCurrentMethod().DeclaringType);

	public bool isSharedSetting(string sharedName, string folderPath)
	{
		string empty = string.Empty;
		string command = "Get-SmbShare -Name " + sharedName;
		if (sharedName == null || sharedName.Equals("") || folderPath == null || folderPath.Equals(""))
		{
			throw new ArgumentException(MethodBase.GetCurrentMethod().Name + "Param null or Empty.");
		}
		empty = executePowerShell(command);
		LOG.DebugFormat("{0}：results-isSharedSetting :{1}", (object)MethodBase.GetCurrentMethod().Name, (object)empty);
		Console.WriteLine(empty);
		if (searchKeyword("ObjectNotFound", empty))
		{
			return false;
		}
		if (searchKeyword("Exception", empty))
		{
			throw new Exception(MethodBase.GetCurrentMethod().Name + "PowerShrellCommand Failed.");
		}
		return searchKeyword_UpAndLow(folderPath, empty);
	}

	public void SetSharedSetting(string sharedName, string folderPath)
	{
		string empty = string.Empty;
		string command = "net share " + sharedName + "=" + folderPath;
		if (sharedName == null || sharedName.Equals("") || folderPath == null || folderPath.Equals(""))
		{
			throw new ArgumentException(MethodBase.GetCurrentMethod().Name + "Param null or Empty.");
		}
		empty = executePowerShell(command);
		LOG.DebugFormat("{0}：results-SetSharedSetting :{1}", (object)MethodBase.GetCurrentMethod().Name, (object)empty);
		Console.WriteLine(empty);
		if (searchKeyword("Exception", empty))
		{
			throw new Exception(MethodBase.GetCurrentMethod().Name + "PowerShrellCommand Failed.");
		}
	}

	public void SetSMBAccount(string folderName, string account, string accessRight)
	{
		string empty = string.Empty;
		string command = "Grant-SmbShareAccess -Name " + folderName + " -AccountName " + account + " -AccessRight " + accessRight + " -Force";
		if (folderName == null || folderName.Equals("") || account == null || account.Equals("") || accessRight == null || accessRight.Equals(""))
		{
			throw new ArgumentException(MethodBase.GetCurrentMethod().Name + "Param null or Empty.");
		}
		if (!accessRight.Equals("Read") && !accessRight.Equals("Change") && !accessRight.Equals("Full"))
		{
			throw new ArgumentException(MethodBase.GetCurrentMethod().Name + "accessRight No Type.");
		}
		empty = executePowerShell(command);
		LOG.DebugFormat("{0}：results-SetSMBAccount :{1}", (object)MethodBase.GetCurrentMethod().Name, (object)empty);
		Console.WriteLine(empty);
		if (searchKeyword("Exception", empty))
		{
			throw new Exception(MethodBase.GetCurrentMethod().Name + "PowerShrellCommand Failed.");
		}
	}

	public string GetSMBStatus()
	{
		OperatingSystem oSVersion = Environment.OSVersion;
		string empty = string.Empty;
		string arg = Resources.DISABLED;
		string arg2 = Resources.DISABLED;
		if (oSVersion.Version.Major == 6 && oSVersion.Version.Minor == 1)
		{
			LOG.DebugFormat("{0}：Use Windows7 method.", (object)MethodBase.GetCurrentMethod().Name);
			LOG.DebugFormat("Get-Item HKLM:\\SYSTEM\\CurrentControlSet\\Services\\LanmanServer\\Parameters | ForEach-Object {{Get-ItemProperty $_.pspath}}", new object[0]);
			empty = executePowerShell("Get-Item HKLM:\\SYSTEM\\CurrentControlSet\\Services\\LanmanServer\\Parameters | ForEach-Object {Get-ItemProperty $_.pspath}");
			LOG.DebugFormat("{0}：results-SMB1 :{1}", (object)MethodBase.GetCurrentMethod().Name, (object)empty);
			Console.WriteLine(empty);
			string parameterSetting = getParameterSetting("SMB1", empty);
			arg = ((string.IsNullOrEmpty(parameterSetting) || parameterSetting.Equals("1")) ? Resources.ENABLED : Resources.DISABLED);
			LOG.DebugFormat("Get-ItemProperty HKLM:\\SYSTEM\\CurrentControlSet\\Services\\LanmanServer\\Parameters | ForEach-Object {{Get-ItemProperty $_.pspath}}", new object[0]);
			empty = executePowerShell("Get-ItemProperty HKLM:\\SYSTEM\\CurrentControlSet\\Services\\LanmanServer\\Parameters | ForEach-Object {Get-ItemProperty $_.pspath}");
			LOG.DebugFormat("{0}：results-SMB2 :{1}", (object)MethodBase.GetCurrentMethod().Name, (object)empty);
			Console.WriteLine(empty);
			parameterSetting = getParameterSetting("SMB2", empty);
			arg2 = ((string.IsNullOrEmpty(parameterSetting) || parameterSetting.Equals("1")) ? Resources.ENABLED : Resources.DISABLED);
		}
		else if ((oSVersion.Version.Major == 6 && (oSVersion.Version.Minor == 2 || oSVersion.Version.Minor == 3)) || oSVersion.Version.Major == 10)
		{
			LOG.DebugFormat("{0}：Use Windows8.1/10 method.", (object)MethodBase.GetCurrentMethod().Name);
			LOG.DebugFormat("Get-SmbServerConfiguration | Select EnableSMB1Protocol", new object[0]);
			empty = executePowerShell("Get-SmbServerConfiguration | Select EnableSMB1Protocol");
			LOG.DebugFormat("{0}：results-SMB1 :{1}", (object)MethodBase.GetCurrentMethod().Name, (object)empty);
			Console.WriteLine(empty);
			arg = (empty.Contains("True") ? Resources.ENABLED : Resources.DISABLED);
			LOG.DebugFormat("Get-SmbServerConfiguration | Select EnableSMB2Protocol", new object[0]);
			empty = executePowerShell("Get-SmbServerConfiguration | Select EnableSMB2Protocol");
			LOG.DebugFormat("{0}：results-SMB2 :{1}", (object)MethodBase.GetCurrentMethod().Name, (object)empty);
			Console.WriteLine(empty);
			arg2 = (empty.Contains("True") ? Resources.ENABLED : Resources.DISABLED);
		}
		string text = $"SMBv1:{arg} | SMBv2/SMBv3:{arg2}";
		LOG.InfoFormat("{0}：Result: {1}", (object)MethodBase.GetCurrentMethod().Name, (object)text);
		return text;
	}

	private string executePowerShell(string command)
	{
		Process process = new Process();
		string result = string.Empty;
		try
		{
			process.StartInfo.FileName = "PowerShell.exe";
			process.StartInfo.UseShellExecute = false;
			process.StartInfo.RedirectStandardOutput = true;
			process.StartInfo.RedirectStandardInput = false;
			process.StartInfo.CreateNoWindow = true;
			process.StartInfo.Verb = "RunAs";
			process.StartInfo.Arguments = command;
			process.Start();
			result = process.StandardOutput.ReadToEnd();
		}
		catch (Exception ex)
		{
			LOG.ErrorFormat("{0}：Exception  :{1}", (object)MethodBase.GetCurrentMethod().Name, (object)ex.ToString());
		}
		finally
		{
			process.Close();
		}
		return result;
	}

	private string getParameterSetting(string parameterName, string parameters)
	{
		string result = string.Empty;
		StringReader stringReader = new StringReader(parameters);
		while (true)
		{
			string text = stringReader.ReadLine();
			if (text == null)
			{
				break;
			}
			string[] array = text.Split(new char[1] { ':' });
			if (array[0].Trim().Equals(parameterName))
			{
				result = array[1].Trim();
			}
		}
		return result;
	}

	private bool searchKeyword(string searchKeyword, string powerShellResult)
	{
		bool result = false;
		if (powerShellResult.IndexOf(searchKeyword) >= 0)
		{
			result = true;
		}
		return result;
	}

	private bool searchKeyword_UpAndLow(string searchKeyword, string powerShellResult)
	{
		bool result = false;
		if (powerShellResult.IndexOf(searchKeyword, StringComparison.OrdinalIgnoreCase) >= 0)
		{
			result = true;
		}
		return result;
	}
}
