using System.Reflection;
using System.Threading.Tasks;
using log4net;

namespace CreateFolder;

public static class StateMachine
{
	public enum SetupType
	{
		CREATEFOLDER,
		ADDRESSBOOK,
		CUSTOMSETUP,
		END
	}

	public enum StateType
	{
		STANDBY,
		CREATE_FOLDER_SETUP,
		USER_INFO_SETUP,
		ADDRESSBOOK_SETUP,
		ADDRESSBOOK_CHECK,
		ENV_SETTING,
		SETUP_FINISH,
		NO_STATE,
		ADDRESSBOOK_SELECTFOLDER,
		ADDRESSBOOK_SELECTFOLDER_SETUP,
		ADDRESSBOOK_SELECTFOLDER_FINISH,
		CUSTOM_SETUP,
		CUSTOM_SETUP_CREATE_FOLDER,
		CUSTOM_SETUP_CREATE_FOLDER_FINISH,
		CUSTOM_SETUP_ADDRESSBOOK,
		CUSTOM_SETUP_ADDRESSBOOK_FINISH,
		CUSTOM_ENV_SETTING,
		ST_NOSTATE
	}

	public enum EventType
	{
		NEXT,
		PREVEW,
		CANCEL,
		ST_NOEVENT
	}

	private static readonly ILog LOG = LogManager.GetLogger(MethodBase.GetCurrentMethod().DeclaringType);

	private static StateType nowState;

	private static StateType nextState;

	private static SetupType selectedType;

	private static FormWizard formWizard;

	public static StateType NowState
	{
		get
		{
			return nowState;
		}
		set
		{
			nowState = value;
		}
	}

	public static StateType NextState
	{
		get
		{
			return nextState;
		}
		set
		{
			nextState = value;
		}
	}

	public static SetupType SelectedType
	{
		get
		{
			return selectedType;
		}
		set
		{
			selectedType = value;
		}
	}

	public static FormWizard FormWizard
	{
		get
		{
			return formWizard;
		}
		set
		{
			formWizard = value;
		}
	}

	public static void init()
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		nowState = StateType.STANDBY;
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	public static async Task execute(EventType ev)
	{
		LOG.DebugFormat("{0}：start. Current state:{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)nowState);
		switch (nowState)
		{
		case StateType.STANDBY:
			nextState = performEventStanby(ev);
			break;
		case StateType.CREATE_FOLDER_SETUP:
			nextState = performEventCreateFolder(ev);
			break;
		case StateType.USER_INFO_SETUP:
			nextState = performEventUserInfoSetup(ev);
			break;
		case StateType.NO_STATE:
			nextState = performEventCreateFolderFinish(ev);
			break;
		case StateType.ADDRESSBOOK_SETUP:
			nextState = performEventAddressSetup(ev);
			break;
		case StateType.ADDRESSBOOK_CHECK:
			nextState = performEventAddressFinish(ev);
			break;
		case StateType.ENV_SETTING:
			nextState = await performEventEnvSetting(ev);
			break;
		case StateType.SETUP_FINISH:
			nextState = performEventSetupFinish(ev);
			break;
		case StateType.ADDRESSBOOK_SELECTFOLDER:
			LOG.ErrorFormat("{0}：ERROR_STATE:ADDRESSBOOK_SELECTFOLDER", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			nextState = performEventAddressSelectFolder(ev);
			break;
		case StateType.ADDRESSBOOK_SELECTFOLDER_SETUP:
			LOG.ErrorFormat("{0}：ERROR_STATE:ADDRESSBOOK_SELECTFOLDER_SETUP", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			nextState = performEventAddressSelectFolderSetup(ev);
			break;
		case StateType.ADDRESSBOOK_SELECTFOLDER_FINISH:
			LOG.ErrorFormat("{0}：ERROR_STATE:ADDRESSBOOK_SELECTFOLDER_FINISH", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			nextState = performEventAddressSelectFolderFinish(ev);
			break;
		case StateType.CUSTOM_SETUP:
			LOG.ErrorFormat("{0}：ERROR_STATE:CUSTOM_SETUP", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			nextState = performEventCustomSetup(ev);
			break;
		case StateType.CUSTOM_SETUP_ADDRESSBOOK_FINISH:
			LOG.ErrorFormat("{0}：ERROR_STATE:CUSTOM_SETUP_ADDRESSBOOK_FINISH", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			nextState = performEventCustomSetupAddressFinish(ev);
			break;
		case StateType.CUSTOM_ENV_SETTING:
			LOG.ErrorFormat("{0}：ERROR_STATE:CUSTOM_ENV_SETTING", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			nextState = performEventCustomEnvSetting(ev);
			break;
		case StateType.ST_NOSTATE:
			LOG.ErrorFormat("{0}：ERROR_STATE:ST_NOSTATE", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			break;
		default:
			LOG.ErrorFormat("{0}：Now State Error !!! NowState:{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)nowState);
			break;
		}
		LOG.DebugFormat("{0}：end. Next state:{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)nextState);
	}

	private static StateType performEventStanby(EventType ev)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		StateType result = nowState;
		switch (ev)
		{
		case EventType.NEXT:
			result = StateType.CREATE_FOLDER_SETUP;
			break;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return result;
	}

	private static StateType performEventCreateFolder(EventType ev)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		StateType result = nowState;
		switch (ev)
		{
		case EventType.NEXT:
			result = StateType.USER_INFO_SETUP;
			break;
		case EventType.PREVEW:
			result = StateType.STANDBY;
			break;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return result;
	}

	private static StateType performEventUserInfoSetup(EventType ev)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		StateType result = nowState;
		switch (ev)
		{
		case EventType.NEXT:
			result = StateType.ADDRESSBOOK_SETUP;
			break;
		case EventType.PREVEW:
			result = StateType.CREATE_FOLDER_SETUP;
			break;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return result;
	}

	private static StateType performEventCreateFolderFinish(EventType ev)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		StateType result = nowState;
		switch (ev)
		{
		case EventType.NEXT:
			result = StateType.ADDRESSBOOK_SETUP;
			break;
		case EventType.PREVEW:
			result = StateType.USER_INFO_SETUP;
			break;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return result;
	}

	private static StateType performEventAddressSetup(EventType ev)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		StateType result = nowState;
		switch (ev)
		{
		case EventType.NEXT:
			result = StateType.ADDRESSBOOK_CHECK;
			break;
		case EventType.PREVEW:
			result = StateType.USER_INFO_SETUP;
			break;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return result;
	}

	private static StateType performEventAddressFinish(EventType ev)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		StateType result = nowState;
		switch (ev)
		{
		case EventType.NEXT:
			result = StateType.ENV_SETTING;
			break;
		case EventType.PREVEW:
			result = StateType.ADDRESSBOOK_SETUP;
			break;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return result;
	}

	private static async Task<StateType> performEventEnvSetting(EventType ev)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		StateType result = nowState;
		switch (ev)
		{
		case EventType.NEXT:
			result = ((await FormWizard.executeCreateFolderAddressBook() != FormWizard.ErrorCode.PREV) ? StateType.SETUP_FINISH : StateType.ADDRESSBOOK_CHECK);
			break;
		case EventType.PREVEW:
			result = StateType.ADDRESSBOOK_CHECK;
			break;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		return result;
	}

	private static StateType performEventSetupFinish(EventType ev)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		StateType result = nowState;
		switch (ev)
		{
		case EventType.NEXT:
			result = StateType.STANDBY;
			break;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return result;
	}

	private static StateType performEventAddressSelectFolder(EventType ev)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		StateType result = nowState;
		switch (ev)
		{
		case EventType.NEXT:
			result = StateType.ADDRESSBOOK_SELECTFOLDER_SETUP;
			break;
		case EventType.PREVEW:
			result = StateType.CREATE_FOLDER_SETUP;
			break;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return result;
	}

	private static StateType performEventAddressSelectFolderSetup(EventType ev)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		StateType result = nowState;
		switch (ev)
		{
		case EventType.NEXT:
			result = StateType.ENV_SETTING;
			break;
		case EventType.PREVEW:
			result = StateType.ADDRESSBOOK_SELECTFOLDER;
			break;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return result;
	}

	private static StateType performEventAddressSelectFolderFinish(EventType ev)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		StateType result = nowState;
		switch (ev)
		{
		case EventType.NEXT:
			result = StateType.ENV_SETTING;
			break;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return result;
	}

	private static StateType performEventCustomSetup(EventType ev)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		StateType result = nowState;
		switch (ev)
		{
		case EventType.NEXT:
			switch (selectedType)
			{
			case SetupType.CREATEFOLDER:
				result = StateType.CUSTOM_SETUP_CREATE_FOLDER;
				break;
			case SetupType.ADDRESSBOOK:
				result = StateType.CUSTOM_SETUP_ADDRESSBOOK;
				break;
			}
			break;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return result;
	}

	private static StateType performEventCustomSetupAddressFinish(EventType ev)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		StateType result = nowState;
		switch (ev)
		{
		case EventType.NEXT:
			result = StateType.CUSTOM_SETUP_CREATE_FOLDER;
			break;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return result;
	}

	private static StateType performEventCustomEnvSetting(EventType ev)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		StateType result = nowState;
		switch (ev)
		{
		case EventType.NEXT:
			switch (selectedType)
			{
			case SetupType.CREATEFOLDER:
				result = StateType.CUSTOM_SETUP_CREATE_FOLDER_FINISH;
				break;
			case SetupType.ADDRESSBOOK:
				result = StateType.CUSTOM_SETUP_ADDRESSBOOK_FINISH;
				break;
			}
			break;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return result;
	}
}
