using System.Collections.Generic;
using System.Reflection;
using System.Threading.Tasks;
using log4net;

namespace CreateFolder;

public static class StateMachineTroubleShoot
{
	public enum StateType
	{
		STANDBY,
		TR_DEVICE,
		TR_USER,
		TR_ANALYZE,
		TR_RESULT,
		TR_CREATE_FOLDER_SETUP,
		TR_USER_INFO_SETUP,
		TR_ADDRESSBOOK_SETUP,
		TR_ADDRESSBOOK_CHECK,
		TR_SETUP_FINISH,
		NO_STATE
	}

	public enum EventType
	{
		NEXT,
		PREVEW,
		CANCEL
	}

	private static readonly ILog LOG = LogManager.GetLogger(MethodBase.GetCurrentMethod().DeclaringType);

	private static StateType nowState;

	private static StateType nextState;

	private static Dictionary<StateType, List<StateType>> stateTable = new Dictionary<StateType, List<StateType>>
	{
		{
			StateType.STANDBY,
			new List<StateType>
			{
				StateType.TR_DEVICE,
				StateType.NO_STATE,
				StateType.NO_STATE
			}
		},
		{
			StateType.TR_DEVICE,
			new List<StateType>
			{
				StateType.TR_USER,
				StateType.STANDBY,
				StateType.NO_STATE
			}
		},
		{
			StateType.TR_USER,
			new List<StateType>
			{
				StateType.TR_ANALYZE,
				StateType.TR_DEVICE,
				StateType.NO_STATE
			}
		},
		{
			StateType.TR_ANALYZE,
			new List<StateType>
			{
				StateType.TR_RESULT,
				StateType.TR_USER,
				StateType.NO_STATE
			}
		},
		{
			StateType.TR_RESULT,
			new List<StateType>
			{
				StateType.TR_CREATE_FOLDER_SETUP,
				StateType.TR_USER,
				StateType.NO_STATE
			}
		},
		{
			StateType.TR_CREATE_FOLDER_SETUP,
			new List<StateType>
			{
				StateType.TR_USER_INFO_SETUP,
				StateType.TR_RESULT,
				StateType.NO_STATE
			}
		},
		{
			StateType.TR_USER_INFO_SETUP,
			new List<StateType>
			{
				StateType.TR_ADDRESSBOOK_SETUP,
				StateType.TR_CREATE_FOLDER_SETUP,
				StateType.NO_STATE
			}
		},
		{
			StateType.TR_ADDRESSBOOK_SETUP,
			new List<StateType>
			{
				StateType.TR_ADDRESSBOOK_CHECK,
				StateType.TR_USER_INFO_SETUP,
				StateType.NO_STATE
			}
		},
		{
			StateType.TR_ADDRESSBOOK_CHECK,
			new List<StateType>
			{
				StateType.TR_SETUP_FINISH,
				StateType.TR_ADDRESSBOOK_SETUP,
				StateType.NO_STATE
			}
		},
		{
			StateType.TR_SETUP_FINISH,
			new List<StateType>
			{
				StateType.STANDBY,
				StateType.NO_STATE,
				StateType.NO_STATE
			}
		}
	};

	public static StateType NowState
	{
		get
		{
			return nowState;
		}
		set
		{
			nowState = value;
		}
	}

	public static StateType NextState
	{
		get
		{
			return nextState;
		}
		set
		{
			nextState = value;
		}
	}

	public static void init()
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		nowState = StateType.STANDBY;
		nextState = StateType.STANDBY;
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	public static async Task execute(EventType ev)
	{
		LOG.DebugFormat("{0}：start. Current state:{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)nowState);
		if (stateTable.ContainsKey(nowState))
		{
			StateType stateType = stateTable[nowState][(int)ev];
			if (stateType != StateType.NO_STATE)
			{
				nextState = stateType;
			}
		}
		LOG.DebugFormat("{0}：end. Next state:{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)nextState);
	}
}
