using System;
using System.Collections;
using System.Collections.Generic;
using System.DirectoryServices;
using System.Linq;
using System.Reflection;
using log4net;

namespace CreateFolder;

internal class UserInfo : IEquatable<UserInfo>
{
	private static readonly ILog LOG = LogManager.GetLogger(MethodBase.GetCurrentMethod().DeclaringType);

	public string Name;

	public byte[] objectSid;

	public string Description;

	public string ParentName;

	private static UserInfoComparer userInfoC = new UserInfoComparer();

	public UserInfo(DirectoryEntry userEntry)
	{
		FieldInfo[] fields = GetType().GetFields();
		foreach (FieldInfo fieldInfo in fields)
		{
			PropertyValueCollection val = userEntry.Properties[fieldInfo.Name];
			if (val != null && ((CollectionBase)(object)val).Count > 0)
			{
				fieldInfo.SetValue(this, val.Value);
			}
		}
		ParentName = userEntry.Parent.Name;
		if (ParentName.Equals("WinNT:"))
		{
			ParentName = string.Empty;
		}
		else
		{
			ParentName += "\\";
		}
	}

	public static List<UserInfo> GetList(string dirpath)
	{
		//IL_0010: Unknown result type (might be due to invalid IL or missing references)
		//IL_0048: Unknown result type (might be due to invalid IL or missing references)
		//IL_004f: Expected O, but got Unknown
		LOG.Debug((object)"UserInfo:GetList：start");
		DirectoryEntry val = new DirectoryEntry(dirpath);
		List<UserInfo> list = new List<UserInfo>();
		UserInfo userInfo = null;
		string empty = string.Empty;
		string text = "DefaultAccount";
		string text2 = "WDAGUtilityAccount";
		foreach (DirectoryEntry child in val.Children)
		{
			DirectoryEntry val2 = child;
			if (val2.Name == text || val2.Name == text2 || !(val2.SchemaClassName == "User"))
			{
				continue;
			}
			userInfo = new UserInfo(val2);
			if (!list.Contains(userInfo, userInfoC))
			{
				list.Add(userInfo);
				empty = $"Add {userInfo.ParentName}:{userInfo.Name}";
				char[] array = userInfo.Name.ToCharArray();
				foreach (int num in array)
				{
					empty += $" {num:X2}";
				}
				LOG.Debug((object)empty);
			}
		}
		LOG.Debug((object)"UserInfo:GetList：end");
		return list;
	}

	public override int GetHashCode()
	{
		int hashCode = Name.ToUpper().GetHashCode();
		int hashCode2 = ParentName.ToUpper().GetHashCode();
		return hashCode ^ hashCode2;
	}

	bool IEquatable<UserInfo>.Equals(UserInfo info)
	{
		bool flag = string.Equals(Name, info.Name, StringComparison.CurrentCultureIgnoreCase);
		flag &= string.Equals(ParentName, info.ParentName, StringComparison.CurrentCultureIgnoreCase);
		LOG.DebugFormat("重複するユーザー情報がありました。 Name:{0}, ParentName:{1} same?:{2}", (object)info.Name, (object)info.ParentName, (object)flag);
		return flag;
	}
}
