using System;
using System.Collections.Generic;
using System.IO;
using System.Net;
using System.Net.Http;
using System.Net.Security;
using System.Reflection;
using System.Security.Cryptography.X509Certificates;
using System.Text;
using System.Threading.Tasks;
using CreateFolder.Properties;
using log4net;

namespace CreateFolder;

public class WebAccessControl
{
	private static readonly ILog LOG = LogManager.GetLogger(MethodBase.GetCurrentMethod().DeclaringType);

	private readonly string URL_CHECK_SITE_DOM = "https://support.ricoh.com/bbv2/html/dr_ut_d/sec/index.htm";

	private readonly string URL_CHECK_SITE_EXP = "http://support.ricoh.com/bb/html/dr_ut_e/rc3/model/stfct/stfcten.htm";

	private readonly string URL_DOWNLOAD_SITE_EXP = "https://support.ricoh.com/bb/html/dr_ut_e/rc3/model/stfct/stfct.htm";

	private readonly string APP_NAME_DOM = "フォルダー送信 環境設定ツール";

	private readonly string APP_NAME_EXP = "Scan to Folder Configuration Tool";

	private readonly string KEYWORD_VERSION_DOM = "hashProgramInfo.VSOR_PV_VERSION2 = 'Ver.";

	private readonly string KEYWORD_APPNAME_TOP_EXP = "<strong>";

	private readonly string KEYWORD_APPNAME_END_EXP = "</strong>";

	private readonly string KEYWORD_VERSION_TOP_EXP = "<span class=\"pr32\">Ver.";

	private readonly string KEYWORD_VERSION_END_EXP = "</span>";

	private readonly string KEYWORD_DLSITEURL_DOM = "hashProgramInfo.VSOR_URL_OBJ_HISTORY = '";

	private static HttpClient client = null;

	private static CookieContainer cookieContainer = null;

	private string wimToken = string.Empty;

	private List<WimError> wimErrorTable = new List<WimError>();

	public string dlSiteUrl { get; set; }

	public WebAccessControl()
	{
		if (client == null)
		{
			createHttpClientInstance();
		}
	}

	public async Task<string> executeGetVersion(string username, string password, string lang)
	{
		Console.WriteLine("executeGetVersion() Task start ");
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		string appVersion = null;
		ServicePointManager.SecurityProtocol = SecurityProtocolType.Tls11 | SecurityProtocolType.Tls12;
		try
		{
			appVersion = ((!lang.Equals("ja")) ? (await connectDLSite(client, URL_CHECK_SITE_EXP, username, password)) : (await connectDLSite(client, URL_CHECK_SITE_DOM, username, password)));
		}
		catch (HttpRequestException ex)
		{
			LOG.InfoFormat("\n例外発生!", new object[0]);
			for (Exception ex2 = ex; ex2 != null; ex2 = ex2.InnerException)
			{
				LOG.InfoFormat("例外メッセージ EX: {0} ", (object)ex2.Message);
			}
		}
		catch (TaskCanceledException ex3)
		{
			LOG.InfoFormat("\nタイムアウト!", new object[0]);
			LOG.InfoFormat("例外メッセージ TCE: {0} ", (object)ex3.Message);
		}
		catch (ArgumentException ex4)
		{
			LOG.InfoFormat("例外メッセージ AE: {0} ", (object)ex4.Message);
		}
		catch (Exception ex5)
		{
			LOG.InfoFormat("例外メッセージ EXP: {0} ", (object)ex5.Message);
		}
		finally
		{
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			Console.WriteLine("executeGetVersion() Task End ");
		}
		return appVersion;
	}

	private async Task<HttpResponseMessage> getAsync(string jobName, HttpClient client, string uri)
	{
		int cntNG = 0;
		int MAXNG = 5;
		HttpResponseMessage response = null;
		while (cntNG < MAXNG)
		{
			try
			{
				response = await client.GetAsync(uri);
			}
			catch (TaskCanceledException ex)
			{
				cntNG++;
				LOG.InfoFormat("\nタイムアウト!\u3000リトライ {0} 回数＝ {1}", (object)jobName, (object)cntNG);
				LOG.InfoFormat("例外メッセージ TCE: {0} ", (object)ex.Message);
				if (cntNG >= MAXNG)
				{
					LOG.InfoFormat("\nリトライアウト!", new object[0]);
					throw;
				}
				continue;
			}
			break;
		}
		return response;
	}

	private async Task<WebAccessResponse> postAsync(string jobName, HttpClient client, string uri, string username, string password, Dictionary<string, string> content = null)
	{
		HttpContent httpContent = null;
		if (content != null)
		{
			httpContent = new FormUrlEncodedContent(content);
		}
		return await postAsyncCommon(jobName, client, uri, httpContent, username, password);
	}

	private async Task<WebAccessResponse> postAsyncCommon(string jobName, HttpClient client, string uri, HttpContent httpContent, string username, string password)
	{
		Console.WriteLine("postAsyncCommon() start.");
		int num = 0;
		int num2 = 2;
		WebAccessResponse webAccessResponse = new WebAccessResponse();
		while (num < num2)
		{
			try
			{
				HttpWebRequest obj = (HttpWebRequest)WebRequest.Create(uri);
				obj.Proxy = WebRequest.GetSystemWebProxy();
				obj.Proxy.Credentials = new NetworkCredential(username, password);
				Console.WriteLine("postAsyncCommon() GetResponse() username = " + username);
				Console.WriteLine("postAsyncCommon() GetResponse() password = " + password);
				obj.Timeout = int.Parse(Settings.Default.versionCheckTimeOut) * 1000;
				HttpWebResponse httpWebResponse = (HttpWebResponse)obj.GetResponse();
				Console.WriteLine("postAsyncCommon() StatusCode = " + httpWebResponse.StatusCode);
				if (httpWebResponse.StatusCode != HttpStatusCode.OK)
				{
					break;
				}
				HttpResponseMessage httpResponseMessage = new HttpResponseMessage(HttpStatusCode.OK);
				using (HttpWebResponse httpWebResponse2 = httpWebResponse)
				{
					using StreamReader streamReader = new StreamReader(httpWebResponse2.GetResponseStream());
					string content = streamReader.ReadToEnd();
					httpResponseMessage.Content = new StringContent(content, Encoding.UTF8, "application/json");
				}
				webAccessResponse.resultCode = WEB_ACCESS_RESULT.SUCCESS;
				webAccessResponse.responseData = httpResponseMessage;
			}
			catch (TaskCanceledException ex)
			{
				num++;
				LOG.InfoFormat("\nタイムアウト!\u3000リトライ {0} 回数＝ {1}", (object)jobName, (object)num);
				LOG.InfoFormat("例外メッセージ TCE: {0} ", (object)ex.Message);
				if (num >= num2)
				{
					LOG.InfoFormat("\nリトライアウト!", new object[0]);
					throw;
				}
				continue;
			}
			catch (WebException ex2)
			{
				Console.WriteLine("WebException = " + ex2.StackTrace);
				if (ex2.Status != WebExceptionStatus.ProtocolError)
				{
					goto IL_020c;
				}
				HttpWebResponse httpWebResponse3 = (HttpWebResponse)ex2.Response;
				Console.WriteLine("WebException StatusCode = " + httpWebResponse3.StatusCode);
				if (httpWebResponse3.StatusCode != HttpStatusCode.ProxyAuthenticationRequired)
				{
					goto IL_020c;
				}
				webAccessResponse.resultCode = WEB_ACCESS_RESULT.AHTU_FAILED;
				goto end_IL_01a9;
				IL_020c:
				num++;
				LOG.InfoFormat("\nタイムアウト!\u3000リトライ {0} 回数＝ {1}", (object)jobName, (object)num);
				LOG.InfoFormat("例外メッセージ TCE: {0} ", (object)ex2.Message);
				if (num >= num2)
				{
					LOG.InfoFormat("\nリトライアウト!", new object[0]);
					throw;
				}
				continue;
				end_IL_01a9:;
			}
			break;
		}
		return webAccessResponse;
	}

	private bool OnRemoteCertificateValidationCallback(object sender, X509Certificate certificate, X509Chain chain, SslPolicyErrors sslPolicyErrors)
	{
		return true;
	}

	private string removaTag(string value)
	{
		string[] array = new string[8] { "<td nowrap align=\"left\" width=\"40\">", "<img src=\"/images/messageIconE.gif\" alt=\"\">", "<td nowrap align=\"left\" height=\"32\">", "<td align=\"left\" valign=\"top\">", "<td>", "</td>", "<br>", "<br/>" };
		string text = value;
		for (int i = 0; i < array.Length; i++)
		{
			text = text.Replace(array[i], "");
		}
		return text;
	}

	private string getToolVersionDOM(string response, string appName)
	{
		string result = "";
		int num = 0;
		int num2 = 0;
		int num3 = 0;
		string text = "";
		byte[] bytes = Encoding.Default.GetBytes(appName);
		text = Encoding.UTF8.GetString(bytes);
		num = response.IndexOf(text);
		if (num == -1)
		{
			Console.WriteLine("Non AppName.");
			return result;
		}
		num2 = response.IndexOf(KEYWORD_VERSION_DOM, num) + KEYWORD_VERSION_DOM.Length;
		num3 = response.IndexOf("';", num2);
		return response.Substring(num2, num3 - num2);
	}

	private string getToolVersionEXP(string response, string appName)
	{
		string result = "";
		int num = 0;
		int num2 = 0;
		int num3 = 0;
		string value = KEYWORD_APPNAME_TOP_EXP + appName + KEYWORD_APPNAME_END_EXP;
		num = response.IndexOf(value);
		if (num == -1)
		{
			Console.WriteLine("Non AppName.");
			return result;
		}
		num2 = response.IndexOf(KEYWORD_VERSION_TOP_EXP, num) + KEYWORD_VERSION_TOP_EXP.Length;
		num3 = response.IndexOf(KEYWORD_VERSION_END_EXP, num2);
		return response.Substring(num2, num3 - num2);
	}

	private string getToolDlSiteUrl(string response, string appName)
	{
		string result = "";
		int num = 0;
		int num2 = 0;
		int num3 = 0;
		string text = "";
		byte[] bytes = Encoding.Default.GetBytes(appName);
		text = Encoding.UTF8.GetString(bytes);
		num = response.IndexOf(text);
		if (num == -1)
		{
			Console.WriteLine("Non AppName.");
			return result;
		}
		num2 = response.IndexOf(KEYWORD_DLSITEURL_DOM, num) + KEYWORD_DLSITEURL_DOM.Length;
		num3 = response.IndexOf("';", num2);
		return response.Substring(num2, num3 - num2);
	}

	private async Task<string> connectDLSite(HttpClient client, string url, string username, string password)
	{
		Console.WriteLine("connectDLSite Start.");
		LOG.DebugFormat("{0}:start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		WebAccessResponse webAccessResponse = ((!url.Equals(URL_CHECK_SITE_EXP)) ? (await postAsync("DLサイト接続！", client, URL_CHECK_SITE_DOM, username, password)) : (await postAsync("DLサイト接続！", client, URL_CHECK_SITE_EXP, username, password)));
		if (webAccessResponse == null || webAccessResponse.resultCode == WEB_ACCESS_RESULT.FAILED)
		{
			return null;
		}
		if (webAccessResponse.resultCode == WEB_ACCESS_RESULT.AHTU_FAILED)
		{
			return "auth failed";
		}
		if (webAccessResponse.resultCode == WEB_ACCESS_RESULT.SUCCESS && webAccessResponse.responseData == null)
		{
			return null;
		}
		string result = webAccessResponse.responseData.Content.ReadAsStringAsync().Result;
		string text;
		if (url.Equals(URL_CHECK_SITE_EXP))
		{
			text = getToolVersionEXP(result, APP_NAME_EXP);
			dlSiteUrl = URL_DOWNLOAD_SITE_EXP;
		}
		else
		{
			text = getToolVersionDOM(result, APP_NAME_DOM);
			dlSiteUrl = Resources.DOWNLOAD_SITE_URL_PREFIX + getToolDlSiteUrl(result, APP_NAME_DOM);
		}
		Console.WriteLine("Vresion = " + text);
		return text;
	}

	private void createHttpClientInstance()
	{
		//IL_001e: Unknown result type (might be due to invalid IL or missing references)
		//IL_002d: Unknown result type (might be due to invalid IL or missing references)
		//IL_003f: Unknown result type (might be due to invalid IL or missing references)
		//IL_004a: Expected O, but got Unknown
		//IL_004a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0051: Expected O, but got Unknown
		//IL_0051: Unknown result type (might be due to invalid IL or missing references)
		//IL_0058: Expected O, but got Unknown
		//IL_006e: Expected O, but got Unknown
		LOG.DebugFormat("{0}:start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		WebRequestHandler val = new WebRequestHandler();
		cookieContainer = new CookieContainer();
		val.ServerCertificateValidationCallback = OnRemoteCertificateValidationCallback;
		((HttpClientHandler)val).CookieContainer = cookieContainer;
		((HttpClientHandler)val).AllowAutoRedirect = true;
		((HttpClientHandler)val).UseCookies = true;
		if (client != null)
		{
			client.Dispose();
		}
		client = new HttpClient((HttpMessageHandler)val);
		client.DefaultRequestHeaders.Add("User-Agent", "Wget/1.11.3");
		client.DefaultRequestHeaders.Add("Accept", "*/*");
		client.DefaultRequestHeaders.Add("Connection", "Keep-Alive");
		client.Timeout = TimeSpan.FromSeconds(short.Parse(Settings.Default.httpTimeout));
		new HttpClientHandler().UseCookies = false;
		LOG.DebugFormat("{0}:end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
	}

	public void Dispose()
	{
		if (client != null)
		{
			client.Dispose();
		}
		client = null;
		cookieContainer = null;
	}

	public COMMUNICATION_ERROR_ONE communicateConfirm(string site)
	{
		LOG.DebugFormat("{0}：start ({1}://{2})", (object)MethodBase.GetCurrentMethod().Name, (object)site);
		COMMUNICATION_ERROR_ONE cOMMUNICATION_ERROR_ONE = COMMUNICATION_ERROR_ONE.ERROR;
		ServicePointManager.SecurityProtocol = SecurityProtocolType.Tls11 | SecurityProtocolType.Tls12;
		ServicePointManager.ServerCertificateValidationCallback = OnRemoteCertificateValidationCallback;
		HttpWebRequest httpWebRequest = (HttpWebRequest)WebRequest.Create(site);
		try
		{
			int timeout = int.Parse(Settings.Default.httpTimeout) * 1000;
			httpWebRequest.Timeout = timeout;
		}
		catch (Exception ex)
		{
			LOG.InfoFormat("timeout値の設定エラー:[{0}] {1}", (object)Settings.Default.httpTimeout, (object)ex.ToString());
		}
		HttpWebResponse httpWebResponse = null;
		try
		{
			httpWebResponse = (HttpWebResponse)httpWebRequest.GetResponse();
			LOG.DebugFormat("Uri:{0} HttpStatusCode:{1} Description:{2}", (object)httpWebResponse.ResponseUri, (object)httpWebResponse.StatusCode, (object)httpWebResponse.StatusDescription);
			cOMMUNICATION_ERROR_ONE = COMMUNICATION_ERROR_ONE.SUCCESS;
		}
		catch (WebException ex2)
		{
			if (ex2.Status == WebExceptionStatus.ProtocolError)
			{
				HttpWebResponse httpWebResponse2 = (HttpWebResponse)ex2.Response;
				LOG.ErrorFormat("Uri:{0} HttpStatusCode:{1} Description{2}", (object)httpWebResponse2.ResponseUri, (object)httpWebResponse2.StatusCode, (object)httpWebResponse2.StatusDescription);
			}
			LOG.Error((object)ex2.Message);
		}
		finally
		{
			httpWebResponse?.Close();
			LOG.DebugFormat("{0}：end {1}", (object)MethodBase.GetCurrentMethod().Name, (object)cOMMUNICATION_ERROR_ONE);
		}
		return cOMMUNICATION_ERROR_ONE;
	}
}
