using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Collections.Specialized;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Globalization;
using System.IO;
using System.Linq;
using System.Management;
using System.Management.Automation;
using System.Net;
using System.Net.Http;
using System.Net.NetworkInformation;
using System.Net.Security;
using System.Reflection;
using System.Runtime.InteropServices;
using System.Security.AccessControl;
using System.Security.Cryptography.X509Certificates;
using System.Text;
using System.Text.RegularExpressions;
using System.Threading;
using System.Threading.Tasks;
using System.Windows.Forms;
using CreateFolder.Properties;
using Lextm.SharpSnmpLib;
using Lextm.SharpSnmpLib.Messaging;
using log4net;

namespace CreateFolder;

public class FormWizard : Form
{
	public class TroubleShootAddressBookInfo
	{
		public Dictionary<AddressBookListControl.ADDRESSBOOK_LIST_ITEM, string> addressBookInfo { get; set; }

		public bool folder { get; set; }

		public bool access { get; set; }

		public bool fireWall { get; set; }
	}

	private enum WRITE_MODE
	{
		NORMAL,
		NON_SEPARATE,
		ALERT,
		ALERT_NON_SEPARATE,
		LABEL_ONLY
	}

	public enum ErrorCode
	{
		NOERROR,
		ADRESS_EMPTY,
		ADRESS_FORMAT_ERROR,
		MFP_NOT_FOUND,
		NOERROR_HTTP_ONLY,
		ABORT,
		ERROR,
		AUTO,
		MFP_NOT_SUPPORTED,
		ADDRESSBOOK_UPDATE_ERROR,
		END,
		PREV
	}

	public enum FolderResult
	{
		EMPTY,
		EXIST_OK,
		EXIST_NO_ACCESS,
		NO_ENTRY_EXIST,
		FOLDER_NOT_EXIST,
		CHANGE_NAME_OR_PATH
	}

	public enum TRPSMBCHECKCODE
	{
		OK,
		END,
		V1ON,
		V1OFF,
		FSOFF,
		FWUPDATE
	}

	private enum FOLDER_TYPE
	{
		CREATE_FOLDRE,
		SHARED_FOLDER,
		NON_SHARED_FOLDER
	}

	private static Hashtable mfpTable = new Hashtable();

	private Hashtable folderTable = new Hashtable();

	private string fqdnname = string.Empty;

	private string hostname = string.Empty;

	private string ipaddr = string.Empty;

	private string registrationNumber = string.Empty;

	private string mfpIpAddr = string.Empty;

	public string displayedContents = string.Empty;

	private static List<string> machineInfoList = new List<string>();

	private static string localBroadCasetAddr = string.Empty;

	private FolderSetting fs = new FolderSetting();

	private static string myHost = string.Empty;

	private static string machineLang = (Application.CurrentCulture.Equals(CultureInfo.GetCultureInfo("ja-JP")) ? "ja" : (Application.CurrentCulture.Equals(CultureInfo.GetCultureInfo("de-DE")) ? "de" : (Application.CurrentCulture.Equals(CultureInfo.GetCultureInfo("it-IT")) ? "it" : (Application.CurrentCulture.Equals(CultureInfo.GetCultureInfo("fr-FR")) ? "fr" : (Application.CurrentCulture.Equals(CultureInfo.GetCultureInfo("es-ES")) ? "es" : (Application.CurrentCulture.Equals(CultureInfo.GetCultureInfo("nl-NL")) ? "nl" : "en"))))));

	private FormMain fMain = new FormMain(FormMain.Mode.DIALOG, machineLang);

	private FormSettingHeadLine fSettingHeadline = new FormSettingHeadLine(machineLang);

	private Dictionary<string, StateMachine.StateType> tabPagesCreateFolder = new Dictionary<string, StateMachine.StateType>();

	private Dictionary<string, StateMachineTroubleShoot.StateType> tabPagesTroubleShoot = new Dictionary<string, StateMachineTroubleShoot.StateType>();

	private FormMFPInfo fGetMFPInfo = new FormMFPInfo(machineLang);

	private static readonly ILog LOG = LogManager.GetLogger(MethodBase.GetCurrentMethod().DeclaringType);

	private AddressBookListControl adrBookListCtrl;

	private Dictionary<AddressBookListControl.ADDRESSBOOK_LIST_ITEM, string> troubleShootAddressBookInfo;

	private TroubleShootAddressBookInfo troubleShootAddressBookInfoUpdate;

	private SemaphoreSlim semaphoreTroubleShootAddressBookInfo = new SemaphoreSlim(1, 1);

	private List<string> procedureNameList = new List<string>
	{
		Resources.FORM_WIZARD_PROCEDURE_2,
		Resources.FORM_WIZARD_PROLOGUE,
		Resources.ITEM_CREATE_FOLDER_2,
		Resources.FORM_WIZARD_PASSWORD,
		Resources.REGISTER_DESTINATION,
		Resources.CONFIRM,
		Resources.FORM_WIZARD_EXECUTING,
		Resources.FORM_WIZARD_COMPLETE
	};

	private List<string> troubleShootProcedureNameList = new List<string>
	{
		Resources.TROUBLE_SHOOTING_PROCEDURE,
		Resources.FORM_WIZARD_PROLOGUE,
		Resources.TROUBLE_SHOOTING_SELECT_DEVICE,
		Resources.TROUBLE_SHOOTING_SELECT_USER,
		Resources.TROUBLE_SHOOTING_ANALYZE_2,
		Resources.TROUBLE_SHOOTING_RESULT_2,
		Resources.ITEM_CREATE_FOLDER_2,
		Resources.FORM_WIZARD_PASSWORD,
		Resources.REGISTER_DESTINATION,
		Resources.CONFIRM,
		Resources.FORM_WIZARD_COMPLETE
	};

	private int PROCEDURE_TITLE_Y_POS = 21;

	private int PROCEDURE_TITLE_INDENT = 5;

	private int PROCEDURE_TITLE_GAP = 40;

	private int PROCEDURE_TITLE_HEIGHT = 19;

	private int PROCEDURE_NAME_INDENT = 24;

	private int PROCEDURE_NAME_GAP = 34;

	private int PROCEDURE_NAME_HEIGHT = 14;

	private int TR_PROGRESS_MAX = 9;

	private static int MODELNAME_SECTION_MAX_NUM = 4;

	private bool PrimaxModel;

	private bool PrimaxUnicode;

	private string PrimaxAdminPasswd = "";

	private List<OneTouchKeyInfo> PrimaxOneTouchKeyInfoList;

	private List<string[]> PrimaxAddressList;

	private string PrimaxTrpOldAddressName = "";

	private string PrimaxKeyCode = "";

	private bool smbv1;

	private TRPSMBCHECKCODE trsmbcode;

	private bool isAlertFolderName;

	private bool isAlertFolderPath;

	private bool isAlertAccountName;

	private bool isAlertPassword;

	private bool isAlertFireWalllSetting;

	private IContainer components;

	private TabPage tabPage5_confirm;

	private Panel panel_P5_3;

	private CancelButton btnP5Cancel;

	private NextButton btnP5Execute;

	private Panel panel_P5_2;

	private Panel panel15;

	private PictureBox pictureBox5;

	private Label labelP5Head;

	private Label labelP5_comment;

	private Panel panel_P5_1;

	private TabPage tabPage4_address;

	private Panel panel_P4_3;

	private CancelButton btnP4Cancel;

	private BackButton btnP4Back;

	private NextButton btnP4Next;

	private Panel panel_P4_2;

	private TextBox textP4Destination;

	private PictureBox pictureBox4;

	private Label labelP4Head;

	private Label label60;

	private Label labelP4_Destination;

	private Label labelP4_Machine;

	private Label labelP4_comment;

	private Panel panel_P4_1;

	private TabPage tabPage3_shareFolder;

	private Panel panel_P3_2;

	private ComboBox cmbP3UserName;

	private PictureBox pictureBox3;

	private Label labelP3Head;

	private Label labelP3_UserName;

	private Label labelP3_comment;

	private Panel panel_P3_3;

	private CancelButton btnP3Cancel;

	private BackButton btnP3Back;

	private NextButton btnP3Next;

	private Panel panel_P3_1;

	private TabPage tabPage2_setupSelect;

	private Panel panel_P2_3;

	private CancelButton btnP2Cancel;

	private Panel panel_P2_2;

	private PictureBox pictureBox2;

	private Label labelP2Head;

	private Label labelP2_comment;

	private Panel panel_P2_1;

	private TabPage tabPage1_introduction;

	private Panel panel_P1_2;

	private PictureBox pictureBox1;

	private Label labelP1Head;

	private Label labelP1_comment;

	private Panel panel_P1_3;

	private CancelButton btnP1Cancel;

	private NextButton btnP1Next;

	private Panel panel_P1_1;

	private TabControl tabControl1_Main;

	private BackButton btnP5Back;

	private TabPage tabPage6_exec;

	private Panel panel_P6_3;

	private Panel panel_P6_2;

	private PictureBox pictureBox6;

	private Label labelP6Head;

	private Label labelP6_comment;

	private Panel panel_P6_1;

	private TabPage tabPage7_finish;

	private Panel panel_P7_3;

	private EndButton btnP7End;

	private Panel panel_P7_2;

	private Panel panel22;

	private PictureBox pictureBox7;

	private Label labelP7Head;

	private Label labelP7_ReportTitle;

	private Label labelP7_comment;

	private Panel panel_P7_1;

	private NextButton btnP2Next;

	private LinkLabel labelP7finsh;

	private NextButton btnP7Top;

	private MenuStrip menuStrip1;

	private ToolStripMenuItem ToolStripMenuItemSecurity_S;

	private ToolStripMenuItem ToolStripMenuItemVersion_H;

	private LinkLabel linkLabelP7HelpRegist;

	private ToolStripMenuItem ToolStripMenuItemDetail_D;

	private Button buttonSelectNonSharedFolder;

	private TextBox textBoxNonSharedFolderPath;

	private Label labelP2_NonSharedFolderPath;

	private TextBox textBoxSharedName;

	private Label labelP2_SharedName;

	private Button buttonSelectFolder;

	private TextBox textBoxFolderPath;

	private Label labelP2_FolderPath;

	private TextBox textBoxFolderName;

	private Label labelP2_FolderName;

	private TextBox textBoxP3Pass;

	private Label labelP3_Password;

	private BackButton btnP2Back;

	private NextButton btnP6Excecute;

	private LinkLabel linkLabelP4Connect;

	private LinkLabel linkLabelP7HelpSend;

	private Label labelP6Execute;

	private ProgressBar progressBar1;

	private Label labelP3_PasswordConfirm;

	private TextBox textBoxP3PassConfirm;

	private ToolStripMenuItem ToolStripMenuItemEnvironments_E;

	private ToolStripMenuItem ToolStripMenuItemMachine;

	private ToolStripMenuItem ToolStripMenuItemComputer;

	private Label labelP4ConnectCheck;

	private ComboBox cmbP4FolderPath;

	private Label labelP4_Path;

	private Label labelP7Report;

	private Label labelP5Info;

	private Label label165;

	private Label label164;

	private Label label163;

	private Label label162;

	private Label label161;

	private Label label149;

	private Label label148;

	private Label label147;

	private Label label145;

	private PictureBox pictureBox15;

	private Label label7;

	private MachineSelectControl machineSelectControl;

	private GroupBox attentionGroup;

	private RichTextBox attentionRichTextBox;

	private Label labelP2_selectFolder;

	private Label labelP2_selectNonSharedFolder;

	private ComboBox cmbP2Folder;

	private RadioButton selectFolderRadioButton;

	private RadioButton createNewFolderRadioButton;

	private RadioButton selectNonSharedFolderRadioButton;

	private Label labelP2_Folder;

	private ToolStripMenuItem ToolStripMenuItemChange;

	private RadioButton radioButtonTroubleShoot;

	private RadioButton radioButtonCreateFolder;

	private TabPage tabTRP2_device;

	private Panel panel_TRP2_3;

	private BackButtonTroubleShoot btnTRP2Back;

	private NextButtonTroubleShoot btnTRP2Next;

	private Panel panel_TRP2_1;

	private TabPage tabTRP3_user;

	private Panel panel_TRP3_3;

	private BackButtonTroubleShoot btnTRP3Back;

	private NextButtonTroubleShoot btnTRP3Next;

	private Panel panel_TRP3_2;

	private PictureBox pictureBox9;

	private Label label_TRP3Head;

	private Panel panel_TRP3_1;

	private Label label_TRP3_comment;

	private Button buttonTRP3Break;

	private Label labelTRP3progressText;

	private Button buttonTRP3ToBottom;

	private Button buttonTRP3Next;

	private Button buttonTRP3Previous;

	private Button buttonTRP3ToTop;

	private Label label_TRP3DisplayedPage;

	private Label label_TRP3Page;

	private ComboBox comboBoxTRP3SelectWay;

	private Button buttonTRP3Search;

	private TextBox textBoxTRP3Search;

	private ListView listViewAddressList;

	private Label labelTRP3MFP_Selected;

	private Label label_TRP3_SelectedDevice;

	private Label label17;

	private Panel panel_TRP2_2;

	private MachineSelectControl machineSelectControlTRP2;

	private Label label_TRP2ConnectCheck;

	private PictureBox pictureBox8;

	private Label label_TRP2Head;

	private Label label_TRP2_Machine;

	private Label label_TRP2_comment;

	private TabPage tabTRP4_analyze;

	private Panel panel_TRP4_3;

	private Panel panel_TRP4_2;

	private ProgressBar progressBarTRP4;

	private PictureBox pictureBox10;

	private Label label_TRP4Head;

	private Label label_TRP4_comment;

	private Panel panel_TRP4_1;

	private TabPage tabTRP7_shareFolder;

	private Panel panel_TRP7_3;

	private BackButtonTroubleShoot btnTRP7Back;

	private NextButtonTroubleShoot btnTRP7Next;

	private Panel panel_TRP7_2;

	private Label label_TRP7_PasswordConfirm;

	private TextBox textBoxTRP7PassConfirm;

	private TextBox textBoxTRP7Pass;

	private Label label_TRP7_Password;

	private PictureBox pictureBox12;

	private Label label_TRP7Head;

	private Label label_TRP7_comment;

	private Panel panel_TRP7_1;

	private TabPage tabTRP10_finish;

	private Panel panel_TRP10_3;

	private NextButtonTroubleShoot btnTRP10Top;

	private EndButton btnTRP10End;

	private Panel panel_TRP10_2;

	private LinkLabel linkLabelTRP10HelpSend;

	private LinkLabel linkLabelTRP10HelpRegist;

	private Panel panelTRP10;

	private Label label_TRP10Report;

	private LinkLabel labelTRP10finish;

	private PictureBox pictureBox11;

	private Label label_TRP10Head;

	private Label label_TRP10_ReportTitle;

	private Label label_TRP10_comment;

	private Panel panel_TRP10_1;

	private LinkLabel linkLabelTRP2;

	private TabPage tabTRP5_result;

	private Panel panel_TRP5_3;

	private BackButtonTroubleShoot btnTRP5Back;

	private NextButtonTroubleShoot btnTRP5Next;

	private Panel panel_TRP5_2;

	private PictureBox pictureBox13;

	private Label label_TRP5Head;

	private Panel panel_TRP5_1;

	private Label label_TRP4_progress;

	private Panel panel40;

	private RichTextBox richTextBoxTRP5;

	private Label label_TRP7_UserName;

	private TabPage tabTRP9_confirm;

	private Panel panel_TRP9_3;

	private BackButtonTroubleShoot btnTRP9Back;

	private NextButtonTroubleShoot btnTRP9Execute;

	private Panel panel_TRP9_2;

	private PictureBox pictureBox14;

	private Label label_TRP9Head;

	private Panel panel45;

	private RichTextBox richTextBoxTRP9;

	private Panel panel_TRP9_1;

	private ComboBox cmbTRP7PcUser;

	private TabPage tabTRP6_setupSelect;

	private Panel panel_TRP6_3;

	private BackButtonTroubleShoot btnTRP6Back;

	private NextButtonTroubleShoot btnTRP6Next;

	private Panel panel_TRP6_2;

	private Label label_TRP6_SelectFolder;

	private Label label_TRP6_SelectNonSharedFolder;

	private ComboBox cmbTRP6Folder;

	private RadioButton radioButtonTRP6selectNonSharedFolder;

	private RadioButton radioButtonTRP6selectExistFolder;

	private RadioButton radioButtonTRP6createNewFolder;

	private Label label_TRP6_Folder;

	private Button buttonTRP6SelectNonSharedFolder;

	private TextBox textBoxTRP6NonSharedFolderPath;

	private TextBox textBoxTRP6SharedName;

	private Label label_TRP6_SharedName;

	private Label label_TRP6_NonSharedFolderPath;

	private Button buttonTRP6SelectFolder;

	private TextBox textBoxTRP6FolderPath;

	private Label label_TRP6_FolderPath;

	private TextBox textBoxTRP6FolderName;

	private Label label_TRP6_FolderName;

	private PictureBox pictureBox16;

	private Label label_TRP6Head;

	private Label label_TRP6_comment;

	private Panel panel_TRP6_1;

	private TabPage tabTRP8_address;

	private Panel panel_TRP8_3;

	private BackButtonTroubleShoot btnTRP8Back;

	private NextButtonTroubleShoot btnTRP8Next;

	private Panel panel_TRP8_2;

	private Label label_TRP8_Path;

	private ComboBox cmbTRP8FolderPath;

	private Button buttonTRP8HeadLine;

	private TextBox textTRP8Destination;

	private PictureBox pictureBox17;

	private Label label_TRP8Head;

	private Label label_TRP8_Destination;

	private Label label_TRP8_comment;

	private Panel panel_TRP8_1;

	private Button buttonTRP3Resume;

	private NextButtonTroubleShoot btnP1TRNext;

	private Label label_TRP9_comment;

	private Label label_TRP5_comment;

	private RichTextBox richTextBoxTRP10;

	private Button buttonP4HeadLine;

	[DllImport("wininet.dll")]
	private static extern bool InternetGetConnectedState(out int lpdwFlags, int dwReserved);

	public FormWizard()
	{
		//IL_1256: Unknown result type (might be due to invalid IL or missing references)
		string winVersion = getWinVersion();
		Console.WriteLine("1:" + DateTime.Now);
		FormSplash formSplash = new FormSplash
		{
			ProgressMsg = Resources.INITIALIZE_MSG_0_4
		};
		((Control)formSplash).Show();
		((Control)formSplash).Refresh();
		Thread.Sleep(500);
		formSplash.ProgressMsg = Resources.INITIALIZE_MSG_1_5;
		formSplash.ProgressRatio = 20;
		Application.DoEvents();
		bool flag = false;
		int lpdwFlags;
		bool flag2 = InternetGetConnectedState(out lpdwFlags, 0);
		if (flag2)
		{
			try
			{
				LOG.DebugFormat("{0}：version check flag = {1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)Settings.Default.versionCheck);
				flag = !Settings.Default.versionCheck || checkVersion();
			}
			catch (Exception ex)
			{
				string message = ex.Message;
				LOG.ErrorFormat("{0}：バージョンチェックエラー\n" + ex.ToString() + "\n*******************************", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
				LOG.ErrorFormat("{0}：Message\n" + message + "\n*******************************", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			}
			Console.WriteLine("0:Version Check. = " + flag);
			if (!flag)
			{
				throw new Exception("Application End");
			}
		}
		else
		{
			Console.WriteLine("0:Version Check Skip.");
		}
		formSplash.ProgressMsg = Resources.INITIALIZE_MSG_1_4;
		formSplash.ProgressRatio = 40;
		Application.DoEvents();
		if (machineLang.Equals("ja") || machineLang.Equals("en"))
		{
			InitializeComponent();
		}
		else
		{
			InitializeComponent_MultiLang();
		}
		((Control)labelP2_FolderName).ForeColor = Color.FromArgb(63, 72, 204);
		((Control)labelP2_FolderPath).ForeColor = Color.FromArgb(63, 72, 204);
		((Control)labelP2_Folder).ForeColor = Color.FromArgb(63, 72, 204);
		((Control)labelP2_NonSharedFolderPath).ForeColor = Color.FromArgb(63, 72, 204);
		((Control)labelP2_SharedName).ForeColor = Color.FromArgb(63, 72, 204);
		((Control)labelP3_UserName).ForeColor = Color.FromArgb(63, 72, 204);
		((Control)labelP3_Password).ForeColor = Color.FromArgb(63, 72, 204);
		((Control)labelP3_PasswordConfirm).ForeColor = Color.FromArgb(63, 72, 204);
		((Control)labelP4_Destination).ForeColor = Color.FromArgb(63, 72, 204);
		((Control)labelP4_Path).ForeColor = Color.FromArgb(63, 72, 204);
		((Control)labelP4_Machine).ForeColor = Color.FromArgb(63, 72, 204);
		Control[] allControls = CreateFolderUtil.GetAllControls((Control)(object)this);
		CreateFolderUtil.ResetFontToControl(((object)this).GetType().Name, allControls);
		int num = 0;
		foreach (StateMachine.StateType value in Enum.GetValues(typeof(StateMachine.StateType)))
		{
			if (value != StateMachine.StateType.NO_STATE)
			{
				tabPagesCreateFolder.Add(((Control)tabControl1_Main.TabPages[num++]).Text, value);
				if (value == StateMachine.StateType.SETUP_FINISH)
				{
					break;
				}
			}
		}
		foreach (StateMachineTroubleShoot.StateType value2 in Enum.GetValues(typeof(StateMachineTroubleShoot.StateType)))
		{
			switch (value2)
			{
			case StateMachineTroubleShoot.StateType.NO_STATE:
				break;
			default:
				tabPagesTroubleShoot.Add(((Control)tabControl1_Main.TabPages[num++]).Text, value2);
				continue;
			case StateMachineTroubleShoot.StateType.STANDBY:
				continue;
			}
			break;
		}
		richTextBoxTRP5.SelectionTabs = new int[2] { 25, 150 };
		richTextBoxTRP9.SelectionTabs = new int[2] { 1, 150 };
		richTextBoxTRP10.SelectionTabs = new int[2] { 1, 150 };
		((Control)this).Text = Resources.PROGRAM_TITLE;
		((ToolStripItem)ToolStripMenuItemDetail_D).Text = Resources.FORM_WIZARD_MENU_ITEM_DETAIL;
		((ToolStripItem)ToolStripMenuItemChange).Text = Resources.MENU_ITEM_CHANGE;
		((ToolStripItem)ToolStripMenuItemSecurity_S).Text = Resources.MENU_ITEM_SECURITY;
		((ToolStripItem)ToolStripMenuItemEnvironments_E).Text = Resources.FORM_WIZARD_MENU_ITEM_ENVIRONMENT;
		((ToolStripItem)ToolStripMenuItemMachine).Text = Resources.ITEM_MACHINE_ENVIRONMENTS;
		((ToolStripItem)ToolStripMenuItemComputer).Text = Resources.ITEM_COMPUTER_ENVIRONMENTS;
		((ToolStripItem)ToolStripMenuItemVersion_H).Text = Resources.MENU_ITEM_VERSION;
		setProcedureNames(procedureNameList, panel_P1_1, 0);
		((Control)labelP1Head).Text = Resources.FORM_WIZARD_PROLOGUE;
		((Control)radioButtonCreateFolder).Text = Resources.REGISTER_DESTINATION;
		((Control)radioButtonTroubleShoot).Text = Resources.LABEL_P1_002;
		((Control)btnP1Next).Text = Resources.ITEM_BUTTON_NEXT;
		((Control)btnP1TRNext).Text = Resources.ITEM_BUTTON_NEXT;
		((Control)btnP1Cancel).Text = Resources.ITEM_BUTTON_CANCEL;
		setProcedureNames(procedureNameList, panel_P2_1, 1);
		((Control)labelP2Head).Text = Resources.ITEM_CREATE_FOLDER;
		((Control)labelP2_FolderName).Text = Resources.FORM_MAIN_FOLDER_NAME;
		((Control)labelP2_FolderPath).Text = Resources.FORM_MAIN_FOLDER_PATH;
		((Control)labelP2_Folder).Text = Resources.FORM_MAIN_FOLDER_NAME;
		((Control)textBoxFolderName).Text = Resources.DEFAULT_FOLDER_NAME;
		((Control)buttonSelectFolder).Text = Resources.ITEM_BUTTON_REFFER;
		((Control)createNewFolderRadioButton).Text = Resources.LABEL_P2_002;
		((Control)selectFolderRadioButton).Text = Resources.LABEL_P2_003;
		((Control)labelP2_selectFolder).Text = Resources.LABEL_P2_004;
		((Control)selectNonSharedFolderRadioButton).Text = Resources.FORM_MAIN_NON_SHARED_FOLDER_PATH;
		((Control)labelP2_NonSharedFolderPath).Text = Resources.LABEL_P2_005;
		((Control)labelP2_selectNonSharedFolder).Text = Resources.LABEL_P2_006;
		((Control)buttonSelectNonSharedFolder).Text = Resources.ITEM_BUTTON_REFFER;
		((Control)labelP2_SharedName).Text = Resources.FORM_MAIN_FOLDER_NAME;
		setTextBoxInitialString(textBoxSharedName, Resources.TXT_P2_INITIAL_001);
		setTextBoxInitialString(textBoxNonSharedFolderPath, Resources.TXT_P2_INITIAL_003);
		((Control)btnP2Back).Text = Resources.ITEM_BUTTON_BACK;
		((Control)btnP2Next).Text = Resources.ITEM_BUTTON_NEXT;
		((Control)btnP2Cancel).Text = Resources.ITEM_BUTTON_CANCEL;
		setProcedureNames(procedureNameList, panel_P3_1, 2);
		((Control)labelP3Head).Text = Resources.FORM_WIZARD_PASSWORD;
		((Control)labelP3_UserName).Text = Resources.CREATE_HTML_DEFAULT_USER;
		((Control)labelP3_Password).Text = Resources.FORM_ADMIN_AUTH_PASSWORD;
		((Control)labelP3_PasswordConfirm).Text = Resources.FORM_MAIN_CONFIRM_PASSWORD;
		((Control)btnP3Back).Text = Resources.ITEM_BUTTON_BACK;
		((Control)btnP3Next).Text = Resources.ITEM_BUTTON_NEXT;
		((Control)btnP3Cancel).Text = Resources.ITEM_BUTTON_CANCEL;
		setProcedureNames(procedureNameList, panel_P4_1, 3);
		((Control)labelP4Head).Text = Resources.REGISTER_DESTINATION;
		((Control)labelP4_Destination).Text = Resources.CREATE_HTML_DEFAULT_DEST;
		((Control)labelP4_Path).Text = Resources.FORM_MAIN_PATH_NAME;
		((Control)labelP4_Machine).Text = Resources.FORM_MAIN_MACHINE;
		((Control)labelP4ConnectCheck).Text = Resources.PROGRESS_MESSAGE_0;
		((Control)linkLabelP4Connect).Text = Resources.FORM_WIZARD_CANNOT_CONNECT_LINK_MESSAGE;
		((Control)buttonP4HeadLine).Text = Resources.SETTING_HEADLINE;
		((Control)btnP4Back).Text = Resources.ITEM_BUTTON_BACK;
		((Control)btnP4Next).Text = Resources.ITEM_BUTTON_NEXT;
		((Control)btnP4Cancel).Text = Resources.ITEM_BUTTON_CANCEL;
		setProcedureNames(procedureNameList, panel_P5_1, 4);
		((Control)labelP5Head).Text = Resources.CONFIRM;
		((Control)label_TRP5_comment).Text = Resources.TROUBLE_SHOOTING_RESULT_COMMENT;
		((Control)btnP5Back).Text = Resources.ITEM_BUTTON_BACK;
		((Control)btnP5Execute).Text = Resources.ITEM_BUTTON_EXECUTE;
		((Control)btnP5Cancel).Text = Resources.ITEM_BUTTON_CANCEL;
		setProcedureNames(procedureNameList, panel_P6_1, 5);
		((Control)labelP6Head).Text = Resources.FORM_WIZARD_EXECUTING_TITLE;
		((Control)btnP6Excecute).Text = Resources.ITEM_BUTTON_EXECUTE;
		setProcedureNames(procedureNameList, panel_P7_1, 6);
		((Control)labelP7Head).Text = Resources.FORM_WIZARD_COMPLETE;
		((Control)linkLabelP7HelpRegist).Text = $"{Resources.DIRECT_REGIST_PROCEDURE_LINK_MESSAGE_01}\n{Resources.DIRECT_REGIST_PROCEDURE_LINK_MESSAGE_02}";
		((Control)linkLabelP7HelpSend).Text = Resources.FOLDER_SEND_PROCEDURE_LINK_MESSAGE;
		((Control)labelP7_ReportTitle).Text = Resources.FORM_WIZARD_REPORT;
		((Control)btnP7Top).Text = Resources.ITEM_BUTTON_TOP;
		((Control)btnP7End).Text = Resources.ITEM_BUTTON_END;
		((Control)labelP1_comment).Text = Resources.LABEL_P1_001;
		((Control)labelP2_comment).Text = Resources.LABEL_P2_001;
		((Control)labelP3_comment).Text = Resources.LABEL_P3_001;
		((Control)labelP4_comment).Text = Resources.LABEL_P4_001;
		((Control)labelP5_comment).Text = Resources.LABEL_P5_001;
		((Control)labelP6_comment).Text = Resources.LABEL_P6_001;
		((Control)attentionGroup).Text = Resources.TXT_P1_ATTENTION_TITLE;
		((Control)attentionRichTextBox).Text = $"{Resources.TXT_P1_ATTENTION_001}\n\n{Resources.TXT_P1_ATTENTION_002}\n{Resources.TXT_P1_ATTENTION_003}\n\n{Resources.TXT_P1_ATTENTION_004}";
		setProcedureNames(troubleShootProcedureNameList, panel_TRP2_1, 1);
		((Control)label_TRP2Head).Text = Resources.TROUBLE_SHOOTING_SELECT_DEVICE;
		((Control)label_TRP2_comment).Text = Resources.TROUBLE_SHOOTING_SELECT_DEVICE_COMMENT;
		((Control)label_TRP2_Machine).Text = Resources.FORM_MAIN_MACHINE;
		((Control)label_TRP2ConnectCheck).Text = Resources.PROGRESS_MESSAGE_0;
		((Control)label_TRP2ConnectCheck).Visible = false;
		((Control)btnTRP2Back).Text = Resources.ITEM_BUTTON_BACK;
		((Control)btnTRP2Next).Text = Resources.ITEM_BUTTON_NEXT;
		setProcedureNames(troubleShootProcedureNameList, panel_TRP3_1, 2);
		((Control)label_TRP3Head).Text = Resources.TROUBLE_SHOOTING_SELECT_USER;
		((Control)label_TRP3_comment).Text = $"{Resources.TROUBLE_SHOOTING_SELECT_USER_COMMENT_01}\n{Resources.TROUBLE_SHOOTING_SELECT_USER_COMMENT_02}";
		((Control)label_TRP3_SelectedDevice).Text = Resources.FORM_MFPINFO_SELECTED_MACHINE;
		((Control)label_TRP3Page).Text = Resources.LABEL_PAGE_NAME;
		((Control)label_TRP3DisplayedPage).Text = string.Empty;
		((Control)labelTRP3progressText).Text = string.Empty;
		((Control)buttonTRP3Search).Text = Resources.ITEM_BUTTON_SEARCH;
		((Control)buttonTRP3Break).Text = Resources.ITEM_BUTTON_SUSPEND;
		((Control)buttonTRP3Resume).Text = Resources.ITEM_BUTTON_RESUME;
		((Control)btnTRP3Back).Text = Resources.ITEM_BUTTON_BACK;
		((Control)btnTRP3Next).Text = Resources.ITEM_BUTTON_NEXT;
		setProcedureNames(troubleShootProcedureNameList, panel_TRP4_1, 3);
		((Control)label_TRP4Head).Text = Resources.TROUBLE_SHOOTING_ANALYZE;
		((Control)label_TRP4_progress).Text = string.Empty;
		progressBarTRP4.Value = 0;
		progressBarTRP4.Maximum = TR_PROGRESS_MAX;
		setProcedureNames(troubleShootProcedureNameList, panel_TRP5_1, 4);
		((Control)label_TRP5Head).Text = Resources.TROUBLE_SHOOTING_RESULT;
		((Control)btnTRP5Back).Text = Resources.ITEM_BUTTON_BACK;
		((Control)btnTRP5Next).Text = Resources.ITEM_BUTTON_NEXT;
		setProcedureNames(troubleShootProcedureNameList, panel_TRP6_1, 5);
		((Control)label_TRP6Head).Text = Resources.ITEM_FOLDER_SETTINGS;
		((Control)label_TRP6_FolderName).Text = Resources.FORM_MAIN_FOLDER_NAME;
		((Control)label_TRP6_FolderPath).Text = Resources.FORM_MAIN_FOLDER_PATH;
		((Control)label_TRP6_Folder).Text = Resources.FORM_MAIN_FOLDER_NAME;
		((Control)buttonTRP6SelectFolder).Text = Resources.ITEM_BUTTON_REFFER;
		((Control)radioButtonTRP6createNewFolder).Text = Resources.LABEL_P2_002;
		((Control)radioButtonTRP6selectExistFolder).Text = Resources.LABEL_P2_003;
		((Control)label_TRP6_SelectFolder).Text = Resources.LABEL_P2_004;
		((Control)label_TRP6_SelectNonSharedFolder).Text = Resources.LABEL_P2_006;
		((Control)label_TRP6_NonSharedFolderPath).Text = Resources.LABEL_P2_005;
		((Control)label_TRP6_SharedName).Text = Resources.FORM_MAIN_FOLDER_NAME;
		((Control)radioButtonTRP6selectNonSharedFolder).Text = Resources.FORM_MAIN_NON_SHARED_FOLDER_PATH;
		((Control)buttonTRP6SelectNonSharedFolder).Text = Resources.ITEM_BUTTON_REFFER;
		setTextBoxInitialString(textBoxTRP6SharedName, Resources.TXT_P2_INITIAL_001);
		setTextBoxInitialString(textBoxTRP6NonSharedFolderPath, Resources.TXT_P2_INITIAL_003);
		((Control)btnTRP6Back).Text = Resources.ITEM_BUTTON_BACK;
		((Control)btnTRP6Next).Text = Resources.ITEM_BUTTON_NEXT;
		setProcedureNames(troubleShootProcedureNameList, panel_TRP7_1, 6);
		((Control)label_TRP7Head).Text = Resources.FORM_WIZARD_PASSWORD;
		((Control)label_TRP7_UserName).Text = Resources.CREATE_HTML_DEFAULT_USER;
		((Control)label_TRP7_Password).Text = Resources.FORM_ADMIN_AUTH_PASSWORD;
		((Control)label_TRP7_PasswordConfirm).Text = Resources.FORM_MAIN_CONFIRM_PASSWORD;
		((Control)btnTRP7Back).Text = Resources.ITEM_BUTTON_BACK;
		((Control)btnTRP7Next).Text = Resources.ITEM_BUTTON_NEXT;
		setProcedureNames(troubleShootProcedureNameList, panel_TRP8_1, 7);
		((Control)label_TRP8Head).Text = Resources.REGISTER_DESTINATION;
		((Control)label_TRP8_Destination).Text = Resources.CREATE_HTML_DEFAULT_DEST;
		((Control)label_TRP8_Path).Text = Resources.FORM_MAIN_PATH_NAME;
		((Control)buttonTRP8HeadLine).Text = Resources.SETTING_HEADLINE;
		((Control)btnTRP8Back).Text = Resources.ITEM_BUTTON_BACK;
		((Control)btnTRP8Next).Text = Resources.ITEM_BUTTON_NEXT;
		setProcedureNames(troubleShootProcedureNameList, panel_TRP9_1, 8);
		((Control)label_TRP9Head).Text = Resources.CONFIRM;
		((Control)btnTRP9Back).Text = Resources.ITEM_BUTTON_BACK;
		((Control)btnTRP9Execute).Text = Resources.ITEM_BUTTON_EXECUTE;
		setProcedureNames(troubleShootProcedureNameList, panel_TRP10_1, 9);
		((Control)label_TRP10Head).Text = Resources.FORM_WIZARD_COMPLETE;
		((Control)linkLabelTRP10HelpRegist).Text = $"{Resources.DIRECT_REGIST_PROCEDURE_LINK_MESSAGE_01}\n{Resources.DIRECT_REGIST_PROCEDURE_LINK_MESSAGE_02}";
		((Control)linkLabelTRP10HelpSend).Text = Resources.FOLDER_SEND_PROCEDURE_LINK_MESSAGE;
		((Control)label_TRP10_ReportTitle).Text = Resources.FORM_WIZARD_REPORT;
		((Control)label_TRP10Report).Text = string.Empty;
		((Control)btnTRP10Top).Text = Resources.ITEM_BUTTON_TOP;
		((Control)btnTRP10End).Text = Resources.ITEM_BUTTON_END;
		((Control)linkLabelTRP10HelpRegist).Visible = false;
		((Control)linkLabelTRP10HelpSend).Visible = false;
		((Control)label_TRP4_comment).Text = Resources.LABEL_TRP4_001;
		((Control)label_TRP6_comment).Text = Resources.LABEL_TRP2_001;
		((Control)label_TRP7_comment).Text = Resources.LABEL_P3_001;
		((Control)label_TRP8_comment).Text = Resources.LABEL_P4_001;
		((Control)label_TRP9_comment).Text = Resources.LABEL_P5_001;
		try
		{
			LOG.InfoFormat("{0}：1:InitializeStart OS Version = {1}", (object)MethodBase.GetCurrentMethod().Name, (object)winVersion);
			LOG.InfoFormat("{0}：設定情報を初期化中 (2/5)……", (object)MethodBase.GetCurrentMethod().Name);
			Thread.Sleep(500);
			string text = (fMain.TextBoxFolderPath = CreateFolderUtil.getWindowsFolderName(CreateFolderUtil.getDesktopDirectory()));
			string text2 = text;
			((Control)textBoxFolderPath).Text = text2;
			((Control)textBoxTRP6FolderPath).Text = text2;
		}
		catch (Exception ex2)
		{
			LOG.InfoFormat("{0}：1:InitializeStart Error {1}", (object)MethodBase.GetCurrentMethod().Name, (object)ex2.ToString());
		}
		Console.WriteLine("2:" + DateTime.Now);
		formSplash.ProgressMsg = Resources.INITIALIZE_MSG_2_4;
		LOG.InfoFormat("{0}：ユーザー情報を取得中 (3/5)……", (object)MethodBase.GetCurrentMethod().Name);
		formSplash.ProgressRatio = 60;
		Application.DoEvents();
		try
		{
			setComboBoxPCUserList();
		}
		catch (Exception ex3)
		{
			LOG.InfoFormat("{0}：2:Create User Error {1}", (object)MethodBase.GetCurrentMethod().Name, (object)ex3.ToString());
		}
		Console.WriteLine("3:" + DateTime.Now);
		formSplash.ProgressMsg = Resources.INITIALIZE_MSG_3_4;
		LOG.InfoFormat("{0}：共有フォルダーを取得中 (4/5)……", (object)MethodBase.GetCurrentMethod().Name);
		formSplash.ProgressRatio = 80;
		Application.DoEvents();
		try
		{
			fs.setSharedFolderListTable();
			fs.setComboBoxPCUserList(fMain.ComboBoxFolder, fMain.ComboBoxPCUser);
		}
		catch (Exception ex4)
		{
			LOG.InfoFormat("{0}：3:Create Folder Error {1}", (object)MethodBase.GetCurrentMethod().Name, (object)ex4.ToString());
		}
		Thread.Sleep(500);
		Console.WriteLine("4:" + DateTime.Now);
		if (!flag2)
		{
			MessageBox.Show($"{Resources.NETWORK_DOWN_01}\n\n{Resources.NETWORK_DOWN_02}", Resources.CANT_GET_NETWORK_INFO_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
			((Form)formSplash).Close();
			((Component)(object)formSplash).Dispose();
			((Form)this).Close();
			return;
		}
		formSplash.ProgressMsg = Resources.INITIALIZE_MSG_4_4;
		LOG.InfoFormat("{0}：機器情報を取得中 (5/5)……", (object)MethodBase.GetCurrentMethod().Name);
		formSplash.ProgressRatio = 100;
		Application.DoEvents();
		try
		{
			setListBoxMFPList();
		}
		catch (Exception ex5)
		{
			LOG.InfoFormat("{0}：4:RICOH MachineList  Error {1}", (object)MethodBase.GetCurrentMethod().Name, (object)ex5.ToString());
		}
		Application.DoEvents();
		((Control)formSplash).Update();
		Thread.Sleep(500);
		Console.WriteLine("5:" + DateTime.Now);
		LOG.InfoFormat("{0}：初期化完了！……", (object)MethodBase.GetCurrentMethod().Name);
		formSplash.ProgressRatio = 100;
		Application.DoEvents();
		StateMachine.init();
		StateMachineTroubleShoot.init();
		tabControl1_Main.Appearance = (TabAppearance)1;
		tabControl1_Main.SizeMode = (TabSizeMode)2;
		tabControl1_Main.ItemSize = new Size(0, 1);
		tabControl1_Main.SelectedTab = tabPage1_introduction;
		((Control)labelP6Execute).Text = string.Empty;
		StateMachine.FormWizard = this;
		((Form)formSplash).Close();
		((Component)(object)formSplash).Dispose();
		((Form)this).Activate();
	}

	public void panelChange(StateMachine.StateType now, StateMachine.StateType next)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		switch (next)
		{
		case StateMachine.StateType.CREATE_FOLDER_SETUP:
			tabControl1_Main.SelectedTab = tabPage2_setupSelect;
			break;
		case StateMachine.StateType.USER_INFO_SETUP:
			tabControl1_Main.SelectedTab = tabPage3_shareFolder;
			break;
		case StateMachine.StateType.ADDRESSBOOK_SETUP:
			((Control)linkLabelP4Connect).Visible = false;
			tabControl1_Main.SelectedTab = tabPage4_address;
			break;
		case StateMachine.StateType.ADDRESSBOOK_CHECK:
			tabControl1_Main.SelectedTab = tabPage5_confirm;
			break;
		case StateMachine.StateType.ENV_SETTING:
			tabControl1_Main.SelectedTab = tabPage6_exec;
			break;
		case StateMachine.StateType.SETUP_FINISH:
			((ToolStripItem)ToolStripMenuItemDetail_D).Enabled = true;
			tabControl1_Main.SelectedTab = tabPage7_finish;
			break;
		case StateMachine.StateType.STANDBY:
			PrimaxModel = false;
			PrimaxUnicode = false;
			((ToolStripItem)ToolStripMenuItemDetail_D).Enabled = true;
			tabControl1_Main.SelectedTab = tabPage1_introduction;
			break;
		default:
			LOG.ErrorFormat("{0}：Next state [{1}] not found.", (object)MethodBase.GetCurrentMethod().Name, (object)next);
			break;
		case StateMachine.StateType.NO_STATE:
			break;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	public void panelChangeTroubleShoot(StateMachineTroubleShoot.StateType now, StateMachineTroubleShoot.StateType next)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		switch (next)
		{
		case StateMachineTroubleShoot.StateType.STANDBY:
			PrimaxModel = false;
			PrimaxUnicode = false;
			((ToolStripItem)ToolStripMenuItemDetail_D).Enabled = true;
			tabControl1_Main.SelectedTab = tabPage1_introduction;
			break;
		case StateMachineTroubleShoot.StateType.TR_DEVICE:
			setAdrBookListCtrl();
			tabControl1_Main.SelectedTab = tabTRP2_device;
			break;
		case StateMachineTroubleShoot.StateType.TR_USER:
			tabControl1_Main.SelectedTab = tabTRP3_user;
			break;
		case StateMachineTroubleShoot.StateType.TR_ANALYZE:
			tabControl1_Main.SelectedTab = tabTRP4_analyze;
			break;
		case StateMachineTroubleShoot.StateType.TR_RESULT:
			tabControl1_Main.SelectedTab = tabTRP5_result;
			break;
		case StateMachineTroubleShoot.StateType.TR_CREATE_FOLDER_SETUP:
			tabControl1_Main.SelectedTab = tabTRP6_setupSelect;
			break;
		case StateMachineTroubleShoot.StateType.TR_USER_INFO_SETUP:
			tabControl1_Main.SelectedTab = tabTRP7_shareFolder;
			break;
		case StateMachineTroubleShoot.StateType.TR_ADDRESSBOOK_SETUP:
			setTrAddressBookSetup();
			tabControl1_Main.SelectedTab = tabTRP8_address;
			break;
		case StateMachineTroubleShoot.StateType.TR_ADDRESSBOOK_CHECK:
			tabControl1_Main.SelectedTab = tabTRP9_confirm;
			break;
		case StateMachineTroubleShoot.StateType.TR_SETUP_FINISH:
			((ToolStripItem)ToolStripMenuItemDetail_D).Enabled = true;
			tabControl1_Main.SelectedTab = tabTRP10_finish;
			break;
		default:
			LOG.ErrorFormat("{0}：Next state [{1}] not found.", (object)MethodBase.GetCurrentMethod().Name, (object)next);
			break;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	private void setAdrBookListCtrl()
	{
		MachineControl mci = new MachineControl(machineLang);
		adrBookListCtrl = new AddressBookListControl(machineLang, mci);
		adrBookListCtrl.ButtonBreak = buttonTRP3Break;
		adrBookListCtrl.ButtonResume = buttonTRP3Resume;
		adrBookListCtrl.ButtonNext = buttonTRP3Next;
		adrBookListCtrl.ButtonPrevious = buttonTRP3Previous;
		adrBookListCtrl.ButtonSearch = buttonTRP3Search;
		adrBookListCtrl.ButtonToBottom = buttonTRP3ToBottom;
		adrBookListCtrl.ButtonToTop = buttonTRP3ToTop;
		adrBookListCtrl.ComboBoxSelectWay = comboBoxTRP3SelectWay;
		adrBookListCtrl.DisplayedPage = label_TRP3DisplayedPage;
		adrBookListCtrl.ListViewAddressList = listViewAddressList;
		adrBookListCtrl.ProgressText = labelTRP3progressText;
		adrBookListCtrl.TextBoxSearch = textBoxTRP3Search;
		adrBookListCtrl.initialize();
	}

	private void setProcedureNames(List<string> nameList, Panel panel, int highLightLineNo)
	{
		//IL_0028: Unknown result type (might be due to invalid IL or missing references)
		//IL_002f: Expected O, but got Unknown
		//IL_0083: Unknown result type (might be due to invalid IL or missing references)
		//IL_004d: Unknown result type (might be due to invalid IL or missing references)
		//IL_00df: Unknown result type (might be due to invalid IL or missing references)
		//IL_00e0: Unknown result type (might be due to invalid IL or missing references)
		//IL_00ea: Expected O, but got Unknown
		//IL_00ad: Unknown result type (might be due to invalid IL or missing references)
		int num = -1;
		int x = PROCEDURE_TITLE_INDENT;
		int num2 = PROCEDURE_TITLE_Y_POS;
		foreach (string name in nameList)
		{
			Label val = new Label();
			((Control)val).Text = name;
			Point location = new Point(x, num2);
			float num3;
			FontStyle val2;
			if (num < 0)
			{
				num3 = 12f;
				val2 = (FontStyle)1;
				x = PROCEDURE_NAME_INDENT;
				num2 += PROCEDURE_TITLE_GAP;
				if (name.Contains("\n"))
				{
					num2 += PROCEDURE_TITLE_HEIGHT;
				}
			}
			else
			{
				num3 = 9f;
				val2 = (FontStyle)0;
				num2 += PROCEDURE_NAME_GAP;
				if (name.Contains("\n"))
				{
					num2 += PROCEDURE_NAME_HEIGHT;
				}
				if (num == highLightLineNo)
				{
					val2 = (FontStyle)1;
					((Control)val).ForeColor = Color.FromArgb(0, 128, 192);
				}
				else if (num < highLightLineNo)
				{
					((Control)val).ForeColor = Color.Gray;
				}
			}
			((Control)val).Font = new Font(Resources.FONT, num3, val2);
			((Control)val).AutoSize = true;
			((Control)val).Location = location;
			((Control)panel).Controls.Add((Control)(object)val);
			((Control)val).BringToFront();
			num++;
		}
	}

	private string getWinVersion()
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		_ = string.Empty;
		OperatingSystem oSVersion = Environment.OSVersion;
		Console.WriteLine(oSVersion.ToString());
		Console.WriteLine(oSVersion.VersionString);
		Console.WriteLine(oSVersion.Version.ToString());
		Console.WriteLine(oSVersion.Platform);
		Console.WriteLine(oSVersion.Version.Major);
		Console.WriteLine(oSVersion.Version.Minor);
		Console.WriteLine(oSVersion.Version.Build);
		Console.WriteLine(oSVersion.Version.Revision);
		Console.WriteLine(oSVersion.ServicePack);
		Console.WriteLine(oSVersion.Version.MajorRevision);
		Console.WriteLine(oSVersion.Version.MinorRevision);
		string result = oSVersion.Version.Major + "." + oSVersion.Version.Minor;
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return result;
	}

	private void setComboBoxPCUserList()
	{
		//IL_018a: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		ComboBox[] array = (ComboBox[])(object)new ComboBox[4] { cmbP3UserName, cmbTRP7PcUser, fMain.ComboBoxUser, fMain.ComboBoxUser_share };
		try
		{
			string hostName = Dns.GetHostName();
			List<string> localUserList = GetLocalUserList();
			ComboBox[] array2;
			foreach (string item in localUserList)
			{
				array2 = array;
				for (int i = 0; i < array2.Length; i++)
				{
					array2[i].Items.Add((object)(hostName + "\\" + item));
				}
			}
			string loginUserName = getLoginUserName();
			Console.Out.WriteLine(loginUserName);
			LOG.DebugFormat("{0}：fullUserName = {1}", (object)MethodBase.GetCurrentMethod().Name, (object)loginUserName);
			int num = 0;
			foreach (string item2 in localUserList)
			{
				if (!loginUserName.Equals(item2, StringComparison.CurrentCultureIgnoreCase))
				{
					num++;
					continue;
				}
				break;
			}
			if (num == localUserList.Count)
			{
				array2 = array;
				for (int i = 0; i < array2.Length; i++)
				{
					array2[i].Items.Add((object)loginUserName);
				}
			}
			array2 = array;
			for (int i = 0; i < array2.Length; i++)
			{
				((ListControl)array2[i]).SelectedIndex = num;
			}
		}
		catch (Exception ex)
		{
			MessageBox.Show(Resources.ERR_MSG_FATAL, Resources.ERR_TITLE_CREATE_FOLDER, (MessageBoxButtons)0, (MessageBoxIcon)16);
			LOG.ErrorFormat("{0}：PCユーザ一覧表示でエラー：\n{1}", (object)MethodBase.GetCurrentMethod().Name, (object)ex.ToString());
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	private string getLoginUserName()
	{
		string text = WmiManager.GetUserName();
		if (string.IsNullOrEmpty(text))
		{
			text = Environment.UserDomainName + "\\" + Environment.UserName;
		}
		LOG.DebugFormat("{0}：Login user name=[{1}]", (object)MethodBase.GetCurrentMethod().Name, (object)text);
		return text;
	}

	public static List<string> GetMFPList()
	{
		//IL_0032: Unknown result type (might be due to invalid IL or missing references)
		//IL_0038: Expected O, but got Unknown
		//IL_004d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0052: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		machineInfoList.Clear();
		mfpTable.Clear();
		OctetString val = new OctetString("public");
		IPEndPoint iPEndPoint = new IPEndPoint(IPAddress.Parse(localBroadCasetAddr), 161);
		Discoverer val2 = new Discoverer();
		val2.AgentFound += DiscovererAgentFound;
		val2.Discover((VersionCode)0, iPEndPoint, val, 3000);
		foreach (string key in mfpTable.Keys)
		{
			string text2 = string.Empty;
			string arg = key.Substring(0, key.IndexOf(":"));
			string[] array = ((string)mfpTable[key]).Split(new char[1] { ' ' });
			for (int i = 0; i < array.Count() && i <= 3; i++)
			{
				text2 = text2 + " " + array[i];
			}
			if (!text2.Contains("IPSiO"))
			{
				machineInfoList.Add($"{text2}  ({arg})");
			}
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return machineInfoList;
	}

	private void setListBoxMFPList()
	{
		//IL_01de: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		try
		{
			machineSelectControl.initialize();
			mfpIpAddr = string.Empty;
			displayedContents = string.Empty;
			ipaddr = fMain.getIPAddress();
			string text = string.Empty;
			NetworkInterface[] allNetworkInterfaces = NetworkInterface.GetAllNetworkInterfaces();
			foreach (NetworkInterface networkInterface in allNetworkInterfaces)
			{
				if (networkInterface.OperationalStatus != OperationalStatus.Up || networkInterface.NetworkInterfaceType == NetworkInterfaceType.Loopback || networkInterface.NetworkInterfaceType == NetworkInterfaceType.Tunnel)
				{
					continue;
				}
				IPInterfaceProperties iPProperties = networkInterface.GetIPProperties();
				if (iPProperties == null)
				{
					continue;
				}
				foreach (UnicastIPAddressInformation unicastAddress in iPProperties.UnicastAddresses)
				{
					if (string.Equals(unicastAddress.Address.ToString(), ipaddr))
					{
						text = unicastAddress.IPv4Mask.ToString();
						break;
					}
				}
				if (!string.IsNullOrEmpty(text))
				{
					break;
				}
			}
			string[] array = ipaddr.Split(new char[1] { '.' });
			string[] array2 = text.Split(new char[1] { '.' });
			byte[] array3 = new byte[4];
			for (int j = 0; j < array.Length; j++)
			{
				array3[j] = (byte)(byte.Parse(array[j]) | ~byte.Parse(array2[j]));
			}
			localBroadCasetAddr = $"{array3[0]}.{array3[1]}.{array3[2]}.{array3[3]}";
			GetMFPList();
			machineSelectControl.setMachineList(machineInfoList);
			machineSelectControlTRP2.setMachineList(machineInfoList);
		}
		catch (Exception ex)
		{
			MessageBox.Show(Resources.ERR_MSG_FATAL, Resources.ERR_TITLE_CREATE_FOLDER, (MessageBoxButtons)0, (MessageBoxIcon)16);
			LOG.ErrorFormat("{0}：機器情報一覧表示でエラー：\n{1}", (object)MethodBase.GetCurrentMethod().Name, (object)ex.ToString());
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	private static void DiscovererAgentFound(object sender, AgentFoundEventArgs e)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		string text = e.Agent.ToString();
		Console.WriteLine("{0} announces {1}", e.Agent, (e.Variable == null) ? "it supports v3" : e.Variable.Data.ToString());
		if (e.Variable != null)
		{
			string text2 = e.Variable.Data.ToString();
			LOG.DebugFormat("{0}：AgentGet：{1} {2}", (object)MethodBase.GetCurrentMethod().Name, (object)text, (object)text2);
			if (text2.IndexOf("RICOH") >= 0 && !mfpTable.ContainsKey(text))
			{
				mfpTable.Add(text, text2);
			}
		}
		else
		{
			LOG.DebugFormat("AgentGet：{0} e.Variable is null", (object)text);
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	private string getHostInfo(string pMachineInfo)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		string empty = string.Empty;
		ipaddr = string.Empty;
		hostname = string.Empty;
		try
		{
			hostname = Dns.GetHostName();
			Dns.GetHostEntry(hostname);
			ipaddr = fMain.getIPAddress();
		}
		catch (Exception ex)
		{
			Console.WriteLine(ex.ToString());
			LOG.ErrorFormat("{0}：！！！ ネットワーク情報取得中にエラー  \n" + ex.ToString() + "\n*******************************", (object)MethodBase.GetCurrentMethod().Name);
		}
		if (hostname != string.Empty)
		{
			if (ipaddr != string.Empty)
			{
				int num = pMachineInfo.LastIndexOf('.');
				int length = ipaddr.LastIndexOf('.');
				if (num > 0 && pMachineInfo.Substring(0, num).Equals(ipaddr.Substring(0, length)))
				{
					empty = hostname;
				}
				else if (ipaddr != string.Empty)
				{
					empty = ipaddr;
				}
			}
		}
		else if (ipaddr != string.Empty)
		{
			empty = ipaddr;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return empty;
	}

	private void setCmbBoxP4Path()
	{
		ipaddr = string.Empty;
		hostname = string.Empty;
		cmbP4FolderPath.Items.Clear();
		string empty = string.Empty;
		empty = (createNewFolderRadioButton.Checked ? ((Control)textBoxFolderName).Text : ((!selectFolderRadioButton.Checked) ? Path.GetFileName(getPathFromWindowsName(((Control)textBoxNonSharedFolderPath).Text)) : ((Control)cmbP2Folder).Text));
		ipaddr = fMain.getIPAddress();
		cmbP4FolderPath.Items.Add((object)("\\\\" + ipaddr + "\\" + empty));
		hostname = Dns.GetHostName();
		cmbP4FolderPath.Items.Add((object)("\\\\" + hostname + "\\" + empty));
		if (fMain.DhcpCaution)
		{
			((ListControl)cmbP4FolderPath).SelectedIndex = 1;
		}
		else
		{
			((ListControl)cmbP4FolderPath).SelectedIndex = 0;
		}
	}

	private void setSelectFolder(TextBox textbox)
	{
		//IL_004d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0053: Expected O, but got Unknown
		//IL_006d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0073: Invalid comparison between Unknown and I4
		//IL_0093: Unknown result type (might be due to invalid IL or missing references)
		//IL_009d: Expected O, but got Unknown
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		LOG.InfoFormat("{0}：フォルダ選択ボタン押下\n", (object)MethodBase.GetCurrentMethod().Name);
		string text = getPathFromWindowsName(((Control)textbox).Text);
		if (!Directory.Exists(text))
		{
			text = CreateFolderUtil.getDesktopDirectory();
		}
		FolderBrowserDialog val = new FolderBrowserDialog();
		val.SelectedPath = text;
		val.Description = Resources.SELECT_DEST_SHARE_FOLDER;
		val.ShowNewFolderButton = false;
		if ((int)((CommonDialog)val).ShowDialog() == 1)
		{
			((Control)textbox).Text = CreateFolderUtil.getWindowsFolderName(val.SelectedPath);
			((Control)textbox).Font = new Font(Resources.FONT, 9f, (FontStyle)0);
			((Control)textbox).ForeColor = Color.Black;
			LOG.InfoFormat("{0}：end フォルダ選択結果:{1}, 表示名：{2}\n", (object)MethodBase.GetCurrentMethod().Name, (object)val.SelectedPath, (object)((Control)textbox).Text);
		}
	}

	private void buttonSelectFolder_Click(object sender, EventArgs e)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		setSelectFolder(textBoxFolderPath);
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	private void buttonNonSharedSelectFolder_Click(object sender, EventArgs e)
	{
		//IL_00bc: Unknown result type (might be due to invalid IL or missing references)
		//IL_00c6: Expected O, but got Unknown
		//IL_005d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0067: Expected O, but got Unknown
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		setSelectFolder(textBoxNonSharedFolderPath);
		if (((Control)textBoxNonSharedFolderPath).Text == string.Empty)
		{
			((Control)textBoxSharedName).Text = Resources.TXT_P2_INITIAL_001;
			((Control)textBoxSharedName).Font = new Font("Resources.FONT", 9f, (FontStyle)2);
			((Control)textBoxSharedName).ForeColor = Color.FromArgb(195, 195, 195);
		}
		else
		{
			string fileName = Path.GetFileName(getPathFromWindowsName(((Control)textBoxNonSharedFolderPath).Text));
			((Control)textBoxSharedName).Text = fileName;
			((Control)textBoxSharedName).Font = new Font("Resources.FONT", 9f, (FontStyle)0);
			((Control)textBoxSharedName).ForeColor = Color.Black;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	private string getPathFromWindowsName(string name)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		_ = string.Empty;
		string[] array = name.Split('(', ')');
		string result = ((array.Length > 2) ? array[1] : name);
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return result;
	}

	private void btnP2Next_Click(object sender, EventArgs e)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		FOLDER_TYPE folder_type = ((!createNewFolderRadioButton.Checked) ? (selectFolderRadioButton.Checked ? FOLDER_TYPE.SHARED_FOLDER : FOLDER_TYPE.NON_SHARED_FOLDER) : FOLDER_TYPE.CREATE_FOLDRE);
		checkFolderSetting(folder_type, ((Control)textBoxFolderName).Text, ((Control)textBoxFolderPath).Text, ((Control)cmbP2Folder).Text, ((Control)textBoxSharedName).Text, ((Control)textBoxNonSharedFolderPath).Text);
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
	}

	private void checkFolderSetting(FOLDER_TYPE folder_type, string folderNameSetting, string folderPathSetting, string existingFolder, string sharedName, string nonSharedFolder)
	{
		//IL_005b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0425: Unknown result type (might be due to invalid IL or missing references)
		//IL_03ac: Unknown result type (might be due to invalid IL or missing references)
		//IL_008d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0458: Unknown result type (might be due to invalid IL or missing references)
		//IL_03f0: Unknown result type (might be due to invalid IL or missing references)
		//IL_00b4: Unknown result type (might be due to invalid IL or missing references)
		//IL_0480: Unknown result type (might be due to invalid IL or missing references)
		//IL_00e7: Unknown result type (might be due to invalid IL or missing references)
		//IL_04b5: Unknown result type (might be due to invalid IL or missing references)
		//IL_012a: Unknown result type (might be due to invalid IL or missing references)
		//IL_04fd: Unknown result type (might be due to invalid IL or missing references)
		//IL_0180: Unknown result type (might be due to invalid IL or missing references)
		//IL_0152: Unknown result type (might be due to invalid IL or missing references)
		//IL_0559: Unknown result type (might be due to invalid IL or missing references)
		//IL_0527: Unknown result type (might be due to invalid IL or missing references)
		//IL_022a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0716: Unknown result type (might be due to invalid IL or missing references)
		//IL_071c: Invalid comparison between Unknown and I4
		//IL_0617: Unknown result type (might be due to invalid IL or missing references)
		//IL_02fb: Unknown result type (might be due to invalid IL or missing references)
		try
		{
			LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			((Control)this).Cursor = Cursors.WaitCursor;
			nonSharedFolder = getPathFromWindowsName(nonSharedFolder);
			switch (folder_type)
			{
			case FOLDER_TYPE.CREATE_FOLDRE:
				if (string.IsNullOrEmpty(folderNameSetting) || folderNameSetting.Equals(Resources.TXT_P2_INITIAL_001))
				{
					MessageBox.Show(Resources.TEXT_BOX_FOLDER_NAME_EMPTY_ERROR_TEXT, Resources.TEXT_BOX_FOLDER_NAME_INPUT_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
					throw new Exception("input error . FolderName");
				}
				if (Encoding.GetEncoding("Shift_JIS").GetByteCount(folderNameSetting) > 80)
				{
					MessageBox.Show(Resources.FOLDER_NAME_LENGTH_ERROR_TEXT, Resources.TEXT_BOX_FOLDER_NAME_INPUT_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
					throw new Exception("input error . FolderName");
				}
				if (!IsSafePath(folderNameSetting))
				{
					MessageBox.Show(Resources.TEXT_BOX_FOLDER_NAME_CONTAINS_ILLEGAL_CHARS_ERROR_TEXT, Resources.TEXT_BOX_FOLDER_NAME_INPUT_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
					throw new Exception("input error . FolderName");
				}
				if (string.IsNullOrEmpty(folderPathSetting) || folderPathSetting.Equals(Resources.TXT_P2_INITIAL_002))
				{
					MessageBox.Show(Resources.ERR_MSG_CMD_FOLDER_PATH_NOT_SET, Resources.TEXT_BOX_FOLDER_PATH_INPUT_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
					throw new Exception("input error . FolderPath");
				}
				if (PrimaxModel)
				{
					string pathFromWindowsName = getPathFromWindowsName(folderPathSetting);
					MachineControl machineControl2 = new MachineControl(machineLang);
					if (machineControl2.convHexString(pathFromWindowsName, MachineControl.PRIMAX_HEX_ENCODINGT.SJIS) == null)
					{
						MessageBox.Show(Resources.ERR_MES_CREATEFOLDERPATH_CHAR_TYPE, Resources.ERR_MES_TITLE_CREATEFOLDERPATH_CHAR_TYPE, (MessageBoxButtons)0, (MessageBoxIcon)16);
						throw new Exception("input error .Location");
					}
					if (machineControl2.convHexString(folderNameSetting, MachineControl.PRIMAX_HEX_ENCODINGT.SJIS) == null)
					{
						MessageBox.Show(Resources.ERR_MSG_SHARENAME_CHAR_TYPE, Resources.ERR_MSG_TITLE_SHARENAME_CHAR_TYPE, (MessageBoxButtons)0, (MessageBoxIcon)16);
						throw new Exception("input error .Shared folder name");
					}
				}
				try
				{
					string pathFromWindowsName2 = getPathFromWindowsName(folderPathSetting);
					if (!Directory.Exists(pathFromWindowsName2))
					{
						MessageBox.Show(Resources.TEXT_BOX_FOLDER_PATH_ERROR_TEXT, Resources.TEXT_BOX_FOLDER_PATH_INPUT_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
						throw new Exception("input error . Folder Not Found！！ FolderPath");
					}
					string sharedFolderPath = getSharedFolderPath(folderNameSetting);
					if (sharedFolderPath != string.Empty)
					{
						string text = string.Empty;
						if (Directory.Exists(sharedFolderPath))
						{
							text = $"\u3000{Resources.ITEM_DEST_SHARE_FOLDER}{sharedFolderPath}\n";
						}
						StringBuilder stringBuilder = new StringBuilder();
						stringBuilder.Append(Resources.EXISTS_SAME_NAME_SHARE_FOLDER_ERROR_1);
						stringBuilder.Append(Resources.EXISTS_SAME_NAME_SHARE_FOLDER_ERROR_2_WIZARD);
						stringBuilder.Append(Resources.EXISTS_SAME_NAME_SHARE_FOLDER_ERROR_3);
						stringBuilder.Append(Resources.ITEM_SHARE_FOLDER_NAME + folderNameSetting + "\n");
						stringBuilder.Append(text + "\n");
						MessageBox.Show(stringBuilder.ToString(), Resources.ERR_TITLE_CREATE_FOLDER, (MessageBoxButtons)0, (MessageBoxIcon)16);
						LOG.ErrorFormat("{0}：!!! 共有フォルダーの作成エラー  \n同じ名前の共有フォルダーが存在します。[共有フォルダー名]を変更してください。\n\n[見つかった共有フォルダー情報]\n\u3000共有フォルダー名：" + folderNameSetting + "\n\u3000作成場所：" + sharedFolderPath, (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
						throw new Exception(string.Format("{0}", "Found Same Folder Name."));
					}
					string text2 = pathFromWindowsName2 + (pathFromWindowsName2.EndsWith("\\") ? "" : "\\") + folderNameSetting;
					if (Directory.Exists(text2))
					{
						StringBuilder stringBuilder2 = new StringBuilder();
						stringBuilder2.Append(Resources.ERR_MSG_EXISTING_SAME_NAME_DEST_TEXT_1);
						stringBuilder2.Append(Resources.ERR_MSG_EXISTING_SAME_NAME_DEST_TEXT_2_WIZARD);
						stringBuilder2.Append(Resources.EXISTS_SAME_NAME_SHARE_FOLDER_ERROR_3);
						stringBuilder2.Append(Resources.ITEM_SHARE_FOLDER_NAME + folderNameSetting + "\n");
						stringBuilder2.Append(Resources.ITEM_DEST_SHARE_FOLDER + text2 + "\n");
						MessageBox.Show(stringBuilder2.ToString(), Resources.ERR_TITLE_CREATE_FOLDER, (MessageBoxButtons)0, (MessageBoxIcon)16);
						throw new Exception(string.Format("{0}", "Found Same Folder Name."));
					}
					return;
				}
				catch (Exception ex)
				{
					Console.Out.WriteLine(ex.ToString());
					LOG.ErrorFormat("{0}：！！！ 共有フォルダー作成エラー  \n" + ex.ToString() + "\n*******************************", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
					LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
					throw new Exception($"{ex.ToString()}");
				}
			case FOLDER_TYPE.SHARED_FOLDER:
				if (string.IsNullOrEmpty(existingFolder))
				{
					MessageBox.Show(Resources.TEXT_BOX_FOLDER_NAME_EMPTY_ERROR_TEXT, Resources.TEXT_BOX_FOLDER_NAME_INPUT_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
					throw new Exception("input error . Existing FolderName");
				}
				if (PrimaxModel)
				{
					MachineControl machineControl = new MachineControl(machineLang);
					if (machineControl.convHexString(existingFolder, MachineControl.PRIMAX_HEX_ENCODINGT.SJIS) == null)
					{
						MessageBox.Show(Resources.ERR_MSG_SHARENAME_CHAR_TYPE, Resources.ERR_MSG_TITLE_SHARENAME_CHAR_TYPE, (MessageBoxButtons)0, (MessageBoxIcon)16);
						throw new Exception("input error .Shared folder name");
					}
				}
				return;
			}
			if (string.IsNullOrEmpty(sharedName) || sharedName.Equals(Resources.TXT_P2_INITIAL_001))
			{
				MessageBox.Show(Resources.TEXT_BOX_FOLDER_NAME_EMPTY_ERROR_TEXT, Resources.TEXT_BOX_FOLDER_NAME_INPUT_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
				throw new Exception("input error . Shared Name");
			}
			if (Encoding.GetEncoding("Shift_JIS").GetByteCount(sharedName) > 80)
			{
				MessageBox.Show(Resources.FOLDER_NAME_LENGTH_ERROR_TEXT, Resources.TEXT_BOX_FOLDER_NAME_INPUT_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
				throw new Exception("input error . Shared Name");
			}
			if (!IsSafePath(sharedName))
			{
				MessageBox.Show(Resources.TEXT_BOX_FOLDER_NAME_CONTAINS_ILLEGAL_CHARS_ERROR_TEXT, Resources.TEXT_BOX_FOLDER_NAME_INPUT_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
				throw new Exception("input error . Shared Name");
			}
			if (string.IsNullOrEmpty(nonSharedFolder) || nonSharedFolder.Equals(Resources.TXT_P2_INITIAL_003))
			{
				MessageBox.Show(Resources.TEXT_BOX_NON_SHARED_FOLDER_NAME_EMPTY_ERROR_TEXT, Resources.TEXT_BOX_NON_SHARED_FOLDER_PATH_INPUT_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
				throw new Exception("input error . NonSharedFilderPath");
			}
			if (PrimaxModel)
			{
				string pathFromWindowsName3 = getPathFromWindowsName(nonSharedFolder);
				MachineControl machineControl3 = new MachineControl(machineLang);
				if (machineControl3.convHexString(pathFromWindowsName3, MachineControl.PRIMAX_HEX_ENCODINGT.SJIS) == null)
				{
					MessageBox.Show(Resources.ERR_MSG_PATH_CHAR_TYPE, Resources.ERR_MSG_TITLE_PATH_CHAR_TYPE, (MessageBoxButtons)0, (MessageBoxIcon)16);
					throw new Exception("input error .Folder location");
				}
				if (machineControl3.convHexString(sharedName, MachineControl.PRIMAX_HEX_ENCODINGT.SJIS) == null)
				{
					MessageBox.Show(Resources.ERR_MSG_SHARENAME_CHAR_TYPE, Resources.ERR_MSG_TITLE_SHARENAME_CHAR_TYPE, (MessageBoxButtons)0, (MessageBoxIcon)16);
					throw new Exception("input error .Shared folder name");
				}
			}
			try
			{
				string pathFromWindowsName4 = getPathFromWindowsName(nonSharedFolder);
				if (!Directory.Exists(pathFromWindowsName4))
				{
					MessageBox.Show(Resources.TEXT_BOX_NON_SHARED_FOLDER_PATH_ERROR_TEXT, Resources.TEXT_BOX_NON_SHARED_FOLDER_PATH_INPUT_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
					throw new Exception("input error . Folder Not Found！！ Folder");
				}
				string sharedFolderPath2 = getSharedFolderPath(sharedName);
				if (sharedFolderPath2 != string.Empty && !new PowerShellManager().isSharedSetting(sharedName, nonSharedFolder))
				{
					string text3 = string.Empty;
					if (Directory.Exists(sharedFolderPath2))
					{
						text3 = sharedFolderPath2;
					}
					MessageBox.Show(Resources.EXISTS_SET_SHARE_NAME_FOLDER_ERROR_1 + "\n" + Resources.EXISTS_SET_SHARE_NAME_FOLDER_ERROR_2 + text3 + "\n\n" + Resources.EXISTS_SET_SHARE_NAME_FOLDER_ERROR_3 + "\n" + Resources.EXISTS_SET_SHARE_NAME_FOLDER_ERROR_4 + "\n" + Resources.EXISTS_SET_SHARE_NAME_FOLDER_ERROR_5 + "\n", Resources.ERR_TITLE_SHARED_SETTING, (MessageBoxButtons)0, (MessageBoxIcon)16);
					LOG.ErrorFormat("{0}：!!! 共有設定エラー  \n同じ名前の共有フォルダーがコンピューターに存在します。[共有フォルダー名]を変更してください。\n\n[見つかった共有フォルダー情報]\n\u3000共有フォルダー名：" + sharedName + "\n\u3000共有設定対象フォルダー：" + nonSharedFolder, (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
					throw new Exception(string.Format("{0}", "Found Same Shared Name."));
				}
				string notShareName = CreateFolderUtil.getNotShareName(pathFromWindowsName4);
				if (!string.IsNullOrEmpty(notShareName) && 0 > notShareName.IndexOf(sharedName))
				{
					string text4 = Resources.EXISTS_SET_SHARE_NAME_CONFIGURED_ERROR_1 + "\n" + Resources.EXISTS_SET_SHARE_NAME_CONFIGURED_ERROR_2 + notShareName + "\n\n" + Resources.EXISTS_SET_SHARE_NAME_CONFIGURED_ERROR_3 + "\n" + Resources.EXISTS_SET_SHARE_NAME_CONFIGURED_ERROR_4 + "\n" + Resources.EXISTS_SET_SHARE_NAME_CONFIGURED_ERROR_5 + "\n";
					if ((int)new CustomizableMessageBox
					{
						ButtonText = 
						{
							Yes = Resources.ITEM_BUTTON_NEXT,
							No = Resources.ITEM_BUTTON_BACK
						}
					}.Show(text4, Resources.CHECK_SHARING_SETTINGS, (MessageBoxButtons)4, (MessageBoxIcon)48) == 7)
					{
						throw new Exception(string.Format("{0}", "Found Same Shared Name."));
					}
					return;
				}
			}
			catch (Exception ex2)
			{
				Console.Out.WriteLine(ex2.ToString());
				LOG.ErrorFormat("{0}：！！！ 共有設定エラー  \n" + ex2.ToString() + "\n*******************************", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
				LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
				throw new Exception($"{ex2.ToString()}");
			}
		}
		finally
		{
			((Control)this).Cursor = Cursors.Default;
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		}
	}

	private void btnP3Next_Click(object sender, EventArgs e)
	{
		//IL_005e: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		((Control)this).Cursor = Cursors.WaitCursor;
		try
		{
			string text = ((Control)cmbP3UserName).Text;
			if (!string.IsNullOrEmpty(text) && Encoding.GetEncoding("Shift_JIS").GetByteCount(text) > 64)
			{
				MessageBox.Show(Resources.USER_NAME_LENGTH_ERROR_TEXT, Resources.USER_NAME_LENGTH_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
				throw new Exception("input error . userInfo");
			}
			passwordCheck(((Control)textBoxP3Pass).Text, ((Control)textBoxP3PassConfirm).Text, "textBoxP4Path", machineLang);
			setCmbBoxP4Path();
		}
		catch (Exception ex)
		{
			Console.Out.WriteLine(ex.ToString());
			LOG.ErrorFormat("{0}：！！！ 共有フォルダー作成エラー  \n" + ex.ToString() + "\n*******************************", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			throw new Exception($"{ex.ToString()}");
		}
		finally
		{
			((Control)this).Cursor = Cursors.Default;
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		}
	}

	private void btnP4Next_Click(object sender, EventArgs e)
	{
		//IL_00bf: Unknown result type (might be due to invalid IL or missing references)
		//IL_00fb: Unknown result type (might be due to invalid IL or missing references)
		//IL_0170: Unknown result type (might be due to invalid IL or missing references)
		//IL_0213: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		((Control)this).Cursor = Cursors.WaitCursor;
		((Control)menuStrip1).Enabled = false;
		((Control)textP4Destination).Enabled = false;
		((Control)cmbP4FolderPath).Enabled = false;
		((Control)buttonP4HeadLine).Enabled = false;
		((Control)machineSelectControl).Enabled = false;
		((Control)btnP4Back).Enabled = false;
		((Control)btnP4Next).Enabled = false;
		((Control)linkLabelP4Connect).Visible = false;
		try
		{
			if (string.IsNullOrEmpty(((Control)textP4Destination).Text) || ((Control)textP4Destination).Text.Equals(Resources.TXT_P4_INITIAL_001))
			{
				MessageBox.Show(Resources.TEXT_P4_ADDRESS_NAME_EMPTY_ERROR_TEXT, Resources.ERR_TITLE_FOLDER_NAME, (MessageBoxButtons)0, (MessageBoxIcon)16);
				throw new Exception("input error . textP4Destination");
			}
			if (Encoding.GetEncoding("Shift_JIS").GetByteCount(((Control)textP4Destination).Text) > 16)
			{
				MessageBox.Show(Resources.TEXT_P4_ADDRESS_NAME_LENGTH_ERROR_TEXT, Resources.ERR_TITLE_FOLDER_NAME, (MessageBoxButtons)0, (MessageBoxIcon)16);
				LOG.InfoFormat("{0}：機器の設定エラー：宛先名16バイト以上{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)((Control)textP4Destination).Text);
				throw new Exception("input error . textP4Destination");
			}
			if (cmbP4FolderPath.SelectedItem.ToString() == null || cmbP4FolderPath.SelectedItem.ToString().Equals(""))
			{
				MessageBox.Show(Resources.TEXT_BOX_P4_PATH_EMPTY_ERROR_TEXT, Resources.MACHINE_SETTING_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
				LOG.ErrorFormat("{0}：機器の設定エラー：PATH無し{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)cmbP4FolderPath.SelectedItem.ToString());
				throw new Exception("input error . cmbP4FolderPath");
			}
			if (cmbP4FolderPath.SelectedItem.ToString() != null && !cmbP4FolderPath.SelectedItem.ToString().Equals("") && Encoding.GetEncoding("Shift_JIS").GetByteCount(cmbP4FolderPath.SelectedItem.ToString()) > 256)
			{
				MessageBox.Show(Resources.TEXT_BOX_P4_PATH_LENGTH_ERROR_TEXT, Resources.INPUT_PASSWORD_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
				LOG.ErrorFormat("{0}：機器の設定エラー：PATH MAX BYTE OVER{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)cmbP4FolderPath.SelectedItem.ToString());
				throw new Exception("input error . cmbP4FolderPath");
			}
			InputCheckToPrimax();
			machineSelectCheck(machineSelectControl, labelP4ConnectCheck, linkLabelP4Connect, fMain.DhcpCaution);
			setReportCreateFolderAddressMsg(finishFlg: false, labelP5Info);
			machineSelectControl.setBackDisplayName(displayedContents);
		}
		finally
		{
			((Control)menuStrip1).Enabled = true;
			((Control)textP4Destination).Enabled = true;
			((Control)cmbP4FolderPath).Enabled = true;
			((Control)buttonP4HeadLine).Enabled = true;
			((Control)machineSelectControl).Enabled = true;
			((Control)btnP4Back).Enabled = true;
			((Control)btnP4Next).Enabled = true;
			((Control)this).Cursor = Cursors.Default;
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		}
	}

	private void InputCheckToPrimax()
	{
		//IL_0104: Unknown result type (might be due to invalid IL or missing references)
		//IL_0052: Unknown result type (might be due to invalid IL or missing references)
		//IL_0185: Unknown result type (might be due to invalid IL or missing references)
		//IL_0134: Unknown result type (might be due to invalid IL or missing references)
		//IL_01ad: Unknown result type (might be due to invalid IL or missing references)
		//IL_015c: Unknown result type (might be due to invalid IL or missing references)
		//IL_01d6: Unknown result type (might be due to invalid IL or missing references)
		//IL_0200: Unknown result type (might be due to invalid IL or missing references)
		//IL_027d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0347: Unknown result type (might be due to invalid IL or missing references)
		//IL_03af: Unknown result type (might be due to invalid IL or missing references)
		PrimaxModel = getInputIpAddressToPrimaxMode();
		if (!PrimaxModel)
		{
			return;
		}
		string text = ((Control)textP4Destination).Text;
		if (PrimaxAddressList != null)
		{
			for (int i = 0; i < PrimaxAddressList.Count; i++)
			{
				if (PrimaxAddressList[i][1].Equals(text))
				{
					MessageBox.Show(Resources.ERR_MSG_ADDRESSNAME_DUPLICATE, Resources.ERR_MSG_TITLE_ADDRESSNAME, (MessageBoxButtons)0, (MessageBoxIcon)16);
					throw new Exception("input error .宛先名（重複）");
				}
			}
		}
		string text2 = "";
		if (!((Control)textBoxP3Pass).Text.Equals(Resources.TXT_P3_INITIAL_001))
		{
			text2 = ((Control)textBoxP3Pass).Text;
		}
		int registrationNo = fSettingHeadline.RegistrationNo;
		string text3 = ((Control)cmbP3UserName).Text;
		string text4 = cmbP4FolderPath.SelectedItem.ToString();
		MachineControl machineControl = new MachineControl(machineLang);
		machineControl.SetPrimaxUnicode(PrimaxUnicode);
		if (!string.IsNullOrEmpty(text2) && machineControl.convHexString(text2, MachineControl.PRIMAX_HEX_ENCODINGT.SJIS) == null)
		{
			MessageBox.Show(Resources.ERR_MSG_PASSWORD_CHAR_TYPE, Resources.ERR_MSG_TITLE_PASSWORD_CHAR_TYPE, (MessageBoxButtons)0, (MessageBoxIcon)16);
			throw new Exception("input error .パスワード");
		}
		if (PrimaxUnicode)
		{
			if (machineControl.convToUnicode(text) == null)
			{
				MessageBox.Show(Resources.ERR_MSG_ADDRESSNAME_CHAR_TYPE_2, Resources.ERR_MSG_TITLE_ADDRESSNAME_CHAR_TYPE, (MessageBoxButtons)0, (MessageBoxIcon)16);
				throw new Exception("input error .宛先名");
			}
			if (!machineControl.checkDestNameCharUnicode(text))
			{
				MessageBox.Show(Resources.ERR_MSG_ADDRESSNAME_CHAR_TYPE_2, Resources.ERR_MSG_TITLE_ADDRESSNAME_CHAR_TYPE, (MessageBoxButtons)0, (MessageBoxIcon)16);
				throw new Exception("input error .宛先名");
			}
		}
		else
		{
			if (machineControl.convHexString(text, MachineControl.PRIMAX_HEX_ENCODINGT.SJIS) == null)
			{
				MessageBox.Show(Resources.ERR_MSG_ADDRESSNAME_CHAR_TYPE, Resources.ERR_MSG_TITLE_ADDRESSNAME_CHAR_TYPE, (MessageBoxButtons)0, (MessageBoxIcon)16);
				throw new Exception("input error .宛先名");
			}
			if (!machineControl.checkDestNameChar(text))
			{
				MessageBox.Show(Resources.ERR_MSG_ADDRESSNAME_CHAR_TYPE, Resources.ERR_MSG_TITLE_ADDRESSNAME_CHAR_TYPE, (MessageBoxButtons)0, (MessageBoxIcon)16);
				throw new Exception("input error .宛先名");
			}
		}
		if (machineControl.convHexString(text3, MachineControl.PRIMAX_HEX_ENCODINGT.SJIS) == null)
		{
			MessageBox.Show(Resources.ERR_MSG_USERNAME_CHAR_TYPE, Resources.ERR_MSG_TITLE_USERNAME_CHAR_TYPE, (MessageBoxButtons)0, (MessageBoxIcon)16);
			throw new Exception("input error .ユーザー名");
		}
		if (machineControl.convHexString(text4, MachineControl.PRIMAX_HEX_ENCODINGT.SJIS) == null)
		{
			MessageBox.Show(Resources.ERR_MSG_PATHNAME_CHAR_TYPE, Resources.ERR_MSG_TITLE_PATHNAME_CHAR_TYPE, (MessageBoxButtons)0, (MessageBoxIcon)16);
			throw new Exception("input error .パス名");
		}
		if (registrationNo <= 0)
		{
			return;
		}
		int count = PrimaxOneTouchKeyInfoList.Count;
		if (1 > registrationNo || registrationNo > count)
		{
			MessageBox.Show(Resources.ERR_MSG_KEY_NO_MAX_1 + count + Resources.ERR_MSG_KEY_NO_MAX_2 + registrationNo + Resources.ERR_MSG_KEY_NO_MAX_3 + "\n" + Resources.ERR_MSG_KEY_NO_MAX_4, Resources.ERR_MSG_TITLE_KEY_NO_MAX, (MessageBoxButtons)0, (MessageBoxIcon)16);
			throw new Exception("input error .ワンタッチキー番号");
		}
		string text5 = "";
		bool flag = true;
		bool flag2 = false;
		for (int j = 0; j < PrimaxOneTouchKeyInfoList.Count; j++)
		{
			if (string.IsNullOrEmpty(PrimaxOneTouchKeyInfoList[j].name))
			{
				flag = false;
				if (!string.IsNullOrEmpty(text5))
				{
					text5 += " ,";
				}
				text5 += PrimaxOneTouchKeyInfoList[j].no;
			}
			else if (registrationNo == PrimaxOneTouchKeyInfoList[j].no)
			{
				flag2 = true;
			}
		}
		if (flag)
		{
			MessageBox.Show(Resources.ERR_MSG_KEY_ALL_USING_1 + registrationNo + Resources.ERR_MSG_KEY_ALL_USING_2, Resources.ERR_MSG_TITLE_KEY_ALL_USING, (MessageBoxButtons)0, (MessageBoxIcon)64);
			fSettingHeadline.RegistrationNo = 0;
		}
		if (!flag2)
		{
			return;
		}
		MessageBox.Show(Resources.ERR_MSG_KEY_USING_1 + registrationNo + Resources.ERR_MSG_KEY_USING_2 + "\n" + Resources.ERR_MSG_KEY_USING_3 + "\n" + Resources.ERR_MSG_KEY_USING_4 + text5, Resources.ERR_MSG_TITLE_KEY_USING, (MessageBoxButtons)0, (MessageBoxIcon)16);
		throw new Exception("input error .ワンタッチキー番号");
	}

	private void btnP5Execute_Click(object sender, EventArgs e)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		((ToolStripItem)ToolStripMenuItemDetail_D).Enabled = false;
		((Control)this).Cursor = Cursors.WaitCursor;
		try
		{
			StateMachine.NextState = StateMachine.StateType.ENV_SETTING;
			panelChange(StateMachine.NowState, StateMachine.NextState);
			Application.DoEvents();
			Thread.Sleep(500);
			StateMachine.NowState = StateMachine.NextState;
		}
		finally
		{
			((Control)this).Cursor = Cursors.Default;
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		}
	}

	private void btnP3Back_Click(object sender, EventArgs e)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
	}

	private void btnP2Back_Click(object sender, EventArgs e)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
	}

	private void setReportCreateFolderAddressMsg(bool finishFlg, Label wkLabel)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		StringBuilder stringBuilder = new StringBuilder();
		stringBuilder.AppendFormat("{0}\n", Resources.SET_REPORT_CREATE_FOLDER_ADDRESS_MSG_01_13);
		string text;
		string arg;
		if (createNewFolderRadioButton.Checked)
		{
			text = ((Control)textBoxFolderName).Text;
			arg = ((Control)textBoxFolderPath).Text;
		}
		else if (selectFolderRadioButton.Checked)
		{
			text = ((Control)cmbP2Folder).Text;
			arg = fs.getSharedFolderPath(text);
		}
		else
		{
			text = ((Control)textBoxNonSharedFolderPath).Text;
			arg = ((Control)textBoxNonSharedFolderPath).Text;
		}
		stringBuilder.AppendFormat("  {0}\t{1}\n", Resources.ITEM_SHARE_FOLDER_NAME, text);
		stringBuilder.AppendFormat("  {0}\t\t{1}\n\n", Resources.ITEM_DEST_SHARE_FOLDER, arg);
		stringBuilder.AppendFormat("{0}\n", Resources.SET_REPORT_CREATE_FOLDER_ADDRESS_MSG_04_13);
		stringBuilder.AppendFormat("  {0}\t\t{1}\n", Resources.ITEM_USER_NAME, ((Control)cmbP3UserName).Text);
		if (((Control)textBoxP3Pass).Text.Equals(Resources.TXT_P3_INITIAL_001))
		{
			stringBuilder.AppendFormat("  {0}\n\n", Resources.SET_REPORT_CREATE_FOLDER_ADDRESS_MSG_06A_13);
		}
		else
		{
			stringBuilder.AppendFormat("  {0}\n\n", Resources.SET_REPORT_CREATE_FOLDER_ADDRESS_MSG_06B_13);
		}
		stringBuilder.AppendFormat("{0}\n", Resources.SET_REPORT_CREATE_FOLDER_ADDRESS_MSG_07_13);
		string text2 = string.Empty;
		if (finishFlg)
		{
			if (!string.IsNullOrEmpty(registrationNumber))
			{
				text2 = registrationNumber.Substring(1, registrationNumber.Length - 2);
			}
			if (PrimaxModel && string.IsNullOrEmpty(registrationNumber))
			{
				text2 = Resources.PRIMAX_ONE_TOUCH_KEY_NOT_USE;
			}
		}
		else
		{
			text2 = ((fSettingHeadline.RegistrationNo == 0) ? Resources.REGISTRATION_NUMBER_NOT_USE : fSettingHeadline.RegistrationNo.ToString());
		}
		if (PrimaxModel)
		{
			if (text2.Equals(Resources.REGISTRATION_NUMBER_NOT_USE))
			{
				text2 = Resources.PRIMAX_ONE_TOUCH_KEY_NOT_USE;
			}
			stringBuilder.AppendFormat("\u3000{0}\t：{1}\n", Resources.PRIMAX_ONE_TOUCH_KEY_BIG, text2);
		}
		else
		{
			stringBuilder.AppendFormat("{0}\t{1}\n", Resources.SET_REPORT_CREATE_FOLDER_ADDRESS_MSG_00_13, text2);
		}
		stringBuilder.AppendFormat("  {0}\t{1}\n", Resources.ITEM_ADDRESS_NAME, ((Control)textP4Destination).Text);
		string arg2 = (string.IsNullOrEmpty(displayedContents) ? mfpIpAddr : displayedContents);
		stringBuilder.AppendFormat("  {0}\t{1}\n", Resources.ITEM_MACHINE, arg2);
		stringBuilder.AppendFormat("  {0}{1}\n", Resources.SET_REPORT_CREATE_FOLDER_ADDRESS_MSG_10_13, cmbP4FolderPath.SelectedItem.ToString());
		if (PrimaxModel)
		{
			stringBuilder.AppendFormat("\n\n");
		}
		else
		{
			stringBuilder.AppendFormat("    {0}\n", Resources.SETTING_HEADLINE);
			stringBuilder.AppendFormat("        {0}:\t{1}\n", Resources.TITLE_01, fSettingHeadline.Str1Headline);
			stringBuilder.AppendFormat("        {0}:\t{1}\n", Resources.TITLE_02, fSettingHeadline.Str2Headline);
			stringBuilder.AppendFormat("        {0}:\t{1}\n", Resources.TITLE_03, fSettingHeadline.Str3Headline);
			stringBuilder.AppendFormat("        {0}:\t{1}\n\n", Resources.TITLE_ADD_TO_FREQ, fSettingHeadline.StrRegularHeading);
		}
		if (finishFlg)
		{
			stringBuilder.AppendFormat("{0}\n", Resources.SET_REPORT_CREATE_FOLDER_ADDRESS_MSG_11_13);
			string arg3 = "-";
			string arg4 = "-";
			if (FormSetup.SmbOpened)
			{
				arg3 = Resources.DO_DO;
			}
			if (FormSetup.BlankPasswordAllowed)
			{
				arg4 = Resources.DO_DO;
			}
			stringBuilder.AppendFormat("  {0}\t{1}\n", Resources.STATE_RELEASING_CONNECTION_RESTRICTION_SHARE_FOLDER, arg3);
			stringBuilder.AppendFormat("  {0}\t{1}\n\n", Resources.SET_REPORT_CREATE_FOLDER_ADDRESS_MSG_13_13, arg4);
		}
		((Control)wkLabel).Text = stringBuilder.ToString();
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	private string getSharedFolderPath(string name)
	{
		//IL_00c4: Unknown result type (might be due to invalid IL or missing references)
		//IL_0024: Unknown result type (might be due to invalid IL or missing references)
		//IL_002a: Expected O, but got Unknown
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		string result = string.Empty;
		try
		{
			ManagementObjectSearcher val = new ManagementObjectSearcher("SELECT * FROM win32_share");
			try
			{
				foreach (var item in from ManagementObject x in (IEnumerable)val.Get()
					select new
					{
						Name = ((ManagementBaseObject)x)["Name"],
						Path = ((ManagementBaseObject)x)["Path"]
					})
				{
					if (string.Equals((string)item.Name, name, StringComparison.CurrentCultureIgnoreCase))
					{
						result = (string)item.Path;
						break;
					}
				}
			}
			finally
			{
				((IDisposable)val)?.Dispose();
			}
		}
		catch (Exception ex)
		{
			MessageBox.Show("******\n" + ex.ToString() + "\n*****");
			LOG.ErrorFormat("{0}：！！！ 共有フォルダー確認でエラー  \n" + ex.ToString() + "\n*******************************", (object)MethodBase.GetCurrentMethod().Name);
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return result;
	}

	public async Task<ErrorCode> executeCreateFolderAddressBook()
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		MachineControl mc = null;
		((Control)labelP7finsh).Text = string.Empty;
		labelP7finsh.Links.Clear();
		((Control)labelP7Report).Text = string.Empty;
		string directRegistLinkMsg = $"{Resources.DIRECT_REGIST_PROCEDURE_LINK_MESSAGE_01}\n{Resources.DIRECT_REGIST_PROCEDURE_LINK_MESSAGE_02}";
		try
		{
			((Control)this).Cursor = Cursors.WaitCursor;
			ErrorCode resAb2 = await checkAddressbook(mfpIpAddr, labelP7Report);
			if (resAb2 == ErrorCode.ERROR)
			{
				setFinishPage(Resources.EXE_RESULT_MSG_ERROR_REGIST_ADDRESS, string.Empty, directRegistLinkMsg, string.Empty);
				LOG.DebugFormat("{0}：end4", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
				return ErrorCode.ERROR;
			}
			string passTxt = string.Empty;
			if (!((Control)textBoxP3Pass).Text.Equals(Resources.TXT_P3_INITIAL_001))
			{
				passTxt = ((Control)textBoxP3Pass).Text;
			}
			new FormSetup(machineLang).enableSMB();
			mc = new MachineControl(machineLang);
			mc.SetPrimaxUnicode(PrimaxUnicode);
			string addMsg = "";
			if (!PCSMBcheck(machineLang))
			{
				return ErrorCode.PREV;
			}
			SettingItemsSetupAddress setting;
			if (PrimaxModel)
			{
				setting = new SettingItemsSetupAddress
				{
					host = mfpIpAddr,
					adminName = PrimaxAdminPasswd,
					passwd = passTxt,
					firstFlg = true,
					httpsFlg = (resAb2 == ErrorCode.NOERROR)
				};
				setting.registrationNo = fSettingHeadline.RegistrationNo;
				setting.addressName = ((Control)textP4Destination).Text;
				setting.authUserName = ((Control)cmbP3UserName).Text;
				setting.folderPath = cmbP4FolderPath.SelectedItem.ToString();
				if (!PrimaxSMBcheck(mfpIpAddr, GetHostNameFromIP(mfpIpAddr), machineLang))
				{
					return ErrorCode.PREV;
				}
				while (true)
				{
					MachineControl.PRIMAX_MACHINE_CONTROL_RESULT pRIMAX_MACHINE_CONTROL_RESULT = await mc.executeSetupAddressToPrimax(setting);
					if (MachineControl.PRIMAX_MACHINE_CONTROL_RESULT.PW_RESETTING == pRIMAX_MACHINE_CONTROL_RESULT)
					{
						FormAdminAuthConfirm formAdminAuthConfirm = new FormAdminAuthConfirm();
						formAdminAuthConfirm.InitializeToPrimax();
						formAdminAuthConfirm.setMsg(firstFlg: true);
						((Form)formAdminAuthConfirm).StartPosition = (FormStartPosition)4;
						((Form)formAdminAuthConfirm).ShowDialog();
						if ((int)((Form)formAdminAuthConfirm).DialogResult != 1)
						{
							resAb2 = ErrorCode.ABORT;
							break;
						}
						setting.adminName = formAdminAuthConfirm.getAuthPass();
						PrimaxAdminPasswd = formAdminAuthConfirm.getAuthPass();
						continue;
					}
					if (MachineControl.PRIMAX_MACHINE_CONTROL_RESULT.ADD_OVER == pRIMAX_MACHINE_CONTROL_RESULT)
					{
						MessageBox.Show(Resources.OVER_REGISTRATION_NAME, Resources.ERR_MSG_TITLE_ADDRESSNAME, (MessageBoxButtons)0, (MessageBoxIcon)16);
						addMsg = "登録数超過の為、";
						resAb2 = ErrorCode.ABORT;
					}
					else if (pRIMAX_MACHINE_CONTROL_RESULT == MachineControl.PRIMAX_MACHINE_CONTROL_RESULT.SUCCESS)
					{
						PrimaxAdminPasswd = setting.adminName;
						resAb2 = ErrorCode.NOERROR;
					}
					else
					{
						resAb2 = ErrorCode.ERROR;
					}
					break;
				}
			}
			else
			{
				setting = new SettingItemsSetupAddress
				{
					host = mfpIpAddr,
					adminName = "admin",
					passwd = "",
					httpsFlg = (resAb2 == ErrorCode.NOERROR),
					addressName = ((Control)textP4Destination).Text,
					authUserName = ((Control)cmbP3UserName).Text,
					authPassword = passTxt,
					folderPath = cmbP4FolderPath.SelectedItem.ToString(),
					firstFlg = true
				};
				if (!(await mc.checkUserAdminPermission(setting)))
				{
					mc.retryLoginState(setting.host, setting.adminName);
					return ErrorCode.PREV;
				}
				if (!(await mc.checkMachineAdminPermission(setting)))
				{
					mc.retryLoginState(setting.host, setting.adminName);
					return ErrorCode.PREV;
				}
				if (!(await MFPSMBcheck(mfpIpAddr, GetHostNameFromIP(mfpIpAddr), machineLang)))
				{
					return ErrorCode.PREV;
				}
				while (true)
				{
					setting.registrationNo = fSettingHeadline.RegistrationNo;
					MACHINE_CONTROL_RESULT mACHINE_CONTROL_RESULT = await mc.executeWimConnect(setting, labelP6Execute, progressBar1);
					if (mACHINE_CONTROL_RESULT != 0)
					{
						LOG.DebugFormat("{0}：executeWimConnect() Failed.\n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
						resAb2 = ((mACHINE_CONTROL_RESULT == MACHINE_CONTROL_RESULT.ERROR) ? ErrorCode.ERROR : ErrorCode.ABORT);
						break;
					}
					if (fSettingHeadline.RegistrationNo == 0)
					{
						resAb2 = ErrorCode.NOERROR;
						break;
					}
					resAb2 = await executeAddressbook(mc, setting, labelP7Report, registNoCheckOnly: true);
					if (resAb2 != ErrorCode.ABORT)
					{
						break;
					}
					fSettingHeadline.SetHeadLine((Form)(object)this);
					LOG.DebugFormat("{0}：New Registration No. = {1}\n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)fSettingHeadline.RegistrationNo);
					if (fSettingHeadline.RegistrationNo == 0)
					{
						setting.registrationNo = 0;
						resAb2 = ErrorCode.NOERROR;
						break;
					}
				}
			}
			if (resAb2 != 0)
			{
				if (resAb2 == ErrorCode.ABORT)
				{
					setFinishPage(Resources.EXE_RESULT_MSG_ERROR_REGIST_ADDRESS, string.Empty, string.Empty, addMsg + Resources.TEXT_STOP_EXECUTE);
				}
				else
				{
					setFinishPage(Resources.EXE_RESULT_MSG_ERROR_REGIST_ADDRESS, string.Empty, directRegistLinkMsg, string.Empty);
				}
				return resAb2;
			}
			_ = string.Empty;
			_ = string.Empty;
			FOLDER_TYPE folder_type;
			string text;
			string pFolderPath;
			if (createNewFolderRadioButton.Checked)
			{
				folder_type = FOLDER_TYPE.CREATE_FOLDRE;
				text = ((Control)textBoxFolderName).Text;
				pFolderPath = ((Control)textBoxFolderPath).Text;
			}
			else if (selectFolderRadioButton.Checked)
			{
				folder_type = FOLDER_TYPE.SHARED_FOLDER;
				text = ((Control)cmbP2Folder).Text;
				pFolderPath = string.Empty;
			}
			else
			{
				folder_type = FOLDER_TYPE.NON_SHARED_FOLDER;
				text = ((Control)textBoxSharedName).Text;
				pFolderPath = ((Control)textBoxNonSharedFolderPath).Text;
			}
			if (!executeCreateFolder(folder_type, text, pFolderPath, ((Control)cmbP3UserName).Text, ((Control)textBoxP3Pass).Text, labelP7finsh))
			{
				setFinishPage(Resources.MSG_FAILED_CREATION_SHARE_FOLDER + "\n", string.Empty, directRegistLinkMsg, ((Control)labelP7finsh).Text);
				LOG.DebugFormat("{0}：end3", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
				return ErrorCode.ERROR;
			}
			fs.setSharedFolderListTable();
			if (PrimaxModel)
			{
				resAb2 = ErrorCode.NOERROR;
			}
			else
			{
				setting.headlineIndex1 = fSettingHeadline.Index1Headline;
				setting.headlineIndex2 = fSettingHeadline.Index2Headline;
				setting.headlineIndex3 = fSettingHeadline.Index3Headline;
				setting.regularHeadingIndex = fSettingHeadline.IndexRegularHeading;
				resAb2 = await executeAddressbook(mc, setting, labelP7Report);
			}
			string fOLDER_SEND_PROCEDURE_LINK_MESSAGE = Resources.FOLDER_SEND_PROCEDURE_LINK_MESSAGE;
			if (resAb2 == ErrorCode.NOERROR)
			{
				setFinishPage(Resources.EXE_RESULT_MSG_SUCCESS, fOLDER_SEND_PROCEDURE_LINK_MESSAGE, string.Empty, string.Empty);
				setReportCreateFolderAddressMsg(finishFlg: true, labelP7Report);
				LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
				return resAb2;
			}
			setFinishPage(Resources.EXE_RESULT_MSG_ERROR_REGIST_ADDRESS, string.Empty, directRegistLinkMsg, string.Empty);
			LOG.DebugFormat("{0}：end2", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			return ErrorCode.ERROR;
		}
		catch (Exception ex)
		{
			string message = ex.Message;
			LOG.ErrorFormat("{0}：共有フォルダの作成＆アドレス帳登録エラー\n" + ex.ToString() + "\n*******************************", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			LOG.ErrorFormat("{0}：Message\n" + message + "\n*******************************", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			if (!string.IsNullOrEmpty(message))
			{
				if (message.IndexOf(Resources.WIM_ERROR_DETECT) >= 0)
				{
					message = message.Substring(Resources.WIM_ERROR_DETECT.Length);
					MessageBox.Show(message, Resources.ERR_TITLE_REGIST_ADDR, (MessageBoxButtons)0, (MessageBoxIcon)16);
					((Control)labelP7Report).Text = message;
				}
			}
			else
			{
				((Control)labelP7Report).Text = Resources.ERR_MSG_FATAL_RETRY;
			}
			((Control)linkLabelP7HelpSend).Visible = false;
			((Control)linkLabelP7HelpRegist).Text = directRegistLinkMsg;
			((Control)linkLabelP7HelpRegist).Visible = true;
			return ErrorCode.ERROR;
		}
		finally
		{
			mc?.Dispose();
			((Control)labelP6Execute).Text = string.Empty;
			progressBar1.Value = 0;
			((Control)this).Cursor = Cursors.Default;
		}
	}

	private void setFinishPage(string stateMsg, string operationOrder, string helpMsg, string reportMsg)
	{
		if (!string.IsNullOrEmpty(stateMsg))
		{
			((Control)labelP7_comment).Text = stateMsg;
		}
		((Control)linkLabelP7HelpSend).Visible = !string.IsNullOrEmpty(operationOrder);
		if (((Control)linkLabelP7HelpSend).Visible)
		{
			((Control)linkLabelP7HelpSend).Text = operationOrder;
		}
		((Control)linkLabelP7HelpRegist).Visible = !string.IsNullOrEmpty(helpMsg);
		if (((Control)linkLabelP7HelpRegist).Visible)
		{
			((Control)linkLabelP7HelpRegist).Text = helpMsg;
		}
		if (!string.IsNullOrEmpty(reportMsg))
		{
			((Control)labelP7Report).Text = reportMsg;
		}
	}

	private void setTroubleShootFinishPage(string stateMsg, string operationOrder, string helpMsg, string reportMsg)
	{
		((Control)label_TRP10Head).Text = Resources.FORM_WIZARD_COMPLETE;
		if (!string.IsNullOrEmpty(stateMsg))
		{
			((Control)label_TRP10_comment).Text = stateMsg;
		}
		((Control)linkLabelTRP10HelpSend).Visible = !string.IsNullOrEmpty(operationOrder);
		if (((Control)linkLabelTRP10HelpSend).Visible)
		{
			((Control)linkLabelTRP10HelpSend).Text = operationOrder;
		}
		((Control)linkLabelTRP10HelpRegist).Visible = !string.IsNullOrEmpty(helpMsg);
		if (((Control)linkLabelTRP10HelpRegist).Visible)
		{
			((Control)linkLabelTRP10HelpRegist).Text = helpMsg;
		}
		if (!string.IsNullOrEmpty(reportMsg))
		{
			((Control)label_TRP10Report).Text = reportMsg;
		}
		((Control)btnTRP10Top).Visible = true;
		((Control)btnTRP10End).Visible = true;
	}

	private bool executeCreateFolder(FOLDER_TYPE folder_type, string pFolderName, string pFolderPath, string pLoginUserName, string password, LinkLabel reportLabel)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		string text = string.Empty;
		bool result = true;
		pFolderPath = getPathFromWindowsName(pFolderPath);
		try
		{
			PowerShellManager powerShellManager = new PowerShellManager();
			if (folder_type == FOLDER_TYPE.NON_SHARED_FOLDER)
			{
				if (!powerShellManager.isSharedSetting(pFolderName, pFolderPath))
				{
					powerShellManager.SetSharedSetting(pFolderName, pFolderPath);
				}
			}
			else if (!string.IsNullOrEmpty(pFolderPath))
			{
				text = getPathFromWindowsName(pFolderPath);
				text += (text.EndsWith("\\") ? string.Empty : "\\");
				pFolderPath = text + pFolderName;
				if (!createShareFolder(pFolderName, text, reportLabel))
				{
					return false;
				}
			}
			else
			{
				pFolderPath = fs.getSharedFolderPath(pFolderName);
			}
			powerShellManager.SetSMBAccount(pFolderName, pLoginUserName, "Full");
			if (string.IsNullOrEmpty(password) || password.Equals(Resources.TXT_P3_INITIAL_001))
			{
				powerShellManager.SetSMBAccount(pFolderName, "Everyone", "Full");
				ShareFolderManager.AddUsersAndPermissions(pFolderPath, "Everyone", FileSystemRights.FullControl, AccessControlType.Allow);
			}
			LOG.InfoFormat("{0}：〇〇〇 共有フォルダー作成完了  \n共有フォルダー名：{1}\n作成場所：{2}", (object)MethodBase.GetCurrentMethod().Name, (object)pFolderName, (object)text);
		}
		catch (Exception ex)
		{
			Console.Out.WriteLine(ex.ToString());
			LOG.ErrorFormat("{0}：！！！ 共有フォルダー作成エラー  \n" + ex.ToString() + "\n*******************************", (object)MethodBase.GetCurrentMethod().Name);
			((Control)reportLabel).Text = Resources.ERR_MSG_CREATE_FOLDER;
			result = false;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return result;
	}

	private void addShareUser(ShareFolderManager.ShareUser newUser, List<ShareFolderManager.ShareUser> shareUsers)
	{
		foreach (ShareFolderManager.ShareUser shareUser in shareUsers)
		{
			if (string.Equals(newUser.AccountName, shareUser.AccountName, StringComparison.CurrentCultureIgnoreCase))
			{
				shareUsers.Remove(shareUser);
				break;
			}
		}
		shareUsers.Add(newUser);
	}

	private bool createShareFolder(string folderName, string folderPath, LinkLabel reportLabel)
	{
		bool result = false;
		string text = folderPath + folderName;
		Directory.CreateDirectory(text);
		LOG.InfoFormat("{0}：フォルダ作成完了 … {1}", (object)MethodBase.GetCurrentMethod().Name, (object)text);
		ShareFolderManager.ErrorCode errorCode = ShareFolderManager.shareFolderAdd(text, folderName, "");
		switch (errorCode)
		{
		case ShareFolderManager.ErrorCode.SUCCESS:
			LOG.InfoFormat("{0}：フォルダ共有完了 … {1}", (object)MethodBase.GetCurrentMethod().Name, (object)folderName);
			result = true;
			break;
		case ShareFolderManager.ErrorCode.DUPLICATE_SHARE:
		{
			reportLabel.Links.Clear();
			StringBuilder stringBuilder3 = new StringBuilder();
			stringBuilder3.Append(Resources.EXISTS_SAME_NAME_SHARE_FOLDER_ERROR_1 + "\n");
			stringBuilder3.Append(Resources.EXISTS_SAME_NAME_SHARE_FOLDER_ERROR_2 + "\n");
			stringBuilder3.Append(Resources.EXISTS_SAME_NAME_SHARE_FOLDER_ERROR_3);
			stringBuilder3.Append(" " + Resources.ITEM_SHARE_FOLDER_NAME + ((Control)textBoxFolderName).Text + "\n");
			((Control)reportLabel).Text = stringBuilder3.ToString();
			LOG.ErrorFormat("{0}：共有フォルダー作成エラー発生 … DUPLICATE_SHARE 共有フォルダー名：{1} / 作成場所：{2}", (object)MethodBase.GetCurrentMethod().Name, (object)folderName, (object)folderPath);
			break;
		}
		case ShareFolderManager.ErrorCode.INVALID_NAME:
		{
			reportLabel.Links.Clear();
			StringBuilder stringBuilder2 = new StringBuilder();
			stringBuilder2.Append(Resources.CREATE_FOLDER_FAILED + "ErrorNo=[" + 9u + "]\n\n");
			stringBuilder2.Append("  " + Resources.ITEM_SHARE_FOLDER_NAME + folderName + "\n");
			stringBuilder2.Append("  " + Resources.ITEM_DEST_SHARE_FOLDER + folderPath + "\n\n");
			stringBuilder2.Append(Resources.FAILED_CREATION_TARGET_FOLDER + "\n");
			((Control)reportLabel).Text = stringBuilder2.ToString();
			LOG.ErrorFormat("{0}：共有フォルダー作成エラー発生 … INVALID_NAME 共有フォルダー名：{1} / 作成場所：{2}", (object)MethodBase.GetCurrentMethod().Name, (object)folderName, (object)folderPath);
			break;
		}
		default:
		{
			StringBuilder stringBuilder = new StringBuilder();
			stringBuilder.Append(Resources.REPORT_OCCURED_ILLEGAL_ERROR);
			stringBuilder.Append("  " + Resources.ITEM_SHARE_FOLDER_NAME + folderName + "\n");
			stringBuilder.Append("  " + Resources.ITEM_DEST_SHARE_FOLDER + folderPath + "\n\n");
			stringBuilder.Append(Resources.FAILED_CREATION_TARGET_FOLDER + "\n");
			((Control)reportLabel).Text = stringBuilder.ToString();
			LOG.ErrorFormat("{0}：共有フォルダー作成エラー発生 … UNKNOWN_ERROR 共有フォルダー名：{1} / 作成場所：{2}", (object)MethodBase.GetCurrentMethod().Name, (object)folderName, (object)folderPath);
			throw new Exception($"{errorCode}");
		}
		}
		return result;
	}

	private async Task<ErrorCode> checkAddressbook(string mfpIpAddrText, Label reportLabel)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		LOG.DebugFormat("{0}：アドレス帳登録ボタン押下 チェック開始\n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		try
		{
			ErrorCode errorCode = IsConnectMFP(mfpIpAddrText);
			ErrorCode errorCode2;
			switch (errorCode)
			{
			case ErrorCode.ADRESS_EMPTY:
				MessageBox.Show(Resources.MACHINE_NOT_SELECTED_ERROR2_TEXT, Resources.MACHINE_SETTING_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
				LOG.ErrorFormat("{0}：IPアドレス入力エラー：IPアドレス無し\n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
				errorCode2 = ErrorCode.ERROR;
				break;
			case ErrorCode.ADRESS_FORMAT_ERROR:
				MessageBox.Show(Resources.MACHINE_NOT_SELECTED_ERROR2_TEXT, Resources.MACHINE_SETTING_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
				LOG.InfoFormat("{0}：IPアドレス：フォーマットエラー：{1}\n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)mfpIpAddrText);
				errorCode2 = ErrorCode.ERROR;
				break;
			case ErrorCode.MFP_NOT_FOUND:
			{
				StringBuilder stringBuilder = new StringBuilder();
				stringBuilder.AppendFormat("{0}\n\n", Resources.CANT_CONNECT_MACHINE_ERROR_TEXT_1_5);
				stringBuilder.AppendFormat("  {0}\n", Resources.CANT_CONNECT_MACHINE_ERROR_TEXT_6_5);
				stringBuilder.AppendFormat("  {0}\n", Resources.CANT_CONNECT_MACHINE_ERROR_TEXT_2_5);
				stringBuilder.AppendFormat("  {0}\n", Resources.CANT_CONNECT_MACHINE_ERROR_TEXT_3_5);
				stringBuilder.AppendFormat("  {0}\n\n", Resources.CANT_CONNECT_MACHINE_ERROR_TEXT_4_5);
				stringBuilder.AppendFormat("{0}", Resources.CANT_CONNECT_MACHINE_ERROR_TEXT_5_5);
				((Control)reportLabel).Text = stringBuilder.ToString();
				errorCode2 = ErrorCode.ERROR;
				break;
			}
			case ErrorCode.MFP_NOT_SUPPORTED:
				LOG.DebugFormat("{0}：not supported machine：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)mfpIpAddrText);
				errorCode2 = ErrorCode.ERROR;
				break;
			case ErrorCode.NOERROR_HTTP_ONLY:
				LOG.DebugFormat("{0}：http only IP Address：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)mfpIpAddrText);
				errorCode2 = ErrorCode.NOERROR_HTTP_ONLY;
				break;
			case ErrorCode.NOERROR:
				LOG.DebugFormat("{0}：IP Address：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)mfpIpAddrText);
				errorCode2 = ErrorCode.NOERROR;
				break;
			default:
				LOG.ErrorFormat("{0}：State Error：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)errorCode);
				errorCode2 = ErrorCode.ERROR;
				break;
			}
			if (errorCode2 == ErrorCode.ERROR)
			{
				return errorCode2;
			}
			if (!new FormSetup(machineLang).checkEnableSMB())
			{
				((Control)reportLabel).Text = Resources.REPORT_INTERRUPTION_BY_FW_SETTING;
				return ErrorCode.ERROR;
			}
			return errorCode2;
		}
		catch (Exception ex)
		{
			LOG.ErrorFormat("{0}：宛先の登録チェックエラー\n{1}\n*******************************", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)ex.ToString());
			((Control)reportLabel).Text = Resources.REPORT_CHECK_ERROR_REGISTER_DEST + ex.Message;
			return ErrorCode.ERROR;
		}
		finally
		{
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		}
	}

	private async Task<ErrorCode> executeAddressbook(MachineControl mc, SettingItemsSetupAddress setting, Label reportLabel, bool registNoCheckOnly = false)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		LOG.DebugFormat("{0}：アドレス帳登録処理\n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		int posNo = 2;
		try
		{
			FormSetup formSetup = new FormSetup(machineLang);
			LOG.DebugFormat("{0}：userInfo:{1}\n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)setting.authUserName);
			formSetup.enableSMB();
			Stopwatch sw = new Stopwatch();
			sw.Start();
			string[] array = await mc.executeSetupAddress(setting, registNoCheckOnly);
			sw.Stop();
			LOG.InfoFormat("{0} time: {1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)sw.Elapsed);
			if (array == null)
			{
				LOG.InfoFormat("{0}：宛先登録エラー", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
				return ErrorCode.ERROR;
			}
			if (array[0].Equals(MachineControl.REGISTRATION_NUMBER_INUSE))
			{
				LOG.InfoFormat("{0}：登録番号重複", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
				return ErrorCode.ABORT;
			}
			if (array[0].Equals(MachineControl.REGISTRATION_NUMBER_PASS))
			{
				LOG.InfoFormat("{0}：登録番号重複なし", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
				return ErrorCode.NOERROR;
			}
			registrationNumber = array[posNo];
			return ErrorCode.NOERROR;
		}
		catch (Exception ex)
		{
			string message = ex.Message;
			LOG.ErrorFormat("{0}：宛先の登録エラー  \n" + ex.ToString() + "\n*******************************", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			LOG.ErrorFormat("{0}：宛先の登録エラーMessage  \n" + message + "\n*******************************", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			if (!string.IsNullOrEmpty(message))
			{
				if (message.IndexOf(Resources.WIM_ERROR_DETECT) >= 0)
				{
					message = message.Substring(Resources.WIM_ERROR_DETECT.Length);
					MessageBox.Show(message, Resources.ERR_TITLE_REGIST_ADDR, (MessageBoxButtons)0, (MessageBoxIcon)16);
					((Control)reportLabel).Text = message;
				}
			}
			else
			{
				((Control)reportLabel).Text = Resources.ERR_MSG_FATAL_RETRY;
			}
			return ErrorCode.ERROR;
		}
		finally
		{
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		}
	}

	private ErrorCode IsConnectMFP(string ipAddr)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		if (string.IsNullOrEmpty(ipAddr))
		{
			LOG.ErrorFormat("{0}：IPアドレス入力エラー：IPアドレス無し\n", (object)MethodBase.GetCurrentMethod().Name);
			return ErrorCode.ADRESS_EMPTY;
		}
		if (!Regex.IsMatch(ipAddr, "^\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}$"))
		{
			LOG.InfoFormat("{0}：IPアドレス：フォーマットエラー：{1}\n", (object)MethodBase.GetCurrentMethod().Name, (object)ipAddr);
			return ErrorCode.ADRESS_FORMAT_ERROR;
		}
		MachineControl machineControl = new MachineControl(machineLang);
		string hostNameFromIP = GetHostNameFromIP(ipAddr);
		PrimaxModel = IsPrimax(hostNameFromIP);
		PrimaxUnicode = IsPrimaxUnicode(hostNameFromIP);
		machineControl.SetPrimaxModel(PrimaxModel);
		machineControl.SetPrimaxUnicode(PrimaxUnicode);
		COMMUNICATION_ERROR_CODE cOMMUNICATION_ERROR_CODE = machineControl.communicateConfirm(ipAddr);
		ErrorCode result = ErrorCode.NOERROR;
		if (cOMMUNICATION_ERROR_CODE == COMMUNICATION_ERROR_CODE.ERROR)
		{
			result = ErrorCode.MFP_NOT_FOUND;
		}
		else if (cOMMUNICATION_ERROR_CODE == COMMUNICATION_ERROR_CODE.NOT_SUPPORT)
		{
			result = ErrorCode.MFP_NOT_SUPPORTED;
		}
		else
		{
			if (cOMMUNICATION_ERROR_CODE == COMMUNICATION_ERROR_CODE.HTTP_ONLY)
			{
				result = ErrorCode.NOERROR_HTTP_ONLY;
			}
			if (PrimaxModel)
			{
				displayedContents = $"{hostNameFromIP} ({ipAddr})";
			}
			else if (string.IsNullOrEmpty(displayedContents))
			{
				displayedContents = $"{machineControl.DisplayMachineName} ({ipAddr})";
			}
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return result;
	}

	private bool OnRemoteCertificateValidationCallback(object sender, X509Certificate certificate, X509Chain chain, SslPolicyErrors sslPolicyErrors)
	{
		return true;
	}

	private string[] getDirectoryList(string dirPath)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		string[] directories = Directory.GetDirectories(dirPath, "*", SearchOption.AllDirectories);
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return directories;
	}

	private string removaTag(string value)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		string[] array = new string[7] { "<td nowrap align=\"left\" width=\"40\">", "<img src=\"/images/messageIconE.gif\" alt=\"\">", "<td nowrap align=\"left\" height=\"32\">", "<td>", "</td>", "<br>", "<br/>" };
		string text = value;
		for (int i = 0; i < array.Length; i++)
		{
			text = text.Replace(array[i], "");
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return text;
	}

	private string[] getResultData(string logFileName)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		Regex regex = new Regex("\\[\\[", RegexOptions.IgnoreCase);
		string text = "";
		using (StreamReader streamReader = new StreamReader(logFileName, Encoding.UTF8))
		{
			string text2 = "";
			while ((text2 = streamReader.ReadLine()) != null)
			{
				if (regex.Match(text2).Success)
				{
					text = text2;
					break;
				}
			}
		}
		new List<string>();
		if (text == null || text.Equals(""))
		{
			Regex regex2 = new Regex("class=\"responseMessage\"", RegexOptions.IgnoreCase);
			bool flag = false;
			string text3 = "";
			using (StreamReader streamReader2 = new StreamReader(logFileName, Encoding.UTF8))
			{
				string text4 = "";
				while ((text4 = streamReader2.ReadLine()) != null)
				{
					if (flag && !text4.Contains("</tr>"))
					{
						string text5 = removaTag(text4);
						text3 = text3 + text5 + "\n";
					}
					else if (flag && text4.Contains("</tr>"))
					{
						flag = false;
					}
					else if (regex2.Match(text4).Success)
					{
						flag = true;
					}
				}
			}
			throw new Exception(text3);
		}
		if (text != null && !text.Equals(""))
		{
			string[] result = text.Split(new char[1] { ',' });
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
			return result;
		}
		LOG.DebugFormat("{0}：NULL end", (object)MethodBase.GetCurrentMethod().Name);
		return null;
	}

	private void ToolStripMenuSecurity_Click(object sender, EventArgs e)
	{
		//IL_0028: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		((Form)new FormSetup(machineLang)).ShowDialog();
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
	}

	private void ToolStripMenuVersion_Click(object sender, EventArgs e)
	{
		//IL_0041: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		LOG.InfoFormat("{0}：バージョン情報押下", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		((Form)new FormVersion()).ShowDialog();
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
	}

	private void ToolStripMenuManual_Click(object sender, EventArgs e)
	{
		//IL_004b: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		fMain.SetMachineInfo(machineInfoList);
		fMain.updateSharedFolderInfo();
		((Form)fMain).StartPosition = (FormStartPosition)4;
		((Form)fMain).ShowDialog();
		fs.setSharedFolderListTable();
		fs.setComboBoxFolderList(cmbP2Folder);
		fs.setComboBoxFolderList(cmbTRP6Folder);
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
	}

	private bool IsSafePath(string path)
	{
		bool flag = false;
		char[] invalidFileNameChars = Path.GetInvalidFileNameChars();
		if (path.IndexOfAny(invalidFileNameChars) >= 0)
		{
			return false;
		}
		return true;
	}

	private void buttonP6Excecute_Click(object sender, EventArgs e)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		((Control)this).Cursor = Cursors.WaitCursor;
		try
		{
			panelChange(StateMachine.NowState, StateMachine.NextState);
			Application.DoEvents();
			Thread.Sleep(500);
		}
		finally
		{
			((Control)this).Cursor = Cursors.Default;
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		}
	}

	private async void tabControl1_Main_Selected(object sender, TabControlEventArgs e)
	{
		string tabNameText = ((Control)((TabControl)sender).TabPages[e.TabPageIndex]).Text;
		LOG.DebugFormat("{0}：start [{1}]", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)tabNameText);
		if (tabPagesCreateFolder.ContainsKey(tabNameText))
		{
			switch (tabPagesCreateFolder[tabNameText])
			{
			case StateMachine.StateType.CREATE_FOLDER_SETUP:
				setTextBoxInitialString(textBoxFolderName, Resources.TXT_P2_INITIAL_001);
				setTextBoxInitialString(textBoxFolderPath, Resources.TXT_P2_INITIAL_002);
				fs.setComboBoxFolderList(cmbP2Folder);
				break;
			case StateMachine.StateType.USER_INFO_SETUP:
				setTextBoxInitialString(textBoxP3Pass, Resources.TXT_P3_INITIAL_001, passwordUse: true);
				setTextBoxInitialString(textBoxP3PassConfirm, Resources.TXT_P3_INITIAL_002, passwordUse: true);
				break;
			case StateMachine.StateType.ADDRESSBOOK_SETUP:
				setTextBoxInitialString(textP4Destination, Resources.TXT_P4_INITIAL_001);
				break;
			}
		}
		else if (tabPagesTroubleShoot.ContainsKey(tabNameText))
		{
			switch (tabPagesTroubleShoot[tabNameText])
			{
			case StateMachineTroubleShoot.StateType.TR_USER:
				((Control)listViewAddressList).Focus();
				troubleShootAddressBookInfo = null;
				troubleShootAddressBookInfoUpdate = new TroubleShootAddressBookInfo();
				break;
			case StateMachineTroubleShoot.StateType.TR_ANALYZE:
				try
				{
					await analyzeAddressBook();
				}
				catch (Exception ex)
				{
					MessageBox.Show(Resources.ERR_MSG_FATAL, Resources.ERR_TITLE_CREATE_FOLDER, (MessageBoxButtons)0, (MessageBoxIcon)16);
					StateMachineTroubleShoot.NextState = StateMachineTroubleShoot.StateType.TR_USER;
					panelChangeTroubleShoot(StateMachineTroubleShoot.NowState, StateMachineTroubleShoot.NextState);
					Application.DoEvents();
					Thread.Sleep(500);
					LOG.DebugFormat("{0} Change State:{1} -> {2}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)StateMachineTroubleShoot.NowState, (object)StateMachineTroubleShoot.NextState);
					StateMachineTroubleShoot.NowState = StateMachineTroubleShoot.NextState;
					LOG.ErrorFormat("{0}：トラブルシュート、アドレス帳情報の診断でエラー：\n{1}", (object)MethodBase.GetCurrentMethod().Name, (object)ex.ToString());
				}
				break;
			case StateMachineTroubleShoot.StateType.TR_CREATE_FOLDER_SETUP:
				setTextBoxInitialString(textBoxTRP6FolderName, Resources.TXT_P2_INITIAL_001);
				setTextBoxInitialString(textBoxTRP6FolderPath, Resources.TXT_P2_INITIAL_002);
				fs.setComboBoxFolderList(cmbTRP6Folder);
				break;
			case StateMachineTroubleShoot.StateType.TR_USER_INFO_SETUP:
				setTextBoxInitialString(textBoxTRP7Pass, Resources.TXT_P3_INITIAL_001, passwordUse: true);
				setTextBoxInitialString(textBoxTRP7PassConfirm, Resources.TXT_P3_INITIAL_002, passwordUse: true);
				break;
			case StateMachineTroubleShoot.StateType.TR_ADDRESSBOOK_SETUP:
				setTextBoxInitialString(textTRP8Destination, Resources.TXT_P4_INITIAL_001);
				setFormSettingHeadLine();
				break;
			case StateMachineTroubleShoot.StateType.TR_ADDRESSBOOK_CHECK:
				((TextBoxBase)richTextBoxTRP9).Clear();
				showAddressBookInfo(richTextBoxTRP9, troubleShootAddressBookInfoUpdate.addressBookInfo);
				break;
			}
		}
		else
		{
			LOG.ErrorFormat("{0}：end. Undefined Tab [{1}]", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)tabNameText);
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
	}

	private void setFormSettingHeadLine()
	{
		int result = 0;
		Dictionary<AddressBookListControl.ADDRESSBOOK_LIST_ITEM, string> addressBookInfo = troubleShootAddressBookInfoUpdate.addressBookInfo;
		fSettingHeadline.PrimaxProcMode = FormSettingHeadLine.PRIMAX_PROC_MODE.NOT_PRIMAX;
		if (PrimaxModel)
		{
			fSettingHeadline.PrimaxProcMode = FormSettingHeadLine.PRIMAX_PROC_MODE.UPDATE;
			fSettingHeadline.PrimaxRegistrationNo = 0;
			string text = addressBookInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_NAME];
			int primaxRegistrationNo = 0;
			if (PrimaxOneTouchKeyInfoList != null)
			{
				for (int i = 0; i < PrimaxOneTouchKeyInfoList.Count; i++)
				{
					if (text.Equals(PrimaxOneTouchKeyInfoList[i].name))
					{
						primaxRegistrationNo = PrimaxOneTouchKeyInfoList[i].no;
						break;
					}
				}
			}
			fSettingHeadline.PrimaxRegistrationNo = primaxRegistrationNo;
			fSettingHeadline.PrimaxOneTouchKeyList = PrimaxOneTouchKeyInfoList;
			fSettingHeadline.PrimaxWizToTrp = true;
		}
		fSettingHeadline.Initialize(regNoEnable: false);
		if (!PrimaxModel)
		{
			int.TryParse(addressBookInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX], out result);
			fSettingHeadline.RegistrationNo = result;
			int.TryParse(addressBookInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_1], out result);
			fSettingHeadline.Index1Headline = result - 1;
			int.TryParse(addressBookInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_2], out result);
			fSettingHeadline.Index2Headline = result - 1;
			int.TryParse(addressBookInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_3], out result);
			fSettingHeadline.Index3Headline = result - 1;
			int.TryParse(addressBookInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_FREQ], out result);
			fSettingHeadline.IndexRegularHeading = result;
		}
	}

	private void getFormSettingHeadLine()
	{
		int registrationNo = fSettingHeadline.RegistrationNo;
		if (registrationNo > 0)
		{
			updateTroubleShootAddressBookInfo(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX, fSettingHeadline.RegistrationNo.ToString());
		}
		updateTroubleShootAddressBookInfo(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_1, (fSettingHeadline.Index1Headline + 1).ToString());
		updateTroubleShootAddressBookInfo(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_2, (fSettingHeadline.Index2Headline + 1).ToString());
		updateTroubleShootAddressBookInfo(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_3, (fSettingHeadline.Index3Headline + 1).ToString());
		updateTroubleShootAddressBookInfo(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_FREQ, fSettingHeadline.IndexRegularHeading.ToString());
	}

	private void setTextBoxInitialString(TextBox textBoxObj, string initialStr, bool passwordUse = false)
	{
		//IL_002e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0038: Expected O, but got Unknown
		//IL_0069: Unknown result type (might be due to invalid IL or missing references)
		//IL_0073: Expected O, but got Unknown
		if (string.IsNullOrEmpty(((Control)textBoxObj).Text) || string.Equals(((Control)textBoxObj).Text, initialStr))
		{
			((Control)textBoxObj).Text = initialStr;
			((Control)textBoxObj).Font = new Font(Resources.FONT, 9f, (FontStyle)2);
			((Control)textBoxObj).ForeColor = Color.FromArgb(195, 195, 195);
			if (passwordUse)
			{
				textBoxObj.PasswordChar = '\0';
			}
		}
		else
		{
			((Control)textBoxObj).Font = new Font(Resources.FONT, 9f, (FontStyle)0);
			((Control)textBoxObj).ForeColor = Color.Black;
			if (passwordUse)
			{
				textBoxObj.PasswordChar = '*';
			}
		}
	}

	public static string GetHostNameFromIP(string ipAddress)
	{
		//IL_003b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0040: Unknown result type (might be due to invalid IL or missing references)
		//IL_004a: Expected O, but got Unknown
		//IL_004a: Expected O, but got Unknown
		//IL_0045: Unknown result type (might be due to invalid IL or missing references)
		//IL_004f: Expected O, but got Unknown
		//IL_0066: Unknown result type (might be due to invalid IL or missing references)
		//IL_0071: Expected O, but got Unknown
		//IL_006c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0086: Expected O, but got Unknown
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		string text = string.Empty;
		try
		{
			List<Variable> list = new List<Variable>(1);
			list.Add(new Variable(new ObjectIdentifier(new uint[9] { 1u, 3u, 6u, 1u, 2u, 1u, 1u, 1u, 0u }), (ISnmpData)new Null()));
			IList<Variable> list2 = list;
			new List<Variable>();
			IPAddress address = IPAddress.Parse(ipAddress);
			string text2 = SnmpMessageExtension.Variables(SnmpMessageExtension.GetResponse((ISnmpMessage)new GetRequestMessage(0, (VersionCode)0, new OctetString("public"), list2), 6000, new IPEndPoint(address, 161)))[0].Data.ToString();
			int num = 0;
			int num2 = text2.IndexOf(" ");
			for (int i = 0; i < MODELNAME_SECTION_MAX_NUM; i++)
			{
				text += text2.Substring(num, num2 - num);
				if (i < MODELNAME_SECTION_MAX_NUM - 1)
				{
					text += " ";
				}
				num = num2 + 1;
				num2 = text2.IndexOf(" ", num);
			}
		}
		catch (Exception ex)
		{
			Console.WriteLine(ex.ToString());
			text = string.Empty;
		}
		LOG.DebugFormat("Return:{0}", (object)text);
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return text;
	}

	private static void DiscovererUnicastAgentFound(object sender, AgentFoundEventArgs e)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		Console.WriteLine("{0} announces {1}", e.Agent, (e.Variable == null) ? "it supports v3" : e.Variable.Data.ToString());
		if (e.Variable != null)
		{
			LOG.DebugFormat("{0}：AgentGet：{1} {2}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)e.Agent.ToString(), (object)e.Variable.Data.ToString());
			if (e.Variable.Data.ToString().IndexOf("RICOH") >= 0)
			{
				try
				{
					myHost = e.Variable.Data.ToString();
				}
				catch (Exception ex)
				{
					LOG.DebugFormat("{0}：same IP addr : {1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)ex.ToString());
				}
			}
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
	}

	private void ToolStripMenuPCInfo_Click(object sender, EventArgs e)
	{
		//IL_0021: Unknown result type (might be due to invalid IL or missing references)
		((Control)this).Cursor = Cursors.WaitCursor;
		FormPCInfo formPCInfo = FormPCInfo.GetFormPCInfo(machineLang);
		((Control)this).Cursor = Cursors.Default;
		((Form)formPCInfo).ShowDialog((IWin32Window)(object)this);
	}

	private void ToolStripMenuMachineInfo_Click(object sender, EventArgs e)
	{
		//IL_0022: Unknown result type (might be due to invalid IL or missing references)
		fGetMFPInfo.clearMachineList();
		fGetMFPInfo.setMachineList(machineInfoList);
		((Form)fGetMFPInfo).ShowDialog((IWin32Window)(object)this);
	}

	private void cmbP4FolderPass_SelectedIndexChanged(object sender, EventArgs e)
	{
	}

	private void createHTML(string pUser, string pHostIP, string pHostName, string pSendName, string pSendFolder)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		string empty = string.Empty;
		string empty2 = string.Empty;
		string empty3 = string.Empty;
		string empty4 = string.Empty;
		string newValue = Resources.TXT_SHARE_FOLDER_INCLUDED_PATH_OF_TOOL;
		try
		{
			empty = pUser.Replace("\\", "&yen;");
			if (empty.Equals(""))
			{
				empty = Resources.CREATE_HTML_DEFAULT_USER;
			}
			empty3 = ((!pHostIP.Equals("")) ? ("\\\\" + pHostIP).Replace("\\", "&yen;") : $"</font color='red'>{Resources.CREATE_HTML_NOT_FOUND_IPADRESS}</font>");
			empty2 = ((!pHostName.Equals("")) ? ("\\\\" + pHostName + "\\" + pSendFolder).Replace("\\", "&yen;") : Resources.CREATE_HTML_NOT_FOUND_PC_NAME);
			empty4 = pSendName.Replace("\\", "&yen;");
			if (empty4.Equals(""))
			{
				empty4 = Resources.CREATE_HTML_DEFAULT_DEST;
			}
			if (!pSendFolder.Equals(""))
			{
				newValue = pSendFolder;
			}
			string baseDirectory = AppDomain.CurrentDomain.BaseDirectory;
			string path = baseDirectory + fMain.HELP_FILE_BASE;
			string path2 = baseDirectory + fMain.HELP_FILE;
			string text = string.Empty;
			if (File.Exists(path))
			{
				StreamReader streamReader = new StreamReader(path, Encoding.GetEncoding("utf-8"));
				text = streamReader.ReadToEnd();
				streamReader.Close();
			}
			string value = text.Replace("{USER}", empty).Replace("{SetIP}", empty3).Replace("{SetPCName}", empty2)
				.Replace("{ADDR}", empty4)
				.Replace("{SendFolder}", newValue);
			StreamWriter streamWriter = new StreamWriter(path2, append: false, Encoding.GetEncoding("utf-8"));
			streamWriter.Write(value);
			streamWriter.Close();
		}
		catch (Exception ex)
		{
			LOG.ErrorFormat("{0}：！！！ HTMLファイル作成でエラー  \n" + ex.ToString() + "\n*******************************", (object)MethodBase.GetCurrentMethod().Name);
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	private void linkLabelP7Help_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
	{
		//IL_006e: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：設定手順表示リンク押下(Finish)", (object)MethodBase.GetCurrentMethod().Name);
		string iPAddress = fMain.getIPAddress();
		createHTML(((Control)cmbP3UserName).Text.Replace("\\", "&yen;"), iPAddress, hostname, ((Control)textP4Destination).Text, ((Control)textBoxFolderName).Text);
		FormHelp formHelp = new FormHelp("help\\Help.html");
		((Form)formHelp).ShowDialog((IWin32Window)(object)this);
		((Component)(object)formHelp).Dispose();
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	private void linkLabelConnect_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
	{
		//IL_006e: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：設定手順表示リンク押下(Finish)", (object)MethodBase.GetCurrentMethod().Name);
		string iPAddress = fMain.getIPAddress();
		createHTML(((Control)cmbP3UserName).Text.Replace("\\", "&yen;"), iPAddress, hostname, ((Control)textP4Destination).Text, ((Control)textBoxFolderName).Text);
		FormHelp formHelp = new FormHelp("help\\Help.html");
		((Form)formHelp).ShowDialog((IWin32Window)(object)this);
		((Component)(object)formHelp).Dispose();
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	private void linkLabel1_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
	{
		//IL_002b: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：フォルダー送信設定手順表示リンク押下", (object)MethodBase.GetCurrentMethod().Name);
		FormHelp formHelp = new FormHelp(fMain.HELP_FILE_FOLDERBASE);
		((Form)formHelp).ShowDialog((IWin32Window)(object)this);
		((Component)(object)formHelp).Dispose();
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	private void textBoxFolderName_Leave(object sender, EventArgs e)
	{
		textBox_LeaveCommon(sender, Resources.TXT_P2_INITIAL_001, passwordUse: false);
	}

	private void textBoxFolderName_Enter(object sender, EventArgs e)
	{
		textBox_EnterCommon(sender, Resources.TXT_P2_INITIAL_001, passwordUse: false);
	}

	private void textBoxFolderPath_Leave(object sender, EventArgs e)
	{
		textBox_LeaveCommon(sender, Resources.TXT_P2_INITIAL_002, passwordUse: false);
	}

	private void textBoxFolderPath_Enter(object sender, EventArgs e)
	{
		textBox_EnterCommon(sender, Resources.TXT_P2_INITIAL_002, passwordUse: false);
	}

	private void textBoxNonSharedFolderPath_Leave(object sender, EventArgs e)
	{
		//IL_005c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0066: Expected O, but got Unknown
		//IL_00b4: Unknown result type (might be due to invalid IL or missing references)
		//IL_00be: Expected O, but got Unknown
		textBox_LeaveCommon(sender, Resources.TXT_P2_INITIAL_003, passwordUse: false);
		if (((Control)textBoxNonSharedFolderPath).Text == string.Empty || ((Control)textBoxNonSharedFolderPath).Text == Resources.TXT_P2_INITIAL_003)
		{
			((Control)textBoxSharedName).Text = Resources.TXT_P2_INITIAL_001;
			((Control)textBoxSharedName).Font = new Font("Resources.FONT", 9f, (FontStyle)2);
			((Control)textBoxSharedName).ForeColor = Color.FromArgb(195, 195, 195);
		}
		else
		{
			string fileName = Path.GetFileName(((Control)textBoxNonSharedFolderPath).Text);
			((Control)textBoxSharedName).Text = fileName;
			((Control)textBoxSharedName).Font = new Font("Resources.FONT", 9f, (FontStyle)0);
			((Control)textBoxSharedName).ForeColor = Color.Black;
		}
	}

	private void textBoxNonSharedFolderPath_Enter(object sender, EventArgs e)
	{
		textBox_EnterCommon(sender, Resources.TXT_P2_INITIAL_003, passwordUse: false);
	}

	private void textBoxSharedName_Leave(object sender, EventArgs e)
	{
		textBox_LeaveCommon(sender, Resources.TXT_P2_INITIAL_001, passwordUse: false);
	}

	private void textBoxSharedName_Enter(object sender, EventArgs e)
	{
		textBox_EnterCommon(sender, Resources.TXT_P2_INITIAL_001, passwordUse: false);
	}

	private void textBoxP4Pass_Leave(object sender, EventArgs e)
	{
		textBox_LeaveCommon(sender, Resources.TXT_P3_INITIAL_001, passwordUse: true);
	}

	private void textBoxP4Pass_Enter(object sender, EventArgs e)
	{
		textBox_EnterCommon(sender, Resources.TXT_P3_INITIAL_001, passwordUse: true);
	}

	private void textBox4PassConfirm_Leave(object sender, EventArgs e)
	{
		textBox_LeaveCommon(sender, Resources.TXT_P3_INITIAL_002, passwordUse: true);
	}

	private void textBox4PassConfirm_Enter(object sender, EventArgs e)
	{
		textBox_EnterCommon(sender, Resources.TXT_P3_INITIAL_002, passwordUse: true);
	}

	private void textP4AddressName_Leave(object sender, EventArgs e)
	{
		textBox_LeaveCommon(sender, Resources.TXT_P4_INITIAL_001, passwordUse: false);
	}

	private void textP4AddressName_Enter(object sender, EventArgs e)
	{
		textBox_EnterCommon(sender, Resources.TXT_P4_INITIAL_001, passwordUse: false);
	}

	private void createNewFolderRadioButton_CheckedChanged(object sender, EventArgs e)
	{
		_ = createNewFolderRadioButton.Checked;
		if (createNewFolderRadioButton.Checked)
		{
			((Control)labelP2_FolderName).Enabled = true;
			((Control)textBoxFolderName).Enabled = true;
			((Control)labelP2_FolderPath).Enabled = true;
			((Control)textBoxFolderPath).Enabled = true;
			((Control)buttonSelectFolder).Enabled = true;
			((Control)labelP2_Folder).Enabled = false;
			((Control)cmbP2Folder).Enabled = false;
			((Control)labelP2_selectFolder).Enabled = false;
			((Control)labelP2_NonSharedFolderPath).Enabled = false;
			((Control)textBoxNonSharedFolderPath).Enabled = false;
			((Control)buttonSelectNonSharedFolder).Enabled = false;
			((Control)labelP2_selectNonSharedFolder).Enabled = false;
			((Control)labelP2_SharedName).Enabled = false;
			((Control)textBoxSharedName).Enabled = false;
		}
		else if (selectFolderRadioButton.Checked)
		{
			((Control)labelP2_FolderName).Enabled = false;
			((Control)textBoxFolderName).Enabled = false;
			((Control)labelP2_FolderPath).Enabled = false;
			((Control)textBoxFolderPath).Enabled = false;
			((Control)buttonSelectFolder).Enabled = false;
			((Control)labelP2_Folder).Enabled = true;
			((Control)cmbP2Folder).Enabled = true;
			((Control)labelP2_selectFolder).Enabled = true;
			((Control)labelP2_NonSharedFolderPath).Enabled = false;
			((Control)textBoxNonSharedFolderPath).Enabled = false;
			((Control)buttonSelectNonSharedFolder).Enabled = false;
			((Control)labelP2_selectNonSharedFolder).Enabled = false;
			((Control)labelP2_SharedName).Enabled = false;
			((Control)textBoxSharedName).Enabled = false;
		}
		else
		{
			((Control)labelP2_FolderName).Enabled = false;
			((Control)textBoxFolderName).Enabled = false;
			((Control)labelP2_FolderPath).Enabled = false;
			((Control)textBoxFolderPath).Enabled = false;
			((Control)buttonSelectFolder).Enabled = false;
			((Control)labelP2_Folder).Enabled = false;
			((Control)cmbP2Folder).Enabled = false;
			((Control)labelP2_selectFolder).Enabled = false;
			((Control)labelP2_NonSharedFolderPath).Enabled = true;
			((Control)textBoxNonSharedFolderPath).Enabled = true;
			((Control)buttonSelectNonSharedFolder).Enabled = true;
			((Control)labelP2_selectNonSharedFolder).Enabled = true;
			((Control)labelP2_SharedName).Enabled = true;
			((Control)textBoxSharedName).Enabled = true;
		}
	}

	private void textBoxTRP6Pass_Leave(object sender, EventArgs e)
	{
		textBox_LeaveCommon(sender, Resources.TXT_P3_INITIAL_001, passwordUse: true);
	}

	private void textBoxTRP6Pass_Enter(object sender, EventArgs e)
	{
		textBox_EnterCommon(sender, Resources.TXT_P3_INITIAL_001, passwordUse: true);
	}

	private void textBoxTRP6PassConfirm_Leave(object sender, EventArgs e)
	{
		textBox_LeaveCommon(sender, Resources.TXT_P3_INITIAL_002, passwordUse: true);
	}

	private void textBoxTRP6PassConfirm_Enter(object sender, EventArgs e)
	{
		textBox_EnterCommon(sender, Resources.TXT_P3_INITIAL_002, passwordUse: true);
	}

	private void textBox_LeaveCommon(object sender, string initialStr, bool passwordUse)
	{
		//IL_0001: Unknown result type (might be due to invalid IL or missing references)
		//IL_0007: Expected O, but got Unknown
		//IL_0035: Unknown result type (might be due to invalid IL or missing references)
		//IL_003f: Expected O, but got Unknown
		TextBox val = (TextBox)sender;
		if (string.IsNullOrEmpty(((Control)val).Text) || string.Equals(((Control)val).Text, initialStr))
		{
			((Control)val).Text = initialStr;
			((Control)val).Font = new Font(Resources.FONT, 9f, (FontStyle)2);
			((Control)val).ForeColor = Color.FromArgb(195, 195, 195);
			if (passwordUse)
			{
				val.PasswordChar = '\0';
			}
		}
	}

	private void textBox_EnterCommon(object sender, string initialStr, bool passwordUse)
	{
		//IL_0001: Unknown result type (might be due to invalid IL or missing references)
		//IL_0007: Expected O, but got Unknown
		//IL_002c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0036: Expected O, but got Unknown
		TextBox val = (TextBox)sender;
		if (((Control)val).Text.Equals(initialStr))
		{
			((Control)val).Text = string.Empty;
			((Control)val).Font = new Font("Resources.FONT", 9f, (FontStyle)0);
			((Control)val).ForeColor = Color.Black;
			if (passwordUse)
			{
				val.PasswordChar = '*';
			}
		}
	}

	private void buttonHeadLine_Click(object sender, EventArgs e)
	{
		if (settingHeadlineInitializeToPrimax())
		{
			fSettingHeadline.Initialize();
			fSettingHeadline.SetHeadLine((Form)(object)this);
		}
	}

	private bool settingHeadlineInitializeToPrimax()
	{
		//IL_0078: Unknown result type (might be due to invalid IL or missing references)
		Cursor current = Cursor.Current;
		Cursor.Current = Cursors.WaitCursor;
		PrimaxModel = getInputIpAddressToPrimaxMode();
		Cursor.Current = current;
		fSettingHeadline.PrimaxProcMode = FormSettingHeadLine.PRIMAX_PROC_MODE.NOT_PRIMAX;
		if (PrimaxModel)
		{
			bool flag = true;
			for (int i = 0; i < PrimaxOneTouchKeyInfoList.Count; i++)
			{
				if (string.IsNullOrEmpty(PrimaxOneTouchKeyInfoList[i].name))
				{
					flag = false;
					break;
				}
			}
			if (flag)
			{
				MessageBox.Show(Resources.ERR_MSG_PRIMAX_NO_ONE_TOUCH_KEY, Resources.ERR_MSG_TITLE_KEY_ALL_USING, (MessageBoxButtons)0, (MessageBoxIcon)64);
				return false;
			}
			fSettingHeadline.PrimaxProcMode = FormSettingHeadLine.PRIMAX_PROC_MODE.INSERT;
			fSettingHeadline.PrimaxOneTouchKeyList = PrimaxOneTouchKeyInfoList;
			fSettingHeadline.PrimaxWizToTrp = true;
		}
		return true;
	}

	private bool getInputIpAddressToPrimaxMode()
	{
		Dictionary<MachineSelectControl.ADDRESS_FORM, string> selectedAddress = machineSelectControl.getSelectedAddress(msgOn: false);
		string ipAddr = selectedAddress[MachineSelectControl.ADDRESS_FORM.IP];
		bool flag = false;
		if (!string.IsNullOrEmpty(ipAddr))
		{
			string hostNameFromIP = GetHostNameFromIP(ipAddr);
			flag = IsPrimax(hostNameFromIP);
			PrimaxUnicode = IsPrimaxUnicode(hostNameFromIP);
			if (flag)
			{
				MachineControl mc = new MachineControl(machineLang);
				mc.SetPrimaxModel(flag);
				mc.SetPrimaxUnicode(PrimaxUnicode);
				COMMUNICATION_ERROR_CODE cOMMUNICATION_ERROR_CODE = mc.communicateConfirm(ipAddr, showErrorDialog: false);
				bool isHttps = false;
				if (!cOMMUNICATION_ERROR_CODE.Equals(COMMUNICATION_ERROR_CODE.HTTP_ONLY))
				{
					isHttps = true;
				}
				Task<List<OneTouchKeyInfo>> task = Task.Run(() => mc.getPrimaxOneTouchKeyInfo(isHttps, ipAddr));
				PrimaxOneTouchKeyInfoList = task.Result;
				Task<List<string[]>> task2 = Task.Run(() => mc.getPrimaxAddressList(isHttps, ipAddr, PrimaxOneTouchKeyInfoList));
				PrimaxAddressList = task2.Result;
			}
		}
		return flag;
	}

	private void AddressBookChangeMenuItem_Click(object sender, EventArgs e)
	{
		//IL_005e: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		if (string.IsNullOrEmpty(ipaddr))
		{
			ipaddr = fMain.getIPAddress();
		}
		FormAddressBookEdit formAddressBookEdit = new FormAddressBookEdit(ipaddr, machineLang);
		formAddressBookEdit.initialize();
		formAddressBookEdit.clearMachineList();
		formAddressBookEdit.setMachineList(machineInfoList);
		((Form)formAddressBookEdit).ShowDialog();
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	private void machineSelectCheck(MachineSelectControl machineSelectCtrl, Label connectCheck, LinkLabel connectErrorLink, bool dhcpCaution)
	{
		//IL_0071: Unknown result type (might be due to invalid IL or missing references)
		//IL_01be: Unknown result type (might be due to invalid IL or missing references)
		//IL_0128: Unknown result type (might be due to invalid IL or missing references)
		//IL_012e: Invalid comparison between Unknown and I4
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		((Control)connectErrorLink).Visible = false;
		Dictionary<MachineSelectControl.ADDRESS_FORM, string> selectedAddress = machineSelectCtrl.getSelectedAddress();
		mfpIpAddr = selectedAddress[MachineSelectControl.ADDRESS_FORM.IP];
		displayedContents = (selectedAddress.ContainsKey(MachineSelectControl.ADDRESS_FORM.NAME) ? selectedAddress[MachineSelectControl.ADDRESS_FORM.NAME] : string.Empty);
		if (string.IsNullOrEmpty(mfpIpAddr))
		{
			MessageBox.Show(Resources.MACHINE_NOT_SELECTED_ERROR2_TEXT, Resources.MACHINE_SETTING_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
			LOG.InfoFormat("{0}：機器の設定エラー：IPアドレス無し", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			throw new Exception("input error . machineSelectControl");
		}
		if (dhcpCaution && cmbP4FolderPath.SelectedItem.ToString().Contains(fMain.getIPAddress()) && (int)MessageBox.Show(Resources.TEXT_P4_DHCP_CAUTION_TEXT_01 + "\n\n " + Resources.TEXT_P4_DHCP_CAUTION_TEXT_02 + "\n\n " + Resources.TEXT_P4_DHCP_CAUTION_TEXT_03 + "\n\n " + Resources.TEXT_P4_DHCP_CAUTION_TEXT_04 + "\n\n " + Resources.TEXT_P4_DHCP_CAUTION_TEXT_05, Resources.CONFIRM, (MessageBoxButtons)1, (MessageBoxIcon)48) == 2)
		{
			LOG.InfoFormat("{0}：機器の設定：DHCP確認でキャンセル選択", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			throw new Exception("Select Cansel. textP4DHCP");
		}
		ErrorCode errorCode = ErrorCode.NOERROR;
		((Control)connectCheck).Visible = true;
		((Control)this).Refresh();
		ErrorCode errorCode2 = IsConnectMFP(mfpIpAddr);
		((Control)connectCheck).Visible = false;
		((Control)this).Refresh();
		switch (errorCode2)
		{
		case ErrorCode.ADRESS_EMPTY:
		case ErrorCode.ADRESS_FORMAT_ERROR:
			MessageBox.Show(Resources.MACHINE_NOT_SELECTED_ERROR2_TEXT, Resources.MACHINE_SETTING_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
			LOG.ErrorFormat("{0}：IPアドレス入力エラー：IPアドレス無し\n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			errorCode = ErrorCode.ERROR;
			break;
		case ErrorCode.MFP_NOT_FOUND:
			LOG.InfoFormat("{0}：機器情報検索エラー IPアドレス：{1}\n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)mfpIpAddr);
			((Control)connectErrorLink).Visible = true;
			errorCode = ErrorCode.ERROR;
			break;
		case ErrorCode.MFP_NOT_SUPPORTED:
			LOG.DebugFormat("{0}：not supported machine：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)mfpIpAddr);
			errorCode = ErrorCode.ERROR;
			break;
		case ErrorCode.NOERROR_HTTP_ONLY:
			LOG.DebugFormat("{0}：http only IP Address：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)mfpIpAddr);
			break;
		case ErrorCode.NOERROR:
			LOG.DebugFormat("{0}：IP Address：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)mfpIpAddr);
			break;
		default:
			LOG.ErrorFormat("{0}：State Error：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)errorCode2);
			break;
		}
		if (errorCode != 0)
		{
			throw new Exception("input error . REGIST_ADDRESS_ERROR");
		}
	}

	private void radioButtonCreateFolder_CheckedChanged(object sender, EventArgs e)
	{
		((Control)panel_P1_1).Controls.Clear();
		bool @checked = radioButtonCreateFolder.Checked;
		if (@checked)
		{
			setProcedureNames(procedureNameList, panel_P1_1, 0);
		}
		else
		{
			setProcedureNames(troubleShootProcedureNameList, panel_P1_1, 0);
		}
		((Control)btnP1Next).Enabled = @checked;
		((Control)btnP1Next).Visible = @checked;
		((Control)btnP1TRNext).Enabled = !@checked;
		((Control)btnP1TRNext).Visible = !@checked;
	}

	private void textBoxSearch_KeyPress(object sender, KeyPressEventArgs e)
	{
		adrBookListCtrl.textBoxSearch_KeyPress(e);
	}

	private void buttonTRP3Search_Click(object sender, EventArgs e)
	{
		PrimaxModel = adrBookListCtrl.SetPrimaxModel(mfpIpAddr);
		PrimaxUnicode = IsPrimaxUnicode(GetHostNameFromIP(mfpIpAddr));
		adrBookListCtrl.buttonSearch_Click();
	}

	private void buttonToTop_Click(object sender, EventArgs e)
	{
		adrBookListCtrl.buttonToTheTop_Click();
	}

	private void buttonPrevious_Click(object sender, EventArgs e)
	{
		adrBookListCtrl.buttonPrevious_Click();
	}

	private void buttonNext_Click(object sender, EventArgs e)
	{
		adrBookListCtrl.buttonNext_Click();
	}

	private void buttonToBottom_Click(object sender, EventArgs e)
	{
		adrBookListCtrl.buttonToTheButtom_Click();
	}

	private void buttonTRP3Break_Click(object sender, EventArgs e)
	{
		adrBookListCtrl.buttonBreak_Click();
	}

	private void buttonResume_Click(object sender, EventArgs e)
	{
		adrBookListCtrl.buttonResume_Click();
	}

	private void listViewAddressList_DrawColumnHeader(object sender, DrawListViewColumnHeaderEventArgs e)
	{
		adrBookListCtrl.listViewAddressList_DrawColumnHeader(e);
	}

	private void listViewAddressList_DrawItem(object sender, DrawListViewItemEventArgs e)
	{
		adrBookListCtrl.listViewAddressList_DrawItem(e);
	}

	private void listViewAddressList_ItemSelectionChanged(object sender, ListViewItemSelectionChangedEventArgs e)
	{
		if (e.IsSelected && e.Item.BackColor == adrBookListCtrl.ListViewSelectDeniedColor)
		{
			e.Item.Selected = false;
		}
		else
		{
			((Control)btnTRP3Next).Visible = e.IsSelected;
		}
	}

	private void btnTRP2Next_Click(object sender, EventArgs e)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		((Control)this).Cursor = Cursors.WaitCursor;
		((Control)menuStrip1).Enabled = false;
		((Control)machineSelectControlTRP2).Enabled = false;
		((Control)btnTRP2Back).Enabled = false;
		((Control)btnTRP2Next).Enabled = false;
		((Control)linkLabelTRP2).Visible = false;
		try
		{
			machineSelectCheck(machineSelectControlTRP2, label_TRP2ConnectCheck, linkLabelTRP2, dhcpCaution: false);
			adrBookListCtrl.MFP_SelectedAddress = mfpIpAddr;
			((Control)labelTRP3MFP_Selected).Text = (string.IsNullOrEmpty(displayedContents) ? mfpIpAddr : displayedContents);
			if (PrimaxModel)
			{
				((Control)labelTRP3MFP_Selected).Text = GetHostNameFromIP(mfpIpAddr);
				displayedContents = ((Control)labelTRP3MFP_Selected).Text;
			}
			machineSelectControlTRP2.setBackDisplayName(displayedContents);
		}
		finally
		{
			adrBookListCtrl.resetSeachEnvironments();
			((Control)menuStrip1).Enabled = true;
			((Control)machineSelectControlTRP2).Enabled = true;
			((Control)btnTRP2Back).Enabled = true;
			((Control)btnTRP2Next).Enabled = true;
			if (PrimaxModel)
			{
				((Control)comboBoxTRP3SelectWay).Visible = false;
				((Control)textBoxTRP3Search).Visible = false;
				listViewAddressList.Columns[0].Text = Resources.PRIMAX_ONE_TOUCH_KEY;
			}
			else
			{
				((Control)comboBoxTRP3SelectWay).Visible = true;
				((Control)textBoxTRP3Search).Visible = true;
				listViewAddressList.Columns[0].Text = Resources.ADDRESSBOOK_REGISTRATION_NO_NAME;
				PrimaxAdminPasswd = "";
			}
			((Control)this).Cursor = Cursors.Default;
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		}
	}

	private void btnTRP7Next_Click(object sender, EventArgs e)
	{
		//IL_0093: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		((Control)this).Cursor = Cursors.WaitCursor;
		try
		{
			passwordCheck(((Control)textBoxTRP7Pass).Text, ((Control)textBoxTRP7PassConfirm).Text, "textBoxTRP6Path", machineLang);
			PrimaxTrpOldAddressName = "";
			if (PrimaxModel)
			{
				string text = ((Control)textBoxTRP7PassConfirm).Text;
				if (!string.IsNullOrEmpty(text))
				{
					MachineControl machineControl = new MachineControl(machineLang);
					if (machineControl.convHexString(text, MachineControl.PRIMAX_HEX_ENCODINGT.SJIS) == null)
					{
						MessageBox.Show(Resources.ERR_MSG_PASSWORD_CHAR_TYPE, Resources.ERR_MSG_TITLE_PASSWORD_CHAR_TYPE, (MessageBoxButtons)0, (MessageBoxIcon)16);
						throw new Exception("input error .パスワード");
					}
				}
				PrimaxTrpOldAddressName = troubleShootAddressBookInfoUpdate.addressBookInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_NAME];
			}
			string valueStr = string.Empty;
			if (!((Control)textBoxTRP7Pass).Text.Equals(Resources.TXT_P3_INITIAL_001))
			{
				valueStr = ((Control)textBoxTRP7Pass).Text;
			}
			updateTroubleShootAddressBookInfo(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PASSWORD, valueStr);
			updateTroubleShootAddressBookInfo(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_AUTH_USER_NAME, ((Control)cmbTRP7PcUser).Text);
			if (!troubleShootAddressBookInfoUpdate.folder)
			{
				StateMachineTroubleShoot.StateType stateType = StateMachineTroubleShoot.StateType.TR_ADDRESSBOOK_SETUP;
				LOG.DebugFormat("{0} Change State:{1} -> {2}", (object)MethodBase.GetCurrentMethod().Name, (object)StateMachineTroubleShoot.NowState, (object)stateType);
				StateMachineTroubleShoot.NowState = stateType;
			}
		}
		catch (Exception ex)
		{
			Console.Out.WriteLine(ex.ToString());
			LOG.ErrorFormat("{0}：！！！ パスワード入力エラー  \n{1}\n*******************************", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)ex.ToString());
			throw;
		}
		finally
		{
			((Control)this).Cursor = Cursors.Default;
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		}
	}

	private void passwordCheck(string password, string passwordConfirm, string textBoxName, string lang)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		PasswordCheck passwordCheck = new PasswordCheck();
		try
		{
			passwordCheck.checkPassword(password, passwordConfirm, machineLang, textBoxName);
		}
		catch (Exception)
		{
			throw;
		}
		finally
		{
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		}
	}

	private async void btnTRP3Next_Click(object sender, EventArgs e)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		((Control)this).Cursor = Cursors.WaitCursor;
		progressBarTRP4.Value = 0;
		await semaphoreTroubleShootAddressBookInfo.WaitAsync();
		PrimaxOneTouchKeyInfoList = null;
		if (PrimaxModel)
		{
			MachineControl machineControl = new MachineControl(machineLang);
			machineControl.SetPrimaxModel(PrimaxModel);
			machineControl.SetPrimaxUnicode(PrimaxUnicode);
			COMMUNICATION_ERROR_CODE cOMMUNICATION_ERROR_CODE = machineControl.communicateConfirm(mfpIpAddr, showErrorDialog: false);
			bool thhpsFlg = false;
			if (!cOMMUNICATION_ERROR_CODE.Equals(COMMUNICATION_ERROR_CODE.HTTP_ONLY))
			{
				thhpsFlg = true;
			}
			FormWizard formWizard = this;
			_ = formWizard.PrimaxOneTouchKeyInfoList;
			formWizard.PrimaxOneTouchKeyInfoList = await machineControl.getPrimaxOneTouchKeyInfo(thhpsFlg, mfpIpAddr);
		}
		try
		{
			troubleShootAddressBookInfo = null;
			FormWizard formWizard = this;
			_ = formWizard.troubleShootAddressBookInfo;
			formWizard.troubleShootAddressBookInfo = await getAddressBookInfo();
		}
		catch (Exception ex)
		{
			string text = adrBookListCtrl.checkException(ex, MethodBase.GetCurrentMethod().DeclaringType.Name);
			if (text.IndexOf(Resources.ERR_MSG_WIM_ADDRESSBOOK_UPDATE) >= 0)
			{
				text = $"{Resources.ERR_MSG_MACHINE_ADDRESSBOOK_UPDATE}\n{Resources.ERR_MSG_DIAGNOSE_RETRY}";
			}
			MessageBox.Show(text, Resources.ERR_MSG_SEARCH_ERROR_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
		}
		finally
		{
			semaphoreTroubleShootAddressBookInfo.Release();
			((Control)this).Cursor = Cursors.Default;
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		}
	}

	public async Task<ErrorCode> analyzeAddressBook()
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		isAlertFolderName = false;
		isAlertFolderPath = false;
		isAlertAccountName = false;
		isAlertPassword = false;
		isAlertFireWalllSetting = false;
		((Control)this).Cursor = Cursors.WaitCursor;
		updateTRprogressBar(string.Empty);
		((Control)progressBarTRP4).Visible = true;
		((Control)this).Refresh();
		PrimaxKeyCode = string.Empty;
		StringBuilder sb = new StringBuilder();
		await semaphoreTroubleShootAddressBookInfo.WaitAsync();
		try
		{
			if (troubleShootAddressBookInfo == null)
			{
				StateMachineTroubleShoot.NextState = StateMachineTroubleShoot.StateType.TR_USER;
				panelChangeTroubleShoot(StateMachineTroubleShoot.NowState, StateMachineTroubleShoot.NextState);
				Application.DoEvents();
				Thread.Sleep(500);
				LOG.DebugFormat("{0} Change State:{1} -> {2}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)StateMachineTroubleShoot.NowState, (object)StateMachineTroubleShoot.NextState);
				StateMachineTroubleShoot.NowState = StateMachineTroubleShoot.NextState;
				return ErrorCode.ERROR;
			}
			troubleShootAddressBookInfoUpdate.addressBookInfo = new Dictionary<AddressBookListControl.ADDRESSBOOK_LIST_ITEM, string>(troubleShootAddressBookInfo);
			troubleShootAddressBookInfoUpdate.access = false;
			troubleShootAddressBookInfoUpdate.folder = false;
			troubleShootAddressBookInfoUpdate.fireWall = false;
			((Control)textBoxTRP6FolderName).Text = string.Empty;
			if (checkFolderPath(troubleShootAddressBookInfo))
			{
				string IPorHostName = string.Empty;
				string folderName = string.Empty;
				parseFolderPath(troubleShootAddressBookInfo, ref IPorHostName, ref folderName);
				((Control)textBoxTRP6FolderName).Text = folderName;
				bool flag;
				switch (checkFolderSetting(folderName))
				{
				case FolderResult.EMPTY:
					sb.AppendFormat("{0}\n  {1}\n", Resources.TROUBLE_SHOOTING_WARNING_NO_FOLDER_SETTING, Resources.TROUBLE_SHOOTING_WARNING_CREATE_FOLDER);
					flag = true;
					isAlertFolderName = true;
					break;
				case FolderResult.CHANGE_NAME_OR_PATH:
					sb.AppendFormat("{0}\n  {1}\n", Resources.TROUBLE_SHOOTING_WARNING_SAME_FOLDER_DESKTOP, Resources.TROUBLE_SHOOTING_WARNING_CREATE_FOLDER);
					flag = true;
					isAlertFolderName = true;
					break;
				case FolderResult.EXIST_NO_ACCESS:
					sb.AppendFormat("{0}\n", Resources.TROUBLE_SHOOTING_WARNING_FOLDER_ACCESS);
					troubleShootAddressBookInfoUpdate.access = true;
					flag = false;
					isAlertFolderPath = true;
					break;
				case FolderResult.NO_ENTRY_EXIST:
				case FolderResult.FOLDER_NOT_EXIST:
					sb.AppendFormat("{0}\n  {1}\n  {2}\n", Resources.TROUBLE_SHOOTING_WARNING_NO_REAL_FOLDER, Resources.TROUBLE_SHOOTING_WARNING_NO_REAL_FOLDER_02, Resources.TROUBLE_SHOOTING_WARNING_CREATE_FOLDER);
					flag = true;
					isAlertFolderPath = true;
					break;
				default:
					flag = false;
					break;
				}
				troubleShootAddressBookInfoUpdate.folder = flag;
				string text = createNewHostStr(IPorHostName);
				if (!string.Equals(IPorHostName, text) && !flag)
				{
					string arg = (Regex.IsMatch(IPorHostName, "^\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}$") ? Resources.TROUBLE_SHOOTING_WARNING_IP_ADDRESS : Resources.TROUBLE_SHOOTING_WARNING_HOSTNAME);
					sb.AppendFormat("{0}\n", arg);
					string valueStr = $"\\\\{text}\\{folderName}";
					updateTroubleShootAddressBookInfo(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PATH_NAME, valueStr);
					isAlertFolderPath = true;
				}
			}
			else
			{
				sb.AppendFormat("{0}\n  {1}\n", Resources.TROUBLE_SHOOTING_INVALID_PATH_FORMAT, Resources.TROUBLE_SHOOTING_WARNING_CREATE_FOLDER);
				updateTroubleShootAddressBookInfo(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PATH_NAME, string.Empty);
				updateTroubleShootAddressBookInfo(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_AUTH_USER_NAME, string.Empty);
				troubleShootAddressBookInfoUpdate.folder = true;
				updateTRprogressBar(string.Empty, 2);
				isAlertFolderPath = true;
			}
			if (!checkAccount(troubleShootAddressBookInfo))
			{
				sb.AppendFormat("{0}\n", Resources.TROUBLE_SHOOTING_WARNING_LOGIN_USER);
				updateTroubleShootAddressBookInfo(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_AUTH_USER_NAME, getLoginUserName());
				troubleShootAddressBookInfoUpdate.access = true;
				isAlertAccountName = true;
			}
			if (!checkFireWallSetting())
			{
				sb.AppendFormat("{0}\n", Resources.TROUBLE_SHOOTING_WARNING_FIREWALL);
				isAlertFireWalllSetting = true;
			}
			if (sb.Length == 0)
			{
				sb.AppendFormat("{0}\n", Resources.TROUBLE_SHOOTING_NO_ERROR);
				isAlertPassword = true;
			}
			else
			{
				sb.AppendFormat("{0}\n", Resources.TROUBLE_SHOOTING_WARNING_PASSWORD);
				isAlertPassword = true;
			}
			((TextBoxBase)richTextBoxTRP5).Clear();
			((TextBoxBase)richTextBoxTRP5).SelectedText = $"{Resources.TROUBLE_SHOOTING_DIAG_RESULT}\n";
			Font selectionFont = richTextBoxTRP5.SelectionFont;
			Font val = new Font(selectionFont.FontFamily, selectionFont.Size + 1f, selectionFont.Style);
			richTextBoxTRP5.SelectionFont = val;
			((TextBoxBase)richTextBoxTRP5).SelectedText = sb.ToString();
			val.Dispose();
			richTextBoxTRP5.SelectionFont = selectionFont;
			selectionFont.Dispose();
			((TextBoxBase)richTextBoxTRP5).SelectedText = $"\n{Resources.TROUBLE_SHOOTING_DIAG_CONTENTS}\n";
			if (PrimaxModel)
			{
				PrimaxKeyCode = troubleShootAddressBookInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.KEY_CODE];
			}
			string hostNameFromIP = GetHostNameFromIP(mfpIpAddr);
			FormWizard formWizard = this;
			_ = formWizard.trsmbcode;
			formWizard.trsmbcode = await SMBTRPcheck1(mfpIpAddr, hostNameFromIP, machineLang);
			showTroubleShootResult(richTextBoxTRP5, troubleShootAddressBookInfo);
		}
		catch (Exception ex)
		{
			LOG.InfoFormat("{0}：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)ex.ToString());
			throw;
		}
		finally
		{
			((Control)this).Cursor = Cursors.Default;
			troubleShootAddressBookInfo = null;
			semaphoreTroubleShootAddressBookInfo.Release();
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		}
		return ErrorCode.END;
	}

	private async Task<Dictionary<AddressBookListControl.ADDRESSBOOK_LIST_ITEM, string>> getAddressBookInfo()
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		updateTRprogressBar(Resources.ADDRESSBOOK_GET_ONE_RECORD);
		((Control)this).Refresh();
		MachineControl machineControl = new MachineControl(machineLang);
		machineControl.SetPrimaxModel(PrimaxModel);
		machineControl.SetPrimaxUnicode(PrimaxUnicode);
		COMMUNICATION_ERROR_CODE comResult = machineControl.communicateConfirm(mfpIpAddr);
		if (comResult == COMMUNICATION_ERROR_CODE.ERROR)
		{
			LOG.DebugFormat("{0}：end. Cannot connect device.", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			return null;
		}
		Dictionary<AddressBookListControl.ADDRESSBOOK_LIST_ITEM, string> result;
		if (PrimaxModel)
		{
			bool thhpsFlg = false;
			if (!comResult.Equals(COMMUNICATION_ERROR_CODE.HTTP_ONLY))
			{
				thhpsFlg = true;
			}
			string reqdestname = adrBookListCtrl.getSelectedItem(AddressBookListControl.COLUMN.NAME);
			List<OneTouchKeyInfo> oneTouchKeyList = await machineControl.getPrimaxOneTouchKeyInfo(thhpsFlg, mfpIpAddr);
			result = await adrBookListCtrl.GetAddressBookInfoToPrimax(mfpIpAddr, reqdestname, oneTouchKeyList);
		}
		else
		{
			string selectedItem = adrBookListCtrl.getSelectedItem(AddressBookListControl.COLUMN.REGISTRATION_NO);
			result = await adrBookListCtrl.GetAddressBookInfo(mfpIpAddr, selectedItem, comResult);
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		return result;
	}

	private bool checkFolderPath(Dictionary<AddressBookListControl.ADDRESSBOOK_LIST_ITEM, string> addressBookInfo)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		updateTRprogressBar(Resources.TROUBLE_SHOOTING_CHECK_PATH);
		((Control)this).Refresh();
		bool flag = addressBookInfo.ContainsKey(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PATH_NAME);
		string text = string.Empty;
		if (flag)
		{
			text = addressBookInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PATH_NAME];
		}
		char[] invalidPathChars = Path.GetInvalidPathChars();
		foreach (char c in invalidPathChars)
		{
			if (Enumerable.Contains(text, c))
			{
				LOG.InfoFormat("パス禁止文字が含まれている:0x{0:X2}", (object)(int)c);
				flag = false;
				break;
			}
		}
		if (flag)
		{
			try
			{
				Path.GetPathRoot(text);
				string fileName = Path.GetFileName(text);
				Path.GetFullPath(text);
				Path.GetDirectoryName(text);
				invalidPathChars = Path.GetInvalidFileNameChars();
				foreach (char c2 in invalidPathChars)
				{
					if (Enumerable.Contains(fileName, c2))
					{
						LOG.InfoFormat("ファイル名禁止文字が含まれている:0x{0:X2}", (object)(int)c2);
						flag = false;
						break;
					}
				}
			}
			catch (Exception ex)
			{
				LOG.InfoFormat("{0}：{1}", (object)MethodBase.GetCurrentMethod().Name, (object)ex.ToString());
				flag = false;
			}
		}
		LOG.DebugFormat("{0}：end result:[{1}]", (object)MethodBase.GetCurrentMethod().Name, (object)flag);
		return flag;
	}

	private void parseFolderPath(Dictionary<AddressBookListControl.ADDRESSBOOK_LIST_ITEM, string> addressBookInfo, ref string IPorHostName, ref string folderName)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		bool num = addressBookInfo.ContainsKey(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PATH_NAME);
		string text = string.Empty;
		if (num)
		{
			text = addressBookInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PATH_NAME];
		}
		IPorHostName = string.Empty;
		folderName = string.Empty;
		string[] array = text.Split(new char[1] { '\\' });
		foreach (string text2 in array)
		{
			if (!string.IsNullOrEmpty(text2))
			{
				if (!string.IsNullOrEmpty(IPorHostName))
				{
					folderName = text2;
					break;
				}
				IPorHostName = text2;
			}
		}
		LOG.DebugFormat("{0}：end [{1}]\\[{2}]", (object)MethodBase.GetCurrentMethod().Name, (object)IPorHostName, (object)folderName);
	}

	private string createNewHostStr(string hostStr)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		string empty = string.Empty;
		if (string.IsNullOrEmpty(hostStr))
		{
			return fMain.getIPAddress();
		}
		return Regex.IsMatch(hostStr, "^\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}$") ? fMain.getIPAddress() : Dns.GetHostName();
	}

	private FolderResult checkFolderSetting(string folderName)
	{
		LOG.DebugFormat("{0}：start. Shared folder=[{1}]", (object)MethodBase.GetCurrentMethod().Name, (object)folderName);
		updateTRprogressBar(Resources.TROUBLE_SHOOTING_CHECK_FOLDER);
		((Control)this).Refresh();
		if (string.IsNullOrEmpty(folderName))
		{
			LOG.DebugFormat("{0}：end. No shared folder setting on address book.", (object)MethodBase.GetCurrentMethod().Name);
			return FolderResult.EMPTY;
		}
		string sharedFolderPath = fs.getSharedFolderPath(folderName, lonly: true);
		if (!string.IsNullOrEmpty(sharedFolderPath))
		{
			if (Directory.Exists(sharedFolderPath))
			{
				bool flag = checkFolderAccess(folderName);
				LOG.DebugFormat("{0}：end. Shared folder found on PC. Check access environment. access:{1}", (object)MethodBase.GetCurrentMethod().Name, (object)flag);
				if (!flag)
				{
					return FolderResult.EXIST_NO_ACCESS;
				}
				return FolderResult.EXIST_OK;
			}
			LOG.DebugFormat("{0}：end. Folder for share not exist.", (object)MethodBase.GetCurrentMethod().Name);
			return FolderResult.FOLDER_NOT_EXIST;
		}
		updateTRprogressBar(string.Empty);
		LOG.DebugFormat("{0}：No shared folder on PC.", (object)MethodBase.GetCurrentMethod().Name);
		string text = Path.Combine(CreateFolderUtil.getDesktopDirectory(), folderName);
		bool flag2 = Directory.Exists(text);
		if (flag2)
		{
			LOG.DebugFormat("{0}：end. Exist same named folder at desktop.", (object)MethodBase.GetCurrentMethod().Name);
			return FolderResult.CHANGE_NAME_OR_PATH;
		}
		LOG.DebugFormat("{0}：end. New folder path=[{1}] Exist(Desktop)=[{2}]", (object)MethodBase.GetCurrentMethod().Name, (object)text, (object)flag2);
		return FolderResult.NO_ENTRY_EXIST;
	}

	private bool checkAccount(Dictionary<AddressBookListControl.ADDRESSBOOK_LIST_ITEM, string> addressBookInfo)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		updateTRprogressBar(Resources.TROUBLE_SHOOTING_CHECK_ACCOUNT);
		((Control)this).Refresh();
		bool flag = false;
		string loginUserName = getLoginUserName();
		if (addressBookInfo.ContainsKey(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_AUTH_USER_NAME) && !string.IsNullOrEmpty(addressBookInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_AUTH_USER_NAME]))
		{
			string text = addressBookInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_AUTH_USER_NAME];
			flag = string.Equals(text, loginUserName, StringComparison.CurrentCultureIgnoreCase);
			LOG.DebugFormat("{0}：LoginUserName:{1} authUserName:{2}", (object)MethodBase.GetCurrentMethod().Name, (object)loginUserName, (object)text);
		}
		LOG.DebugFormat("{0}：end userExist:{1}", (object)MethodBase.GetCurrentMethod().Name, (object)flag);
		return flag;
	}

	private bool checkFolderAccess(string folderName)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		updateTRprogressBar(Resources.TROUBLE_SHOOTING_CHECK_FOLDER_ACCESS);
		((Control)this).Refresh();
		string loginUserName = getLoginUserName();
		List<ShareFolderManager.ShareUser> folderCurrentUsers = ShareFolderManager.GetFolderCurrentUsers(folderName);
		bool flag = false;
		foreach (ShareFolderManager.ShareUser item in folderCurrentUsers)
		{
			flag = string.Equals(item.AccountName, loginUserName, StringComparison.CurrentCultureIgnoreCase);
			if (flag)
			{
				break;
			}
		}
		if (flag)
		{
			ShareFolderManager.ShareMode accessRights = ShareFolderManager.GetAccessRights(folderName, loginUserName);
			AceType accessType = ShareFolderManager.GetAccessType();
			LOG.DebugFormat("{0}：Share mode:[{1}]", (object)MethodBase.GetCurrentMethod().Name, (object)accessRights);
			flag = accessRights > ShareFolderManager.ShareMode.SHARE_READ;
			if (accessType == AceType.AccessDenied)
			{
				LOG.DebugFormat("{0}：Set access right to false since access type is devied.", (object)MethodBase.GetCurrentMethod().Name);
				flag = false;
			}
		}
		LOG.DebugFormat("{0}：end. access right:[{1}]", (object)MethodBase.GetCurrentMethod().Name, (object)flag);
		return flag;
	}

	private bool checkFireWallSetting()
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		updateTRprogressBar(Resources.TROUBLE_SHOOTING_CHECK_FIREWALL);
		((Control)this).Refresh();
		bool num = new FormSetup(machineLang).checkEnableSMB(showDlgFlg: false);
		if (!num)
		{
			troubleShootAddressBookInfoUpdate.fireWall = true;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return num;
	}

	private void showTroubleShootResult(RichTextBox rTextBox, Dictionary<AddressBookListControl.ADDRESSBOOK_LIST_ITEM, string> addressBookInfo)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		StateMachineTroubleShoot.NextState = StateMachineTroubleShoot.StateType.TR_RESULT;
		panelChangeTroubleShoot(StateMachineTroubleShoot.NowState, StateMachineTroubleShoot.NextState);
		Application.DoEvents();
		Thread.Sleep(500);
		LOG.DebugFormat("{0} Change State:{1} -> {2}", (object)MethodBase.GetCurrentMethod().Name, (object)StateMachineTroubleShoot.NowState, (object)StateMachineTroubleShoot.NextState);
		StateMachineTroubleShoot.NowState = StateMachineTroubleShoot.NextState;
		showAddressBookInfo(rTextBox, addressBookInfo);
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	private void showAddressBookInfo(RichTextBox rTextBox, Dictionary<AddressBookListControl.ADDRESSBOOK_LIST_ITEM, string> addressBookInfo)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		if (rTextBox != richTextBoxTRP5)
		{
			isAlertFolderName = false;
			isAlertFolderPath = false;
			isAlertAccountName = false;
			isAlertPassword = false;
			isAlertFireWalllSetting = false;
		}
		addBlankLine(rTextBox);
		new StringBuilder();
		if (PrimaxModel)
		{
			addLabelAndValue(WRITE_MODE.NORMAL, rTextBox, Resources.PRIMAX_ONE_TOUCH_KEY_BIG, getAddressBookInfoStr(addressBookInfo, AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX));
		}
		else
		{
			addLabelAndValue(WRITE_MODE.NORMAL, rTextBox, Resources.ADDRESSBOOK_REGISTRATION_NO_NAME, getAddressBookInfoStr(addressBookInfo, AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX));
		}
		addLabelAndValue(WRITE_MODE.NORMAL, rTextBox, Resources.ADDRESSBOOK_NAME_NAME, getAddressBookInfoStr(addressBookInfo, AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_NAME));
		string addressBookInfoStr = getAddressBookInfoStr(addressBookInfo, AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PATH_NAME);
		if (isAlertFolderName)
		{
			addLabelAndValue(WRITE_MODE.ALERT, rTextBox, Resources.FORM_MAIN_FOLDER_NAME, Path.GetFileName(addressBookInfoStr));
		}
		else
		{
			addLabelAndValue(WRITE_MODE.NORMAL, rTextBox, Resources.FORM_MAIN_FOLDER_NAME, Path.GetFileName(addressBookInfoStr));
		}
		if (isAlertAccountName)
		{
			addLabelAndValue(WRITE_MODE.ALERT, rTextBox, Resources.ADDRESSBOOK_LOGIN_USER_NAME, getAddressBookInfoStr(addressBookInfo, AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_AUTH_USER_NAME));
		}
		else
		{
			addLabelAndValue(WRITE_MODE.NORMAL, rTextBox, Resources.ADDRESSBOOK_LOGIN_USER_NAME, getAddressBookInfoStr(addressBookInfo, AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_AUTH_USER_NAME));
		}
		string value = string.Empty;
		if (addressBookInfo.ContainsKey(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PASSWORD))
		{
			value = getAddressBookInfoStr(addressBookInfo, AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PASSWORD);
			if (!string.IsNullOrEmpty(value))
			{
				value = "*****";
			}
		}
		if (isAlertPassword)
		{
			addLabelAndValue(WRITE_MODE.ALERT, rTextBox, Resources.ADDRESSBOOK_LOGIN_PASSWORD_NAME, value);
		}
		else
		{
			addLabelAndValue(WRITE_MODE.NORMAL, rTextBox, Resources.ADDRESSBOOK_LOGIN_PASSWORD_NAME, value);
		}
		if (isAlertFolderPath)
		{
			addLabelAndValue(WRITE_MODE.ALERT, rTextBox, Resources.FORM_MAIN_PATH_NAME, addressBookInfoStr);
		}
		else
		{
			addLabelAndValue(WRITE_MODE.NORMAL, rTextBox, Resources.FORM_MAIN_PATH_NAME, addressBookInfoStr);
		}
		string value2 = (string.IsNullOrEmpty(displayedContents) ? mfpIpAddr : displayedContents);
		addLabelAndValue(WRITE_MODE.NORMAL, rTextBox, Resources.FORM_MAIN_MACHINE, value2);
		if (!PrimaxModel)
		{
			addLabelAndValue(WRITE_MODE.NORMAL, rTextBox, Resources.TITLE_01, getAddressBookInfoStr(addressBookInfo, AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_1));
			addLabelAndValue(WRITE_MODE.NORMAL, rTextBox, Resources.TITLE_02, getAddressBookInfoStr(addressBookInfo, AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_2));
			addLabelAndValue(WRITE_MODE.NORMAL, rTextBox, Resources.TITLE_03, getAddressBookInfoStr(addressBookInfo, AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_3));
			addLabelAndValue(WRITE_MODE.NORMAL, rTextBox, Resources.TITLE_ADD_TO_FREQ, getAddressBookInfoStr(addressBookInfo, AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_FREQ));
		}
		bool num = rTextBox == richTextBoxTRP5;
		string label = (num ? Resources.TROUBLE_SHOOTING_RESULT_MSG_SECURITY : Resources.SET_REPORT_CREATE_FOLDER_ADDRESS_MSG_11_13);
		addLabelAndValue(WRITE_MODE.LABEL_ONLY, rTextBox, label, null);
		string empty = string.Empty;
		string value3 = "-";
		empty = ((!num) ? (troubleShootAddressBookInfoUpdate.fireWall ? Resources.DO_DO : "-") : (troubleShootAddressBookInfoUpdate.fireWall ? Resources.DO_NOT : Resources.DO_DO));
		if (FormSetup.BlankPasswordAllowed)
		{
			value3 = Resources.DO_DO;
		}
		if (isAlertFireWalllSetting)
		{
			addLabelAndValue(WRITE_MODE.ALERT_NON_SEPARATE, rTextBox, Resources.STATE_RELEASING_CONNECTION_RESTRICTION_SHARE_FOLDER, empty);
			addLabelAndValue(WRITE_MODE.ALERT_NON_SEPARATE, rTextBox, Resources.SET_REPORT_CREATE_FOLDER_ADDRESS_MSG_13_13, value3);
		}
		else
		{
			addLabelAndValue(WRITE_MODE.NON_SEPARATE, rTextBox, Resources.STATE_RELEASING_CONNECTION_RESTRICTION_SHARE_FOLDER, empty);
			addLabelAndValue(WRITE_MODE.NON_SEPARATE, rTextBox, Resources.SET_REPORT_CREATE_FOLDER_ADDRESS_MSG_13_13, value3);
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	private void addLabelAndValue(WRITE_MODE mode, RichTextBox textBox, object label, object value)
	{
		//IL_0027: Unknown result type (might be due to invalid IL or missing references)
		//IL_002d: Expected O, but got Unknown
		StringBuilder stringBuilder = new StringBuilder();
		Color selectionColor = textBox.SelectionColor;
		Font selectionFont = textBox.SelectionFont;
		Font selectionFont2 = new Font(selectionFont.FontFamily, selectionFont.Size + 1f, (FontStyle)1);
		switch (mode)
		{
		case WRITE_MODE.NON_SEPARATE:
			stringBuilder.AppendFormat("\t  {0} {1}\n", label, value);
			((TextBoxBase)textBox).SelectedText = stringBuilder.ToString();
			break;
		case WRITE_MODE.ALERT:
			stringBuilder.AppendFormat("\t{0}{1}\t{2}\n", label, Resources.SETTING_SEPARATE, value);
			textBox.SelectionFont = selectionFont2;
			textBox.SelectionColor = Color.Red;
			((TextBoxBase)textBox).SelectedText = stringBuilder.ToString();
			stringBuilder.Clear();
			textBox.SelectionFont = selectionFont;
			textBox.SelectionColor = selectionColor;
			break;
		case WRITE_MODE.ALERT_NON_SEPARATE:
			stringBuilder.AppendFormat("\t  {0} {1}\n", label, value);
			textBox.SelectionFont = selectionFont2;
			textBox.SelectionColor = Color.Red;
			((TextBoxBase)textBox).SelectedText = stringBuilder.ToString();
			stringBuilder.Clear();
			textBox.SelectionFont = selectionFont;
			textBox.SelectionColor = selectionColor;
			break;
		case WRITE_MODE.LABEL_ONLY:
			stringBuilder.AppendFormat("\t{0}\n", label);
			((TextBoxBase)textBox).SelectedText = stringBuilder.ToString();
			break;
		default:
			stringBuilder.AppendFormat("\t{0}{1}\t{2}\n", label, Resources.SETTING_SEPARATE, value);
			((TextBoxBase)textBox).SelectedText = stringBuilder.ToString();
			break;
		}
		addBlankLine(textBox);
	}

	private void addBlankLine(RichTextBox textBox)
	{
		//IL_0019: Unknown result type (might be due to invalid IL or missing references)
		//IL_001f: Expected O, but got Unknown
		StringBuilder stringBuilder = new StringBuilder();
		Font selectionFont = textBox.SelectionFont;
		Font selectionFont2 = new Font(selectionFont.FontFamily, 1f, (FontStyle)0);
		textBox.SelectionFont = selectionFont2;
		stringBuilder.AppendFormat("\n");
		((TextBoxBase)textBox).SelectedText = stringBuilder.ToString();
		textBox.SelectionFont = selectionFont;
	}

	private string getAddressBookInfoStr(Dictionary<AddressBookListControl.ADDRESSBOOK_LIST_ITEM, string> addressBookInfo, AddressBookListControl.ADDRESSBOOK_LIST_ITEM item)
	{
		LOG.DebugFormat("{0}", (object)MethodBase.GetCurrentMethod().Name);
		string text = string.Empty;
		try
		{
			if (addressBookInfo.ContainsKey(item))
			{
				text = addressBookInfo[item];
			}
			if (!string.IsNullOrEmpty(text))
			{
				int result;
				switch (item)
				{
				case AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_1:
					int.TryParse(text, out result);
					fSettingHeadline.Index1Headline = result - 1;
					text = fSettingHeadline.Str1Headline;
					break;
				case AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_2:
					int.TryParse(text, out result);
					fSettingHeadline.Index2Headline = result - 1;
					text = fSettingHeadline.Str2Headline;
					break;
				case AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_3:
					int.TryParse(text, out result);
					fSettingHeadline.Index3Headline = result - 1;
					text = fSettingHeadline.Str3Headline;
					break;
				case AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_FREQ:
					int.TryParse(text, out result);
					fSettingHeadline.IndexRegularHeading = result;
					text = fSettingHeadline.StrRegularHeading;
					break;
				}
			}
			string text2 = ((item == AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PASSWORD) ? "*****" : text);
			LOG.DebugFormat("{0} item[{1}] str[{2}]", (object)MethodBase.GetCurrentMethod().Name, (object)item.ToString(), (object)text2);
		}
		catch (Exception ex)
		{
			LOG.ErrorFormat("{0}：{1}", (object)MethodBase.GetCurrentMethod().Name, (object)ex);
		}
		finally
		{
			LOG.DebugFormat("{0} end.", (object)MethodBase.GetCurrentMethod().Name);
		}
		return text;
	}

	private async Task<ErrorCode> updateMfpAddressbook()
	{
		LOG.Debug((object)"updateMfpAddressbook：start");
		try
		{
			MachineControl mc = adrBookListCtrl.getMachineControlInstance();
			COMMUNICATION_ERROR_CODE cOMMUNICATION_ERROR_CODE = mc.communicateConfirm(mfpIpAddr);
			if (cOMMUNICATION_ERROR_CODE == COMMUNICATION_ERROR_CODE.ERROR)
			{
				StringBuilder stringBuilder = new StringBuilder();
				stringBuilder.AppendFormat("{0}\n\n", Resources.CANT_CONNECT_MACHINE_ERROR_TEXT_1_5);
				stringBuilder.AppendFormat("  {0}\n", Resources.CANT_CONNECT_MACHINE_ERROR_TEXT_6_5);
				stringBuilder.AppendFormat("  {0}\n", Resources.CANT_CONNECT_MACHINE_ERROR_TEXT_2_5);
				stringBuilder.AppendFormat("  {0}\n", Resources.CANT_CONNECT_MACHINE_ERROR_TEXT_3_5);
				stringBuilder.AppendFormat("  {0}\n\n", Resources.CANT_CONNECT_MACHINE_ERROR_TEXT_4_5);
				stringBuilder.AppendFormat("{0}", Resources.CANT_CONNECT_MACHINE_ERROR_TEXT_5_5);
				((Control)richTextBoxTRP10).Text = stringBuilder.ToString();
				return ErrorCode.ERROR;
			}
			Dictionary<AddressBookListControl.ADDRESSBOOK_LIST_ITEM, string> addressBookInfo = troubleShootAddressBookInfoUpdate.addressBookInfo;
			SettingItemsSetupAddress setting = new SettingItemsSetupAddress
			{
				host = mfpIpAddr,
				adminName = "admin",
				passwd = "",
				firstFlg = true,
				httpsFlg = (cOMMUNICATION_ERROR_CODE != COMMUNICATION_ERROR_CODE.HTTP_ONLY)
			};
			if (addressBookInfo.ContainsKey(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_NAME))
			{
				setting.addressName = addressBookInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_NAME];
			}
			if (addressBookInfo.ContainsKey(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX_NAME))
			{
				setting.readName = addressBookInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX_NAME];
			}
			if (addressBookInfo.ContainsKey(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_DISPLAY_NAME))
			{
				setting.displayName = addressBookInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_DISPLAY_NAME];
			}
			if (addressBookInfo.ContainsKey(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_AUTH_USER_NAME))
			{
				setting.authUserName = addressBookInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_AUTH_USER_NAME];
			}
			if (addressBookInfo.ContainsKey(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PATH_NAME))
			{
				setting.folderPath = addressBookInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PATH_NAME];
			}
			if (addressBookInfo.ContainsKey(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PASSWORD))
			{
				setting.authPassword = addressBookInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PASSWORD];
			}
			int result = 0;
			int.TryParse(addressBookInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_1], out result);
			setting.headlineIndex1 = result;
			int.TryParse(addressBookInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_2], out result);
			setting.headlineIndex2 = result;
			int.TryParse(addressBookInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_3], out result);
			setting.headlineIndex3 = result;
			int.TryParse(addressBookInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_TAG_INFO_FREQ], out result);
			setting.regularHeadingIndex = result;
			int.TryParse(addressBookInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_INDEX], out result);
			setting.registrationNo = result;
			string msg = string.Empty;
			if (PrimaxModel)
			{
				msg = await updateMfpAddressbookToPrimax(mc, setting, cOMMUNICATION_ERROR_CODE != COMMUNICATION_ERROR_CODE.HTTP_ONLY);
				if (string.IsNullOrEmpty(msg))
				{
					return ErrorCode.NOERROR;
				}
			}
			else
			{
				if (!smbv1)
				{
					await SMBTRPcheck2(mfpIpAddr, GetHostNameFromIP(mfpIpAddr), machineLang);
				}
				HttpResponseMessage httpResponseMessage = await mc.setAddressbookBase(setting);
				if (httpResponseMessage.StatusCode != HttpStatusCode.OK)
				{
					LOG.Debug((object)"updateMfpAddressbook：end（エラー）");
					return ErrorCode.ERROR;
				}
				WimError winError = mc.checkWimErrorCode(httpResponseMessage);
				LOG.DebugFormat("WIM Info. id:[{0}] msg:[{1}] [{2}]", (object)winError.id, (object)winError.message, (object)winError.errPoint);
				if (winError.kind != 0)
				{
					httpResponseMessage = await mc.setAddressbookFolder(setting);
					if (httpResponseMessage.StatusCode != HttpStatusCode.OK)
					{
						LOG.Debug((object)"updateMfpAddressbook：end（エラー）");
						return ErrorCode.ERROR;
					}
					winError = mc.checkWimErrorCode(httpResponseMessage);
					LOG.DebugFormat("WIM Info. id:[{0}] msg:[{1}] [{2}]", (object)winError.id, (object)winError.message, (object)winError.errPoint);
					if (winError.kind != 0)
					{
						await mc.setAddressbookGo();
						LOG.Debug((object)"updateMfpAddressbook：end");
						return ErrorCode.NOERROR;
					}
				}
				if (string.Equals(winError.id, "INDEX_E"))
				{
					msg = $"{Resources.ASK_IF_RESUNDANT_REGISTRATION_NUMBER_01}\n\n No. {setting.registrationNo:D5}";
					LOG.Debug((object)"checkWimError：end（登録番号重複）");
				}
				else if (string.Equals(winError.id, "NGPARAM_WIZARD_E"))
				{
					msg = $"{winError.message}\n\n{winError.errPoint}";
					LOG.Debug((object)"checkWimError：end（入力エラー）");
				}
			}
			if (!string.IsNullOrEmpty(msg))
			{
				MessageBox.Show(msg, Resources.SET_REGISTRATION_NUMBER_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
			}
			return ErrorCode.ERROR;
		}
		catch (Exception ex)
		{
			string text = ex.Message;
			LOG.ErrorFormat("{0}：WIMログインエラー  \n" + ex.ToString() + "\n*******************************", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			LOG.ErrorFormat("{0}：WIMログインエラーMessage  \n" + text + "\n*******************************", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
			if (!string.IsNullOrEmpty(text))
			{
				if (text.IndexOf(Resources.ERR_MSG_WIM_ADDRESSBOOK_UPDATE) >= 0)
				{
					text = $"{Resources.ERR_MSG_MACHINE_ADDRESSBOOK_UPDATE}\n{Resources.ERR_MSG_DIAGNOSE_AGAIN}";
					MessageBox.Show(text, Resources.ERR_TITLE_REGIST_ADDR, (MessageBoxButtons)0, (MessageBoxIcon)16);
					return ErrorCode.ADDRESSBOOK_UPDATE_ERROR;
				}
				if (text.IndexOf(Resources.WIM_ERROR_DETECT) >= 0)
				{
					text = text.Substring(Resources.WIM_ERROR_DETECT.Length);
					MessageBox.Show(text, Resources.ERR_TITLE_REGIST_ADDR, (MessageBoxButtons)0, (MessageBoxIcon)16);
				}
				((Control)labelTRP10finish).Text = text;
			}
			else
			{
				((Control)labelTRP10finish).Text = Resources.ERR_MSG_FATAL_RETRY;
			}
			return ErrorCode.ERROR;
		}
	}

	private async Task<string> updateMfpAddressbookToPrimax(MachineControl mc, SettingItemsSetupAddress setting, bool httpsFlg)
	{
		string addressName = setting.addressName;
		string primaxTrpOldAddressName = PrimaxTrpOldAddressName;
		string value = setting.registrationNo.ToString();
		if (!addressName.Equals(primaxTrpOldAddressName) && "0".Equals(value) && (int)MessageBox.Show($"{Resources.PRIMAX_NEW_UPDATE_CAUTION_01}\n{Resources.PRIMAX_NEW_UPDATE_CAUTION_02}\n{Resources.PRIMAX_NEW_UPDATE_CAUTION_03}\n", Resources.ERR_MSG_TITLE_KEY_ALL_USING, (MessageBoxButtons)4, (MessageBoxIcon)32) == 7)
		{
			((Control)richTextBoxTRP10).Text = Resources.TEXT_STOP_EXECUTE;
			return Resources.TEXT_STOP_EXECUTE;
		}
		setting.adminName = PrimaxAdminPasswd;
		string folder_password_change = "1";
		setting.firstFlg = false;
		setting.httpsFlg = httpsFlg;
		_ = string.Empty;
		string old_entry_name = ((!PrimaxUnicode) ? PrimaxKeyCode : primaxTrpOldAddressName);
		MachineControl.PRIMAX_MACHINE_CONTROL_RESULT pRIMAX_MACHINE_CONTROL_RESULT;
		while (true)
		{
			pRIMAX_MACHINE_CONTROL_RESULT = await mc.executeSetupAddressToPrimax(setting, old_entry_name, folder_password_change);
			if (MachineControl.PRIMAX_MACHINE_CONTROL_RESULT.PW_RESETTING != pRIMAX_MACHINE_CONTROL_RESULT)
			{
				break;
			}
			FormAdminAuthConfirm formAdminAuthConfirm = new FormAdminAuthConfirm();
			formAdminAuthConfirm.InitializeToPrimax();
			formAdminAuthConfirm.setMsg(firstFlg: true);
			((Form)formAdminAuthConfirm).StartPosition = (FormStartPosition)4;
			((Form)formAdminAuthConfirm).ShowDialog();
			if ((int)((Form)formAdminAuthConfirm).DialogResult != 1)
			{
				((Control)richTextBoxTRP10).Text = Resources.TEXT_STOP_EXECUTE;
				return Resources.TEXT_STOP_EXECUTE;
			}
			setting.adminName = formAdminAuthConfirm.getAuthPass();
			PrimaxAdminPasswd = formAdminAuthConfirm.getAuthPass();
		}
		if (pRIMAX_MACHINE_CONTROL_RESULT == MachineControl.PRIMAX_MACHINE_CONTROL_RESULT.SUCCESS)
		{
			PrimaxAdminPasswd = setting.adminName;
			return "";
		}
		((Control)richTextBoxTRP10).Text = Resources.EXE_RESULT_MSG_ERROR_REGIST_ADDRESS;
		return Resources.EXE_RESULT_MSG_ERROR_REGIST_ADDRESS;
	}

	private void btnTRP3Back_Click(object sender, EventArgs e)
	{
		LOG.DebugFormat("{0}", (object)MethodBase.GetCurrentMethod().Name);
		((Control)labelTRP3MFP_Selected).Text = string.Empty;
		adrBookListCtrl.resetSeachEnvironments();
	}

	private async void btnTRP9Execute_Click(object sender, EventArgs e)
	{
		LOG.DebugFormat("{0} start.", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		((Control)linkLabelTRP10HelpRegist).Visible = false;
		((Control)linkLabelTRP10HelpSend).Visible = false;
		((Control)btnTRP10Top).Visible = false;
		((Control)btnTRP10End).Visible = false;
		((Control)label_TRP10Head).Text = Resources.FORM_WIZARD_EXECUTING_TITLE;
		((Control)label_TRP10_comment).Text = Resources.LABEL_P6_001;
		((Control)labelTRP10finish).Text = string.Empty;
		labelTRP10finish.Links.Clear();
		((Control)label_TRP10Report).Text = string.Empty;
		((Control)richTextBoxTRP10).Text = string.Empty;
		ErrorCode result = ErrorCode.ERROR;
		try
		{
			((Control)this).Cursor = Cursors.WaitCursor;
			result = await updateMfpAddressbook();
			switch (result)
			{
			case ErrorCode.ADDRESSBOOK_UPDATE_ERROR:
				StateMachineTroubleShoot.NextState = StateMachineTroubleShoot.StateType.TR_USER;
				adrBookListCtrl.resetSeachEnvironments();
				panelChangeTroubleShoot(StateMachineTroubleShoot.NowState, StateMachineTroubleShoot.NextState);
				Application.DoEvents();
				Thread.Sleep(500);
				LOG.DebugFormat("{0} Change State:{1} -> {2}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)StateMachineTroubleShoot.NowState, (object)StateMachineTroubleShoot.NextState);
				StateMachineTroubleShoot.NowState = StateMachineTroubleShoot.NextState;
				LOG.DebugFormat("{0} end. result:{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)result);
				return;
			case ErrorCode.NOERROR:
			{
				string text = string.Empty;
				string text2 = string.Empty;
				FOLDER_TYPE folder_type = FOLDER_TYPE.CREATE_FOLDRE;
				if (troubleShootAddressBookInfoUpdate.folder)
				{
					if (radioButtonTRP6createNewFolder.Checked)
					{
						folder_type = FOLDER_TYPE.CREATE_FOLDRE;
						text = ((Control)textBoxTRP6FolderName).Text;
						text2 = ((Control)textBoxTRP6FolderPath).Text;
					}
					else if (radioButtonTRP6selectExistFolder.Checked)
					{
						folder_type = FOLDER_TYPE.SHARED_FOLDER;
						text = ((Control)cmbTRP6Folder).Text;
						text2 = string.Empty;
					}
					else
					{
						folder_type = FOLDER_TYPE.NON_SHARED_FOLDER;
						text = ((Control)textBoxTRP6SharedName).Text;
						text2 = ((Control)textBoxTRP6NonSharedFolderPath).Text;
					}
				}
				else if (troubleShootAddressBookInfoUpdate.access)
				{
					text = Path.GetFileName(troubleShootAddressBookInfoUpdate.addressBookInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PATH_NAME]);
					text2 = string.Empty;
					folder_type = FOLDER_TYPE.SHARED_FOLDER;
				}
				if (!string.IsNullOrEmpty(text))
				{
					if (!executeCreateFolder(folder_type, text, text2, ((Control)cmbTRP7PcUser).Text, ((Control)textBoxTRP7Pass).Text, labelTRP10finish))
					{
						result = ErrorCode.ERROR;
						LOG.DebugFormat("{0} Create folder failed.", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)result);
					}
					else
					{
						fs.setSharedFolderListTable();
						string text3 = (string.IsNullOrEmpty(text2) ? "Change folder access rights" : "Create folder");
						LOG.DebugFormat("{0} {1} success.", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)text3);
					}
				}
				if (troubleShootAddressBookInfoUpdate.fireWall)
				{
					new FormSetup(machineLang).enableSMB();
					LOG.DebugFormat("{0} Call enableSMB.", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
				}
				break;
			}
			}
			if (result == ErrorCode.NOERROR)
			{
				string fOLDER_SEND_PROCEDURE_LINK_MESSAGE = Resources.FOLDER_SEND_PROCEDURE_LINK_MESSAGE;
				setTroubleShootFinishPage(Resources.EXE_RESULT_MSG_SUCCESS, fOLDER_SEND_PROCEDURE_LINK_MESSAGE, string.Empty, string.Empty);
				showAddressBookInfo(richTextBoxTRP10, troubleShootAddressBookInfoUpdate.addressBookInfo);
			}
			else
			{
				string helpMsg = $"{Resources.DIRECT_REGIST_PROCEDURE_LINK_MESSAGE_01}\n{Resources.DIRECT_REGIST_PROCEDURE_LINK_MESSAGE_02}";
				setTroubleShootFinishPage(Resources.MSG_FAILED_CREATION_SHARE_FOLDER + "\n", string.Empty, helpMsg, ((Control)labelTRP10finish).Text);
			}
		}
		catch (Exception ex)
		{
			LOG.ErrorFormat("{0}：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)ex);
		}
		finally
		{
			((Control)this).Cursor = Cursors.Default;
			LOG.DebugFormat("{0} end. result:{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)result);
		}
	}

	private void btnTRP5Next_Click(object sender, EventArgs e)
	{
		//IL_002f: Unknown result type (might be due to invalid IL or missing references)
		//IL_004c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0070: Unknown result type (might be due to invalid IL or missing references)
		if (trsmbcode != 0)
		{
			if (trsmbcode == TRPSMBCHECKCODE.V1ON)
			{
				smbv1 = true;
			}
			else
			{
				if (trsmbcode != TRPSMBCHECKCODE.FWUPDATE)
				{
					if (trsmbcode == TRPSMBCHECKCODE.V1OFF)
					{
						MessageBox.Show(Resources.MSG_SMB_NOT_SUPPORTED, Resources.CONFIRM, (MessageBoxButtons)0, (MessageBoxIcon)0);
						smbv1 = false;
					}
					else if (trsmbcode == TRPSMBCHECKCODE.FSOFF)
					{
						MessageBox.Show(Resources.MSG_PC_FILE_SHARE_FALSE, Resources.CONFIRM, (MessageBoxButtons)0, (MessageBoxIcon)0);
					}
					StateMachineTroubleShoot.NowState = StateMachineTroubleShoot.StateType.TR_ANALYZE;
					return;
				}
				MessageBox.Show(Resources.MSG_FW_UPDATE, Resources.CONFIRM, (MessageBoxButtons)0, (MessageBoxIcon)0);
			}
		}
		if (!troubleShootAddressBookInfoUpdate.folder)
		{
			StateMachineTroubleShoot.StateType stateType = StateMachineTroubleShoot.StateType.TR_CREATE_FOLDER_SETUP;
			LOG.DebugFormat("{0} Change State:{1} -> {2}", (object)MethodBase.GetCurrentMethod().Name, (object)StateMachineTroubleShoot.NowState, (object)stateType);
			StateMachineTroubleShoot.NowState = stateType;
		}
	}

	private void updateTRprogressBar(string message, int upCount = 1)
	{
		((Control)label_TRP4_progress).Text = message;
		if (progressBarTRP4.Value < TR_PROGRESS_MAX)
		{
			ProgressBar obj = progressBarTRP4;
			obj.Value += upCount;
			LOG.DebugFormat("updateTRprogressBar update. value:{0}", (object)progressBarTRP4.Value);
		}
		else
		{
			LOG.DebugFormat("updateTRprogressBar skip.", new object[0]);
		}
	}

	private void buttonTRP6SelectFolder_Click(object sender, EventArgs e)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		setSelectFolder(textBoxTRP6FolderPath);
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	private void buttonTRP6SelectNonSharedFolder_Click(object sender, EventArgs e)
	{
		//IL_00bc: Unknown result type (might be due to invalid IL or missing references)
		//IL_00c6: Expected O, but got Unknown
		//IL_005d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0067: Expected O, but got Unknown
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		setSelectFolder(textBoxTRP6NonSharedFolderPath);
		if (((Control)textBoxTRP6NonSharedFolderPath).Text == string.Empty)
		{
			((Control)textBoxTRP6SharedName).Text = Resources.TXT_P2_INITIAL_001;
			((Control)textBoxTRP6SharedName).Font = new Font("Resources.FONT", 9f, (FontStyle)2);
			((Control)textBoxTRP6SharedName).ForeColor = Color.FromArgb(195, 195, 195);
		}
		else
		{
			string fileName = Path.GetFileName(getPathFromWindowsName(((Control)textBoxTRP6NonSharedFolderPath).Text));
			((Control)textBoxTRP6SharedName).Text = fileName;
			((Control)textBoxTRP6SharedName).Font = new Font("Resources.FONT", 9f, (FontStyle)0);
			((Control)textBoxTRP6SharedName).ForeColor = Color.Black;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
	}

	private void radioButtonTRP6createNewFolder_CheckedChanged(object sender, EventArgs e)
	{
		if (radioButtonTRP6createNewFolder.Checked)
		{
			((Control)label_TRP6_FolderName).Enabled = true;
			((Control)textBoxTRP6FolderName).Enabled = true;
			((Control)label_TRP6_FolderPath).Enabled = true;
			((Control)textBoxTRP6FolderPath).Enabled = true;
			((Control)buttonTRP6SelectFolder).Enabled = true;
			((Control)label_TRP6_Folder).Enabled = false;
			((Control)cmbTRP6Folder).Enabled = false;
			((Control)label_TRP6_SelectFolder).Enabled = false;
			((Control)label_TRP6_NonSharedFolderPath).Enabled = false;
			((Control)textBoxTRP6NonSharedFolderPath).Enabled = false;
			((Control)buttonTRP6SelectNonSharedFolder).Enabled = false;
			((Control)label_TRP6_SelectNonSharedFolder).Enabled = false;
			((Control)label_TRP6_SharedName).Enabled = false;
			((Control)textBoxTRP6SharedName).Enabled = false;
		}
		else if (radioButtonTRP6selectExistFolder.Checked)
		{
			((Control)label_TRP6_FolderName).Enabled = false;
			((Control)textBoxTRP6FolderName).Enabled = false;
			((Control)label_TRP6_FolderPath).Enabled = false;
			((Control)textBoxTRP6FolderPath).Enabled = false;
			((Control)buttonTRP6SelectFolder).Enabled = false;
			((Control)label_TRP6_Folder).Enabled = true;
			((Control)cmbTRP6Folder).Enabled = true;
			((Control)label_TRP6_SelectFolder).Enabled = true;
			((Control)label_TRP6_NonSharedFolderPath).Enabled = false;
			((Control)textBoxTRP6NonSharedFolderPath).Enabled = false;
			((Control)buttonTRP6SelectNonSharedFolder).Enabled = false;
			((Control)label_TRP6_SelectNonSharedFolder).Enabled = false;
			((Control)label_TRP6_SharedName).Enabled = false;
			((Control)textBoxTRP6SharedName).Enabled = false;
		}
		else
		{
			((Control)label_TRP6_FolderName).Enabled = false;
			((Control)textBoxTRP6FolderName).Enabled = false;
			((Control)label_TRP6_FolderPath).Enabled = false;
			((Control)textBoxTRP6FolderPath).Enabled = false;
			((Control)buttonTRP6SelectFolder).Enabled = false;
			((Control)label_TRP6_Folder).Enabled = false;
			((Control)cmbTRP6Folder).Enabled = false;
			((Control)label_TRP6_SelectFolder).Enabled = false;
			((Control)label_TRP6_NonSharedFolderPath).Enabled = true;
			((Control)textBoxTRP6NonSharedFolderPath).Enabled = true;
			((Control)buttonTRP6SelectNonSharedFolder).Enabled = true;
			((Control)label_TRP6_SelectNonSharedFolder).Enabled = true;
			((Control)label_TRP6_SharedName).Enabled = true;
			((Control)textBoxTRP6SharedName).Enabled = true;
		}
	}

	private void buttonTRP8HeadLine_Click(object sender, EventArgs e)
	{
		fSettingHeadline.SetHeadLine((Form)(object)this);
		getFormSettingHeadLine();
	}

	private void textTRP8Destination_Enter(object sender, EventArgs e)
	{
		textBox_EnterCommon(sender, Resources.TXT_P4_INITIAL_001, passwordUse: false);
	}

	private void textTRP8Destination_Leave(object sender, EventArgs e)
	{
		textBox_LeaveCommon(sender, Resources.TXT_P4_INITIAL_001, passwordUse: false);
	}

	private void textBoxTRP6FolderName_Enter(object sender, EventArgs e)
	{
		textBox_EnterCommon(sender, Resources.TXT_P2_INITIAL_001, passwordUse: false);
	}

	private void textBoxTRP6FolderName_Leave(object sender, EventArgs e)
	{
		textBox_LeaveCommon(sender, Resources.TXT_P2_INITIAL_001, passwordUse: false);
	}

	private void textBoxTRP6FolderPath_Enter(object sender, EventArgs e)
	{
		textBox_EnterCommon(sender, Resources.TXT_P2_INITIAL_002, passwordUse: false);
	}

	private void textBoxTRP6FolderPath_Leave(object sender, EventArgs e)
	{
		textBox_LeaveCommon(sender, Resources.TXT_P2_INITIAL_002, passwordUse: false);
	}

	private void textBoxTRP6NonSharedFolderPath_Enter(object sender, EventArgs e)
	{
		textBox_EnterCommon(sender, Resources.TXT_P2_INITIAL_003, passwordUse: false);
	}

	private void textBoxTRP6NonSharedFolderPath_Leave(object sender, EventArgs e)
	{
		//IL_005c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0066: Expected O, but got Unknown
		//IL_00b4: Unknown result type (might be due to invalid IL or missing references)
		//IL_00be: Expected O, but got Unknown
		textBox_LeaveCommon(sender, Resources.TXT_P2_INITIAL_003, passwordUse: false);
		if (((Control)textBoxTRP6NonSharedFolderPath).Text == string.Empty || ((Control)textBoxTRP6NonSharedFolderPath).Text == Resources.TXT_P2_INITIAL_003)
		{
			((Control)textBoxTRP6SharedName).Text = Resources.TXT_P2_INITIAL_001;
			((Control)textBoxTRP6SharedName).Font = new Font("Resources.FONT", 9f, (FontStyle)2);
			((Control)textBoxTRP6SharedName).ForeColor = Color.FromArgb(195, 195, 195);
		}
		else
		{
			string fileName = Path.GetFileName(((Control)textBoxTRP6NonSharedFolderPath).Text);
			((Control)textBoxTRP6SharedName).Text = fileName;
			((Control)textBoxTRP6SharedName).Font = new Font("Resources.FONT", 9f, (FontStyle)0);
			((Control)textBoxTRP6SharedName).ForeColor = Color.Black;
		}
	}

	private void textBoxTRP6SharedName_Enter(object sender, EventArgs e)
	{
		textBox_EnterCommon(sender, Resources.TXT_P2_INITIAL_001, passwordUse: false);
	}

	private void textBoxTRP6SharedName_Leave(object sender, EventArgs e)
	{
		textBox_LeaveCommon(sender, Resources.TXT_P2_INITIAL_001, passwordUse: false);
	}

	private void setTrAddressBookSetup()
	{
		((Control)textTRP8Destination).Text = troubleShootAddressBookInfoUpdate.addressBookInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_NAME];
		ipaddr = string.Empty;
		hostname = string.Empty;
		cmbTRP8FolderPath.Items.Clear();
		string empty = string.Empty;
		empty = (radioButtonTRP6createNewFolder.Checked ? ((Control)textBoxTRP6FolderName).Text : ((!radioButtonTRP6selectExistFolder.Checked) ? ((Control)textBoxTRP6SharedName).Text : ((Control)cmbTRP6Folder).Text));
		ipaddr = fMain.getIPAddress();
		cmbTRP8FolderPath.Items.Add((object)("\\\\" + ipaddr + "\\" + empty));
		hostname = Dns.GetHostName();
		cmbTRP8FolderPath.Items.Add((object)("\\\\" + hostname + "\\" + empty));
		if (fMain.DhcpCaution)
		{
			((ListControl)cmbTRP8FolderPath).SelectedIndex = 1;
		}
		else
		{
			((ListControl)cmbTRP8FolderPath).SelectedIndex = 0;
		}
	}

	private void btnTRP8Next_Click(object sender, EventArgs e)
	{
		//IL_006b: Unknown result type (might be due to invalid IL or missing references)
		//IL_00a7: Unknown result type (might be due to invalid IL or missing references)
		//IL_0191: Unknown result type (might be due to invalid IL or missing references)
		//IL_012b: Unknown result type (might be due to invalid IL or missing references)
		//IL_01c2: Unknown result type (might be due to invalid IL or missing references)
		//IL_015f: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		((Control)this).Cursor = Cursors.WaitCursor;
		((Control)linkLabelP4Connect).Visible = false;
		try
		{
			if (string.IsNullOrEmpty(((Control)textTRP8Destination).Text) || ((Control)textTRP8Destination).Text.Equals(Resources.TXT_P4_INITIAL_001))
			{
				MessageBox.Show(Resources.TEXT_P4_ADDRESS_NAME_EMPTY_ERROR_TEXT, Resources.ERR_TITLE_FOLDER_NAME, (MessageBoxButtons)0, (MessageBoxIcon)16);
				throw new Exception("input error . textP4Destination");
			}
			if (Encoding.GetEncoding("Shift_JIS").GetByteCount(((Control)textTRP8Destination).Text) > 16)
			{
				MessageBox.Show(Resources.TEXT_P4_ADDRESS_NAME_LENGTH_ERROR_TEXT, Resources.ERR_TITLE_FOLDER_NAME, (MessageBoxButtons)0, (MessageBoxIcon)16);
				LOG.InfoFormat("{0}：機器の設定エラー：宛先名16バイト以上{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)((Control)textTRP8Destination).Text);
				throw new Exception("input error . textTRP8Destination");
			}
			if (PrimaxModel)
			{
				MachineControl machineControl = new MachineControl(machineLang);
				machineControl.SetPrimaxUnicode(PrimaxUnicode);
				if (PrimaxUnicode)
				{
					if (machineControl.convToUnicode(((Control)textTRP8Destination).Text) == null)
					{
						MessageBox.Show(Resources.ERR_MSG_ADDRESSNAME_CHAR_TYPE_2, Resources.ERR_MSG_TITLE_ADDRESSNAME_CHAR_TYPE, (MessageBoxButtons)0, (MessageBoxIcon)16);
						throw new Exception("input error .宛先名");
					}
					if (!machineControl.checkDestNameCharUnicode(((Control)textTRP8Destination).Text))
					{
						MessageBox.Show(Resources.ERR_MSG_ADDRESSNAME_CHAR_TYPE_2, Resources.ERR_MSG_TITLE_ADDRESSNAME_CHAR_TYPE, (MessageBoxButtons)0, (MessageBoxIcon)16);
						throw new Exception("input error .宛先名");
					}
				}
				else
				{
					if (machineControl.convHexString(((Control)textTRP8Destination).Text, MachineControl.PRIMAX_HEX_ENCODINGT.SJIS) == null)
					{
						MessageBox.Show(Resources.ERR_MSG_ADDRESSNAME_CHAR_TYPE, Resources.ERR_MSG_TITLE_ADDRESSNAME_CHAR_TYPE, (MessageBoxButtons)0, (MessageBoxIcon)16);
						throw new Exception("input error .宛先名");
					}
					if (!machineControl.checkDestNameChar(((Control)textTRP8Destination).Text))
					{
						MessageBox.Show(Resources.ERR_MSG_ADDRESSNAME_CHAR_TYPE, Resources.ERR_MSG_TITLE_ADDRESSNAME_CHAR_TYPE, (MessageBoxButtons)0, (MessageBoxIcon)16);
						throw new Exception("input error .宛先名");
					}
				}
				PrimaxTrpOldAddressName = troubleShootAddressBookInfoUpdate.addressBookInfo[AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_NAME];
			}
			updateTroubleShootAddressBookInfo(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.ENTRY_NAME, ((Control)textTRP8Destination).Text);
			updateTroubleShootAddressBookInfo(AddressBookListControl.ADDRESSBOOK_LIST_ITEM.FOLDER_PATH_NAME, cmbTRP8FolderPath.SelectedItem.ToString());
		}
		finally
		{
			((Control)this).Cursor = Cursors.Default;
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		}
	}

	private void updateTroubleShootAddressBookInfo(AddressBookListControl.ADDRESSBOOK_LIST_ITEM item, string valueStr)
	{
		if (troubleShootAddressBookInfoUpdate.addressBookInfo.ContainsKey(item))
		{
			troubleShootAddressBookInfoUpdate.addressBookInfo.Remove(item);
		}
		if (!string.IsNullOrEmpty(valueStr))
		{
			troubleShootAddressBookInfoUpdate.addressBookInfo.Add(item, valueStr);
		}
	}

	private void btnTRP6Next_Click(object sender, EventArgs e)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		FOLDER_TYPE fOLDER_TYPE = FOLDER_TYPE.CREATE_FOLDRE;
		fOLDER_TYPE = ((!radioButtonTRP6createNewFolder.Checked) ? (radioButtonTRP6selectExistFolder.Checked ? FOLDER_TYPE.SHARED_FOLDER : FOLDER_TYPE.NON_SHARED_FOLDER) : FOLDER_TYPE.CREATE_FOLDRE);
		checkFolderSetting(fOLDER_TYPE, ((Control)textBoxTRP6FolderName).Text, ((Control)textBoxTRP6FolderPath).Text, ((Control)cmbTRP6Folder).Text, ((Control)textBoxTRP6SharedName).Text, ((Control)textBoxTRP6NonSharedFolderPath).Text);
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
	}

	private void btnTRP9Back_Click(object sender, EventArgs e)
	{
		if (!troubleShootAddressBookInfoUpdate.folder)
		{
			StateMachineTroubleShoot.StateType stateType = StateMachineTroubleShoot.StateType.TR_ADDRESSBOOK_SETUP;
			LOG.DebugFormat("{0} Change State:{1} -> {2}", (object)MethodBase.GetCurrentMethod().Name, (object)StateMachineTroubleShoot.NowState, (object)stateType);
			StateMachineTroubleShoot.NowState = stateType;
		}
	}

	private void btnTRP7Back_Click(object sender, EventArgs e)
	{
		if (!troubleShootAddressBookInfoUpdate.folder)
		{
			StateMachineTroubleShoot.StateType stateType = StateMachineTroubleShoot.StateType.TR_CREATE_FOLDER_SETUP;
			LOG.DebugFormat("{0} Change State:{1} -> {2}", (object)MethodBase.GetCurrentMethod().Name, (object)StateMachineTroubleShoot.NowState, (object)stateType);
			StateMachineTroubleShoot.NowState = stateType;
		}
	}

	private void machineSelectControl_SearchButtonClicked(object sender, ControlEnableFlag e)
	{
		bool enableFlag = e.flag;
		((Control)this).Invoke((Delegate)(Action)delegate
		{
			((Control)menuStrip1).Enabled = enableFlag;
			((Control)textP4Destination).Enabled = enableFlag;
			((Control)cmbP4FolderPath).Enabled = enableFlag;
			((Control)buttonP4HeadLine).Enabled = enableFlag;
			((Control)btnP4Back).Enabled = enableFlag;
			((Control)btnP4Next).Enabled = enableFlag;
			if (!enableFlag)
			{
				((Control)linkLabelP4Connect).Visible = false;
			}
		});
		LOG.DebugFormat("{0} Enabled:{1}", (object)MethodBase.GetCurrentMethod().Name, (object)((Control)buttonP4HeadLine).Enabled);
	}

	private void machineSelectControlTRP2_SearchButtonClicked(object sender, ControlEnableFlag e)
	{
		bool enableFlag = e.flag;
		((Control)this).Invoke((Delegate)(Action)delegate
		{
			((Control)menuStrip1).Enabled = enableFlag;
			((Control)btnTRP2Back).Enabled = enableFlag;
			((Control)btnTRP2Next).Enabled = enableFlag;
			if (!enableFlag)
			{
				((Control)linkLabelTRP2).Visible = false;
			}
		});
		LOG.DebugFormat("{0} Enabled:{1}", (object)MethodBase.GetCurrentMethod().Name, (object)((Control)buttonP4HeadLine).Enabled);
	}

	public bool checkVersion()
	{
		//IL_0054: Unknown result type (might be due to invalid IL or missing references)
		//IL_005d: Unknown result type (might be due to invalid IL or missing references)
		//IL_00f5: Unknown result type (might be due to invalid IL or missing references)
		//IL_00f8: Invalid comparison between Unknown and I4
		//IL_01cf: Unknown result type (might be due to invalid IL or missing references)
		//IL_01d1: Invalid comparison between Unknown and I4
		//IL_01c9: Unknown result type (might be due to invalid IL or missing references)
		//IL_01ce: Unknown result type (might be due to invalid IL or missing references)
		//IL_0122: Unknown result type (might be due to invalid IL or missing references)
		//IL_0127: Unknown result type (might be due to invalid IL or missing references)
		//IL_012e: Unknown result type (might be due to invalid IL or missing references)
		//IL_013f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0142: Invalid comparison between Unknown and I4
		//IL_0150: Unknown result type (might be due to invalid IL or missing references)
		//IL_0153: Invalid comparison between Unknown and I4
		Console.WriteLine("checkVersion() start ");
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		string strA = Assembly.GetExecutingAssembly().GetName().Version.ToString();
		string retVersion = null;
		bool result = true;
		bool isFinished = false;
		DialogResult val = (DialogResult)7;
		string dlSiteUrl = null;
		DialogResult val2 = (DialogResult)1;
		bool flag = true;
		string username = "";
		string password = "";
		WebAccessControl webAccess;
		while (true)
		{
			isFinished = false;
			new Thread((ThreadStart)async delegate
			{
				Console.WriteLine("checkVersion() Thread start ");
				webAccess = new WebAccessControl();
				try
				{
					_ = retVersion;
					retVersion = await webAccess.executeGetVersion(username, password, machineLang);
				}
				catch (HttpRequestException ex)
				{
					Console.WriteLine("checkVersin HttpRequestException = " + ex.StackTrace);
					isFinished = true;
					return;
				}
				dlSiteUrl = webAccess.dlSiteUrl;
				isFinished = true;
				Console.WriteLine("checkVersion() Thread End");
			}).Start();
			while (!isFinished)
			{
				Thread.Sleep(500);
			}
			if (retVersion == null || retVersion != "auth failed")
			{
				break;
			}
			FormProxyLogin formProxyLogin;
			while (true)
			{
				formProxyLogin = new FormProxyLogin(username, password);
				if (flag || (int)val2 == 4)
				{
					formProxyLogin.setLoginErrorMsg("");
					flag = false;
				}
				else
				{
					formProxyLogin.setLoginErrorMsg(Resources.FORM_WIZARD_LOGIN_PROXY_LOGIN_ERROR);
				}
				((Form)formProxyLogin).StartPosition = (FormStartPosition)1;
				val2 = ((Form)formProxyLogin).ShowDialog((IWin32Window)(object)this);
				Console.WriteLine("dResult = " + val2);
				if ((int)val2 != 4)
				{
					break;
				}
				Console.WriteLine("Return Login Dialog.");
			}
			if ((int)val2 != 1)
			{
				return true;
			}
			username = formProxyLogin.getAuthUser();
			password = formProxyLogin.getAuthPass();
			Console.WriteLine("Login Input Agein.");
		}
		Console.WriteLine("checkVersion() retVersion = " + retVersion);
		if (retVersion == null || dlSiteUrl == null)
		{
			return result;
		}
		if (string.Compare(strA, retVersion) < 0)
		{
			FormVersionUp formVersionUp = new FormVersionUp(dlSiteUrl);
			((Form)formVersionUp).StartPosition = (FormStartPosition)1;
			val = ((Form)formVersionUp).ShowDialog((IWin32Window)(object)this);
		}
		if ((int)val == 1)
		{
			result = false;
		}
		Console.WriteLine("checkVersion() End");
		return result;
	}

	public static bool IsPrimax(string hostName)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		bool flag = false;
		StringEnumerator enumerator = Settings.Default.machineSupported2.GetEnumerator();
		try
		{
			while (enumerator.MoveNext())
			{
				string current = enumerator.Current;
				if (hostName.IndexOf("RICOH " + current) >= 0)
				{
					flag = true;
					break;
				}
			}
		}
		finally
		{
			if (enumerator is IDisposable disposable)
			{
				disposable.Dispose();
			}
		}
		LOG.DebugFormat("hostName:{0} ret:{1]", (object)hostName, (object)flag);
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return flag;
	}

	public static bool IsPrimaxUnicode(string hostName)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		bool flag = false;
		StringEnumerator enumerator = Settings.Default.machineSupported3.GetEnumerator();
		try
		{
			while (enumerator.MoveNext())
			{
				string current = enumerator.Current;
				if (hostName.IndexOf("RICOH " + current) >= 0)
				{
					flag = true;
					break;
				}
			}
		}
		finally
		{
			if (enumerator is IDisposable disposable)
			{
				disposable.Dispose();
			}
		}
		LOG.DebugFormat("hostName:{0} ret:{1]", (object)hostName, (object)flag);
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return flag;
	}

	public static bool isMfpSmbSupported(string hostName)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		bool flag = false;
		if (hostName.IndexOf("IM") >= 0)
		{
			LOG.DebugFormat("hostName:{0} ret:true", (object)hostName);
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
			return true;
		}
		StringEnumerator enumerator = Settings.Default.machineSMBSupported.GetEnumerator();
		try
		{
			while (enumerator.MoveNext())
			{
				string current = enumerator.Current;
				if (hostName.IndexOf(current) >= 0)
				{
					flag = true;
					break;
				}
			}
		}
		finally
		{
			if (enumerator is IDisposable disposable)
			{
				disposable.Dispose();
			}
		}
		LOG.DebugFormat("hostName:{0} ret:{1}", (object)hostName, (object)flag);
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return flag;
	}

	public static bool isPrimaxSmbSupported(string hostName)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		bool flag = false;
		StringEnumerator enumerator = Settings.Default.machineSMBSupported2.GetEnumerator();
		try
		{
			while (enumerator.MoveNext())
			{
				string current = enumerator.Current;
				if (hostName.IndexOf(current) >= 0)
				{
					flag = true;
					break;
				}
			}
		}
		finally
		{
			if (enumerator is IDisposable disposable)
			{
				disposable.Dispose();
			}
		}
		LOG.DebugFormat("hostName:{0} ret:{1}", (object)hostName, (object)flag);
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return flag;
	}

	public static bool PCSMBcheck(string lang)
	{
		//IL_017a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0098: Unknown result type (might be due to invalid IL or missing references)
		//IL_009e: Invalid comparison between Unknown and I4
		//IL_00ac: Unknown result type (might be due to invalid IL or missing references)
		//IL_00b2: Invalid comparison between Unknown and I4
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		try
		{
			bool flag = isFilerShare(lang);
			if (flag)
			{
				LOG.InfoFormat("PCファイル共有有効:{0}", (object)flag);
				if (isPCSMBv2v3())
				{
					LOG.InfoFormat("PC:SMBv2/v3有効", new object[0]);
					LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
					return true;
				}
				LOG.InfoFormat("PC:SMBv2/v3無効:{0}", (object)flag);
				if ((int)MessageBox.Show(Resources.MSG_PC_SMBV2V3_FALSE, Resources.CONFIRM, (MessageBoxButtons)4, (MessageBoxIcon)0) == 7)
				{
					if ((int)MessageBox.Show(Resources.MSG_SMB_NEXT_ADDRESS_REGISTER, Resources.CONFIRM, (MessageBoxButtons)4, (MessageBoxIcon)0) == 7)
					{
						LOG.InfoFormat("Stop Address register", new object[0]);
						LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
						return false;
					}
					LOG.InfoFormat("Next Address register", new object[0]);
					LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
					return true;
				}
				PCSMBv2v3Enable();
				LOG.InfoFormat("PC:SMBv2/v3有効化完了", new object[0]);
				LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
				return true;
			}
			LOG.InfoFormat("PCファイル共有無効:{0}", (object)flag);
			MessageBox.Show(Resources.MSG_PC_FILE_SHARE_FALSE, Resources.CONFIRM, (MessageBoxButtons)0, (MessageBoxIcon)0);
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
			return false;
		}
		catch (Exception ex)
		{
			LOG.InfoFormat("PC:SMB設定変更エラー:{0}", (object)ex.ToString());
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
			throw ex;
		}
		finally
		{
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		}
	}

	public static async Task<bool> MFPSMBcheck(string ipAddr, string hostname, string lang)
	{
		try
		{
			LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
			bool issupprted = isMfpSmbSupported(hostname);
			if (issupprted)
			{
				LOG.InfoFormat("MFP SMBv2v3対象機種:{0}", (object)issupprted);
				if (await MFPFWUpdateCheck(ipAddr, lang))
				{
					MessageBox.Show(Resources.MSG_FW_UPDATE, Resources.CONFIRM, (MessageBoxButtons)0, (MessageBoxIcon)0);
					LOG.InfoFormat("MFPファームウェアアップデート必要", new object[0]);
					LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
					return false;
				}
				if (await isMFPSMBv2v3(ipAddr, lang))
				{
					LOG.InfoFormat("MFP:SMBv2/v3有効", new object[0]);
					LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
					return true;
				}
				LOG.InfoFormat("MFP:SMBv2/v3無効", new object[0]);
				if ((int)MessageBox.Show(Resources.MSG_MFP_SMBV2V3_FALSE, Resources.CONFIRM, (MessageBoxButtons)4, (MessageBoxIcon)0) == 7)
				{
					if ((int)MessageBox.Show(Resources.MSG_SMB_NEXT_ADDRESS_REGISTER, Resources.CONFIRM, (MessageBoxButtons)4, (MessageBoxIcon)0) == 7)
					{
						LOG.InfoFormat("Stop Address register", new object[0]);
						LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
						return false;
					}
					LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
					LOG.InfoFormat("Next Address register", new object[0]);
					return true;
				}
				await MFPSMBv2v3Eable(enable: true, ipAddr, lang);
				LOG.InfoFormat("MFP:SMBv2/v3有効化完了", new object[0]);
				LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
				return true;
			}
			LOG.InfoFormat("MFP SMBv2v3対象外機種:{0}", (object)issupprted);
			if (isPCSMBv1())
			{
				LOG.InfoFormat("PC SMBv1有効", new object[0]);
				LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
				return true;
			}
			MessageBox.Show(Resources.MSG_SMB_NOT_SUPPORTED, Resources.CONFIRM, (MessageBoxButtons)0, (MessageBoxIcon)0);
			LOG.InfoFormat("PC SMBv1無効", new object[0]);
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
			return false;
		}
		catch (Exception ex)
		{
			LOG.InfoFormat("MFP:SMB設定変更エラー:{0}", (object)ex.ToString());
			throw ex;
		}
		finally
		{
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		}
	}

	public static bool PrimaxSMBcheck(string ipAddr, string hostname, string lang)
	{
		//IL_00b5: Unknown result type (might be due to invalid IL or missing references)
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		try
		{
			bool flag = isPrimaxSmbSupported(hostname);
			if (flag)
			{
				LOG.InfoFormat("Primax:SMBv2/v3対象機種", (object)flag);
				LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
				return true;
			}
			LOG.InfoFormat("Primax:SMBv2/v3対象外機種", (object)flag);
			if (isPCSMBv1())
			{
				LOG.InfoFormat("SMBv1有効", new object[0]);
				LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
				return true;
			}
			MessageBox.Show(Resources.MSG_SMB_NOT_SUPPORTED, Resources.CONFIRM, (MessageBoxButtons)0, (MessageBoxIcon)0);
			LOG.InfoFormat("SMBv1無効", new object[0]);
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
			return false;
		}
		catch (Exception ex)
		{
			LOG.InfoFormat("Primax:SMB設定確認エラー:{0}", (object)ex.ToString());
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
			throw ex;
		}
		finally
		{
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		}
	}

	public static async Task<TRPSMBCHECKCODE> SMBTRPcheck1(string ipAddr, string hostname, string lang)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		TRPSMBCHECKCODE ret = TRPSMBCHECKCODE.OK;
		try
		{
			if (isFilerShare(lang))
			{
				LOG.InfoFormat("PCファイル共有有効", new object[0]);
				bool flag = IsPrimax(hostname);
				if ((!flag) ? isMfpSmbSupported(hostname) : isPrimaxSmbSupported(hostname))
				{
					if (flag)
					{
						LOG.InfoFormat("Primax:SMBv2/v3 有効", new object[0]);
						LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
						return TRPSMBCHECKCODE.OK;
					}
					if (await MFPFWUpdateCheck(ipAddr, lang))
					{
						LOG.InfoFormat("ファームウェアアップデート必要", new object[0]);
						ret = TRPSMBCHECKCODE.FWUPDATE;
					}
					else
					{
						LOG.InfoFormat("ファームウェアアップデート不要", new object[0]);
					}
				}
				else if (isPCSMBv1())
				{
					LOG.InfoFormat("PC:SMBv1有効", new object[0]);
					ret = TRPSMBCHECKCODE.V1ON;
				}
				else
				{
					MessageBox.Show(Resources.MSG_SMB_NOT_SUPPORTED, Resources.CONFIRM, (MessageBoxButtons)0, (MessageBoxIcon)0);
					LOG.InfoFormat("PC:SMBv1無効", new object[0]);
					ret = TRPSMBCHECKCODE.V1OFF;
				}
			}
			else
			{
				LOG.InfoFormat("PC:ファイル共有無効", new object[0]);
				ret = TRPSMBCHECKCODE.FSOFF;
			}
		}
		catch (Exception ex)
		{
			LOG.InfoFormat("トラシュー:SMB設定変更エラー:{0}", (object)ex.ToString());
			throw ex;
		}
		finally
		{
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		}
		return ret;
	}

	public static async Task<bool> SMBTRPcheck2(string ipAddr, string hostname, string lang)
	{
		_ = 1;
		try
		{
			LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
			if (IsPrimax(hostname))
			{
				LOG.InfoFormat("Primax:SMBv2/v3有効", new object[0]);
				return true;
			}
			if (!isPCSMBv2v3())
			{
				LOG.InfoFormat("PC:SMBv2/v3無効", new object[0]);
				if ((int)MessageBox.Show(Resources.MSG_PC_SMBV2V3_FALSE, Resources.CONFIRM, (MessageBoxButtons)4, (MessageBoxIcon)0) == 6)
				{
					PCSMBv2v3Enable();
					LOG.InfoFormat("PC:SMBv2/v3有効化完了", new object[0]);
				}
			}
			if (!(await isMFPSMBv2v3(ipAddr, lang)))
			{
				LOG.InfoFormat("MFP:SMBv2/v3無効", new object[0]);
				if ((int)MessageBox.Show(Resources.MSG_MFP_SMBV2V3_FALSE, Resources.CONFIRM, (MessageBoxButtons)4, (MessageBoxIcon)0) == 6)
				{
					await MFPSMBv2v3Eable(enable: true, ipAddr, lang);
					LOG.InfoFormat("MFP:SMBv2/v3有効化完了", new object[0]);
				}
			}
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
			return true;
		}
		catch (Exception ex)
		{
			LOG.InfoFormat("トラシュー:SMB設定変更エラー:{0}", (object)ex.ToString());
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
			throw ex;
		}
		finally
		{
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		}
	}

	public static bool isPCSMBv2v3()
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		string text = RunPSCommand("Get-SmbServerConfiguration", "EnableSMB2Protocol");
		LOG.DebugFormat("Powershell command SMBv2/v3 result:{0}", (object)text);
		if (text.Equals("True"))
		{
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
			return true;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return false;
	}

	public static void PCSMBv2v3Enable(bool enable = true)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		string text = "Set-SmbServerConfiguration";
		string text2 = "EnableSMB2Protocol";
		try
		{
			PowerShell.Create().AddCommand(text).AddParameter(text2, (object)enable)
				.AddParameter("Confirm", (object)false)
				.Invoke();
		}
		catch (Exception ex)
		{
			LOG.InfoFormat("PC:SMB設定変更エラー:{0}", (object)ex.ToString());
		}
		finally
		{
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		}
	}

	public static bool isPCSMBv1()
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		string text = RunPSCommand("Get-SmbServerConfiguration", "EnableSMB1Protocol");
		LOG.DebugFormat("Powershell command SMBv1 result:{0}", (object)text);
		if (text.Equals("True"))
		{
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
			return true;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return false;
	}

	public static bool isFilerShare(string lang = "ja")
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		bool result = false;
		try
		{
			if (isPCSMBv2v3() || isPCSMBv1())
			{
				result = true;
			}
		}
		catch (Exception ex)
		{
			LOG.InfoFormat("PC:ファイル共有設定確認エラー:{0}", (object)ex.ToString());
			throw ex;
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return result;
	}

	public static string RunPSCommand(string cmd, string properties = null)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		Collection<PSObject> collection = null;
		try
		{
			PowerShell obj = PowerShell.Create();
			obj.AddCommand(cmd);
			collection = obj.Invoke();
		}
		catch (Exception ex)
		{
			LOG.DebugFormat("PSCommand Exception:{0}", (object)ex.ToString());
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
			return null;
		}
		if (properties == null)
		{
			LOG.DebugFormat("RsultGetProperties:null", new object[0]);
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
			return "";
		}
		object value = ((PSMemberInfo)collection[0].Properties[properties]).Value;
		LOG.DebugFormat("RsultGetPropertiesResult:{0}", value);
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return value.ToString();
	}

	public static async Task<bool> isMFPSMBv2v3(string ipAddr, string lang = "ja", bool showErrorDialog = true)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		try
		{
			MachineControl machineControl = new MachineControl(lang);
			string hostNameFromIP = GetHostNameFromIP(ipAddr);
			bool flag = IsPrimax(hostNameFromIP);
			bool primaxUnicode = IsPrimaxUnicode(hostNameFromIP);
			machineControl.SetPrimaxModel(flag);
			machineControl.SetPrimaxUnicode(primaxUnicode);
			COMMUNICATION_ERROR_CODE cOMMUNICATION_ERROR_CODE = machineControl.communicateConfirm(ipAddr, showErrorDialog);
			if (cOMMUNICATION_ERROR_CODE != 0 && cOMMUNICATION_ERROR_CODE != COMMUNICATION_ERROR_CODE.NOT_SUPPORT)
			{
				if (flag)
				{
					LOG.DebugFormat("Primax: SMBv2/v3 有効", new object[0]);
					LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
					return true;
				}
				SettingItemsSetupAddress info = new SettingItemsSetupAddress
				{
					host = ipAddr,
					adminName = "admin",
					passwd = "",
					firstFlg = true,
					httpsFlg = false
				};
				string text = (await machineControl.GetMFPSMBInfo(info))[FormMFPInfo.KEY.SMBVERSION].ToString();
				if (text.Equals("true"))
				{
					LOG.DebugFormat("SMBv2/v3有効{0}", (object)text);
					LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
					return true;
				}
				LOG.DebugFormat("SMBv2/v3無効:{0}", (object)text);
				LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
				return false;
			}
			LOG.DebugFormat("疎通確認:エラー{0}", (object)cOMMUNICATION_ERROR_CODE);
		}
		catch (Exception ex)
		{
			Console.WriteLine(ex.ToString());
			LOG.ErrorFormat("{0}：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)ex.ToString());
			MessageBox.Show(Resources.ERR_MSG_FATAL_RETRY, Resources.ERR_MSG_MACHINE_INFO_CAPTION, (MessageBoxButtons)0, (MessageBoxIcon)16);
		}
		finally
		{
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		}
		return false;
	}

	public static async Task<bool> MFPFWUpdateCheck(string ipAddr, string lang)
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		try
		{
			MachineControl machineControl = new MachineControl(lang);
			string hostNameFromIP = GetHostNameFromIP(ipAddr);
			bool flag = IsPrimax(hostNameFromIP);
			bool primaxUnicode = IsPrimaxUnicode(hostNameFromIP);
			machineControl.SetPrimaxModel(flag);
			machineControl.SetPrimaxUnicode(primaxUnicode);
			COMMUNICATION_ERROR_CODE cOMMUNICATION_ERROR_CODE = COMMUNICATION_ERROR_CODE.HTTP_ONLY;
			if (cOMMUNICATION_ERROR_CODE != 0 && cOMMUNICATION_ERROR_CODE != COMMUNICATION_ERROR_CODE.NOT_SUPPORT)
			{
				if (flag)
				{
					LOG.DebugFormat("Primax:FWcheckend", new object[0]);
					LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
					return true;
				}
				SettingItemsSetupAddress info = new SettingItemsSetupAddress
				{
					host = ipAddr,
					adminName = "admin",
					passwd = "",
					firstFlg = true,
					httpsFlg = false
				};
				string text = (await machineControl.GetMFPSMBInfo(info))[FormMFPInfo.KEY.SMBVERSION].ToString();
				if (text.Equals(""))
				{
					LOG.DebugFormat("ファームウェアアップデート必要:{0}", (object)text);
					LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
					return true;
				}
				LOG.DebugFormat("ファームウェアアップデート不要:{0}", (object)text);
				LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
				return false;
			}
			LOG.DebugFormat("疎通確認:エラー{0}", (object)cOMMUNICATION_ERROR_CODE);
		}
		catch (Exception ex)
		{
			Console.WriteLine(ex.ToString());
			LOG.ErrorFormat("{0}：{1}", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)ex.ToString());
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
			throw ex;
		}
		finally
		{
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		}
		return false;
	}

	public static async Task<bool> MFPSMBv2v3Eable(bool enable, string ipAddr, string lang = "ja")
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		SettingItemsSetupAddress setting = new SettingItemsSetupAddress
		{
			host = ipAddr,
			adminName = "admin",
			passwd = "",
			httpsFlg = false
		};
		MachineControl mc = new MachineControl(lang);
		string hostNameFromIP = GetHostNameFromIP(setting.host);
		bool flag = IsPrimax(hostNameFromIP);
		bool primaxUnicode = IsPrimaxUnicode(hostNameFromIP);
		mc.SetPrimaxModel(flag);
		mc.SetPrimaxUnicode(primaxUnicode);
		mc.communicateConfirm(setting.host);
		bool ret = false;
		if (flag)
		{
			LOG.DebugFormat("Primax:SMBv2/v3 有効", new object[0]);
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
			return false;
		}
		if (await mc.executeWimConnect(setting, null, null) != 0)
		{
			LOG.DebugFormat("{0}：executeWimConnect() Failed.\n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name);
		}
		else
		{
			string result = await mc.executeSetupSMB(setting, enable);
			if (result.Length > 0)
			{
				if (result.Contains(Resources.WIM_MSG_CHANGING_SETTINGS))
				{
					ret = true;
					for (int i = 0; i < 10; i++)
					{
						bool flag2 = await isMFPSMBv2v3(ipAddr, lang, showErrorDialog: false);
						if (flag2)
						{
							LOG.DebugFormat("MFP:SMbv2/v3有効化完了:{0}", (object)flag2);
							break;
						}
						Thread.Sleep(5000);
					}
				}
				else
				{
					LOG.DebugFormat("{0}：SMB設定変更 {1}.\n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)"失敗");
				}
			}
			else
			{
				LOG.DebugFormat("{0}：SMB設定変更 {1}.\n", (object)MethodBase.GetCurrentMethod().DeclaringType.Name, (object)((result == null) ? "失敗" : "成功"));
			}
		}
		LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		return ret;
	}

	private List<string> GetLocalUserList()
	{
		LOG.DebugFormat("{0}：start", (object)MethodBase.GetCurrentMethod().Name);
		List<string> list = new List<string>();
		string text = "DefaultAccount";
		string text2 = "WDAGUtilityAccount";
		try
		{
			PowerShell obj = PowerShell.Create();
			obj.AddCommand("Get-LocalUser");
			foreach (PSObject item in obj.Invoke())
			{
				string text3 = ((PSMemberInfo)item.Properties["Name"]).Value.ToString();
				if (!(text3 == text) && !(text3 == text2))
				{
					list.Add(text3);
				}
			}
			return list;
		}
		catch (Exception ex)
		{
			LOG.DebugFormat("PSCommand Exception:{0}", (object)ex.ToString());
			throw ex;
		}
		finally
		{
			LOG.DebugFormat("{0}：end", (object)MethodBase.GetCurrentMethod().Name);
		}
	}

	protected override void Dispose(bool disposing)
	{
		if (disposing && components != null)
		{
			components.Dispose();
		}
		((Form)this).Dispose(disposing);
	}

	private void InitializeComponent()
	{
		//IL_0011: Unknown result type (might be due to invalid IL or missing references)
		//IL_001b: Expected O, but got Unknown
		//IL_001c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0026: Expected O, but got Unknown
		//IL_0027: Unknown result type (might be due to invalid IL or missing references)
		//IL_0031: Expected O, but got Unknown
		//IL_0032: Unknown result type (might be due to invalid IL or missing references)
		//IL_003c: Expected O, but got Unknown
		//IL_003d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0047: Expected O, but got Unknown
		//IL_0048: Unknown result type (might be due to invalid IL or missing references)
		//IL_0052: Expected O, but got Unknown
		//IL_0053: Unknown result type (might be due to invalid IL or missing references)
		//IL_005d: Expected O, but got Unknown
		//IL_005e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0068: Expected O, but got Unknown
		//IL_0069: Unknown result type (might be due to invalid IL or missing references)
		//IL_0073: Expected O, but got Unknown
		//IL_0074: Unknown result type (might be due to invalid IL or missing references)
		//IL_007e: Expected O, but got Unknown
		//IL_007f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0089: Expected O, but got Unknown
		//IL_008a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0094: Expected O, but got Unknown
		//IL_0095: Unknown result type (might be due to invalid IL or missing references)
		//IL_009f: Expected O, but got Unknown
		//IL_00a0: Unknown result type (might be due to invalid IL or missing references)
		//IL_00aa: Expected O, but got Unknown
		//IL_00ab: Unknown result type (might be due to invalid IL or missing references)
		//IL_00b5: Expected O, but got Unknown
		//IL_00b6: Unknown result type (might be due to invalid IL or missing references)
		//IL_00c0: Expected O, but got Unknown
		//IL_00c1: Unknown result type (might be due to invalid IL or missing references)
		//IL_00cb: Expected O, but got Unknown
		//IL_00cc: Unknown result type (might be due to invalid IL or missing references)
		//IL_00d6: Expected O, but got Unknown
		//IL_00d7: Unknown result type (might be due to invalid IL or missing references)
		//IL_00e1: Expected O, but got Unknown
		//IL_00e2: Unknown result type (might be due to invalid IL or missing references)
		//IL_00ec: Expected O, but got Unknown
		//IL_00ed: Unknown result type (might be due to invalid IL or missing references)
		//IL_00f7: Expected O, but got Unknown
		//IL_00f8: Unknown result type (might be due to invalid IL or missing references)
		//IL_0102: Expected O, but got Unknown
		//IL_0103: Unknown result type (might be due to invalid IL or missing references)
		//IL_010d: Expected O, but got Unknown
		//IL_010e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0118: Expected O, but got Unknown
		//IL_0119: Unknown result type (might be due to invalid IL or missing references)
		//IL_0123: Expected O, but got Unknown
		//IL_0124: Unknown result type (might be due to invalid IL or missing references)
		//IL_012e: Expected O, but got Unknown
		//IL_012f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0139: Expected O, but got Unknown
		//IL_013a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0144: Expected O, but got Unknown
		//IL_0145: Unknown result type (might be due to invalid IL or missing references)
		//IL_014f: Expected O, but got Unknown
		//IL_0150: Unknown result type (might be due to invalid IL or missing references)
		//IL_015a: Expected O, but got Unknown
		//IL_015b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0165: Expected O, but got Unknown
		//IL_0166: Unknown result type (might be due to invalid IL or missing references)
		//IL_0170: Expected O, but got Unknown
		//IL_0171: Unknown result type (might be due to invalid IL or missing references)
		//IL_017b: Expected O, but got Unknown
		//IL_017c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0186: Expected O, but got Unknown
		//IL_0187: Unknown result type (might be due to invalid IL or missing references)
		//IL_0191: Expected O, but got Unknown
		//IL_0192: Unknown result type (might be due to invalid IL or missing references)
		//IL_019c: Expected O, but got Unknown
		//IL_019d: Unknown result type (might be due to invalid IL or missing references)
		//IL_01a7: Expected O, but got Unknown
		//IL_01a8: Unknown result type (might be due to invalid IL or missing references)
		//IL_01b2: Expected O, but got Unknown
		//IL_01b3: Unknown result type (might be due to invalid IL or missing references)
		//IL_01bd: Expected O, but got Unknown
		//IL_01be: Unknown result type (might be due to invalid IL or missing references)
		//IL_01c8: Expected O, but got Unknown
		//IL_01c9: Unknown result type (might be due to invalid IL or missing references)
		//IL_01d3: Expected O, but got Unknown
		//IL_01d4: Unknown result type (might be due to invalid IL or missing references)
		//IL_01de: Expected O, but got Unknown
		//IL_01df: Unknown result type (might be due to invalid IL or missing references)
		//IL_01e9: Expected O, but got Unknown
		//IL_01ea: Unknown result type (might be due to invalid IL or missing references)
		//IL_01f4: Expected O, but got Unknown
		//IL_01f5: Unknown result type (might be due to invalid IL or missing references)
		//IL_01ff: Expected O, but got Unknown
		//IL_0200: Unknown result type (might be due to invalid IL or missing references)
		//IL_020a: Expected O, but got Unknown
		//IL_020b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0215: Expected O, but got Unknown
		//IL_0216: Unknown result type (might be due to invalid IL or missing references)
		//IL_0220: Expected O, but got Unknown
		//IL_0221: Unknown result type (might be due to invalid IL or missing references)
		//IL_022b: Expected O, but got Unknown
		//IL_022c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0236: Expected O, but got Unknown
		//IL_0237: Unknown result type (might be due to invalid IL or missing references)
		//IL_0241: Expected O, but got Unknown
		//IL_0242: Unknown result type (might be due to invalid IL or missing references)
		//IL_024c: Expected O, but got Unknown
		//IL_024d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0257: Expected O, but got Unknown
		//IL_0258: Unknown result type (might be due to invalid IL or missing references)
		//IL_0262: Expected O, but got Unknown
		//IL_0263: Unknown result type (might be due to invalid IL or missing references)
		//IL_026d: Expected O, but got Unknown
		//IL_026e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0278: Expected O, but got Unknown
		//IL_0279: Unknown result type (might be due to invalid IL or missing references)
		//IL_0283: Expected O, but got Unknown
		//IL_0284: Unknown result type (might be due to invalid IL or missing references)
		//IL_028e: Expected O, but got Unknown
		//IL_028f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0299: Expected O, but got Unknown
		//IL_029a: Unknown result type (might be due to invalid IL or missing references)
		//IL_02a4: Expected O, but got Unknown
		//IL_02a5: Unknown result type (might be due to invalid IL or missing references)
		//IL_02af: Expected O, but got Unknown
		//IL_02b0: Unknown result type (might be due to invalid IL or missing references)
		//IL_02ba: Expected O, but got Unknown
		//IL_02bb: Unknown result type (might be due to invalid IL or missing references)
		//IL_02c5: Expected O, but got Unknown
		//IL_02c6: Unknown result type (might be due to invalid IL or missing references)
		//IL_02d0: Expected O, but got Unknown
		//IL_02d1: Unknown result type (might be due to invalid IL or missing references)
		//IL_02db: Expected O, but got Unknown
		//IL_02dc: Unknown result type (might be due to invalid IL or missing references)
		//IL_02e6: Expected O, but got Unknown
		//IL_02e7: Unknown result type (might be due to invalid IL or missing references)
		//IL_02f1: Expected O, but got Unknown
		//IL_02f2: Unknown result type (might be due to invalid IL or missing references)
		//IL_02fc: Expected O, but got Unknown
		//IL_02fd: Unknown result type (might be due to invalid IL or missing references)
		//IL_0307: Expected O, but got Unknown
		//IL_0308: Unknown result type (might be due to invalid IL or missing references)
		//IL_0312: Expected O, but got Unknown
		//IL_0313: Unknown result type (might be due to invalid IL or missing references)
		//IL_031d: Expected O, but got Unknown
		//IL_031e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0328: Expected O, but got Unknown
		//IL_0329: Unknown result type (might be due to invalid IL or missing references)
		//IL_0333: Expected O, but got Unknown
		//IL_0334: Unknown result type (might be due to invalid IL or missing references)
		//IL_033e: Expected O, but got Unknown
		//IL_033f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0349: Expected O, but got Unknown
		//IL_034a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0354: Expected O, but got Unknown
		//IL_0355: Unknown result type (might be due to invalid IL or missing references)
		//IL_035f: Expected O, but got Unknown
		//IL_0360: Unknown result type (might be due to invalid IL or missing references)
		//IL_036a: Expected O, but got Unknown
		//IL_036b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0375: Expected O, but got Unknown
		//IL_0376: Unknown result type (might be due to invalid IL or missing references)
		//IL_0380: Expected O, but got Unknown
		//IL_0381: Unknown result type (might be due to invalid IL or missing references)
		//IL_038b: Expected O, but got Unknown
		//IL_038c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0396: Expected O, but got Unknown
		//IL_0397: Unknown result type (might be due to invalid IL or missing references)
		//IL_03a1: Expected O, but got Unknown
		//IL_03a2: Unknown result type (might be due to invalid IL or missing references)
		//IL_03ac: Expected O, but got Unknown
		//IL_03ad: Unknown result type (might be due to invalid IL or missing references)
		//IL_03b7: Expected O, but got Unknown
		//IL_03b8: Unknown result type (might be due to invalid IL or missing references)
		//IL_03c2: Expected O, but got Unknown
		//IL_03c3: Unknown result type (might be due to invalid IL or missing references)
		//IL_03cd: Expected O, but got Unknown
		//IL_03ce: Unknown result type (might be due to invalid IL or missing references)
		//IL_03d8: Expected O, but got Unknown
		//IL_03d9: Unknown result type (might be due to invalid IL or missing references)
		//IL_03e3: Expected O, but got Unknown
		//IL_03e4: Unknown result type (might be due to invalid IL or missing references)
		//IL_03ee: Expected O, but got Unknown
		//IL_03ef: Unknown result type (might be due to invalid IL or missing references)
		//IL_03f9: Expected O, but got Unknown
		//IL_03fa: Unknown result type (might be due to invalid IL or missing references)
		//IL_0404: Expected O, but got Unknown
		//IL_0405: Unknown result type (might be due to invalid IL or missing references)
		//IL_040f: Expected O, but got Unknown
		//IL_0410: Unknown result type (might be due to invalid IL or missing references)
		//IL_041a: Expected O, but got Unknown
		//IL_041b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0425: Expected O, but got Unknown
		//IL_0426: Unknown result type (might be due to invalid IL or missing references)
		//IL_0430: Expected O, but got Unknown
		//IL_0431: Unknown result type (might be due to invalid IL or missing references)
		//IL_043b: Expected O, but got Unknown
		//IL_043c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0446: Expected O, but got Unknown
		//IL_0447: Unknown result type (might be due to invalid IL or missing references)
		//IL_0451: Expected O, but got Unknown
		//IL_0452: Unknown result type (might be due to invalid IL or missing references)
		//IL_045c: Expected O, but got Unknown
		//IL_045d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0467: Expected O, but got Unknown
		//IL_0468: Unknown result type (might be due to invalid IL or missing references)
		//IL_0472: Expected O, but got Unknown
		//IL_0473: Unknown result type (might be due to invalid IL or missing references)
		//IL_047d: Expected O, but got Unknown
		//IL_047e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0488: Expected O, but got Unknown
		//IL_0489: Unknown result type (might be due to invalid IL or missing references)
		//IL_0493: Expected O, but got Unknown
		//IL_0494: Unknown result type (might be due to invalid IL or missing references)
		//IL_049e: Expected O, but got Unknown
		//IL_049f: Unknown result type (might be due to invalid IL or missing references)
		//IL_04a9: Expected O, but got Unknown
		//IL_04aa: Unknown result type (might be due to invalid IL or missing references)
		//IL_04b4: Expected O, but got Unknown
		//IL_04b5: Unknown result type (might be due to invalid IL or missing references)
		//IL_04bf: Expected O, but got Unknown
		//IL_04c0: Unknown result type (might be due to invalid IL or missing references)
		//IL_04ca: Expected O, but got Unknown
		//IL_04cb: Unknown result type (might be due to invalid IL or missing references)
		//IL_04d5: Expected O, but got Unknown
		//IL_04d6: Unknown result type (might be due to invalid IL or missing references)
		//IL_04e0: Expected O, but got Unknown
		//IL_04e1: Unknown result type (might be due to invalid IL or missing references)
		//IL_04eb: Expected O, but got Unknown
		//IL_04ec: Unknown result type (might be due to invalid IL or missing references)
		//IL_04f6: Expected O, but got Unknown
		//IL_04f7: Unknown result type (might be due to invalid IL or missing references)
		//IL_0501: Expected O, but got Unknown
		//IL_0502: Unknown result type (might be due to invalid IL or missing references)
		//IL_050c: Expected O, but got Unknown
		//IL_050d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0517: Expected O, but got Unknown
		//IL_0518: Unknown result type (might be due to invalid IL or missing references)
		//IL_0522: Expected O, but got Unknown
		//IL_0523: Unknown result type (might be due to invalid IL or missing references)
		//IL_052d: Expected O, but got Unknown
		//IL_052e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0538: Expected O, but got Unknown
		//IL_0539: Unknown result type (might be due to invalid IL or missing references)
		//IL_0543: Expected O, but got Unknown
		//IL_0544: Unknown result type (might be due to invalid IL or missing references)
		//IL_054e: Expected O, but got Unknown
		//IL_054f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0559: Expected O, but got Unknown
		//IL_055a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0564: Expected O, but got Unknown
		//IL_0565: Unknown result type (might be due to invalid IL or missing references)
		//IL_056f: Expected O, but got Unknown
		//IL_0570: Unknown result type (might be due to invalid IL or missing references)
		//IL_057a: Expected O, but got Unknown
		//IL_057b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0585: Expected O, but got Unknown
		//IL_0586: Unknown result type (might be due to invalid IL or missing references)
		//IL_0590: Expected O, but got Unknown
		//IL_0591: Unknown result type (might be due to invalid IL or missing references)
		//IL_059b: Expected O, but got Unknown
		//IL_059c: Unknown result type (might be due to invalid IL or missing references)
		//IL_05a6: Expected O, but got Unknown
		//IL_05a7: Unknown result type (might be due to invalid IL or missing references)
		//IL_05b1: Expected O, but got Unknown
		//IL_05b2: Unknown result type (might be due to invalid IL or missing references)
		//IL_05bc: Expected O, but got Unknown
		//IL_05bd: Unknown result type (might be due to invalid IL or missing references)
		//IL_05c7: Expected O, but got Unknown
		//IL_05c8: Unknown result type (might be due to invalid IL or missing references)
		//IL_05d2: Expected O, but got Unknown
		//IL_05d3: Unknown result type (might be due to invalid IL or missing references)
		//IL_05dd: Expected O, but got Unknown
		//IL_05de: Unknown result type (might be due to invalid IL or missing references)
		//IL_05e8: Expected O, but got Unknown
		//IL_05e9: Unknown result type (might be due to invalid IL or missing references)
		//IL_05f3: Expected O, but got Unknown
		//IL_05f4: Unknown result type (might be due to invalid IL or missing references)
		//IL_05fe: Expected O, but got Unknown
		//IL_05ff: Unknown result type (might be due to invalid IL or missing references)
		//IL_0609: Expected O, but got Unknown
		//IL_060a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0614: Expected O, but got Unknown
		//IL_0615: Unknown result type (might be due to invalid IL or missing references)
		//IL_061f: Expected O, but got Unknown
		//IL_0620: Unknown result type (might be due to invalid IL or missing references)
		//IL_062a: Expected O, but got Unknown
		//IL_062b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0635: Expected O, but got Unknown
		//IL_0636: Unknown result type (might be due to invalid IL or missing references)
		//IL_0640: Expected O, but got Unknown
		//IL_0641: Unknown result type (might be due to invalid IL or missing references)
		//IL_064b: Expected O, but got Unknown
		//IL_064c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0656: Expected O, but got Unknown
		//IL_0657: Unknown result type (might be due to invalid IL or missing references)
		//IL_0661: Expected O, but got Unknown
		//IL_0662: Unknown result type (might be due to invalid IL or missing references)
		//IL_066c: Expected O, but got Unknown
		//IL_066d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0677: Expected O, but got Unknown
		//IL_0678: Unknown result type (might be due to invalid IL or missing references)
		//IL_0682: Expected O, but got Unknown
		//IL_0683: Unknown result type (might be due to invalid IL or missing references)
		//IL_068d: Expected O, but got Unknown
		//IL_068e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0698: Expected O, but got Unknown
		//IL_0699: Unknown result type (might be due to invalid IL or missing references)
		//IL_06a3: Expected O, but got Unknown
		//IL_06a4: Unknown result type (might be due to invalid IL or missing references)
		//IL_06ae: Expected O, but got Unknown
		//IL_06af: Unknown result type (might be due to invalid IL or missing references)
		//IL_06b9: Expected O, but got Unknown
		//IL_06ba: Unknown result type (might be due to invalid IL or missing references)
		//IL_06c4: Expected O, but got Unknown
		//IL_06c5: Unknown result type (might be due to invalid IL or missing references)
		//IL_06cf: Expected O, but got Unknown
		//IL_06d0: Unknown result type (might be due to invalid IL or missing references)
		//IL_06da: Expected O, but got Unknown
		//IL_06db: Unknown result type (might be due to invalid IL or missing references)
		//IL_06e5: Expected O, but got Unknown
		//IL_06e6: Unknown result type (might be due to invalid IL or missing references)
		//IL_06f0: Expected O, but got Unknown
		//IL_06f1: Unknown result type (might be due to invalid IL or missing references)
		//IL_06fb: Expected O, but got Unknown
		//IL_06fc: Unknown result type (might be due to invalid IL or missing references)
		//IL_0706: Expected O, but got Unknown
		//IL_0707: Unknown result type (might be due to invalid IL or missing references)
		//IL_0711: Expected O, but got Unknown
		//IL_0712: Unknown result type (might be due to invalid IL or missing references)
		//IL_071c: Expected O, but got Unknown
		//IL_071d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0727: Expected O, but got Unknown
		//IL_0728: Unknown result type (might be due to invalid IL or missing references)
		//IL_0732: Expected O, but got Unknown
		//IL_0733: Unknown result type (might be due to invalid IL or missing references)
		//IL_073d: Expected O, but got Unknown
		//IL_073e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0748: Expected O, but got Unknown
		//IL_0749: Unknown result type (might be due to invalid IL or missing references)
		//IL_0753: Expected O, but got Unknown
		//IL_0754: Unknown result type (might be due to invalid IL or missing references)
		//IL_075e: Expected O, but got Unknown
		//IL_075f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0769: Expected O, but got Unknown
		//IL_076a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0774: Expected O, but got Unknown
		//IL_0775: Unknown result type (might be due to invalid IL or missing references)
		//IL_077f: Expected O, but got Unknown
		//IL_0780: Unknown result type (might be due to invalid IL or missing references)
		//IL_078a: Expected O, but got Unknown
		//IL_078b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0795: Expected O, but got Unknown
		//IL_0796: Unknown result type (might be due to invalid IL or missing references)
		//IL_07a0: Expected O, but got Unknown
		//IL_07a1: Unknown result type (might be due to invalid IL or missing references)
		//IL_07ab: Expected O, but got Unknown
		//IL_07ac: Unknown result type (might be due to invalid IL or missing references)
		//IL_07b6: Expected O, but got Unknown
		//IL_07b7: Unknown result type (might be due to invalid IL or missing references)
		//IL_07c1: Expected O, but got Unknown
		//IL_07c2: Unknown result type (might be due to invalid IL or missing references)
		//IL_07cc: Expected O, but got Unknown
		//IL_07cd: Unknown result type (might be due to invalid IL or missing references)
		//IL_07d7: Expected O, but got Unknown
		//IL_07d8: Unknown result type (might be due to invalid IL or missing references)
		//IL_07e2: Expected O, but got Unknown
		//IL_07e3: Unknown result type (might be due to invalid IL or missing references)
		//IL_07ed: Expected O, but got Unknown
		//IL_07ee: Unknown result type (might be due to invalid IL or missing references)
		//IL_07f8: Expected O, but got Unknown
		//IL_07f9: Unknown result type (might be due to invalid IL or missing references)
		//IL_0803: Expected O, but got Unknown
		//IL_0804: Unknown result type (might be due to invalid IL or missing references)
		//IL_080e: Expected O, but got Unknown
		//IL_080f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0819: Expected O, but got Unknown
		//IL_081a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0824: Expected O, but got Unknown
		//IL_0825: Unknown result type (might be due to invalid IL or missing references)
		//IL_082f: Expected O, but got Unknown
		//IL_0830: Unknown result type (might be due to invalid IL or missing references)
		//IL_083a: Expected O, but got Unknown
		//IL_083b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0845: Expected O, but got Unknown
		//IL_0846: Unknown result type (might be due to invalid IL or missing references)
		//IL_0850: Expected O, but got Unknown
		//IL_0851: Unknown result type (might be due to invalid IL or missing references)
		//IL_085b: Expected O, but got Unknown
		//IL_085c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0866: Expected O, but got Unknown
		//IL_0867: Unknown result type (might be due to invalid IL or missing references)
		//IL_0871: Expected O, but got Unknown
		//IL_0872: Unknown result type (might be due to invalid IL or missing references)
		//IL_087c: Expected O, but got Unknown
		//IL_087d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0887: Expected O, but got Unknown
		//IL_0888: Unknown result type (might be due to invalid IL or missing references)
		//IL_0892: Expected O, but got Unknown
		//IL_0893: Unknown result type (might be due to invalid IL or missing references)
		//IL_089d: Expected O, but got Unknown
		//IL_089e: Unknown result type (might be due to invalid IL or missing references)
		//IL_08a8: Expected O, but got Unknown
		//IL_08a9: Unknown result type (might be due to invalid IL or missing references)
		//IL_08b3: Expected O, but got Unknown
		//IL_08b4: Unknown result type (might be due to invalid IL or missing references)
		//IL_08be: Expected O, but got Unknown
		//IL_08bf: Unknown result type (might be due to invalid IL or missing references)
		//IL_08c9: Expected O, but got Unknown
		//IL_08ca: Unknown result type (might be due to invalid IL or missing references)
		//IL_08d4: Expected O, but got Unknown
		//IL_08d5: Unknown result type (might be due to invalid IL or missing references)
		//IL_08df: Expected O, but got Unknown
		//IL_08e0: Unknown result type (might be due to invalid IL or missing references)
		//IL_08ea: Expected O, but got Unknown
		//IL_08eb: Unknown result type (might be due to invalid IL or missing references)
		//IL_08f5: Expected O, but got Unknown
		//IL_08f6: Unknown result type (might be due to invalid IL or missing references)
		//IL_0900: Expected O, but got Unknown
		//IL_0901: Unknown result type (might be due to invalid IL or missing references)
		//IL_090b: Expected O, but got Unknown
		//IL_090c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0916: Expected O, but got Unknown
		//IL_0917: Unknown result type (might be due to invalid IL or missing references)
		//IL_0921: Expected O, but got Unknown
		//IL_0922: Unknown result type (might be due to invalid IL or missing references)
		//IL_092c: Expected O, but got Unknown
		//IL_092d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0937: Expected O, but got Unknown
		//IL_0938: Unknown result type (might be due to invalid IL or missing references)
		//IL_0942: Expected O, but got Unknown
		//IL_0943: Unknown result type (might be due to invalid IL or missing references)
		//IL_094d: Expected O, but got Unknown
		//IL_094e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0958: Expected O, but got Unknown
		//IL_0959: Unknown result type (might be due to invalid IL or missing references)
		//IL_0963: Expected O, but got Unknown
		//IL_0964: Unknown result type (might be due to invalid IL or missing references)
		//IL_096e: Expected O, but got Unknown
		//IL_096f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0979: Expected O, but got Unknown
		//IL_097a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0984: Expected O, but got Unknown
		//IL_0985: Unknown result type (might be due to invalid IL or missing references)
		//IL_098f: Expected O, but got Unknown
		//IL_0990: Unknown result type (might be due to invalid IL or missing references)
		//IL_099a: Expected O, but got Unknown
		//IL_099b: Unknown result type (might be due to invalid IL or missing references)
		//IL_09a5: Expected O, but got Unknown
		//IL_09a6: Unknown result type (might be due to invalid IL or missing references)
		//IL_09b0: Expected O, but got Unknown
		//IL_09b1: Unknown result type (might be due to invalid IL or missing references)
		//IL_09bb: Expected O, but got Unknown
		//IL_09bc: Unknown result type (might be due to invalid IL or missing references)
		//IL_09c6: Expected O, but got Unknown
		//IL_09c7: Unknown result type (might be due to invalid IL or missing references)
		//IL_09d1: Expected O, but got Unknown
		//IL_09d2: Unknown result type (might be due to invalid IL or missing references)
		//IL_09dc: Expected O, but got Unknown
		//IL_09dd: Unknown result type (might be due to invalid IL or missing references)
		//IL_09e7: Expected O, but got Unknown
		//IL_09e8: Unknown result type (might be due to invalid IL or missing references)
		//IL_09f2: Expected O, but got Unknown
		//IL_09f3: Unknown result type (might be due to invalid IL or missing references)
		//IL_09fd: Expected O, but got Unknown
		//IL_09fe: Unknown result type (might be due to invalid IL or missing references)
		//IL_0a08: Expected O, but got Unknown
		//IL_0a09: Unknown result type (might be due to invalid IL or missing references)
		//IL_0a13: Expected O, but got Unknown
		//IL_0a14: Unknown result type (might be due to invalid IL or missing references)
		//IL_0a1e: Expected O, but got Unknown
		//IL_0a1f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0a29: Expected O, but got Unknown
		//IL_0a2a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0a34: Expected O, but got Unknown
		//IL_0a35: Unknown result type (might be due to invalid IL or missing references)
		//IL_0a3f: Expected O, but got Unknown
		//IL_0a40: Unknown result type (might be due to invalid IL or missing references)
		//IL_0a4a: Expected O, but got Unknown
		//IL_0f4f: Unknown result type (might be due to invalid IL or missing references)
		//IL_1036: Unknown result type (might be due to invalid IL or missing references)
		//IL_1167: Unknown result type (might be due to invalid IL or missing references)
		//IL_1171: Expected O, but got Unknown
		//IL_125d: Unknown result type (might be due to invalid IL or missing references)
		//IL_12c3: Unknown result type (might be due to invalid IL or missing references)
		//IL_12cd: Expected O, but got Unknown
		//IL_1349: Unknown result type (might be due to invalid IL or missing references)
		//IL_1353: Expected O, but got Unknown
		//IL_13e8: Unknown result type (might be due to invalid IL or missing references)
		//IL_1485: Unknown result type (might be due to invalid IL or missing references)
		//IL_156c: Unknown result type (might be due to invalid IL or missing references)
		//IL_1757: Unknown result type (might be due to invalid IL or missing references)
		//IL_1761: Expected O, but got Unknown
		//IL_1800: Unknown result type (might be due to invalid IL or missing references)
		//IL_180a: Expected O, but got Unknown
		//IL_189a: Unknown result type (might be due to invalid IL or missing references)
		//IL_18a4: Expected O, but got Unknown
		//IL_192e: Unknown result type (might be due to invalid IL or missing references)
		//IL_1938: Expected O, but got Unknown
		//IL_19d3: Unknown result type (might be due to invalid IL or missing references)
		//IL_19dd: Expected O, but got Unknown
		//IL_1b02: Unknown result type (might be due to invalid IL or missing references)
		//IL_1b0c: Expected O, but got Unknown
		//IL_1b1c: Unknown result type (might be due to invalid IL or missing references)
		//IL_1b26: Expected O, but got Unknown
		//IL_1bd6: Unknown result type (might be due to invalid IL or missing references)
		//IL_1c3c: Unknown result type (might be due to invalid IL or missing references)
		//IL_1c46: Expected O, but got Unknown
		//IL_1cc2: Unknown result type (might be due to invalid IL or missing references)
		//IL_1ccc: Expected O, but got Unknown
		//IL_1d6a: Unknown result type (might be due to invalid IL or missing references)
		//IL_1d74: Expected O, but got Unknown
		//IL_1e03: Unknown result type (might be due to invalid IL or missing references)
		//IL_1e0d: Expected O, but got Unknown
		//IL_1e9c: Unknown result type (might be due to invalid IL or missing references)
		//IL_1ea6: Expected O, but got Unknown
		//IL_1f3e: Unknown result type (might be due to invalid IL or missing references)
		//IL_1fdb: Unknown result type (might be due to invalid IL or missing references)
		//IL_20c2: Unknown result type (might be due to invalid IL or missing references)
		//IL_224b: Unknown result type (might be due to invalid IL or missing references)
		//IL_2255: Expected O, but got Unknown
		//IL_22d9: Unknown result type (might be due to invalid IL or missing references)
		//IL_22e3: Expected O, but got Unknown
		//IL_237c: Unknown result type (might be due to invalid IL or missing references)
		//IL_2386: Expected O, but got Unknown
		//IL_242b: Unknown result type (might be due to invalid IL or missing references)
		//IL_2435: Expected O, but got Unknown
		//IL_24c5: Unknown result type (might be due to invalid IL or missing references)
		//IL_24cf: Expected O, but got Unknown
		//IL_255d: Unknown result type (might be due to invalid IL or missing references)
		//IL_25c3: Unknown result type (might be due to invalid IL or missing references)
		//IL_25cd: Expected O, but got Unknown
		//IL_2649: Unknown result type (might be due to invalid IL or missing references)
		//IL_2653: Expected O, but got Unknown
		//IL_26e2: Unknown result type (might be due to invalid IL or missing references)
		//IL_26ec: Expected O, but got Unknown
		//IL_2784: Unknown result type (might be due to invalid IL or missing references)
		//IL_2821: Unknown result type (might be due to invalid IL or missing references)
		//IL_2908: Unknown result type (might be due to invalid IL or missing references)
		//IL_2f90: Unknown result type (might be due to invalid IL or missing references)
		//IL_2f9a: Expected O, but got Unknown
		//IL_303f: Unknown result type (might be due to invalid IL or missing references)
		//IL_3049: Expected O, but got Unknown
		//IL_30ec: Unknown result type (might be due to invalid IL or missing references)
		//IL_30f6: Expected O, but got Unknown
		//IL_3186: Unknown result type (might be due to invalid IL or missing references)
		//IL_3190: Expected O, but got Unknown
		//IL_3233: Unknown result type (might be due to invalid IL or missing references)
		//IL_323d: Expected O, but got Unknown
		//IL_32cd: Unknown result type (might be due to invalid IL or missing references)
		//IL_32d7: Expected O, but got Unknown
		//IL_3370: Unknown result type (might be due to invalid IL or missing references)
		//IL_337a: Expected O, but got Unknown
		//IL_3411: Unknown result type (might be due to invalid IL or missing references)
		//IL_341b: Expected O, but got Unknown
		//IL_349f: Unknown result type (might be due to invalid IL or missing references)
		//IL_34a9: Expected O, but got Unknown
		//IL_3550: Unknown result type (might be due to invalid IL or missing references)
		//IL_355a: Expected O, but got Unknown
		//IL_3605: Unknown result type (might be due to invalid IL or missing references)
		//IL_366b: Unknown result type (might be due to invalid IL or missing references)
		//IL_3675: Expected O, but got Unknown
		//IL_36f1: Unknown result type (might be due to invalid IL or missing references)
		//IL_36fb: Expected O, but got Unknown
		//IL_3790: Unknown result type (might be due to invalid IL or missing references)
		//IL_383d: Unknown result type (might be due to invalid IL or missing references)
		//IL_3918: Unknown result type (might be due to invalid IL or missing references)
		//IL_3a66: Unknown result type (might be due to invalid IL or missing references)
		//IL_3a70: Expected O, but got Unknown
		//IL_3b0e: Unknown result type (might be due to invalid IL or missing references)
		//IL_3b18: Expected O, but got Unknown
		//IL_3bd1: Unknown result type (might be due to invalid IL or missing references)
		//IL_3bdb: Expected O, but got Unknown
		//IL_3c70: Unknown result type (might be due to invalid IL or missing references)
		//IL_3c7a: Expected O, but got Unknown
		//IL_3d17: Unknown result type (might be due to invalid IL or missing references)
		//IL_3d7d: Unknown result type (might be due to invalid IL or missing references)
		//IL_3d87: Expected O, but got Unknown
		//IL_3e03: Unknown result type (might be due to invalid IL or missing references)
		//IL_3e0d: Expected O, but got Unknown
		//IL_3ea2: Unknown result type (might be due to invalid IL or missing references)
		//IL_405e: Unknown result type (might be due to invalid IL or missing references)
		//IL_40c9: Unknown result type (might be due to invalid IL or missing references)
		//IL_40d3: Expected O, but got Unknown
		//IL_412f: Unknown result type (might be due to invalid IL or missing references)
		//IL_41d4: Unknown result type (might be due to invalid IL or missing references)
		//IL_437d: Unknown result type (might be due to invalid IL or missing references)
		//IL_4387: Expected O, but got Unknown
		//IL_4421: Unknown result type (might be due to invalid IL or missing references)
		//IL_4487: Unknown result type (might be due to invalid IL or missing references)
		//IL_4491: Expected O, but got Unknown
		//IL_450d: Unknown result type (might be due to invalid IL or missing references)
		//IL_4517: Expected O, but got Unknown
		//IL_45ac: Unknown result type (might be due to invalid IL or missing references)
		//IL_4649: Unknown result type (might be due to invalid IL or missing references)
		//IL_471a: Unknown result type (might be due to invalid IL or missing references)
		//IL_4877: Unknown result type (might be due to invalid IL or missing references)
		//IL_4881: Expected O, but got Unknown
		//IL_48fe: Unknown result type (might be due to invalid IL or missing references)
		//IL_4908: Expected O, but got Unknown
		//IL_4924: Unknown result type (might be due to invalid IL or missing references)
		//IL_492e: Expected O, but got Unknown
		//IL_49bb: Unknown result type (might be due to invalid IL or missing references)
		//IL_49c5: Expected O, but got Unknown
		//IL_4a19: Unknown result type (might be due to invalid IL or missing references)
		//IL_4a23: Expected O, but got Unknown
		//IL_4b98: Unknown result type (might be due to invalid IL or missing references)
		//IL_4bfe: Unknown result type (might be due to invalid IL or missing references)
		//IL_4c08: Expected O, but got Unknown
		//IL_4c84: Unknown result type (might be due to invalid IL or missing references)
		//IL_4c8e: Expected O, but got Unknown
		//IL_4d0d: Unknown result type (might be due to invalid IL or missing references)
		//IL_4d17: Expected O, but got Unknown
		//IL_4dac: Unknown result type (might be due to invalid IL or missing references)
		//IL_4e49: Unknown result type (might be due to invalid IL or missing references)
		//IL_4f1a: Unknown result type (might be due to invalid IL or missing references)
		//IL_506b: Unknown result type (might be due to invalid IL or missing references)
		//IL_5075: Expected O, but got Unknown
		//IL_519b: Unknown result type (might be due to invalid IL or missing references)
		//IL_51a5: Expected O, but got Unknown
		//IL_51dc: Unknown result type (might be due to invalid IL or missing references)
		//IL_5242: Unknown result type (might be due to invalid IL or missing references)
		//IL_524c: Expected O, but got Unknown
		//IL_52c8: Unknown result type (might be due to invalid IL or missing references)
		//IL_52d2: Expected O, but got Unknown
		//IL_5361: Unknown result type (might be due to invalid IL or missing references)
		//IL_536b: Expected O, but got Unknown
		//IL_5400: Unknown result type (might be due to invalid IL or missing references)
		//IL_549d: Unknown result type (might be due to invalid IL or missing references)
		//IL_556e: Unknown result type (might be due to invalid IL or missing references)
		//IL_5869: Unknown result type (might be due to invalid IL or missing references)
		//IL_5873: Expected O, but got Unknown
		//IL_5ea3: Unknown result type (might be due to invalid IL or missing references)
		//IL_5ead: Expected O, but got Unknown
		//IL_5f8c: Unknown result type (might be due to invalid IL or missing references)
		//IL_5f96: Expected O, but got Unknown
		//IL_5fa3: Unknown result type (might be due to invalid IL or missing references)
		//IL_5fad: Expected O, but got Unknown
		//IL_5fba: Unknown result type (might be due to invalid IL or missing references)
		//IL_5fc4: Expected O, but got Unknown
		//IL_6136: Unknown result type (might be due to invalid IL or missing references)
		//IL_619c: Unknown result type (might be due to invalid IL or missing references)
		//IL_61a6: Expected O, but got Unknown
		//IL_623b: Unknown result type (might be due to invalid IL or missing references)
		//IL_62d8: Unknown result type (might be due to invalid IL or missing references)
		//IL_637e: Unknown result type (might be due to invalid IL or missing references)
		//IL_6511: Unknown result type (might be due to invalid IL or missing references)
		//IL_651b: Expected O, but got Unknown
		//IL_65b5: Unknown result type (might be due to invalid IL or missing references)
		//IL_661b: Unknown result type (might be due to invalid IL or missing references)
		//IL_6625: Expected O, but got Unknown
		//IL_66a1: Unknown result type (might be due to invalid IL or missing references)
		//IL_66ab: Expected O, but got Unknown
		//IL_6740: Unknown result type (might be due to invalid IL or missing references)
		//IL_689e: Unknown result type (might be due to invalid IL or missing references)
		//IL_69b9: Unknown result type (might be due to invalid IL or missing references)
		//IL_69c3: Expected O, but got Unknown
		//IL_6a5a: Unknown result type (might be due to invalid IL or missing references)
		//IL_6ac0: Unknown result type (might be due to invalid IL or missing references)
		//IL_6aca: Expected O, but got Unknown
		//IL_6b5c: Unknown result type (might be due to invalid IL or missing references)
		//IL_6b66: Expected O, but got Unknown
		//IL_6c55: Unknown result type (might be due to invalid IL or missing references)
		//IL_6db3: Unknown result type (might be due to invalid IL or missing references)
		//IL_7423: Unknown result type (might be due to invalid IL or missing references)
		//IL_742d: Expected O, but got Unknown
		//IL_74c6: Unknown result type (might be due to invalid IL or missing references)
		//IL_74d0: Expected O, but got Unknown
		//IL_7567: Unknown result type (might be due to invalid IL or missing references)
		//IL_7571: Expected O, but got Unknown
		//IL_75f5: Unknown result type (might be due to invalid IL or missing references)
		//IL_75ff: Expected O, but got Unknown
		//IL_76a6: Unknown result type (might be due to invalid IL or missing references)
		//IL_76b0: Expected O, but got Unknown
		//IL_774c: Unknown result type (might be due to invalid IL or missing references)
		//IL_7756: Expected O, but got Unknown
		//IL_77f2: Unknown result type (might be due to invalid IL or missing references)
		//IL_77fc: Expected O, but got Unknown
		//IL_78a1: Unknown result type (might be due to invalid IL or missing references)
		//IL_78ab: Expected O, but got Unknown
		//IL_795d: Unknown result type (might be due to invalid IL or missing references)
		//IL_79c2: Unknown result type (might be due to invalid IL or missing references)
		//IL_79cc: Expected O, but got Unknown
		//IL_7a6f: Unknown result type (might be due to invalid IL or missing references)
		//IL_7a79: Expected O, but got Unknown
		//IL_7b0a: Unknown result type (might be due to invalid IL or missing references)
		//IL_7b14: Expected O, but got Unknown
		//IL_7b90: Unknown result type (might be due to invalid IL or missing references)
		//IL_7b9a: Expected O, but got Unknown
		//IL_7c2f: Unknown result type (might be due to invalid IL or missing references)
		//IL_7ccc: Unknown result type (might be due to invalid IL or missing references)
		//IL_7d9e: Unknown result type (might be due to invalid IL or missing references)
		//IL_7f33: Unknown result type (might be due to invalid IL or missing references)
		//IL_7f3d: Expected O, but got Unknown
		//IL_7fb0: Unknown result type (might be due to invalid IL or missing references)
		//IL_7fba: Expected O, but got Unknown
		//IL_804a: Unknown result type (might be due to invalid IL or missing references)
		//IL_8054: Expected O, but got Unknown
		//IL_80d8: Unknown result type (might be due to invalid IL or missing references)
		//IL_80e2: Expected O, but got Unknown
		//IL_817b: Unknown result type (might be due to invalid IL or missing references)
		//IL_8185: Expected O, but got Unknown
		//IL_822a: Unknown result type (might be due to invalid IL or missing references)
		//IL_8234: Expected O, but got Unknown
		//IL_82df: Unknown result type (might be due to invalid IL or missing references)
		//IL_8345: Unknown result type (might be due to invalid IL or missing references)
		//IL_834f: Expected O, but got Unknown
		//IL_83cb: Unknown result type (might be due to invalid IL or missing references)
		//IL_83d5: Expected O, but got Unknown
		//IL_846d: Unknown result type (might be due to invalid IL or missing references)
		//IL_85cb: Unknown result type (might be due to invalid IL or missing references)
		//IL_8732: Unknown result type (might be due to invalid IL or missing references)
		//IL_873c: Expected O, but got Unknown
		//IL_87cc: Unknown result type (might be due to invalid IL or missing references)
		//IL_87d6: Expected O, but got Unknown
		//IL_8849: Unknown result type (might be due to invalid IL or missing references)
		//IL_8853: Expected O, but got Unknown
		//IL_88ed: Unknown result type (might be due to invalid IL or missing references)
		//IL_88f7: Expected O, but got Unknown
		//IL_89a7: Unknown result type (might be due to invalid IL or missing references)
		//IL_8a0d: Unknown result type (might be due to invalid IL or missing references)
		//IL_8a17: Expected O, but got Unknown
		//IL_8a93: Unknown result type (might be due to invalid IL or missing references)
		//IL_8a9d: Expected O, but got Unknown
		//IL_8b2c: Unknown result type (might be due to invalid IL or missing references)
		//IL_8b36: Expected O, but got Unknown
		//IL_8bce: Unknown result type (might be due to invalid IL or missing references)
		//IL_8d2c: Unknown result type (might be due to invalid IL or missing references)
		//IL_8e47: Unknown result type (might be due to invalid IL or missing references)
		//IL_8e51: Expected O, but got Unknown
		//IL_8ee8: Unknown result type (might be due to invalid IL or missing references)
		//IL_8f4e: Unknown result type (might be due to invalid IL or missing references)
		//IL_8f58: Expected O, but got Unknown
		//IL_8fea: Unknown result type (might be due to invalid IL or missing references)
		//IL_8ff4: Expected O, but got Unknown
		//IL_90e3: Unknown result type (might be due to invalid IL or missing references)
		//IL_9180: Unknown result type (might be due to invalid IL or missing references)
		//IL_9252: Unknown result type (might be due to invalid IL or missing references)
		//IL_93af: Unknown result type (might be due to invalid IL or missing references)
		//IL_93b9: Expected O, but got Unknown
		//IL_9436: Unknown result type (might be due to invalid IL or missing references)
		//IL_9440: Expected O, but got Unknown
		//IL_945c: Unknown result type (might be due to invalid IL or missing references)
		//IL_9466: Expected O, but got Unknown
		//IL_94f3: Unknown result type (might be due to invalid IL or missing references)
		//IL_94fd: Expected O, but got Unknown
		//IL_9567: Unknown result type (might be due to invalid IL or missing references)
		//IL_9571: Expected O, but got Unknown
		//IL_9756: Unknown result type (might be due to invalid IL or missing references)
		//IL_97bc: Unknown result type (might be due to invalid IL or missing references)
		//IL_97c6: Expected O, but got Unknown
		//IL_9842: Unknown result type (might be due to invalid IL or missing references)
		//IL_984c: Expected O, but got Unknown
		//IL_98cb: Unknown result type (might be due to invalid IL or missing references)
		//IL_98d5: Expected O, but got Unknown
		//IL_996a: Unknown result type (might be due to invalid IL or missing references)
		//IL_9c84: Unknown result type (might be due to invalid IL or missing references)
		//IL_9c8e: Expected O, but got Unknown
		//IL_9cfa: Unknown result type (might be due to invalid IL or missing references)
		//IL_9d04: Expected O, but got Unknown
		//IL_9d80: Unknown result type (might be due to invalid IL or missing references)
		//IL_9d8a: Expected O, but got Unknown
		//IL_9e09: Unknown result type (might be due to invalid IL or missing references)
		//IL_9e13: Expected O, but got Unknown
		//IL_9e92: Unknown result type (might be due to invalid IL or missing references)
		//IL_9e9c: Expected O, but got Unknown
		//IL_9f1c: Unknown result type (might be due to invalid IL or missing references)
		//IL_9f26: Expected O, but got Unknown
		//IL_9fa5: Unknown result type (might be due to invalid IL or missing references)
		//IL_9faf: Expected O, but got Unknown
		//IL_a01e: Unknown result type (might be due to invalid IL or missing references)
		//IL_a028: Expected O, but got Unknown
		//IL_a098: Unknown result type (might be due to invalid IL or missing references)
		//IL_a0a2: Expected O, but got Unknown
		//IL_a103: Unknown result type (might be due to invalid IL or missing references)
		//IL_a10d: Expected O, but got Unknown
		//IL_a134: Unknown result type (might be due to invalid IL or missing references)
		//IL_a1d0: Unknown result type (might be due to invalid IL or missing references)
		//IL_a1da: Expected O, but got Unknown
		//IL_a2b2: Unknown result type (might be due to invalid IL or missing references)
		//IL_a2bc: Expected O, but got Unknown
		//IL_a388: Unknown result type (might be due to invalid IL or missing references)
		//IL_a392: Expected O, but got Unknown
		//IL_a45e: Unknown result type (might be due to invalid IL or missing references)
		//IL_a468: Expected O, but got Unknown
		//IL_a54b: Unknown result type (might be due to invalid IL or missing references)
		//IL_a555: Expected O, but got Unknown
		//IL_a62d: Unknown result type (might be due to invalid IL or missing references)
		//IL_a637: Expected O, but got Unknown
		//IL_a71a: Unknown result type (might be due to invalid IL or missing references)
		//IL_a724: Expected O, but got Unknown
		//IL_a7fd: Unknown result type (might be due to invalid IL or missing references)
		//IL_a807: Expected O, but got Unknown
		//IL_a8eb: Unknown result type (might be due to invalid IL or missing references)
		//IL_a8f5: Expected O, but got Unknown
		//IL_a9d9: Unknown result type (might be due to invalid IL or missing references)
		//IL_a9e3: Expected O, but got Unknown
		//IL_aabc: Unknown result type (might be due to invalid IL or missing references)
		//IL_aac6: Expected O, but got Unknown
		//IL_ab93: Unknown result type (might be due to invalid IL or missing references)
		//IL_ab9d: Expected O, but got Unknown
		//IL_ace6: Unknown result type (might be due to invalid IL or missing references)
		//IL_acf0: Expected O, but got Unknown
		//IL_adc9: Unknown result type (might be due to invalid IL or missing references)
		//IL_add3: Expected O, but got Unknown
		//IL_aea0: Unknown result type (might be due to invalid IL or missing references)
		//IL_aeaa: Expected O, but got Unknown
		//IL_b023: Unknown result type (might be due to invalid IL or missing references)
		//IL_b02d: Expected O, but got Unknown
		//IL_b0e4: Unknown result type (might be due to invalid IL or missing references)
		//IL_b0ee: Expected O, but got Unknown
		//IL_b1bb: Unknown result type (might be due to invalid IL or missing references)
		//IL_b1c5: Expected O, but got Unknown
		//IL_b292: Unknown result type (might be due to invalid IL or missing references)
		//IL_b29c: Expected O, but got Unknown
		//IL_b3e2: Unknown result type (might be due to invalid IL or missing references)
		//IL_b3ec: Expected O, but got Unknown
		//IL_b4d0: Unknown result type (might be due to invalid IL or missing references)
		//IL_b4da: Expected O, but got Unknown
		//IL_b5ca: Unknown result type (might be due to invalid IL or missing references)
		//IL_b5d4: Expected O, but got Unknown
		//IL_b6a1: Unknown result type (might be due to invalid IL or missing references)
		//IL_b6ab: Expected O, but got Unknown
		//IL_b78f: Unknown result type (might be due to invalid IL or missing references)
		//IL_b799: Expected O, but got Unknown
		//IL_b865: Unknown result type (might be due to invalid IL or missing references)
		//IL_b86f: Expected O, but got Unknown
		//IL_b952: Unknown result type (might be due to invalid IL or missing references)
		//IL_b95c: Expected O, but got Unknown
		//IL_ba40: Unknown result type (might be due to invalid IL or missing references)
		//IL_ba4a: Expected O, but got Unknown
		//IL_bb2e: Unknown result type (might be due to invalid IL or missing references)
		//IL_bb38: Expected O, but got Unknown
		//IL_bc05: Unknown result type (might be due to invalid IL or missing references)
		//IL_bc0f: Expected O, but got Unknown
		//IL_bcf3: Unknown result type (might be due to invalid IL or missing references)
		//IL_bcfd: Expected O, but got Unknown
		//IL_bde1: Unknown result type (might be due to invalid IL or missing references)
		//IL_bdeb: Expected O, but got Unknown
		//IL_becf: Unknown result type (might be due to invalid IL or missing references)
		//IL_bed9: Expected O, but got Unknown
		//IL_bf90: Unknown result type (might be due to invalid IL or missing references)
		//IL_bf9a: Expected O, but got Unknown
		//IL_c091: Unknown result type (might be due to invalid IL or missing references)
		//IL_c09b: Expected O, but got Unknown
		ComponentResourceManager componentResourceManager = new ComponentResourceManager(typeof(FormWizard));
		tabPage5_confirm = new TabPage();
		panel_P5_3 = new Panel();
		panel_P5_2 = new Panel();
		panel15 = new Panel();
		labelP5Info = new Label();
		pictureBox5 = new PictureBox();
		labelP5Head = new Label();
		labelP5_comment = new Label();
		panel_P5_1 = new Panel();
		tabPage4_address = new TabPage();
		panel_P4_3 = new Panel();
		panel_P4_2 = new Panel();
		label7 = new Label();
		labelP4_Path = new Label();
		cmbP4FolderPath = new ComboBox();
		labelP4ConnectCheck = new Label();
		buttonP4HeadLine = new Button();
		linkLabelP4Connect = new LinkLabel();
		textP4Destination = new TextBox();
		pictureBox4 = new PictureBox();
		labelP4Head = new Label();
		label60 = new Label();
		labelP4_Destination = new Label();
		labelP4_Machine = new Label();
		labelP4_comment = new Label();
		panel_P4_1 = new Panel();
		tabPage3_shareFolder = new TabPage();
		panel_P3_3 = new Panel();
		panel_P3_2 = new Panel();
		labelP3_PasswordConfirm = new Label();
		textBoxP3PassConfirm = new TextBox();
		textBoxP3Pass = new TextBox();
		labelP3_Password = new Label();
		cmbP3UserName = new ComboBox();
		pictureBox3 = new PictureBox();
		labelP3Head = new Label();
		labelP3_UserName = new Label();
		labelP3_comment = new Label();
		panel_P3_1 = new Panel();
		tabPage2_setupSelect = new TabPage();
		panel_P2_3 = new Panel();
		panel_P2_2 = new Panel();
		labelP2_selectFolder = new Label();
		labelP2_selectNonSharedFolder = new Label();
		cmbP2Folder = new ComboBox();
		selectFolderRadioButton = new RadioButton();
		createNewFolderRadioButton = new RadioButton();
		selectNonSharedFolderRadioButton = new RadioButton();
		labelP2_Folder = new Label();
		buttonSelectNonSharedFolder = new Button();
		textBoxNonSharedFolderPath = new TextBox();
		labelP2_NonSharedFolderPath = new Label();
		textBoxSharedName = new TextBox();
		labelP2_SharedName = new Label();
		buttonSelectFolder = new Button();
		textBoxFolderPath = new TextBox();
		labelP2_FolderPath = new Label();
		textBoxFolderName = new TextBox();
		labelP2_FolderName = new Label();
		pictureBox2 = new PictureBox();
		labelP2Head = new Label();
		labelP2_comment = new Label();
		panel_P2_1 = new Panel();
		tabPage1_introduction = new TabPage();
		panel_P1_3 = new Panel();
		panel_P1_2 = new Panel();
		radioButtonTroubleShoot = new RadioButton();
		radioButtonCreateFolder = new RadioButton();
		attentionGroup = new GroupBox();
		attentionRichTextBox = new RichTextBox();
		pictureBox1 = new PictureBox();
		labelP1Head = new Label();
		labelP1_comment = new Label();
		panel_P1_1 = new Panel();
		tabControl1_Main = new TabControl();
		tabPage6_exec = new TabPage();
		panel_P6_3 = new Panel();
		panel_P6_2 = new Panel();
		progressBar1 = new ProgressBar();
		labelP6Execute = new Label();
		pictureBox6 = new PictureBox();
		labelP6Head = new Label();
		labelP6_comment = new Label();
		panel_P6_1 = new Panel();
		tabPage7_finish = new TabPage();
		panel_P7_3 = new Panel();
		panel_P7_2 = new Panel();
		linkLabelP7HelpSend = new LinkLabel();
		linkLabelP7HelpRegist = new LinkLabel();
		panel22 = new Panel();
		labelP7Report = new Label();
		labelP7finsh = new LinkLabel();
		pictureBox7 = new PictureBox();
		labelP7Head = new Label();
		labelP7_ReportTitle = new Label();
		labelP7_comment = new Label();
		panel_P7_1 = new Panel();
		tabTRP2_device = new TabPage();
		panel_TRP2_3 = new Panel();
		panel_TRP2_2 = new Panel();
		label_TRP2ConnectCheck = new Label();
		linkLabelTRP2 = new LinkLabel();
		pictureBox8 = new PictureBox();
		label_TRP2Head = new Label();
		label_TRP2_Machine = new Label();
		label_TRP2_comment = new Label();
		panel_TRP2_1 = new Panel();
		tabTRP3_user = new TabPage();
		panel_TRP3_3 = new Panel();
		panel_TRP3_2 = new Panel();
		buttonTRP3Resume = new Button();
		label_TRP3_comment = new Label();
		buttonTRP3Break = new Button();
		labelTRP3progressText = new Label();
		buttonTRP3ToBottom = new Button();
		buttonTRP3Next = new Button();
		buttonTRP3Previous = new Button();
		buttonTRP3ToTop = new Button();
		label_TRP3DisplayedPage = new Label();
		label_TRP3Page = new Label();
		comboBoxTRP3SelectWay = new ComboBox();
		buttonTRP3Search = new Button();
		textBoxTRP3Search = new TextBox();
		listViewAddressList = new ListView();
		labelTRP3MFP_Selected = new Label();
		label_TRP3_SelectedDevice = new Label();
		label17 = new Label();
		pictureBox9 = new PictureBox();
		label_TRP3Head = new Label();
		panel_TRP3_1 = new Panel();
		tabTRP4_analyze = new TabPage();
		panel_TRP4_3 = new Panel();
		panel_TRP4_2 = new Panel();
		progressBarTRP4 = new ProgressBar();
		label_TRP4_progress = new Label();
		pictureBox10 = new PictureBox();
		label_TRP4Head = new Label();
		label_TRP4_comment = new Label();
		panel_TRP4_1 = new Panel();
		tabTRP5_result = new TabPage();
		panel_TRP5_3 = new Panel();
		panel_TRP5_2 = new Panel();
		label_TRP5_comment = new Label();
		pictureBox13 = new PictureBox();
		label_TRP5Head = new Label();
		panel40 = new Panel();
		richTextBoxTRP5 = new RichTextBox();
		panel_TRP5_1 = new Panel();
		tabTRP6_setupSelect = new TabPage();
		panel_TRP6_3 = new Panel();
		panel_TRP6_2 = new Panel();
		label_TRP6_SelectFolder = new Label();
		label_TRP6_SelectNonSharedFolder = new Label();
		cmbTRP6Folder = new ComboBox();
		radioButtonTRP6selectNonSharedFolder = new RadioButton();
		radioButtonTRP6selectExistFolder = new RadioButton();
		radioButtonTRP6createNewFolder = new RadioButton();
		label_TRP6_Folder = new Label();
		buttonTRP6SelectFolder = new Button();
		textBoxTRP6FolderPath = new TextBox();
		label_TRP6_FolderPath = new Label();
		textBoxTRP6FolderName = new TextBox();
		label_TRP6_FolderName = new Label();
		label_TRP6_NonSharedFolderPath = new Label();
		buttonTRP6SelectNonSharedFolder = new Button();
		textBoxTRP6NonSharedFolderPath = new TextBox();
		pictureBox16 = new PictureBox();
		textBoxTRP6SharedName = new TextBox();
		label_TRP6_SharedName = new Label();
		label_TRP6Head = new Label();
		label_TRP6_comment = new Label();
		panel_TRP6_1 = new Panel();
		tabTRP7_shareFolder = new TabPage();
		panel_TRP7_3 = new Panel();
		panel_TRP7_2 = new Panel();
		cmbTRP7PcUser = new ComboBox();
		label_TRP7_UserName = new Label();
		label_TRP7_PasswordConfirm = new Label();
		textBoxTRP7PassConfirm = new TextBox();
		textBoxTRP7Pass = new TextBox();
		label_TRP7_Password = new Label();
		pictureBox12 = new PictureBox();
		label_TRP7Head = new Label();
		label_TRP7_comment = new Label();
		panel_TRP7_1 = new Panel();
		tabTRP8_address = new TabPage();
		panel_TRP8_3 = new Panel();
		panel_TRP8_2 = new Panel();
		label_TRP8_Path = new Label();
		cmbTRP8FolderPath = new ComboBox();
		buttonTRP8HeadLine = new Button();
		textTRP8Destination = new TextBox();
		pictureBox17 = new PictureBox();
		label_TRP8Head = new Label();
		label_TRP8_Destination = new Label();
		label_TRP8_comment = new Label();
		panel_TRP8_1 = new Panel();
		tabTRP9_confirm = new TabPage();
		panel_TRP9_3 = new Panel();
		panel_TRP9_2 = new Panel();
		label_TRP9_comment = new Label();
		pictureBox14 = new PictureBox();
		label_TRP9Head = new Label();
		panel45 = new Panel();
		richTextBoxTRP9 = new RichTextBox();
		panel_TRP9_1 = new Panel();
		tabTRP10_finish = new TabPage();
		panel_TRP10_3 = new Panel();
		panel_TRP10_2 = new Panel();
		linkLabelTRP10HelpSend = new LinkLabel();
		linkLabelTRP10HelpRegist = new LinkLabel();
		panelTRP10 = new Panel();
		label_TRP10Report = new Label();
		labelTRP10finish = new LinkLabel();
		richTextBoxTRP10 = new RichTextBox();
		pictureBox11 = new PictureBox();
		label_TRP10Head = new Label();
		label_TRP10_ReportTitle = new Label();
		label_TRP10_comment = new Label();
		panel_TRP10_1 = new Panel();
		menuStrip1 = new MenuStrip();
		ToolStripMenuItemDetail_D = new ToolStripMenuItem();
		ToolStripMenuItemChange = new ToolStripMenuItem();
		ToolStripMenuItemSecurity_S = new ToolStripMenuItem();
		ToolStripMenuItemEnvironments_E = new ToolStripMenuItem();
		ToolStripMenuItemMachine = new ToolStripMenuItem();
		ToolStripMenuItemComputer = new ToolStripMenuItem();
		ToolStripMenuItemVersion_H = new ToolStripMenuItem();
		label165 = new Label();
		label164 = new Label();
		label163 = new Label();
		label162 = new Label();
		label161 = new Label();
		label149 = new Label();
		label148 = new Label();
		label147 = new Label();
		label145 = new Label();
		pictureBox15 = new PictureBox();
		btnP1TRNext = new NextButtonTroubleShoot();
		btnP1Cancel = new CancelButton();
		btnP1Next = new NextButton();
		btnP2Back = new BackButton();
		btnP2Cancel = new CancelButton();
		btnP2Next = new NextButton();
		btnP3Cancel = new CancelButton();
		btnP3Back = new BackButton();
		btnP3Next = new NextButton();
		btnP4Cancel = new CancelButton();
		btnP4Back = new BackButton();
		btnP4Next = new NextButton();
		machineSelectControl = new MachineSelectControl("ja");
		btnP5Cancel = new CancelButton();
		btnP5Back = new BackButton();
		btnP5Execute = new NextButton();
		btnP6Excecute = new NextButton();
		btnP7Top = new NextButton();
		btnP7End = new EndButton();
		btnTRP2Back = new BackButtonTroubleShoot();
		btnTRP2Next = new NextButtonTroubleShoot();
		machineSelectControlTRP2 = new MachineSelectControl("ja");
		btnTRP3Back = new BackButtonTroubleShoot();
		btnTRP3Next = new NextButtonTroubleShoot();
		btnTRP5Back = new BackButtonTroubleShoot();
		btnTRP5Next = new NextButtonTroubleShoot();
		btnTRP6Back = new BackButtonTroubleShoot();
		btnTRP6Next = new NextButtonTroubleShoot();
		btnTRP7Back = new BackButtonTroubleShoot();
		btnTRP7Next = new NextButtonTroubleShoot();
		btnTRP8Back = new BackButtonTroubleShoot();
		btnTRP8Next = new NextButtonTroubleShoot();
		btnTRP9Back = new BackButtonTroubleShoot();
		btnTRP9Execute = new NextButtonTroubleShoot();
		btnTRP10Top = new NextButtonTroubleShoot();
		btnTRP10End = new EndButton();
		((Control)tabPage5_confirm).SuspendLayout();
		((Control)panel_P5_3).SuspendLayout();
		((Control)panel_P5_2).SuspendLayout();
		((Control)panel15).SuspendLayout();
		((ISupportInitialize)pictureBox5).BeginInit();
		((Control)tabPage4_address).SuspendLayout();
		((Control)panel_P4_3).SuspendLayout();
		((Control)panel_P4_2).SuspendLayout();
		((ISupportInitialize)pictureBox4).BeginInit();
		((Control)tabPage3_shareFolder).SuspendLayout();
		((Control)panel_P3_3).SuspendLayout();
		((Control)panel_P3_2).SuspendLayout();
		((ISupportInitialize)pictureBox3).BeginInit();
		((Control)tabPage2_setupSelect).SuspendLayout();
		((Control)panel_P2_3).SuspendLayout();
		((Control)panel_P2_2).SuspendLayout();
		((ISupportInitialize)pictureBox2).BeginInit();
		((Control)tabPage1_introduction).SuspendLayout();
		((Control)panel_P1_3).SuspendLayout();
		((Control)panel_P1_2).SuspendLayout();
		((Control)attentionGroup).SuspendLayout();
		((ISupportInitialize)pictureBox1).BeginInit();
		((Control)tabControl1_Main).SuspendLayout();
		((Control)tabPage6_exec).SuspendLayout();
		((Control)panel_P6_2).SuspendLayout();
		((ISupportInitialize)pictureBox6).BeginInit();
		((Control)tabPage7_finish).SuspendLayout();
		((Control)panel_P7_3).SuspendLayout();
		((Control)panel_P7_2).SuspendLayout();
		((Control)panel22).SuspendLayout();
		((ISupportInitialize)pictureBox7).BeginInit();
		((Control)tabTRP2_device).SuspendLayout();
		((Control)panel_TRP2_3).SuspendLayout();
		((Control)panel_TRP2_2).SuspendLayout();
		((ISupportInitialize)pictureBox8).BeginInit();
		((Control)tabTRP3_user).SuspendLayout();
		((Control)panel_TRP3_3).SuspendLayout();
		((Control)panel_TRP3_2).SuspendLayout();
		((ISupportInitialize)pictureBox9).BeginInit();
		((Control)tabTRP4_analyze).SuspendLayout();
		((Control)panel_TRP4_2).SuspendLayout();
		((ISupportInitialize)pictureBox10).BeginInit();
		((Control)tabTRP5_result).SuspendLayout();
		((Control)panel_TRP5_3).SuspendLayout();
		((Control)panel_TRP5_2).SuspendLayout();
		((ISupportInitialize)pictureBox13).BeginInit();
		((Control)panel40).SuspendLayout();
		((Control)tabTRP6_setupSelect).SuspendLayout();
		((Control)panel_TRP6_3).SuspendLayout();
		((Control)panel_TRP6_2).SuspendLayout();
		((ISupportInitialize)pictureBox16).BeginInit();
		((Control)tabTRP7_shareFolder).SuspendLayout();
		((Control)panel_TRP7_3).SuspendLayout();
		((Control)panel_TRP7_2).SuspendLayout();
		((ISupportInitialize)pictureBox12).BeginInit();
		((Control)tabTRP8_address).SuspendLayout();
		((Control)panel_TRP8_3).SuspendLayout();
		((Control)panel_TRP8_2).SuspendLayout();
		((ISupportInitialize)pictureBox17).BeginInit();
		((Control)tabTRP9_confirm).SuspendLayout();
		((Control)panel_TRP9_3).SuspendLayout();
		((Control)panel_TRP9_2).SuspendLayout();
		((ISupportInitialize)pictureBox14).BeginInit();
		((Control)panel45).SuspendLayout();
		((Control)tabTRP10_finish).SuspendLayout();
		((Control)panel_TRP10_3).SuspendLayout();
		((Control)panel_TRP10_2).SuspendLayout();
		((Control)panelTRP10).SuspendLayout();
		((ISupportInitialize)pictureBox11).BeginInit();
		((Control)menuStrip1).SuspendLayout();
		((ISupportInitialize)pictureBox15).BeginInit();
		((Control)this).SuspendLayout();
		((Control)tabPage5_confirm).Controls.Add((Control)(object)panel_P5_3);
		((Control)tabPage5_confirm).Controls.Add((Control)(object)panel_P5_2);
		((Control)tabPage5_confirm).Controls.Add((Control)(object)panel_P5_1);
		tabPage5_confirm.Location = new Point(4, 22);
		((Control)tabPage5_confirm).Margin = new Padding(0);
		((Control)tabPage5_confirm).Name = "tabPage5_confirm";
		((Control)tabPage5_confirm).Size = new Size(760, 497);
		tabPage5_confirm.TabIndex = 4;
		((Control)tabPage5_confirm).Text = "tabP5_confirm";
		tabPage5_confirm.UseVisualStyleBackColor = true;
		((Control)panel_P5_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_P5_3.BorderStyle = (BorderStyle)1;
		((Control)panel_P5_3).Controls.Add((Control)(object)btnP5Cancel);
		((Control)panel_P5_3).Controls.Add((Control)(object)btnP5Back);
		((Control)panel_P5_3).Controls.Add((Control)(object)btnP5Execute);
		((Control)panel_P5_3).Dock = (DockStyle)2;
		((Control)panel_P5_3).Location = new Point(0, 446);
		((Control)panel_P5_3).Margin = new Padding(0);
		((Control)panel_P5_3).Name = "panel_P5_3";
		((Control)panel_P5_3).Size = new Size(760, 51);
		((Control)panel_P5_3).TabIndex = 18;
		((Control)panel_P5_2).BackColor = Color.White;
		panel_P5_2.BorderStyle = (BorderStyle)1;
		((Control)panel_P5_2).Controls.Add((Control)(object)panel15);
		((Control)panel_P5_2).Controls.Add((Control)(object)pictureBox5);
		((Control)panel_P5_2).Controls.Add((Control)(object)labelP5Head);
		((Control)panel_P5_2).Controls.Add((Control)(object)labelP5_comment);
		((Control)panel_P5_2).Location = new Point(184, 3);
		((Control)panel_P5_2).Name = "panel_P5_2";
		((Control)panel_P5_2).Size = new Size(575, 470);
		((Control)panel_P5_2).TabIndex = 17;
		panel15.BorderStyle = (BorderStyle)2;
		((Control)panel15).Controls.Add((Control)(object)labelP5Info);
		((Control)panel15).Font = new Font("MS UI Gothic", 9f);
		((Control)panel15).Location = new Point(44, 117);
		((Control)panel15).Name = "panel15";
		((Control)panel15).Size = new Size(503, 316);
		((Control)panel15).TabIndex = 3;
		((Control)labelP5Info).AutoSize = true;
		labelP5Info.ImeMode = (ImeMode)0;
		((Control)labelP5Info).Location = new Point(5, 13);
		((Control)labelP5Info).Name = "labelP5Info";
		((Control)labelP5Info).Size = new Size(61, 12);
		((Control)labelP5Info).TabIndex = 1;
		((Control)labelP5Info).Text = "labelP5Info";
		pictureBox5.Image = (Image)(object)Resources.Line;
		pictureBox5.ImeMode = (ImeMode)0;
		((Control)pictureBox5).Location = new Point(39, 48);
		((Control)pictureBox5).Margin = new Padding(1);
		((Control)pictureBox5).Name = "pictureBox5";
		((Control)pictureBox5).Size = new Size(539, 10);
		pictureBox5.TabIndex = 1;
		pictureBox5.TabStop = false;
		((Control)labelP5Head).AutoSize = true;
		((Control)labelP5Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		labelP5Head.ImeMode = (ImeMode)0;
		((Control)labelP5Head).Location = new Point(40, 21);
		((Control)labelP5Head).Name = "labelP5Head";
		((Control)labelP5Head).Size = new Size(106, 16);
		((Control)labelP5Head).TabIndex = 0;
		((Control)labelP5Head).Text = "Confirmation";
		((Control)labelP5_comment).AutoSize = true;
		((Control)labelP5_comment).Font = new Font("MS UI Gothic", 9f);
		labelP5_comment.ImeMode = (ImeMode)0;
		((Control)labelP5_comment).Location = new Point(45, 77);
		((Control)labelP5_comment).Name = "labelP5_comment";
		((Control)labelP5_comment).Size = new Size(119, 12);
		((Control)labelP5_comment).TabIndex = 2;
		((Control)labelP5_comment).Text = "Confirmation message";
		((Control)panel_P5_1).BackColor = SystemColors.Control;
		panel_P5_1.BorderStyle = (BorderStyle)1;
		((Control)panel_P5_1).Location = new Point(0, 3);
		((Control)panel_P5_1).Margin = new Padding(0);
		((Control)panel_P5_1).Name = "panel_P5_1";
		((Control)panel_P5_1).Size = new Size(181, 470);
		((Control)panel_P5_1).TabIndex = 16;
		((Control)tabPage4_address).Controls.Add((Control)(object)panel_P4_3);
		((Control)tabPage4_address).Controls.Add((Control)(object)panel_P4_2);
		((Control)tabPage4_address).Controls.Add((Control)(object)panel_P4_1);
		tabPage4_address.Location = new Point(4, 22);
		((Control)tabPage4_address).Margin = new Padding(0);
		((Control)tabPage4_address).Name = "tabPage4_address";
		((Control)tabPage4_address).Size = new Size(760, 497);
		tabPage4_address.TabIndex = 3;
		((Control)tabPage4_address).Text = "tabP4_address";
		tabPage4_address.UseVisualStyleBackColor = true;
		((Control)panel_P4_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_P4_3.BorderStyle = (BorderStyle)1;
		((Control)panel_P4_3).Controls.Add((Control)(object)btnP4Cancel);
		((Control)panel_P4_3).Controls.Add((Control)(object)btnP4Back);
		((Control)panel_P4_3).Controls.Add((Control)(object)btnP4Next);
		((Control)panel_P4_3).Dock = (DockStyle)2;
		((Control)panel_P4_3).Location = new Point(0, 446);
		((Control)panel_P4_3).Margin = new Padding(0);
		((Control)panel_P4_3).Name = "panel_P4_3";
		((Control)panel_P4_3).Size = new Size(760, 51);
		((Control)panel_P4_3).TabIndex = 23;
		((Control)panel_P4_2).BackColor = Color.White;
		((Control)panel_P4_2).Controls.Add((Control)(object)machineSelectControl);
		((Control)panel_P4_2).Controls.Add((Control)(object)label7);
		((Control)panel_P4_2).Controls.Add((Control)(object)labelP4_Path);
		((Control)panel_P4_2).Controls.Add((Control)(object)cmbP4FolderPath);
		((Control)panel_P4_2).Controls.Add((Control)(object)labelP4ConnectCheck);
		((Control)panel_P4_2).Controls.Add((Control)(object)buttonP4HeadLine);
		((Control)panel_P4_2).Controls.Add((Control)(object)linkLabelP4Connect);
		((Control)panel_P4_2).Controls.Add((Control)(object)textP4Destination);
		((Control)panel_P4_2).Controls.Add((Control)(object)pictureBox4);
		((Control)panel_P4_2).Controls.Add((Control)(object)labelP4Head);
		((Control)panel_P4_2).Controls.Add((Control)(object)label60);
		((Control)panel_P4_2).Controls.Add((Control)(object)labelP4_Destination);
		((Control)panel_P4_2).Controls.Add((Control)(object)labelP4_Machine);
		((Control)panel_P4_2).Controls.Add((Control)(object)labelP4_comment);
		((Control)panel_P4_2).Location = new Point(184, 3);
		((Control)panel_P4_2).Name = "panel_P4_2";
		((Control)panel_P4_2).Size = new Size(575, 470);
		((Control)panel_P4_2).TabIndex = 22;
		((Control)label7).AutoSize = true;
		((Control)label7).Font = new Font("MS UI Gothic", 10f);
		((Control)label7).ForeColor = Color.Blue;
		label7.ImeMode = (ImeMode)0;
		((Control)label7).Location = new Point(158, 336);
		((Control)label7).Name = "label7";
		((Control)label7).Size = new Size(85, 14);
		((Control)label7).TabIndex = 40;
		((Control)label7).Text = "共有フォルダー";
		((Control)label7).Visible = false;
		((Control)labelP4_Path).AutoSize = true;
		((Control)labelP4_Path).Font = new Font("MS UI Gothic", 9f);
		((Control)labelP4_Path).ForeColor = Color.Blue;
		labelP4_Path.ImeMode = (ImeMode)0;
		((Control)labelP4_Path).Location = new Point(45, 165);
		((Control)labelP4_Path).Name = "labelP4_Path";
		((Control)labelP4_Path).Size = new Size(28, 12);
		((Control)labelP4_Path).TabIndex = 38;
		((Control)labelP4_Path).Text = "Path";
		cmbP4FolderPath.DropDownStyle = (ComboBoxStyle)2;
		((Control)cmbP4FolderPath).Font = new Font("MS UI Gothic", 9f);
		((ListControl)cmbP4FolderPath).FormattingEnabled = true;
		((Control)cmbP4FolderPath).Location = new Point(118, 163);
		((Control)cmbP4FolderPath).Name = "cmbP4FolderPath";
		((Control)cmbP4FolderPath).Size = new Size(314, 20);
		((Control)cmbP4FolderPath).TabIndex = 17;
		cmbP4FolderPath.SelectedIndexChanged += cmbP4FolderPass_SelectedIndexChanged;
		((Control)labelP4ConnectCheck).AutoSize = true;
		((Control)labelP4ConnectCheck).Font = new Font("MS UI Gothic", 9f);
		((Control)labelP4ConnectCheck).ForeColor = Color.Black;
		labelP4ConnectCheck.ImeMode = (ImeMode)0;
		((Control)labelP4ConnectCheck).Location = new Point(5, 423);
		((Control)labelP4ConnectCheck).Name = "labelP4ConnectCheck";
		((Control)labelP4ConnectCheck).Size = new Size(80, 12);
		((Control)labelP4ConnectCheck).TabIndex = 34;
		((Control)labelP4ConnectCheck).Text = "Connecting . . .";
		((Control)labelP4ConnectCheck).Visible = false;
		((Control)buttonP4HeadLine).AutoSize = true;
		((Control)buttonP4HeadLine).Font = new Font("MS UI Gothic", 9f);
		((ButtonBase)buttonP4HeadLine).ImeMode = (ImeMode)0;
		((Control)buttonP4HeadLine).Location = new Point(435, 128);
		((Control)buttonP4HeadLine).Name = "buttonP4HeadLine";
		((Control)buttonP4HeadLine).Size = new Size(103, 23);
		((Control)buttonP4HeadLine).TabIndex = 16;
		((Control)buttonP4HeadLine).Text = "Index";
		((ButtonBase)buttonP4HeadLine).UseVisualStyleBackColor = true;
		((Control)buttonP4HeadLine).Click += buttonHeadLine_Click;
		((Control)linkLabelP4Connect).AutoSize = true;
		((Label)linkLabelP4Connect).ImeMode = (ImeMode)0;
		linkLabelP4Connect.LinkColor = Color.Red;
		((Control)linkLabelP4Connect).Location = new Point(3, 423);
		((Control)linkLabelP4Connect).Name = "linkLabelP4Connect";
		((Control)linkLabelP4Connect).Size = new Size(156, 12);
		((Control)linkLabelP4Connect).TabIndex = 18;
		linkLabelP4Connect.TabStop = true;
		((Control)linkLabelP4Connect).Text = "Cannot connect link message";
		linkLabelP4Connect.LinkClicked += new LinkLabelLinkClickedEventHandler(linkLabelConnect_LinkClicked);
		((Control)textP4Destination).Font = new Font("MS UI Gothic", 9f);
		((Control)textP4Destination).Location = new Point(118, 130);
		((Control)textP4Destination).Name = "textP4Destination";
		((Control)textP4Destination).Size = new Size(314, 19);
		((Control)textP4Destination).TabIndex = 15;
		((Control)textP4Destination).Enter += textP4AddressName_Enter;
		((Control)textP4Destination).Leave += textP4AddressName_Leave;
		pictureBox4.Image = (Image)(object)Resources.Line;
		pictureBox4.ImeMode = (ImeMode)0;
		((Control)pictureBox4).Location = new Point(39, 48);
		((Control)pictureBox4).Margin = new Padding(1);
		((Control)pictureBox4).Name = "pictureBox4";
		((Control)pictureBox4).Size = new Size(539, 10);
		pictureBox4.TabIndex = 1;
		pictureBox4.TabStop = false;
		((Control)labelP4Head).AutoSize = true;
		((Control)labelP4Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		labelP4Head.ImeMode = (ImeMode)0;
		((Control)labelP4Head).Location = new Point(40, 21);
		((Control)labelP4Head).Name = "labelP4Head";
		((Control)labelP4Head).Size = new Size(94, 16);
		((Control)labelP4Head).TabIndex = 0;
		((Control)labelP4Head).Text = "Destination";
		((Control)label60).AutoSize = true;
		((Control)label60).Font = new Font("MS UI Gothic", 10f);
		((Control)label60).ForeColor = Color.Blue;
		label60.ImeMode = (ImeMode)0;
		((Control)label60).Location = new Point(158, 387);
		((Control)label60).Name = "label60";
		((Control)label60).Size = new Size(120, 14);
		((Control)label60).TabIndex = 2;
		((Control)label60).Text = "パソコンのユーザー名";
		((Control)label60).Visible = false;
		((Control)labelP4_Destination).AutoSize = true;
		((Control)labelP4_Destination).Font = new Font("MS UI Gothic", 9f);
		((Control)labelP4_Destination).ForeColor = Color.Blue;
		labelP4_Destination.ImeMode = (ImeMode)0;
		((Control)labelP4_Destination).Location = new Point(45, 130);
		((Control)labelP4_Destination).Name = "labelP4_Destination";
		((Control)labelP4_Destination).Size = new Size(63, 12);
		((Control)labelP4_Destination).TabIndex = 2;
		((Control)labelP4_Destination).Text = "Destination";
		((Control)labelP4_Machine).AutoSize = true;
		((Control)labelP4_Machine).Font = new Font("MS UI Gothic", 9f);
		((Control)labelP4_Machine).ForeColor = Color.Blue;
		labelP4_Machine.ImeMode = (ImeMode)0;
		((Control)labelP4_Machine).Location = new Point(45, 200);
		((Control)labelP4_Machine).Name = "labelP4_Machine";
		((Control)labelP4_Machine).Size = new Size(47, 12);
		((Control)labelP4_Machine).TabIndex = 2;
		((Control)labelP4_Machine).Text = "Machine";
		((Control)labelP4_comment).AutoSize = true;
		((Control)labelP4_comment).Font = new Font("MS UI Gothic", 9f);
		labelP4_comment.ImeMode = (ImeMode)0;
		((Control)labelP4_comment).Location = new Point(45, 75);
		((Control)labelP4_comment).Name = "labelP4_comment";
		((Control)labelP4_comment).Size = new Size(151, 12);
		((Control)labelP4_comment).TabIndex = 2;
		((Control)labelP4_comment).Text = "Destination setting message";
		((Control)panel_P4_1).BackColor = SystemColors.Control;
		panel_P4_1.BorderStyle = (BorderStyle)1;
		((Control)panel_P4_1).Location = new Point(0, 3);
		((Control)panel_P4_1).Margin = new Padding(0);
		((Control)panel_P4_1).Name = "panel_P4_1";
		((Control)panel_P4_1).Size = new Size(181, 470);
		((Control)panel_P4_1).TabIndex = 20;
		((Control)tabPage3_shareFolder).Controls.Add((Control)(object)panel_P3_3);
		((Control)tabPage3_shareFolder).Controls.Add((Control)(object)panel_P3_2);
		((Control)tabPage3_shareFolder).Controls.Add((Control)(object)panel_P3_1);
		tabPage3_shareFolder.Location = new Point(4, 22);
		((Control)tabPage3_shareFolder).Margin = new Padding(0);
		((Control)tabPage3_shareFolder).Name = "tabPage3_shareFolder";
		((Control)tabPage3_shareFolder).Size = new Size(760, 497);
		tabPage3_shareFolder.TabIndex = 2;
		((Control)tabPage3_shareFolder).Text = "tabP3_shareFolder";
		tabPage3_shareFolder.UseVisualStyleBackColor = true;
		((Control)panel_P3_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_P3_3.BorderStyle = (BorderStyle)1;
		((Control)panel_P3_3).Controls.Add((Control)(object)btnP3Cancel);
		((Control)panel_P3_3).Controls.Add((Control)(object)btnP3Back);
		((Control)panel_P3_3).Controls.Add((Control)(object)btnP3Next);
		((Control)panel_P3_3).Dock = (DockStyle)2;
		((Control)panel_P3_3).Location = new Point(0, 446);
		((Control)panel_P3_3).Margin = new Padding(0);
		((Control)panel_P3_3).Name = "panel_P3_3";
		((Control)panel_P3_3).Size = new Size(760, 51);
		((Control)panel_P3_3).TabIndex = 18;
		((Control)panel_P3_2).BackColor = Color.White;
		panel_P3_2.BorderStyle = (BorderStyle)1;
		((Control)panel_P3_2).Controls.Add((Control)(object)labelP3_PasswordConfirm);
		((Control)panel_P3_2).Controls.Add((Control)(object)textBoxP3PassConfirm);
		((Control)panel_P3_2).Controls.Add((Control)(object)textBoxP3Pass);
		((Control)panel_P3_2).Controls.Add((Control)(object)labelP3_Password);
		((Control)panel_P3_2).Controls.Add((Control)(object)cmbP3UserName);
		((Control)panel_P3_2).Controls.Add((Control)(object)pictureBox3);
		((Control)panel_P3_2).Controls.Add((Control)(object)labelP3Head);
		((Control)panel_P3_2).Controls.Add((Control)(object)labelP3_UserName);
		((Control)panel_P3_2).Controls.Add((Control)(object)labelP3_comment);
		((Control)panel_P3_2).Location = new Point(184, 3);
		((Control)panel_P3_2).Name = "panel_P3_2";
		((Control)panel_P3_2).Size = new Size(575, 470);
		((Control)panel_P3_2).TabIndex = 19;
		((Control)labelP3_PasswordConfirm).AutoSize = true;
		((Control)labelP3_PasswordConfirm).Font = new Font("MS UI Gothic", 9f);
		((Control)labelP3_PasswordConfirm).ForeColor = Color.Blue;
		labelP3_PasswordConfirm.ImeMode = (ImeMode)0;
		((Control)labelP3_PasswordConfirm).Location = new Point(45, 190);
		((Control)labelP3_PasswordConfirm).Name = "labelP3_PasswordConfirm";
		((Control)labelP3_PasswordConfirm).Size = new Size(102, 12);
		((Control)labelP3_PasswordConfirm).TabIndex = 22;
		((Control)labelP3_PasswordConfirm).Text = "Password(Confirm)";
		((Control)textBoxP3PassConfirm).Font = new Font("MS UI Gothic", 9f);
		((Control)textBoxP3PassConfirm).Location = new Point(155, 188);
		((Control)textBoxP3PassConfirm).Name = "textBoxP3PassConfirm";
		textBoxP3PassConfirm.PasswordChar = '*';
		((Control)textBoxP3PassConfirm).Size = new Size(388, 19);
		((Control)textBoxP3PassConfirm).TabIndex = 11;
		((Control)textBoxP3PassConfirm).Enter += textBox4PassConfirm_Enter;
		((Control)textBoxP3PassConfirm).Leave += textBox4PassConfirm_Leave;
		((Control)textBoxP3Pass).Font = new Font("MS UI Gothic", 9f);
		((Control)textBoxP3Pass).Location = new Point(155, 157);
		((Control)textBoxP3Pass).Name = "textBoxP3Pass";
		textBoxP3Pass.PasswordChar = '*';
		((Control)textBoxP3Pass).Size = new Size(388, 19);
		((Control)textBoxP3Pass).TabIndex = 10;
		((Control)textBoxP3Pass).Enter += textBoxP4Pass_Enter;
		((Control)textBoxP3Pass).Leave += textBoxP4Pass_Leave;
		((Control)labelP3_Password).AutoSize = true;
		((Control)labelP3_Password).Font = new Font("MS UI Gothic", 9f);
		((Control)labelP3_Password).ForeColor = Color.Blue;
		labelP3_Password.ImeMode = (ImeMode)0;
		((Control)labelP3_Password).Location = new Point(45, 159);
		((Control)labelP3_Password).Name = "labelP3_Password";
		((Control)labelP3_Password).Size = new Size(54, 12);
		((Control)labelP3_Password).TabIndex = 20;
		((Control)labelP3_Password).Text = "Password";
		cmbP3UserName.DropDownStyle = (ComboBoxStyle)2;
		((Control)cmbP3UserName).Font = new Font("MS UI Gothic", 9f);
		((ListControl)cmbP3UserName).FormattingEnabled = true;
		((Control)cmbP3UserName).Location = new Point(155, 125);
		((Control)cmbP3UserName).Name = "cmbP3UserName";
		((Control)cmbP3UserName).Size = new Size(388, 20);
		((Control)cmbP3UserName).TabIndex = 9;
		pictureBox3.Image = (Image)(object)Resources.Line;
		pictureBox3.ImeMode = (ImeMode)0;
		((Control)pictureBox3).Location = new Point(39, 48);
		((Control)pictureBox3).Margin = new Padding(1);
		((Control)pictureBox3).Name = "pictureBox3";
		((Control)pictureBox3).Size = new Size(539, 10);
		pictureBox3.TabIndex = 1;
		pictureBox3.TabStop = false;
		((Control)labelP3Head).AutoSize = true;
		((Control)labelP3Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		labelP3Head.ImeMode = (ImeMode)0;
		((Control)labelP3Head).Location = new Point(40, 21);
		((Control)labelP3Head).Name = "labelP3Head";
		((Control)labelP3Head).Size = new Size(80, 16);
		((Control)labelP3Head).TabIndex = 0;
		((Control)labelP3Head).Text = "Password";
		((Control)labelP3_UserName).AutoSize = true;
		((Control)labelP3_UserName).Font = new Font("MS UI Gothic", 9f);
		((Control)labelP3_UserName).ForeColor = Color.Blue;
		labelP3_UserName.ImeMode = (ImeMode)0;
		((Control)labelP3_UserName).Location = new Point(45, 128);
		((Control)labelP3_UserName).Name = "labelP3_UserName";
		((Control)labelP3_UserName).Size = new Size(62, 12);
		((Control)labelP3_UserName).TabIndex = 2;
		((Control)labelP3_UserName).Text = "User Name";
		((Control)labelP3_comment).AutoSize = true;
		((Control)labelP3_comment).Font = new Font("MS UI Gothic", 9f);
		labelP3_comment.ImeMode = (ImeMode)0;
		((Control)labelP3_comment).Location = new Point(45, 75);
		((Control)labelP3_comment).Name = "labelP3_comment";
		((Control)labelP3_comment).Size = new Size(142, 12);
		((Control)labelP3_comment).TabIndex = 2;
		((Control)labelP3_comment).Text = "Password setting message";
		((Control)panel_P3_1).BackColor = SystemColors.Control;
		panel_P3_1.BorderStyle = (BorderStyle)1;
		((Control)panel_P3_1).Location = new Point(0, 3);
		((Control)panel_P3_1).Margin = new Padding(0);
		((Control)panel_P3_1).Name = "panel_P3_1";
		((Control)panel_P3_1).Size = new Size(181, 470);
		((Control)panel_P3_1).TabIndex = 15;
		((Control)tabPage2_setupSelect).Controls.Add((Control)(object)panel_P2_3);
		((Control)tabPage2_setupSelect).Controls.Add((Control)(object)panel_P2_2);
		((Control)tabPage2_setupSelect).Controls.Add((Control)(object)panel_P2_1);
		tabPage2_setupSelect.Location = new Point(4, 22);
		((Control)tabPage2_setupSelect).Margin = new Padding(0);
		((Control)tabPage2_setupSelect).Name = "tabPage2_setupSelect";
		((Control)tabPage2_setupSelect).Size = new Size(760, 497);
		tabPage2_setupSelect.TabIndex = 1;
		((Control)tabPage2_setupSelect).Text = "tabP2_setupSelect";
		tabPage2_setupSelect.UseVisualStyleBackColor = true;
		((Control)panel_P2_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_P2_3.BorderStyle = (BorderStyle)1;
		((Control)panel_P2_3).Controls.Add((Control)(object)btnP2Back);
		((Control)panel_P2_3).Controls.Add((Control)(object)btnP2Cancel);
		((Control)panel_P2_3).Controls.Add((Control)(object)btnP2Next);
		((Control)panel_P2_3).Dock = (DockStyle)2;
		((Control)panel_P2_3).Location = new Point(0, 446);
		((Control)panel_P2_3).Margin = new Padding(0);
		((Control)panel_P2_3).Name = "panel_P2_3";
		((Control)panel_P2_3).Size = new Size(760, 51);
		((Control)panel_P2_3).TabIndex = 17;
		((Control)panel_P2_2).BackColor = Color.White;
		panel_P2_2.BorderStyle = (BorderStyle)1;
		((Control)panel_P2_2).Controls.Add((Control)(object)labelP2_selectFolder);
		((Control)panel_P2_2).Controls.Add((Control)(object)labelP2_selectNonSharedFolder);
		((Control)panel_P2_2).Controls.Add((Control)(object)cmbP2Folder);
		((Control)panel_P2_2).Controls.Add((Control)(object)selectFolderRadioButton);
		((Control)panel_P2_2).Controls.Add((Control)(object)createNewFolderRadioButton);
		((Control)panel_P2_2).Controls.Add((Control)(object)selectNonSharedFolderRadioButton);
		((Control)panel_P2_2).Controls.Add((Control)(object)labelP2_Folder);
		((Control)panel_P2_2).Controls.Add((Control)(object)buttonSelectNonSharedFolder);
		((Control)panel_P2_2).Controls.Add((Control)(object)textBoxNonSharedFolderPath);
		((Control)panel_P2_2).Controls.Add((Control)(object)labelP2_NonSharedFolderPath);
		((Control)panel_P2_2).Controls.Add((Control)(object)textBoxSharedName);
		((Control)panel_P2_2).Controls.Add((Control)(object)labelP2_SharedName);
		((Control)panel_P2_2).Controls.Add((Control)(object)buttonSelectFolder);
		((Control)panel_P2_2).Controls.Add((Control)(object)textBoxFolderPath);
		((Control)panel_P2_2).Controls.Add((Control)(object)labelP2_FolderPath);
		((Control)panel_P2_2).Controls.Add((Control)(object)textBoxFolderName);
		((Control)panel_P2_2).Controls.Add((Control)(object)labelP2_FolderName);
		((Control)panel_P2_2).Controls.Add((Control)(object)pictureBox2);
		((Control)panel_P2_2).Controls.Add((Control)(object)labelP2Head);
		((Control)panel_P2_2).Controls.Add((Control)(object)labelP2_comment);
		((Control)panel_P2_2).Location = new Point(184, 3);
		((Control)panel_P2_2).Name = "panel_P2_2";
		((Control)panel_P2_2).Size = new Size(575, 470);
		((Control)panel_P2_2).TabIndex = 16;
		((Control)labelP2_selectFolder).AutoSize = true;
		((Control)labelP2_selectFolder).Enabled = false;
		labelP2_selectFolder.ImeMode = (ImeMode)0;
		((Control)labelP2_selectFolder).Location = new Point(56, 367);
		((Control)labelP2_selectFolder).Name = "labelP2_selectFolder";
		((Control)labelP2_selectFolder).Size = new Size(149, 17);
		((Control)labelP2_selectFolder).TabIndex = 16;
		((Control)labelP2_selectFolder).Text = "Select folder for destination";
		labelP2_selectFolder.UseCompatibleTextRendering = true;
		((Control)labelP2_selectNonSharedFolder).AutoSize = true;
		((Control)labelP2_selectNonSharedFolder).Enabled = false;
		labelP2_selectNonSharedFolder.ImeMode = (ImeMode)0;
		((Control)labelP2_selectNonSharedFolder).Location = new Point(56, 250);
		((Control)labelP2_selectNonSharedFolder).Name = "labelP2_selectNonSharedFolder";
		((Control)labelP2_selectNonSharedFolder).Size = new Size(149, 17);
		((Control)labelP2_selectNonSharedFolder).TabIndex = 16;
		((Control)labelP2_selectNonSharedFolder).Text = "Select folder for destination";
		labelP2_selectNonSharedFolder.UseCompatibleTextRendering = true;
		cmbP2Folder.DropDownStyle = (ComboBoxStyle)2;
		cmbP2Folder.DropDownWidth = 401;
		((Control)cmbP2Folder).Enabled = false;
		((ListControl)cmbP2Folder).FormattingEnabled = true;
		((Control)cmbP2Folder).Location = new Point(180, 388);
		((Control)cmbP2Folder).Name = "cmbP2Folder";
		((Control)cmbP2Folder).Size = new Size(343, 20);
		cmbP2Folder.Sorted = true;
		((Control)cmbP2Folder).TabIndex = 15;
		((Control)selectFolderRadioButton).AutoSize = true;
		((ButtonBase)selectFolderRadioButton).ImeMode = (ImeMode)0;
		((Control)selectFolderRadioButton).Location = new Point(50, 342);
		((Control)selectFolderRadioButton).Name = "selectFolderRadioButton";
		((Control)selectFolderRadioButton).Size = new Size(117, 16);
		((Control)selectFolderRadioButton).TabIndex = 14;
		((Control)selectFolderRadioButton).Text = "Select folder";
		((ButtonBase)selectFolderRadioButton).UseVisualStyleBackColor = true;
		selectFolderRadioButton.CheckedChanged += createNewFolderRadioButton_CheckedChanged;
		((Control)createNewFolderRadioButton).AutoSize = true;
		createNewFolderRadioButton.Checked = true;
		((ButtonBase)createNewFolderRadioButton).ImeMode = (ImeMode)0;
		((Control)createNewFolderRadioButton).Location = new Point(50, 132);
		((Control)createNewFolderRadioButton).Name = "createNewFolderRadioButton";
		((Control)createNewFolderRadioButton).Size = new Size(114, 16);
		((Control)createNewFolderRadioButton).TabIndex = 13;
		createNewFolderRadioButton.TabStop = true;
		((Control)createNewFolderRadioButton).Text = "Create new folder";
		((ButtonBase)createNewFolderRadioButton).UseVisualStyleBackColor = true;
		createNewFolderRadioButton.CheckedChanged += createNewFolderRadioButton_CheckedChanged;
		((Control)selectNonSharedFolderRadioButton).AutoSize = true;
		((ButtonBase)selectNonSharedFolderRadioButton).ImeMode = (ImeMode)0;
		((Control)selectNonSharedFolderRadioButton).Location = new Point(50, 226);
		((Control)selectNonSharedFolderRadioButton).Name = "selectNonSharedFolderRadioButton";
		((Control)selectNonSharedFolderRadioButton).Size = new Size(117, 16);
		((Control)selectNonSharedFolderRadioButton).TabIndex = 14;
		((Control)selectNonSharedFolderRadioButton).Text = "Select folder";
		((ButtonBase)selectNonSharedFolderRadioButton).UseVisualStyleBackColor = true;
		selectNonSharedFolderRadioButton.CheckedChanged += createNewFolderRadioButton_CheckedChanged;
		((Control)labelP2_Folder).AutoSize = true;
		((Control)labelP2_Folder).Enabled = false;
		((Control)labelP2_Folder).ForeColor = Color.Blue;
		labelP2_Folder.ImeMode = (ImeMode)0;
		((Control)labelP2_Folder).Location = new Point(56, 390);
		((Control)labelP2_Folder).Name = "labelP2_Folder";
		((Control)labelP2_Folder).Size = new Size(37, 12);
		((Control)labelP2_Folder).TabIndex = 12;
		((Control)labelP2_Folder).Text = "Folder";
		((Control)buttonSelectNonSharedFolder).AutoSize = true;
		((Control)buttonSelectNonSharedFolder).Enabled = false;
		((Control)buttonSelectNonSharedFolder).Font = new Font("MS UI Gothic", 9f);
		((ButtonBase)buttonSelectNonSharedFolder).ImeMode = (ImeMode)0;
		((Control)buttonSelectNonSharedFolder).Location = new Point(497, 272);
		((Control)buttonSelectNonSharedFolder).Name = "buttonSelectNonSharedFolder";
		((Control)buttonSelectNonSharedFolder).Size = new Size(55, 22);
		((Control)buttonSelectNonSharedFolder).TabIndex = 5;
		((Control)buttonSelectNonSharedFolder).Text = "参照";
		((ButtonBase)buttonSelectNonSharedFolder).UseVisualStyleBackColor = true;
		((Control)buttonSelectNonSharedFolder).Click += buttonNonSharedSelectFolder_Click;
		((Control)textBoxNonSharedFolderPath).Enabled = false;
		((Control)textBoxNonSharedFolderPath).Font = new Font("MS UI Gothic", 9f);
		((Control)textBoxNonSharedFolderPath).Location = new Point(180, 273);
		((Control)textBoxNonSharedFolderPath).Name = "textBoxNonSharedFolderPath";
		((Control)textBoxNonSharedFolderPath).Size = new Size(311, 19);
		((Control)textBoxNonSharedFolderPath).TabIndex = 4;
		((Control)textBoxNonSharedFolderPath).Enter += textBoxNonSharedFolderPath_Enter;
		((Control)textBoxNonSharedFolderPath).Leave += textBoxNonSharedFolderPath_Leave;
		((Control)labelP2_NonSharedFolderPath).AutoSize = true;
		((Control)labelP2_NonSharedFolderPath).Enabled = false;
		((Control)labelP2_NonSharedFolderPath).Font = new Font("MS UI Gothic", 9f);
		((Control)labelP2_NonSharedFolderPath).ForeColor = Color.Blue;
		labelP2_NonSharedFolderPath.ImeMode = (ImeMode)0;
		((Control)labelP2_NonSharedFolderPath).Location = new Point(56, 275);
		((Control)labelP2_NonSharedFolderPath).Name = "labelP2_NonSharedFolderPath";
		((Control)labelP2_NonSharedFolderPath).Size = new Size(64, 12);
		((Control)labelP2_NonSharedFolderPath).TabIndex = 11;
		((Control)labelP2_NonSharedFolderPath).Text = "Folder Path";
		((Control)textBoxSharedName).Enabled = false;
		((Control)textBoxSharedName).Font = new Font("MS UI Gothic", 9f);
		((Control)textBoxSharedName).Location = new Point(180, 303);
		((Control)textBoxSharedName).Name = "textBoxSharedName";
		((Control)textBoxSharedName).Size = new Size(373, 19);
		((Control)textBoxSharedName).TabIndex = 4;
		((Control)textBoxSharedName).Enter += textBoxSharedName_Enter;
		((Control)textBoxSharedName).Leave += textBoxSharedName_Leave;
		((Control)labelP2_SharedName).AutoSize = true;
		((Control)labelP2_SharedName).Enabled = false;
		((Control)labelP2_SharedName).Font = new Font("MS UI Gothic", 9f);
		((Control)labelP2_SharedName).ForeColor = Color.Blue;
		labelP2_SharedName.ImeMode = (ImeMode)0;
		((Control)labelP2_SharedName).Location = new Point(56, 305);
		((Control)labelP2_SharedName).Name = "labelP2_SharedName";
		((Control)labelP2_SharedName).Size = new Size(64, 12);
		((Control)labelP2_SharedName).TabIndex = 11;
		((Control)labelP2_SharedName).Text = "Shared Name";
		((Control)buttonSelectFolder).AutoSize = true;
		((Control)buttonSelectFolder).Font = new Font("MS UI Gothic", 9f);
		((ButtonBase)buttonSelectFolder).ImeMode = (ImeMode)0;
		((Control)buttonSelectFolder).Location = new Point(497, 157);
		((Control)buttonSelectFolder).Name = "buttonSelectFolder";
		((Control)buttonSelectFolder).Size = new Size(55, 22);
		((Control)buttonSelectFolder).TabIndex = 5;
		((Control)buttonSelectFolder).Text = "参照";
		((ButtonBase)buttonSelectFolder).UseVisualStyleBackColor = true;
		((Control)buttonSelectFolder).Click += buttonSelectFolder_Click;
		((Control)textBoxFolderPath).Font = new Font("MS UI Gothic", 9f);
		((Control)textBoxFolderPath).Location = new Point(180, 158);
		((Control)textBoxFolderPath).Name = "textBoxFolderPath";
		((Control)textBoxFolderPath).Size = new Size(311, 19);
		((Control)textBoxFolderPath).TabIndex = 4;
		((Control)textBoxFolderPath).Enter += textBoxFolderPath_Enter;
		((Control)textBoxFolderPath).Leave += textBoxFolderPath_Leave;
		((Control)labelP2_FolderPath).AutoSize = true;
		((Control)labelP2_FolderPath).Font = new Font("MS UI Gothic", 9f);
		((Control)labelP2_FolderPath).ForeColor = Color.Blue;
		labelP2_FolderPath.ImeMode = (ImeMode)0;
		((Control)labelP2_FolderPath).Location = new Point(56, 160);
		((Control)labelP2_FolderPath).Name = "labelP2_FolderPath";
		((Control)labelP2_FolderPath).Size = new Size(64, 12);
		((Control)labelP2_FolderPath).TabIndex = 11;
		((Control)labelP2_FolderPath).Text = "Folder Path";
		((Control)textBoxFolderName).Font = new Font("MS UI Gothic", 9f);
		((Control)textBoxFolderName).Location = new Point(180, 186);
		((Control)textBoxFolderName).Name = "textBoxFolderName";
		((Control)textBoxFolderName).Size = new Size(373, 19);
		((Control)textBoxFolderName).TabIndex = 3;
		((Control)textBoxFolderName).Text = "ScanDoc";
		((Control)textBoxFolderName).Enter += textBoxFolderName_Enter;
		((Control)textBoxFolderName).Leave += textBoxFolderName_Leave;
		((Control)labelP2_FolderName).AutoSize = true;
		((Control)labelP2_FolderName).Font = new Font("MS UI Gothic", 9f);
		((Control)labelP2_FolderName).ForeColor = Color.Blue;
		labelP2_FolderName.ImeMode = (ImeMode)0;
		((Control)labelP2_FolderName).Location = new Point(56, 188);
		((Control)labelP2_FolderName).Name = "labelP2_FolderName";
		((Control)labelP2_FolderName).Size = new Size(66, 12);
		((Control)labelP2_FolderName).TabIndex = 9;
		((Control)labelP2_FolderName).Text = "FolderName";
		pictureBox2.Image = (Image)(object)Resources.Line;
		pictureBox2.ImeMode = (ImeMode)0;
		((Control)pictureBox2).Location = new Point(39, 48);
		((Control)pictureBox2).Margin = new Padding(1);
		((Control)pictureBox2).Name = "pictureBox2";
		((Control)pictureBox2).Size = new Size(539, 10);
		pictureBox2.TabIndex = 1;
		pictureBox2.TabStop = false;
		((Control)labelP2Head).AutoSize = true;
		((Control)labelP2Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		labelP2Head.ImeMode = (ImeMode)0;
		((Control)labelP2Head).Location = new Point(40, 21);
		((Control)labelP2Head).Name = "labelP2Head";
		((Control)labelP2Head).Size = new Size(109, 16);
		((Control)labelP2Head).TabIndex = 0;
		((Control)labelP2Head).Text = "CreateFolder";
		((Control)labelP2_comment).AutoSize = true;
		((Control)labelP2_comment).Font = new Font("MS UI Gothic", 9f);
		labelP2_comment.ImeMode = (ImeMode)0;
		((Control)labelP2_comment).Location = new Point(45, 75);
		((Control)labelP2_comment).Name = "labelP2_comment";
		((Control)labelP2_comment).Size = new Size(125, 12);
		((Control)labelP2_comment).TabIndex = 2;
		((Control)labelP2_comment).Text = "Folder setting message";
		((Control)panel_P2_1).BackColor = SystemColors.Control;
		panel_P2_1.BorderStyle = (BorderStyle)1;
		((Control)panel_P2_1).Location = new Point(0, 3);
		((Control)panel_P2_1).Margin = new Padding(0);
		((Control)panel_P2_1).Name = "panel_P2_1";
		((Control)panel_P2_1).Size = new Size(181, 470);
		((Control)panel_P2_1).TabIndex = 14;
		((Control)tabPage1_introduction).BackColor = SystemColors.Control;
		((Control)tabPage1_introduction).Controls.Add((Control)(object)panel_P1_3);
		((Control)tabPage1_introduction).Controls.Add((Control)(object)panel_P1_2);
		((Control)tabPage1_introduction).Controls.Add((Control)(object)panel_P1_1);
		tabPage1_introduction.Location = new Point(4, 22);
		((Control)tabPage1_introduction).Margin = new Padding(0);
		((Control)tabPage1_introduction).Name = "tabPage1_introduction";
		((Control)tabPage1_introduction).Size = new Size(760, 497);
		tabPage1_introduction.TabIndex = 0;
		((Control)tabPage1_introduction).Text = "tabP1_introduction";
		((Control)panel_P1_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_P1_3.BorderStyle = (BorderStyle)1;
		((Control)panel_P1_3).Controls.Add((Control)(object)btnP1TRNext);
		((Control)panel_P1_3).Controls.Add((Control)(object)btnP1Cancel);
		((Control)panel_P1_3).Controls.Add((Control)(object)btnP1Next);
		((Control)panel_P1_3).Dock = (DockStyle)2;
		((Control)panel_P1_3).Location = new Point(0, 446);
		((Control)panel_P1_3).Margin = new Padding(0);
		((Control)panel_P1_3).Name = "panel_P1_3";
		((Control)panel_P1_3).Size = new Size(760, 51);
		((Control)panel_P1_3).TabIndex = 14;
		((Control)panel_P1_2).BackColor = Color.White;
		panel_P1_2.BorderStyle = (BorderStyle)1;
		((Control)panel_P1_2).Controls.Add((Control)(object)radioButtonTroubleShoot);
		((Control)panel_P1_2).Controls.Add((Control)(object)radioButtonCreateFolder);
		((Control)panel_P1_2).Controls.Add((Control)(object)attentionGroup);
		((Control)panel_P1_2).Controls.Add((Control)(object)pictureBox1);
		((Control)panel_P1_2).Controls.Add((Control)(object)labelP1Head);
		((Control)panel_P1_2).Controls.Add((Control)(object)labelP1_comment);
		((Control)panel_P1_2).Location = new Point(184, 3);
		((Control)panel_P1_2).Name = "panel_P1_2";
		((Control)panel_P1_2).Size = new Size(575, 470);
		((Control)panel_P1_2).TabIndex = 15;
		((Control)radioButtonTroubleShoot).AutoSize = true;
		((Control)radioButtonTroubleShoot).Font = new Font("MS UI Gothic", 9f, (FontStyle)1, (GraphicsUnit)3, (byte)128);
		((ButtonBase)radioButtonTroubleShoot).ImeMode = (ImeMode)0;
		((Control)radioButtonTroubleShoot).Location = new Point(56, 175);
		((Control)radioButtonTroubleShoot).Name = "radioButtonTroubleShoot";
		((Control)radioButtonTroubleShoot).Size = new Size(107, 16);
		((Control)radioButtonTroubleShoot).TabIndex = 7;
		((Control)radioButtonTroubleShoot).Text = "Trouble Shoot";
		((ButtonBase)radioButtonTroubleShoot).UseVisualStyleBackColor = true;
		((Control)radioButtonCreateFolder).AutoSize = true;
		radioButtonCreateFolder.Checked = true;
		((Control)radioButtonCreateFolder).Font = new Font("MS UI Gothic", 9f, (FontStyle)1, (GraphicsUnit)3, (byte)128);
		((ButtonBase)radioButtonCreateFolder).ImeMode = (ImeMode)0;
		((Control)radioButtonCreateFolder).Location = new Point(56, 140);
		((Control)radioButtonCreateFolder).Name = "radioButtonCreateFolder";
		((Control)radioButtonCreateFolder).Size = new Size(74, 16);
		((Control)radioButtonCreateFolder).TabIndex = 5;
		radioButtonCreateFolder.TabStop = true;
		((Control)radioButtonCreateFolder).Text = "Register";
		((ButtonBase)radioButtonCreateFolder).UseVisualStyleBackColor = true;
		radioButtonCreateFolder.CheckedChanged += radioButtonCreateFolder_CheckedChanged;
		((Control)attentionGroup).Controls.Add((Control)(object)attentionRichTextBox);
		((Control)attentionGroup).Font = new Font("MS UI Gothic", 9f, (FontStyle)1);
		((Control)attentionGroup).Location = new Point(37, 224);
		((Control)attentionGroup).Name = "attentionGroup";
		((Control)attentionGroup).Size = new Size(503, 185);
		((Control)attentionGroup).TabIndex = 3;
		attentionGroup.TabStop = false;
		((Control)attentionGroup).Text = "attention_title";
		((Control)attentionRichTextBox).BackColor = SystemColors.Window;
		((TextBoxBase)attentionRichTextBox).BorderStyle = (BorderStyle)0;
		((Control)attentionRichTextBox).Font = new Font("MS UI Gothic", 9f);
		((Control)attentionRichTextBox).Location = new Point(19, 27);
		((Control)attentionRichTextBox).Name = "attentionRichTextBox";
		((TextBoxBase)attentionRichTextBox).ReadOnly = true;
		((Control)attentionRichTextBox).Size = new Size(467, 145);
		((Control)attentionRichTextBox).TabIndex = 4;
		((Control)attentionRichTextBox).Text = "";
		pictureBox1.Image = (Image)(object)Resources.Line;
		pictureBox1.ImeMode = (ImeMode)0;
		((Control)pictureBox1).Location = new Point(39, 48);
		((Control)pictureBox1).Margin = new Padding(1);
		((Control)pictureBox1).Name = "pictureBox1";
		((Control)pictureBox1).Size = new Size(539, 10);
		pictureBox1.TabIndex = 1;
		pictureBox1.TabStop = false;
		((Control)labelP1Head).AutoSize = true;
		((Control)labelP1Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		labelP1Head.ImeMode = (ImeMode)0;
		((Control)labelP1Head).Location = new Point(40, 21);
		((Control)labelP1Head).Name = "labelP1Head";
		((Control)labelP1Head).Size = new Size(74, 16);
		((Control)labelP1Head).TabIndex = 0;
		((Control)labelP1Head).Text = "Prologue";
		((Control)labelP1_comment).AutoSize = true;
		((Control)labelP1_comment).Font = new Font("MS UI Gothic", 9f);
		labelP1_comment.ImeMode = (ImeMode)0;
		((Control)labelP1_comment).Location = new Point(41, 91);
		((Control)labelP1_comment).Name = "labelP1_comment";
		((Control)labelP1_comment).Size = new Size(114, 12);
		((Control)labelP1_comment).TabIndex = 2;
		((Control)labelP1_comment).Text = "Introduction message";
		((Control)panel_P1_1).BackColor = SystemColors.Control;
		panel_P1_1.BorderStyle = (BorderStyle)1;
		((Control)panel_P1_1).Location = new Point(0, 3);
		((Control)panel_P1_1).Margin = new Padding(0);
		((Control)panel_P1_1).Name = "panel_P1_1";
		((Control)panel_P1_1).Size = new Size(181, 470);
		((Control)panel_P1_1).TabIndex = 13;
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabPage1_introduction);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabPage2_setupSelect);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabPage3_shareFolder);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabPage4_address);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabPage5_confirm);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabPage6_exec);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabPage7_finish);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabTRP2_device);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabTRP3_user);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabTRP4_analyze);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabTRP5_result);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabTRP6_setupSelect);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabTRP7_shareFolder);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabTRP8_address);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabTRP9_confirm);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabTRP10_finish);
		((Control)tabControl1_Main).Location = new Point(-3, 21);
		((Control)tabControl1_Main).Margin = new Padding(0);
		((Control)tabControl1_Main).Name = "tabControl1_Main";
		tabControl1_Main.Padding = new Point(0, 0);
		tabControl1_Main.SelectedIndex = 0;
		((Control)tabControl1_Main).Size = new Size(768, 523);
		((Control)tabControl1_Main).TabIndex = 0;
		tabControl1_Main.Selected += new TabControlEventHandler(tabControl1_Main_Selected);
		((Control)tabPage6_exec).Controls.Add((Control)(object)panel_P6_3);
		((Control)tabPage6_exec).Controls.Add((Control)(object)panel_P6_2);
		((Control)tabPage6_exec).Controls.Add((Control)(object)panel_P6_1);
		tabPage6_exec.Location = new Point(4, 22);
		((Control)tabPage6_exec).Margin = new Padding(0);
		((Control)tabPage6_exec).Name = "tabPage6_exec";
		((Control)tabPage6_exec).Size = new Size(760, 497);
		tabPage6_exec.TabIndex = 5;
		((Control)tabPage6_exec).Text = "tabP6_exec";
		tabPage6_exec.UseVisualStyleBackColor = true;
		((Control)panel_P6_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_P6_3.BorderStyle = (BorderStyle)1;
		((Control)panel_P6_3).Dock = (DockStyle)2;
		((Control)panel_P6_3).Location = new Point(0, 446);
		((Control)panel_P6_3).Margin = new Padding(0);
		((Control)panel_P6_3).Name = "panel_P6_3";
		((Control)panel_P6_3).Size = new Size(760, 51);
		((Control)panel_P6_3).TabIndex = 21;
		((Control)panel_P6_2).BackColor = Color.White;
		panel_P6_2.BorderStyle = (BorderStyle)1;
		((Control)panel_P6_2).Controls.Add((Control)(object)progressBar1);
		((Control)panel_P6_2).Controls.Add((Control)(object)labelP6Execute);
		((Control)panel_P6_2).Controls.Add((Control)(object)btnP6Excecute);
		((Control)panel_P6_2).Controls.Add((Control)(object)pictureBox6);
		((Control)panel_P6_2).Controls.Add((Control)(object)labelP6Head);
		((Control)panel_P6_2).Controls.Add((Control)(object)labelP6_comment);
		((Control)panel_P6_2).Location = new Point(184, 3);
		((Control)panel_P6_2).Name = "panel_P6_2";
		((Control)panel_P6_2).Size = new Size(575, 470);
		((Control)panel_P6_2).TabIndex = 20;
		progressBar1.ImeMode = (ImeMode)0;
		((Control)progressBar1).Location = new Point(44, 145);
		progressBar1.Maximum = 7;
		((Control)progressBar1).Name = "progressBar1";
		((Control)progressBar1).Size = new Size(476, 23);
		((Control)progressBar1).TabIndex = 5;
		((Control)labelP6Execute).AutoSize = true;
		((Control)labelP6Execute).Font = new Font("MS UI Gothic", 9f);
		labelP6Execute.ImeMode = (ImeMode)0;
		((Control)labelP6Execute).Location = new Point(46, 130);
		((Control)labelP6Execute).Name = "labelP6Execute";
		((Control)labelP6Execute).Size = new Size(41, 12);
		((Control)labelP6Execute).TabIndex = 4;
		((Control)labelP6Execute).Text = "label19";
		pictureBox6.Image = (Image)(object)Resources.Line;
		pictureBox6.ImeMode = (ImeMode)0;
		((Control)pictureBox6).Location = new Point(39, 48);
		((Control)pictureBox6).Margin = new Padding(1);
		((Control)pictureBox6).Name = "pictureBox6";
		((Control)pictureBox6).Size = new Size(537, 10);
		pictureBox6.TabIndex = 1;
		pictureBox6.TabStop = false;
		((Control)labelP6Head).AutoSize = true;
		((Control)labelP6Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		labelP6Head.ImeMode = (ImeMode)0;
		((Control)labelP6Head).Location = new Point(40, 21);
		((Control)labelP6Head).Name = "labelP6Head";
		((Control)labelP6Head).Size = new Size(81, 16);
		((Control)labelP6Head).TabIndex = 0;
		((Control)labelP6Head).Text = "Executing";
		((Control)labelP6_comment).AutoSize = true;
		((Control)labelP6_comment).Font = new Font("MS UI Gothic", 9f);
		labelP6_comment.ImeMode = (ImeMode)0;
		((Control)labelP6_comment).Location = new Point(45, 75);
		((Control)labelP6_comment).Name = "labelP6_comment";
		((Control)labelP6_comment).Size = new Size(104, 12);
		((Control)labelP6_comment).TabIndex = 2;
		((Control)labelP6_comment).Text = "Executing message";
		((Control)panel_P6_1).BackColor = SystemColors.Control;
		panel_P6_1.BorderStyle = (BorderStyle)1;
		((Control)panel_P6_1).Location = new Point(0, 3);
		((Control)panel_P6_1).Margin = new Padding(0);
		((Control)panel_P6_1).Name = "panel_P6_1";
		((Control)panel_P6_1).Size = new Size(181, 470);
		((Control)panel_P6_1).TabIndex = 19;
		((Control)tabPage7_finish).Controls.Add((Control)(object)panel_P7_3);
		((Control)tabPage7_finish).Controls.Add((Control)(object)panel_P7_2);
		((Control)tabPage7_finish).Controls.Add((Control)(object)panel_P7_1);
		tabPage7_finish.Location = new Point(4, 22);
		((Control)tabPage7_finish).Margin = new Padding(0);
		((Control)tabPage7_finish).Name = "tabPage7_finish";
		((Control)tabPage7_finish).Size = new Size(760, 497);
		tabPage7_finish.TabIndex = 6;
		((Control)tabPage7_finish).Text = "tabP7_finish";
		tabPage7_finish.UseVisualStyleBackColor = true;
		((Control)panel_P7_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_P7_3.BorderStyle = (BorderStyle)1;
		((Control)panel_P7_3).Controls.Add((Control)(object)btnP7Top);
		((Control)panel_P7_3).Controls.Add((Control)(object)btnP7End);
		((Control)panel_P7_3).Dock = (DockStyle)2;
		((Control)panel_P7_3).Location = new Point(0, 446);
		((Control)panel_P7_3).Margin = new Padding(0);
		((Control)panel_P7_3).Name = "panel_P7_3";
		((Control)panel_P7_3).Size = new Size(760, 51);
		((Control)panel_P7_3).TabIndex = 24;
		((Control)panel_P7_2).BackColor = Color.White;
		panel_P7_2.BorderStyle = (BorderStyle)1;
		((Control)panel_P7_2).Controls.Add((Control)(object)linkLabelP7HelpSend);
		((Control)panel_P7_2).Controls.Add((Control)(object)linkLabelP7HelpRegist);
		((Control)panel_P7_2).Controls.Add((Control)(object)panel22);
		((Control)panel_P7_2).Controls.Add((Control)(object)pictureBox7);
		((Control)panel_P7_2).Controls.Add((Control)(object)labelP7Head);
		((Control)panel_P7_2).Controls.Add((Control)(object)labelP7_ReportTitle);
		((Control)panel_P7_2).Controls.Add((Control)(object)labelP7_comment);
		((Control)panel_P7_2).Location = new Point(184, 3);
		((Control)panel_P7_2).Name = "panel_P7_2";
		((Control)panel_P7_2).Size = new Size(575, 470);
		((Control)panel_P7_2).TabIndex = 23;
		((Control)linkLabelP7HelpSend).AutoSize = true;
		((Control)linkLabelP7HelpSend).Font = new Font("MS UI Gothic", 9f);
		((Label)linkLabelP7HelpSend).ImeMode = (ImeMode)0;
		((Control)linkLabelP7HelpSend).Location = new Point(45, 109);
		((Control)linkLabelP7HelpSend).Name = "linkLabelP7HelpSend";
		((Control)linkLabelP7HelpSend).Size = new Size(141, 12);
		((Control)linkLabelP7HelpSend).TabIndex = 26;
		linkLabelP7HelpSend.TabStop = true;
		((Control)linkLabelP7HelpSend).Text = "Folder send procedure link";
		linkLabelP7HelpSend.LinkClicked += new LinkLabelLinkClickedEventHandler(linkLabel1_LinkClicked);
		((Control)linkLabelP7HelpRegist).AutoSize = true;
		((Control)linkLabelP7HelpRegist).Font = new Font("MS UI Gothic", 9f);
		((Label)linkLabelP7HelpRegist).ImeMode = (ImeMode)0;
		linkLabelP7HelpRegist.LinkColor = Color.Red;
		((Control)linkLabelP7HelpRegist).Location = new Point(45, 94);
		((Control)linkLabelP7HelpRegist).Name = "linkLabelP7HelpRegist";
		((Control)linkLabelP7HelpRegist).Size = new Size(145, 12);
		((Control)linkLabelP7HelpRegist).TabIndex = 25;
		linkLabelP7HelpRegist.TabStop = true;
		((Control)linkLabelP7HelpRegist).Text = "Direct regist procedure link";
		linkLabelP7HelpRegist.LinkClicked += new LinkLabelLinkClickedEventHandler(linkLabelP7Help_LinkClicked);
		((ScrollableControl)panel22).AutoScroll = true;
		panel22.BorderStyle = (BorderStyle)2;
		((Control)panel22).Controls.Add((Control)(object)labelP7Report);
		((Control)panel22).Controls.Add((Control)(object)labelP7finsh);
		((Control)panel22).Font = new Font("MS UI Gothic", 9f);
		((Control)panel22).Location = new Point(48, 159);
		((Control)panel22).Name = "panel22";
		((Control)panel22).Size = new Size(469, 242);
		((Control)panel22).TabIndex = 4;
		((Control)labelP7Report).AutoSize = true;
		labelP7Report.ImeMode = (ImeMode)0;
		((Control)labelP7Report).Location = new Point(4, 11);
		((Control)labelP7Report).Name = "labelP7Report";
		((Control)labelP7Report).Size = new Size(35, 12);
		((Control)labelP7Report).TabIndex = 2;
		((Control)labelP7Report).Text = "label7";
		((Control)labelP7finsh).AutoSize = true;
		((Label)labelP7finsh).ImeMode = (ImeMode)0;
		((Control)labelP7finsh).Location = new Point(381, 0);
		((Control)labelP7finsh).Name = "labelP7finsh";
		((Control)labelP7finsh).Size = new Size(41, 12);
		((Control)labelP7finsh).TabIndex = 1;
		labelP7finsh.TabStop = true;
		((Control)labelP7finsh).Text = "reports";
		((Control)labelP7finsh).Visible = false;
		pictureBox7.Image = (Image)(object)Resources.Line;
		pictureBox7.ImeMode = (ImeMode)0;
		((Control)pictureBox7).Location = new Point(39, 48);
		((Control)pictureBox7).Margin = new Padding(1);
		((Control)pictureBox7).Name = "pictureBox7";
		((Control)pictureBox7).Size = new Size(539, 10);
		pictureBox7.TabIndex = 1;
		pictureBox7.TabStop = false;
		((Control)labelP7Head).AutoSize = true;
		((Control)labelP7Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		labelP7Head.ImeMode = (ImeMode)0;
		((Control)labelP7Head).Location = new Point(40, 21);
		((Control)labelP7Head).Name = "labelP7Head";
		((Control)labelP7Head).Size = new Size(80, 16);
		((Control)labelP7Head).TabIndex = 0;
		((Control)labelP7Head).Text = "Complete";
		((Control)labelP7_ReportTitle).AutoSize = true;
		((Control)labelP7_ReportTitle).Font = new Font("MS UI Gothic", 9f);
		labelP7_ReportTitle.ImeMode = (ImeMode)0;
		((Control)labelP7_ReportTitle).Location = new Point(45, 142);
		((Control)labelP7_ReportTitle).Name = "labelP7_ReportTitle";
		((Control)labelP7_ReportTitle).Size = new Size(45, 12);
		((Control)labelP7_ReportTitle).TabIndex = 2;
		((Control)labelP7_ReportTitle).Text = "Report :";
		((Control)labelP7_comment).AutoSize = true;
		((Control)labelP7_comment).Font = new Font("MS UI Gothic", 9f);
		labelP7_comment.ImeMode = (ImeMode)0;
		((Control)labelP7_comment).Location = new Point(45, 75);
		((Control)labelP7_comment).Name = "labelP7_comment";
		((Control)labelP7_comment).Size = new Size(102, 12);
		((Control)labelP7_comment).TabIndex = 2;
		((Control)labelP7_comment).Text = "Complete message";
		((Control)panel_P7_1).BackColor = SystemColors.Control;
		panel_P7_1.BorderStyle = (BorderStyle)1;
		((Control)panel_P7_1).Location = new Point(0, 3);
		((Control)panel_P7_1).Margin = new Padding(0);
		((Control)panel_P7_1).Name = "panel_P7_1";
		((Control)panel_P7_1).Size = new Size(181, 470);
		((Control)panel_P7_1).TabIndex = 22;
		((Control)tabTRP2_device).Controls.Add((Control)(object)panel_TRP2_3);
		((Control)tabTRP2_device).Controls.Add((Control)(object)panel_TRP2_2);
		((Control)tabTRP2_device).Controls.Add((Control)(object)panel_TRP2_1);
		tabTRP2_device.Location = new Point(4, 22);
		((Control)tabTRP2_device).Margin = new Padding(0);
		((Control)tabTRP2_device).Name = "tabTRP2_device";
		((Control)tabTRP2_device).Size = new Size(760, 497);
		tabTRP2_device.TabIndex = 7;
		((Control)tabTRP2_device).Text = "tabTRP2_device";
		tabTRP2_device.UseVisualStyleBackColor = true;
		((Control)panel_TRP2_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_TRP2_3.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP2_3).Controls.Add((Control)(object)btnTRP2Back);
		((Control)panel_TRP2_3).Controls.Add((Control)(object)btnTRP2Next);
		((Control)panel_TRP2_3).Dock = (DockStyle)2;
		((Control)panel_TRP2_3).Location = new Point(0, 446);
		((Control)panel_TRP2_3).Margin = new Padding(0);
		((Control)panel_TRP2_3).Name = "panel_TRP2_3";
		((Control)panel_TRP2_3).Size = new Size(760, 51);
		((Control)panel_TRP2_3).TabIndex = 26;
		((Control)panel_TRP2_2).BackColor = Color.White;
		((Control)panel_TRP2_2).Controls.Add((Control)(object)label_TRP2ConnectCheck);
		((Control)panel_TRP2_2).Controls.Add((Control)(object)linkLabelTRP2);
		((Control)panel_TRP2_2).Controls.Add((Control)(object)machineSelectControlTRP2);
		((Control)panel_TRP2_2).Controls.Add((Control)(object)pictureBox8);
		((Control)panel_TRP2_2).Controls.Add((Control)(object)label_TRP2Head);
		((Control)panel_TRP2_2).Controls.Add((Control)(object)label_TRP2_Machine);
		((Control)panel_TRP2_2).Controls.Add((Control)(object)label_TRP2_comment);
		((Control)panel_TRP2_2).Location = new Point(184, 3);
		((Control)panel_TRP2_2).Name = "panel_TRP2_2";
		((Control)panel_TRP2_2).Size = new Size(575, 470);
		((Control)panel_TRP2_2).TabIndex = 27;
		((Control)label_TRP2ConnectCheck).AutoSize = true;
		((Control)label_TRP2ConnectCheck).Font = new Font("MS UI Gothic", 9f);
		((Control)label_TRP2ConnectCheck).ForeColor = Color.Black;
		label_TRP2ConnectCheck.ImeMode = (ImeMode)0;
		((Control)label_TRP2ConnectCheck).Location = new Point(5, 423);
		((Control)label_TRP2ConnectCheck).Name = "label_TRP2ConnectCheck";
		((Control)label_TRP2ConnectCheck).Size = new Size(80, 12);
		((Control)label_TRP2ConnectCheck).TabIndex = 34;
		((Control)label_TRP2ConnectCheck).Text = "Connecting . . .";
		((Control)label_TRP2ConnectCheck).Visible = false;
		((Control)linkLabelTRP2).AutoSize = true;
		((Label)linkLabelTRP2).ImeMode = (ImeMode)0;
		linkLabelTRP2.LinkColor = Color.Red;
		((Control)linkLabelTRP2).Location = new Point(3, 423);
		((Control)linkLabelTRP2).Name = "linkLabelTRP2";
		((Control)linkLabelTRP2).Size = new Size(569, 12);
		((Control)linkLabelTRP2).TabIndex = 42;
		linkLabelTRP2.TabStop = true;
		((Control)linkLabelTRP2).Text = "接続の問題が解消しない場合はこちらをクリックしてください。機器の操作パネルから宛先を登録する手順が表示されます。";
		((Control)linkLabelTRP2).Visible = false;
		linkLabelTRP2.LinkClicked += new LinkLabelLinkClickedEventHandler(linkLabelConnect_LinkClicked);
		pictureBox8.Image = (Image)(object)Resources.Line;
		pictureBox8.ImeMode = (ImeMode)0;
		((Control)pictureBox8).Location = new Point(39, 48);
		((Control)pictureBox8).Margin = new Padding(1);
		((Control)pictureBox8).Name = "pictureBox8";
		((Control)pictureBox8).Size = new Size(539, 10);
		pictureBox8.TabIndex = 1;
		pictureBox8.TabStop = false;
		((Control)label_TRP2Head).AutoSize = true;
		((Control)label_TRP2Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		label_TRP2Head.ImeMode = (ImeMode)0;
		((Control)label_TRP2Head).Location = new Point(40, 21);
		((Control)label_TRP2Head).Name = "label_TRP2Head";
		((Control)label_TRP2Head).Size = new Size(114, 16);
		((Control)label_TRP2Head).TabIndex = 0;
		((Control)label_TRP2Head).Text = "Select Device";
		((Control)label_TRP2_Machine).AutoSize = true;
		((Control)label_TRP2_Machine).Font = new Font("MS UI Gothic", 9f);
		((Control)label_TRP2_Machine).ForeColor = Color.Blue;
		label_TRP2_Machine.ImeMode = (ImeMode)0;
		((Control)label_TRP2_Machine).Location = new Point(44, 130);
		((Control)label_TRP2_Machine).Name = "label_TRP2_Machine";
		((Control)label_TRP2_Machine).Size = new Size(40, 12);
		((Control)label_TRP2_Machine).TabIndex = 2;
		((Control)label_TRP2_Machine).Text = "Device";
		((Control)label_TRP2_comment).AutoSize = true;
		((Control)label_TRP2_comment).Font = new Font("MS UI Gothic", 9f);
		label_TRP2_comment.ImeMode = (ImeMode)0;
		((Control)label_TRP2_comment).Location = new Point(44, 75);
		((Control)label_TRP2_comment).Name = "label_TRP2_comment";
		((Control)label_TRP2_comment).Size = new Size(51, 12);
		((Control)label_TRP2_comment).TabIndex = 2;
		((Control)label_TRP2_comment).Text = "comment";
		((Control)panel_TRP2_1).BackColor = SystemColors.Control;
		panel_TRP2_1.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP2_1).Location = new Point(0, 3);
		((Control)panel_TRP2_1).Margin = new Padding(0);
		((Control)panel_TRP2_1).Name = "panel_TRP2_1";
		((Control)panel_TRP2_1).Size = new Size(181, 470);
		((Control)panel_TRP2_1).TabIndex = 24;
		((Control)tabTRP3_user).Controls.Add((Control)(object)panel_TRP3_3);
		((Control)tabTRP3_user).Controls.Add((Control)(object)panel_TRP3_2);
		((Control)tabTRP3_user).Controls.Add((Control)(object)panel_TRP3_1);
		tabTRP3_user.Location = new Point(4, 22);
		((Control)tabTRP3_user).Margin = new Padding(0);
		((Control)tabTRP3_user).Name = "tabTRP3_user";
		((Control)tabTRP3_user).Size = new Size(760, 497);
		tabTRP3_user.TabIndex = 8;
		((Control)tabTRP3_user).Text = "tabTRP3_user";
		tabTRP3_user.UseVisualStyleBackColor = true;
		((Control)panel_TRP3_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_TRP3_3.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP3_3).Controls.Add((Control)(object)btnTRP3Back);
		((Control)panel_TRP3_3).Controls.Add((Control)(object)btnTRP3Next);
		((Control)panel_TRP3_3).Dock = (DockStyle)2;
		((Control)panel_TRP3_3).Location = new Point(0, 446);
		((Control)panel_TRP3_3).Margin = new Padding(0);
		((Control)panel_TRP3_3).Name = "panel_TRP3_3";
		((Control)panel_TRP3_3).Size = new Size(760, 51);
		((Control)panel_TRP3_3).TabIndex = 29;
		((Control)panel_TRP3_2).BackColor = Color.White;
		((Control)panel_TRP3_2).Controls.Add((Control)(object)buttonTRP3Resume);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)label_TRP3_comment);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)buttonTRP3Break);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)labelTRP3progressText);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)buttonTRP3ToBottom);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)buttonTRP3Next);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)buttonTRP3Previous);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)buttonTRP3ToTop);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)label_TRP3DisplayedPage);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)label_TRP3Page);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)comboBoxTRP3SelectWay);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)buttonTRP3Search);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)textBoxTRP3Search);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)listViewAddressList);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)labelTRP3MFP_Selected);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)label_TRP3_SelectedDevice);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)label17);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)pictureBox9);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)label_TRP3Head);
		((Control)panel_TRP3_2).Location = new Point(184, 3);
		((Control)panel_TRP3_2).Name = "panel_TRP3_2";
		((Control)panel_TRP3_2).Size = new Size(575, 470);
		((Control)panel_TRP3_2).TabIndex = 28;
		((Control)buttonTRP3Resume).AutoSize = true;
		((ButtonBase)buttonTRP3Resume).ImeMode = (ImeMode)0;
		((Control)buttonTRP3Resume).Location = new Point(400, 182);
		((Control)buttonTRP3Resume).Name = "buttonTRP3Resume";
		((Control)buttonTRP3Resume).Size = new Size(65, 23);
		((Control)buttonTRP3Resume).TabIndex = 40;
		((Control)buttonTRP3Resume).Text = "btn3";
		((ButtonBase)buttonTRP3Resume).UseVisualStyleBackColor = true;
		((Control)buttonTRP3Resume).Visible = false;
		((Control)buttonTRP3Resume).Click += buttonResume_Click;
		((Control)label_TRP3_comment).AutoSize = true;
		((Control)label_TRP3_comment).Font = new Font("MS UI Gothic", 9f);
		label_TRP3_comment.ImeMode = (ImeMode)0;
		((Control)label_TRP3_comment).Location = new Point(44, 75);
		((Control)label_TRP3_comment).Name = "label_TRP3_comment";
		((Control)label_TRP3_comment).Size = new Size(51, 12);
		((Control)label_TRP3_comment).TabIndex = 41;
		((Control)label_TRP3_comment).Text = "comment";
		((Control)buttonTRP3Break).AutoSize = true;
		((ButtonBase)buttonTRP3Break).ImeMode = (ImeMode)0;
		((Control)buttonTRP3Break).Location = new Point(471, 182);
		((Control)buttonTRP3Break).Name = "buttonTRP3Break";
		((Control)buttonTRP3Break).Size = new Size(65, 23);
		((Control)buttonTRP3Break).TabIndex = 39;
		((Control)buttonTRP3Break).Text = "btn4";
		((ButtonBase)buttonTRP3Break).UseVisualStyleBackColor = true;
		((Control)buttonTRP3Break).Visible = false;
		((Control)buttonTRP3Break).Click += buttonTRP3Break_Click;
		labelTRP3progressText.ImeMode = (ImeMode)0;
		((Control)labelTRP3progressText).Location = new Point(287, 187);
		((Control)labelTRP3progressText).Name = "labelTRP3progressText";
		((Control)labelTRP3progressText).Size = new Size(249, 17);
		((Control)labelTRP3progressText).TabIndex = 38;
		((Control)labelTRP3progressText).Text = "label7";
		labelTRP3progressText.TextAlign = (ContentAlignment)4;
		((Control)buttonTRP3ToBottom).AutoSize = true;
		((ButtonBase)buttonTRP3ToBottom).ImeMode = (ImeMode)0;
		((Control)buttonTRP3ToBottom).Location = new Point(230, 182);
		((Control)buttonTRP3ToBottom).Name = "buttonTRP3ToBottom";
		((Control)buttonTRP3ToBottom).Size = new Size(30, 23);
		((Control)buttonTRP3ToBottom).TabIndex = 37;
		((Control)buttonTRP3ToBottom).Text = ">>";
		((ButtonBase)buttonTRP3ToBottom).UseVisualStyleBackColor = true;
		((Control)buttonTRP3ToBottom).Visible = false;
		((Control)buttonTRP3ToBottom).Click += buttonToBottom_Click;
		((Control)buttonTRP3Next).AutoSize = true;
		((ButtonBase)buttonTRP3Next).ImeMode = (ImeMode)0;
		((Control)buttonTRP3Next).Location = new Point(194, 182);
		((Control)buttonTRP3Next).Name = "buttonTRP3Next";
		((Control)buttonTRP3Next).Size = new Size(30, 23);
		((Control)buttonTRP3Next).TabIndex = 36;
		((Control)buttonTRP3Next).Text = ">";
		((ButtonBase)buttonTRP3Next).UseVisualStyleBackColor = true;
		((Control)buttonTRP3Next).Visible = false;
		((Control)buttonTRP3Next).Click += buttonNext_Click;
		((Control)buttonTRP3Previous).AutoSize = true;
		((ButtonBase)buttonTRP3Previous).ImeMode = (ImeMode)0;
		((Control)buttonTRP3Previous).Location = new Point(123, 182);
		((Control)buttonTRP3Previous).Name = "buttonTRP3Previous";
		((Control)buttonTRP3Previous).Size = new Size(30, 23);
		((Control)buttonTRP3Previous).TabIndex = 35;
		((Control)buttonTRP3Previous).Text = "<";
		((ButtonBase)buttonTRP3Previous).UseVisualStyleBackColor = true;
		((Control)buttonTRP3Previous).Visible = false;
		((Control)buttonTRP3Previous).Click += buttonPrevious_Click;
		((Control)buttonTRP3ToTop).AutoSize = true;
		((ButtonBase)buttonTRP3ToTop).ImeMode = (ImeMode)0;
		((Control)buttonTRP3ToTop).Location = new Point(87, 182);
		((Control)buttonTRP3ToTop).Name = "buttonTRP3ToTop";
		((Control)buttonTRP3ToTop).Size = new Size(30, 23);
		((Control)buttonTRP3ToTop).TabIndex = 34;
		((Control)buttonTRP3ToTop).Text = "<<";
		((ButtonBase)buttonTRP3ToTop).UseVisualStyleBackColor = true;
		((Control)buttonTRP3ToTop).Visible = false;
		((Control)buttonTRP3ToTop).Click += buttonToTop_Click;
		((Control)label_TRP3DisplayedPage).AutoSize = true;
		label_TRP3DisplayedPage.ImeMode = (ImeMode)0;
		((Control)label_TRP3DisplayedPage).Location = new Point(159, 187);
		((Control)label_TRP3DisplayedPage).Name = "label_TRP3DisplayedPage";
		((Control)label_TRP3DisplayedPage).Size = new Size(35, 12);
		((Control)label_TRP3DisplayedPage).TabIndex = 33;
		((Control)label_TRP3DisplayedPage).Text = "label6";
		((Control)label_TRP3Page).AutoSize = true;
		label_TRP3Page.ImeMode = (ImeMode)0;
		((Control)label_TRP3Page).Location = new Point(50, 187);
		((Control)label_TRP3Page).Name = "label_TRP3Page";
		((Control)label_TRP3Page).Size = new Size(35, 12);
		((Control)label_TRP3Page).TabIndex = 32;
		((Control)label_TRP3Page).Text = "label5";
		((ListControl)comboBoxTRP3SelectWay).FormattingEnabled = true;
		((Control)comboBoxTRP3SelectWay).Location = new Point(49, 149);
		((Control)comboBoxTRP3SelectWay).Name = "comboBoxTRP3SelectWay";
		((Control)comboBoxTRP3SelectWay).Size = new Size(110, 20);
		((Control)comboBoxTRP3SelectWay).TabIndex = 31;
		((Control)buttonTRP3Search).Anchor = (AnchorStyles)9;
		((Control)buttonTRP3Search).AutoSize = true;
		((ButtonBase)buttonTRP3Search).ImeMode = (ImeMode)0;
		((Control)buttonTRP3Search).Location = new Point(438, 148);
		((Control)buttonTRP3Search).Name = "buttonTRP3Search";
		((Control)buttonTRP3Search).Size = new Size(98, 23);
		((Control)buttonTRP3Search).TabIndex = 30;
		((Control)buttonTRP3Search).Text = "button2";
		((ButtonBase)buttonTRP3Search).UseVisualStyleBackColor = true;
		((Control)buttonTRP3Search).Click += buttonTRP3Search_Click;
		((Control)textBoxTRP3Search).Location = new Point(164, 150);
		((Control)textBoxTRP3Search).Name = "textBoxTRP3Search";
		((Control)textBoxTRP3Search).Size = new Size(269, 19);
		((Control)textBoxTRP3Search).TabIndex = 29;
		((Control)textBoxTRP3Search).KeyPress += new KeyPressEventHandler(textBoxSearch_KeyPress);
		listViewAddressList.Activation = (ItemActivation)1;
		listViewAddressList.AutoArrange = false;
		listViewAddressList.FullRowSelect = true;
		listViewAddressList.GridLines = true;
		listViewAddressList.HeaderStyle = (ColumnHeaderStyle)1;
		listViewAddressList.HideSelection = false;
		((Control)listViewAddressList).Location = new Point(49, 214);
		listViewAddressList.MultiSelect = false;
		((Control)listViewAddressList).Name = "listViewAddressList";
		listViewAddressList.OwnerDraw = true;
		listViewAddressList.ShowGroups = false;
		((Control)listViewAddressList).Size = new Size(487, 210);
		((Control)listViewAddressList).TabIndex = 27;
		listViewAddressList.UseCompatibleStateImageBehavior = false;
		listViewAddressList.View = (View)1;
		listViewAddressList.DrawColumnHeader += new DrawListViewColumnHeaderEventHandler(listViewAddressList_DrawColumnHeader);
		listViewAddressList.DrawItem += new DrawListViewItemEventHandler(listViewAddressList_DrawItem);
		listViewAddressList.ItemSelectionChanged += new ListViewItemSelectionChangedEventHandler(listViewAddressList_ItemSelectionChanged);
		((Control)labelTRP3MFP_Selected).AutoSize = true;
		labelTRP3MFP_Selected.ImeMode = (ImeMode)0;
		((Control)labelTRP3MFP_Selected).Location = new Point(149, 119);
		((Control)labelTRP3MFP_Selected).Name = "labelTRP3MFP_Selected";
		((Control)labelTRP3MFP_Selected).Size = new Size(0, 12);
		((Control)labelTRP3MFP_Selected).TabIndex = 25;
		((Control)label_TRP3_SelectedDevice).AutoSize = true;
		label_TRP3_SelectedDevice.ImeMode = (ImeMode)0;
		((Control)label_TRP3_SelectedDevice).Location = new Point(50, 119);
		((Control)label_TRP3_SelectedDevice).Name = "label_TRP3_SelectedDevice";
		((Control)label_TRP3_SelectedDevice).Size = new Size(35, 12);
		((Control)label_TRP3_SelectedDevice).TabIndex = 24;
		((Control)label_TRP3_SelectedDevice).Text = "label3";
		((Control)label17).Anchor = (AnchorStyles)13;
		label17.BorderStyle = (BorderStyle)2;
		label17.ImeMode = (ImeMode)0;
		((Control)label17).Location = new Point(47, 428);
		((Control)label17).Name = "label17";
		((Control)label17).Size = new Size(481, 1);
		((Control)label17).TabIndex = 26;
		pictureBox9.Image = (Image)(object)Resources.Line;
		pictureBox9.ImeMode = (ImeMode)0;
		((Control)pictureBox9).Location = new Point(39, 48);
		((Control)pictureBox9).Margin = new Padding(1);
		((Control)pictureBox9).Name = "pictureBox9";
		((Control)pictureBox9).Size = new Size(539, 10);
		pictureBox9.TabIndex = 1;
		pictureBox9.TabStop = false;
		((Control)label_TRP3Head).AutoSize = true;
		((Control)label_TRP3Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		label_TRP3Head.ImeMode = (ImeMode)0;
		((Control)label_TRP3Head).Location = new Point(40, 21);
		((Control)label_TRP3Head).Name = "label_TRP3Head";
		((Control)label_TRP3Head).Size = new Size(98, 16);
		((Control)label_TRP3Head).TabIndex = 0;
		((Control)label_TRP3Head).Text = "Select User";
		((Control)panel_TRP3_1).BackColor = SystemColors.Control;
		panel_TRP3_1.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP3_1).Location = new Point(0, 3);
		((Control)panel_TRP3_1).Margin = new Padding(0);
		((Control)panel_TRP3_1).Name = "panel_TRP3_1";
		((Control)panel_TRP3_1).Size = new Size(181, 470);
		((Control)panel_TRP3_1).TabIndex = 27;
		((Control)tabTRP4_analyze).Controls.Add((Control)(object)panel_TRP4_3);
		((Control)tabTRP4_analyze).Controls.Add((Control)(object)panel_TRP4_2);
		((Control)tabTRP4_analyze).Controls.Add((Control)(object)panel_TRP4_1);
		tabTRP4_analyze.Location = new Point(4, 22);
		((Control)tabTRP4_analyze).Margin = new Padding(0);
		((Control)tabTRP4_analyze).Name = "tabTRP4_analyze";
		((Control)tabTRP4_analyze).Size = new Size(760, 497);
		tabTRP4_analyze.TabIndex = 9;
		((Control)tabTRP4_analyze).Text = "tabTRP4_analyze";
		tabTRP4_analyze.UseVisualStyleBackColor = true;
		((Control)panel_TRP4_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_TRP4_3.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP4_3).Dock = (DockStyle)2;
		((Control)panel_TRP4_3).Location = new Point(0, 446);
		((Control)panel_TRP4_3).Margin = new Padding(0);
		((Control)panel_TRP4_3).Name = "panel_TRP4_3";
		((Control)panel_TRP4_3).Size = new Size(760, 51);
		((Control)panel_TRP4_3).TabIndex = 23;
		((Control)panel_TRP4_2).BackColor = Color.White;
		panel_TRP4_2.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP4_2).Controls.Add((Control)(object)progressBarTRP4);
		((Control)panel_TRP4_2).Controls.Add((Control)(object)label_TRP4_progress);
		((Control)panel_TRP4_2).Controls.Add((Control)(object)pictureBox10);
		((Control)panel_TRP4_2).Controls.Add((Control)(object)label_TRP4Head);
		((Control)panel_TRP4_2).Controls.Add((Control)(object)label_TRP4_comment);
		((Control)panel_TRP4_2).Location = new Point(184, 3);
		((Control)panel_TRP4_2).Name = "panel_TRP4_2";
		((Control)panel_TRP4_2).Size = new Size(575, 470);
		((Control)panel_TRP4_2).TabIndex = 22;
		progressBarTRP4.ImeMode = (ImeMode)0;
		((Control)progressBarTRP4).Location = new Point(44, 145);
		progressBarTRP4.Maximum = 7;
		((Control)progressBarTRP4).Name = "progressBarTRP4";
		((Control)progressBarTRP4).Size = new Size(476, 23);
		((Control)progressBarTRP4).TabIndex = 5;
		((Control)label_TRP4_progress).AutoSize = true;
		((Control)label_TRP4_progress).Font = new Font("MS UI Gothic", 9f);
		label_TRP4_progress.ImeMode = (ImeMode)0;
		((Control)label_TRP4_progress).Location = new Point(46, 130);
		((Control)label_TRP4_progress).Name = "label_TRP4_progress";
		((Control)label_TRP4_progress).Size = new Size(41, 12);
		((Control)label_TRP4_progress).TabIndex = 4;
		((Control)label_TRP4_progress).Text = "label28";
		pictureBox10.Image = (Image)(object)Resources.Line;
		pictureBox10.ImeMode = (ImeMode)0;
		((Control)pictureBox10).Location = new Point(39, 48);
		((Control)pictureBox10).Margin = new Padding(1);
		((Control)pictureBox10).Name = "pictureBox10";
		((Control)pictureBox10).Size = new Size(537, 10);
		pictureBox10.TabIndex = 1;
		pictureBox10.TabStop = false;
		((Control)label_TRP4Head).AutoSize = true;
		((Control)label_TRP4Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		label_TRP4Head.ImeMode = (ImeMode)0;
		((Control)label_TRP4Head).Location = new Point(40, 21);
		((Control)label_TRP4Head).Name = "label_TRP4Head";
		((Control)label_TRP4Head).Size = new Size(67, 16);
		((Control)label_TRP4Head).TabIndex = 0;
		((Control)label_TRP4Head).Text = "Analyze";
		((Control)label_TRP4_comment).AutoSize = true;
		((Control)label_TRP4_comment).Font = new Font("MS UI Gothic", 9f);
		label_TRP4_comment.ImeMode = (ImeMode)0;
		((Control)label_TRP4_comment).Location = new Point(45, 75);
		((Control)label_TRP4_comment).Name = "label_TRP4_comment";
		((Control)label_TRP4_comment).Size = new Size(103, 12);
		((Control)label_TRP4_comment).TabIndex = 2;
		((Control)label_TRP4_comment).Text = "Analyzing message";
		((Control)panel_TRP4_1).BackColor = SystemColors.Control;
		panel_TRP4_1.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP4_1).Location = new Point(0, 3);
		((Control)panel_TRP4_1).Margin = new Padding(0);
		((Control)panel_TRP4_1).Name = "panel_TRP4_1";
		((Control)panel_TRP4_1).Size = new Size(181, 470);
		((Control)panel_TRP4_1).TabIndex = 21;
		((Control)tabTRP5_result).Controls.Add((Control)(object)panel_TRP5_3);
		((Control)tabTRP5_result).Controls.Add((Control)(object)panel_TRP5_2);
		((Control)tabTRP5_result).Controls.Add((Control)(object)panel_TRP5_1);
		tabTRP5_result.Location = new Point(4, 22);
		((Control)tabTRP5_result).Name = "tabTRP5_result";
		((Control)tabTRP5_result).Size = new Size(760, 497);
		tabTRP5_result.TabIndex = 12;
		((Control)tabTRP5_result).Text = "tabTRP5_result";
		tabTRP5_result.UseVisualStyleBackColor = true;
		((Control)panel_TRP5_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_TRP5_3.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP5_3).Controls.Add((Control)(object)btnTRP5Back);
		((Control)panel_TRP5_3).Controls.Add((Control)(object)btnTRP5Next);
		((Control)panel_TRP5_3).Dock = (DockStyle)2;
		((Control)panel_TRP5_3).Location = new Point(0, 446);
		((Control)panel_TRP5_3).Margin = new Padding(0);
		((Control)panel_TRP5_3).Name = "panel_TRP5_3";
		((Control)panel_TRP5_3).Size = new Size(760, 51);
		((Control)panel_TRP5_3).TabIndex = 24;
		((Control)panel_TRP5_2).BackColor = Color.White;
		panel_TRP5_2.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP5_2).Controls.Add((Control)(object)label_TRP5_comment);
		((Control)panel_TRP5_2).Controls.Add((Control)(object)pictureBox13);
		((Control)panel_TRP5_2).Controls.Add((Control)(object)label_TRP5Head);
		((Control)panel_TRP5_2).Controls.Add((Control)(object)panel40);
		((Control)panel_TRP5_2).Location = new Point(184, 3);
		((Control)panel_TRP5_2).Name = "panel_TRP5_2";
		((Control)panel_TRP5_2).Size = new Size(575, 470);
		((Control)panel_TRP5_2).TabIndex = 23;
		((Control)label_TRP5_comment).AutoSize = true;
		((Control)label_TRP5_comment).Font = new Font("MS UI Gothic", 9f);
		label_TRP5_comment.ImeMode = (ImeMode)0;
		((Control)label_TRP5_comment).Location = new Point(45, 77);
		((Control)label_TRP5_comment).Name = "label_TRP5_comment";
		((Control)label_TRP5_comment).Size = new Size(119, 12);
		((Control)label_TRP5_comment).TabIndex = 8;
		((Control)label_TRP5_comment).Text = "Confirmation message";
		pictureBox13.Image = (Image)(object)Resources.Line;
		pictureBox13.ImeMode = (ImeMode)0;
		((Control)pictureBox13).Location = new Point(39, 48);
		((Control)pictureBox13).Margin = new Padding(1);
		((Control)pictureBox13).Name = "pictureBox13";
		((Control)pictureBox13).Size = new Size(537, 10);
		pictureBox13.TabIndex = 1;
		pictureBox13.TabStop = false;
		((Control)label_TRP5Head).AutoSize = true;
		((Control)label_TRP5Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		label_TRP5Head.ImeMode = (ImeMode)0;
		((Control)label_TRP5Head).Location = new Point(40, 21);
		((Control)label_TRP5Head).Name = "label_TRP5Head";
		((Control)label_TRP5Head).Size = new Size(56, 16);
		((Control)label_TRP5Head).TabIndex = 0;
		((Control)label_TRP5Head).Text = "Result";
		panel40.BorderStyle = (BorderStyle)2;
		((Control)panel40).Controls.Add((Control)(object)richTextBoxTRP5);
		((Control)panel40).Font = new Font("MS UI Gothic", 9f);
		((Control)panel40).Location = new Point(44, 117);
		((Control)panel40).Name = "panel40";
		((Control)panel40).Size = new Size(503, 316);
		((Control)panel40).TabIndex = 6;
		((TextBoxBase)richTextBoxTRP5).BorderStyle = (BorderStyle)0;
		richTextBoxTRP5.DetectUrls = false;
		((Control)richTextBoxTRP5).Location = new Point(3, 3);
		((Control)richTextBoxTRP5).Name = "richTextBoxTRP5";
		((Control)richTextBoxTRP5).Size = new Size(490, 306);
		((Control)richTextBoxTRP5).TabIndex = 2;
		((Control)richTextBoxTRP5).Text = "";
		((Control)panel_TRP5_1).BackColor = SystemColors.Control;
		panel_TRP5_1.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP5_1).Location = new Point(0, 3);
		((Control)panel_TRP5_1).Margin = new Padding(0);
		((Control)panel_TRP5_1).Name = "panel_TRP5_1";
		((Control)panel_TRP5_1).Size = new Size(181, 470);
		((Control)panel_TRP5_1).TabIndex = 22;
		((Control)tabTRP6_setupSelect).Controls.Add((Control)(object)panel_TRP6_3);
		((Control)tabTRP6_setupSelect).Controls.Add((Control)(object)panel_TRP6_2);
		((Control)tabTRP6_setupSelect).Controls.Add((Control)(object)panel_TRP6_1);
		tabTRP6_setupSelect.Location = new Point(4, 22);
		((Control)tabTRP6_setupSelect).Name = "tabTRP6_setupSelect";
		((Control)tabTRP6_setupSelect).Size = new Size(760, 497);
		tabTRP6_setupSelect.TabIndex = 14;
		((Control)tabTRP6_setupSelect).Text = "tabTRP6_setupSelect";
		tabTRP6_setupSelect.UseVisualStyleBackColor = true;
		((Control)panel_TRP6_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_TRP6_3.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP6_3).Controls.Add((Control)(object)btnTRP6Back);
		((Control)panel_TRP6_3).Controls.Add((Control)(object)btnTRP6Next);
		((Control)panel_TRP6_3).Dock = (DockStyle)2;
		((Control)panel_TRP6_3).Location = new Point(0, 446);
		((Control)panel_TRP6_3).Margin = new Padding(0);
		((Control)panel_TRP6_3).Name = "panel_TRP6_3";
		((Control)panel_TRP6_3).Size = new Size(760, 51);
		((Control)panel_TRP6_3).TabIndex = 18;
		((Control)panel_TRP6_2).BackColor = Color.White;
		panel_TRP6_2.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP6_2).Controls.Add((Control)(object)label_TRP6_SelectFolder);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)label_TRP6_SelectNonSharedFolder);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)cmbTRP6Folder);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)radioButtonTRP6selectNonSharedFolder);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)radioButtonTRP6selectExistFolder);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)radioButtonTRP6createNewFolder);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)label_TRP6_Folder);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)buttonTRP6SelectFolder);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)textBoxTRP6FolderPath);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)label_TRP6_FolderPath);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)textBoxTRP6FolderName);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)label_TRP6_FolderName);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)label_TRP6_NonSharedFolderPath);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)buttonTRP6SelectNonSharedFolder);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)textBoxTRP6NonSharedFolderPath);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)pictureBox16);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)textBoxTRP6SharedName);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)label_TRP6_SharedName);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)label_TRP6Head);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)label_TRP6_comment);
		((Control)panel_TRP6_2).Location = new Point(184, 3);
		((Control)panel_TRP6_2).Name = "panel_TRP6_2";
		((Control)panel_TRP6_2).Size = new Size(575, 470);
		((Control)panel_TRP6_2).TabIndex = 19;
		((Control)label_TRP6_SelectFolder).AutoSize = true;
		((Control)label_TRP6_SelectFolder).Enabled = false;
		label_TRP6_SelectFolder.ImeMode = (ImeMode)0;
		((Control)label_TRP6_SelectFolder).Location = new Point(56, 355);
		((Control)label_TRP6_SelectFolder).Name = "label_TRP6_SelectFolder";
		((Control)label_TRP6_SelectFolder).Size = new Size(148, 12);
		((Control)label_TRP6_SelectFolder).TabIndex = 16;
		((Control)label_TRP6_SelectFolder).Text = "Select folder for destination";
		((Control)label_TRP6_SelectNonSharedFolder).AutoSize = true;
		((Control)label_TRP6_SelectNonSharedFolder).Enabled = false;
		label_TRP6_SelectNonSharedFolder.ImeMode = (ImeMode)0;
		((Control)label_TRP6_SelectNonSharedFolder).Location = new Point(56, 246);
		((Control)label_TRP6_SelectNonSharedFolder).Name = "label_TRP6_SelectNonSharedFolder";
		((Control)label_TRP6_SelectNonSharedFolder).Size = new Size(130, 12);
		((Control)label_TRP6_SelectNonSharedFolder).TabIndex = 16;
		((Control)label_TRP6_SelectNonSharedFolder).Text = "Select non shared folder";
		cmbTRP6Folder.DropDownStyle = (ComboBoxStyle)2;
		cmbTRP6Folder.DropDownWidth = 401;
		((Control)cmbTRP6Folder).Enabled = false;
		((ListControl)cmbTRP6Folder).FormattingEnabled = true;
		((Control)cmbTRP6Folder).Location = new Point(180, 380);
		((Control)cmbTRP6Folder).Name = "cmbTRP6Folder";
		((Control)cmbTRP6Folder).Size = new Size(343, 20);
		cmbTRP6Folder.Sorted = true;
		((Control)cmbTRP6Folder).TabIndex = 15;
		((Control)radioButtonTRP6selectNonSharedFolder).AutoSize = true;
		((ButtonBase)radioButtonTRP6selectNonSharedFolder).ImeMode = (ImeMode)0;
		((Control)radioButtonTRP6selectNonSharedFolder).Location = new Point(50, 224);
		((Control)radioButtonTRP6selectNonSharedFolder).Name = "radioButtonTRP6selectNonSharedFolder";
		((Control)radioButtonTRP6selectNonSharedFolder).Size = new Size(114, 16);
		((Control)radioButtonTRP6selectNonSharedFolder).TabIndex = 13;
		radioButtonTRP6selectNonSharedFolder.TabStop = true;
		((Control)radioButtonTRP6selectNonSharedFolder).Text = "Create new folder";
		((ButtonBase)radioButtonTRP6selectNonSharedFolder).UseVisualStyleBackColor = true;
		radioButtonTRP6selectNonSharedFolder.CheckedChanged += radioButtonTRP6createNewFolder_CheckedChanged;
		((Control)radioButtonTRP6selectExistFolder).AutoSize = true;
		((ButtonBase)radioButtonTRP6selectExistFolder).ImeMode = (ImeMode)0;
		((Control)radioButtonTRP6selectExistFolder).Location = new Point(50, 333);
		((Control)radioButtonTRP6selectExistFolder).Name = "radioButtonTRP6selectExistFolder";
		((Control)radioButtonTRP6selectExistFolder).Size = new Size(117, 16);
		((Control)radioButtonTRP6selectExistFolder).TabIndex = 14;
		((Control)radioButtonTRP6selectExistFolder).Text = "Select exist folder";
		((ButtonBase)radioButtonTRP6selectExistFolder).UseVisualStyleBackColor = true;
		radioButtonTRP6selectExistFolder.CheckedChanged += radioButtonTRP6createNewFolder_CheckedChanged;
		((Control)radioButtonTRP6createNewFolder).AutoSize = true;
		radioButtonTRP6createNewFolder.Checked = true;
		((ButtonBase)radioButtonTRP6createNewFolder).ImeMode = (ImeMode)0;
		((Control)radioButtonTRP6createNewFolder).Location = new Point(50, 132);
		((Control)radioButtonTRP6createNewFolder).Name = "radioButtonTRP6createNewFolder";
		((Control)radioButtonTRP6createNewFolder).Size = new Size(114, 16);
		((Control)radioButtonTRP6createNewFolder).TabIndex = 13;
		radioButtonTRP6createNewFolder.TabStop = true;
		((Control)radioButtonTRP6createNewFolder).Text = "Create new folder";
		((ButtonBase)radioButtonTRP6createNewFolder).UseVisualStyleBackColor = true;
		radioButtonTRP6createNewFolder.CheckedChanged += radioButtonTRP6createNewFolder_CheckedChanged;
		((Control)label_TRP6_Folder).AutoSize = true;
		((Control)label_TRP6_Folder).Enabled = false;
		((Control)label_TRP6_Folder).ForeColor = Color.Blue;
		label_TRP6_Folder.ImeMode = (ImeMode)0;
		((Control)label_TRP6_Folder).Location = new Point(56, 384);
		((Control)label_TRP6_Folder).Name = "label_TRP6_Folder";
		((Control)label_TRP6_Folder).Size = new Size(37, 12);
		((Control)label_TRP6_Folder).TabIndex = 12;
		((Control)label_TRP6_Folder).Text = "Folder";
		((Control)buttonTRP6SelectFolder).AutoSize = true;
		((Control)buttonTRP6SelectFolder).Font = new Font("MS UI Gothic", 9f);
		((ButtonBase)buttonTRP6SelectFolder).ImeMode = (ImeMode)0;
		((Control)buttonTRP6SelectFolder).Location = new Point(497, 157);
		((Control)buttonTRP6SelectFolder).Name = "buttonTRP6SelectFolder";
		((Control)buttonTRP6SelectFolder).Size = new Size(55, 22);
		((Control)buttonTRP6SelectFolder).TabIndex = 5;
		((Control)buttonTRP6SelectFolder).Text = "参照";
		((ButtonBase)buttonTRP6SelectFolder).UseVisualStyleBackColor = true;
		((Control)buttonTRP6SelectFolder).Click += buttonTRP6SelectFolder_Click;
		((Control)textBoxTRP6FolderPath).Font = new Font("MS UI Gothic", 9f);
		((Control)textBoxTRP6FolderPath).Location = new Point(180, 158);
		((Control)textBoxTRP6FolderPath).Name = "textBoxTRP6FolderPath";
		((Control)textBoxTRP6FolderPath).Size = new Size(311, 19);
		((Control)textBoxTRP6FolderPath).TabIndex = 4;
		((Control)textBoxTRP6FolderPath).Enter += textBoxTRP6FolderPath_Enter;
		((Control)textBoxTRP6FolderPath).Leave += textBoxTRP6FolderPath_Leave;
		((Control)label_TRP6_FolderPath).AutoSize = true;
		((Control)label_TRP6_FolderPath).Font = new Font("MS UI Gothic", 9f);
		((Control)label_TRP6_FolderPath).ForeColor = Color.Blue;
		label_TRP6_FolderPath.ImeMode = (ImeMode)0;
		((Control)label_TRP6_FolderPath).Location = new Point(56, 160);
		((Control)label_TRP6_FolderPath).Name = "label_TRP6_FolderPath";
		((Control)label_TRP6_FolderPath).Size = new Size(64, 12);
		((Control)label_TRP6_FolderPath).TabIndex = 11;
		((Control)label_TRP6_FolderPath).Text = "Folder Path";
		((Control)textBoxTRP6FolderName).Font = new Font("MS UI Gothic", 9f);
		((Control)textBoxTRP6FolderName).Location = new Point(180, 186);
		((Control)textBoxTRP6FolderName).Name = "textBoxTRP6FolderName";
		((Control)textBoxTRP6FolderName).Size = new Size(373, 19);
		((Control)textBoxTRP6FolderName).TabIndex = 3;
		((Control)textBoxTRP6FolderName).Text = "ScanDoc";
		((Control)textBoxTRP6FolderName).Enter += textBoxTRP6FolderName_Enter;
		((Control)textBoxTRP6FolderName).Leave += textBoxTRP6FolderName_Leave;
		((Control)label_TRP6_FolderName).AutoSize = true;
		((Control)label_TRP6_FolderName).Font = new Font("MS UI Gothic", 9f);
		((Control)label_TRP6_FolderName).ForeColor = Color.Blue;
		label_TRP6_FolderName.ImeMode = (ImeMode)0;
		((Control)label_TRP6_FolderName).Location = new Point(56, 188);
		((Control)label_TRP6_FolderName).Name = "label_TRP6_FolderName";
		((Control)label_TRP6_FolderName).Size = new Size(66, 12);
		((Control)label_TRP6_FolderName).TabIndex = 9;
		((Control)label_TRP6_FolderName).Text = "FolderName";
		((Control)label_TRP6_NonSharedFolderPath).AutoSize = true;
		((Control)label_TRP6_NonSharedFolderPath).Enabled = false;
		((Control)label_TRP6_NonSharedFolderPath).Font = new Font("MS UI Gothic", 9f);
		((Control)label_TRP6_NonSharedFolderPath).ForeColor = Color.Blue;
		label_TRP6_NonSharedFolderPath.ImeMode = (ImeMode)0;
		((Control)label_TRP6_NonSharedFolderPath).Location = new Point(56, 270);
		((Control)label_TRP6_NonSharedFolderPath).Name = "label_TRP6_NonSharedFolderPath";
		((Control)label_TRP6_NonSharedFolderPath).Size = new Size(64, 12);
		((Control)label_TRP6_NonSharedFolderPath).TabIndex = 11;
		((Control)label_TRP6_NonSharedFolderPath).Text = "Folder Path";
		((Control)buttonTRP6SelectNonSharedFolder).AutoSize = true;
		((Control)buttonTRP6SelectNonSharedFolder).Enabled = false;
		((Control)buttonTRP6SelectNonSharedFolder).Font = new Font("MS UI Gothic", 9f);
		((ButtonBase)buttonTRP6SelectNonSharedFolder).ImeMode = (ImeMode)0;
		((Control)buttonTRP6SelectNonSharedFolder).Location = new Point(497, 268);
		((Control)buttonTRP6SelectNonSharedFolder).Name = "buttonTRP6SelectNonSharedFolder";
		((Control)buttonTRP6SelectNonSharedFolder).Size = new Size(55, 22);
		((Control)buttonTRP6SelectNonSharedFolder).TabIndex = 5;
		((Control)buttonTRP6SelectNonSharedFolder).Text = "参照";
		((ButtonBase)buttonTRP6SelectNonSharedFolder).UseVisualStyleBackColor = true;
		((Control)buttonTRP6SelectNonSharedFolder).Click += buttonTRP6SelectNonSharedFolder_Click;
		((Control)textBoxTRP6NonSharedFolderPath).Enabled = false;
		((Control)textBoxTRP6NonSharedFolderPath).Font = new Font("MS UI Gothic", 9f);
		((Control)textBoxTRP6NonSharedFolderPath).Location = new Point(180, 268);
		((Control)textBoxTRP6NonSharedFolderPath).Name = "textBoxTRP6NonSharedFolderPath";
		((Control)textBoxTRP6NonSharedFolderPath).Size = new Size(261, 19);
		((Control)textBoxTRP6NonSharedFolderPath).TabIndex = 4;
		((Control)textBoxTRP6NonSharedFolderPath).Enter += textBoxTRP6NonSharedFolderPath_Enter;
		((Control)textBoxTRP6NonSharedFolderPath).Leave += textBoxTRP6NonSharedFolderPath_Leave;
		pictureBox16.Image = (Image)(object)Resources.Line;
		pictureBox16.ImeMode = (ImeMode)0;
		((Control)pictureBox16).Location = new Point(39, 48);
		((Control)pictureBox16).Margin = new Padding(1);
		((Control)pictureBox16).Name = "pictureBox16";
		((Control)pictureBox16).Size = new Size(539, 10);
		pictureBox16.TabIndex = 1;
		pictureBox16.TabStop = false;
		((Control)textBoxTRP6SharedName).Enabled = false;
		((Control)textBoxTRP6SharedName).Font = new Font("MS UI Gothic", 9f);
		((Control)textBoxTRP6SharedName).Location = new Point(180, 298);
		((Control)textBoxTRP6SharedName).Name = "textBoxTRP6SharedName";
		((Control)textBoxTRP6SharedName).Size = new Size(371, 19);
		((Control)textBoxTRP6SharedName).TabIndex = 4;
		((Control)textBoxTRP6SharedName).Enter += textBoxTRP6SharedName_Enter;
		((Control)textBoxTRP6SharedName).Leave += textBoxTRP6SharedName_Leave;
		((Control)label_TRP6_SharedName).AutoSize = true;
		((Control)label_TRP6_SharedName).Enabled = false;
		((Control)label_TRP6_SharedName).Font = new Font("MS UI Gothic", 9f);
		((Control)label_TRP6_SharedName).ForeColor = Color.Blue;
		label_TRP6_SharedName.ImeMode = (ImeMode)0;
		((Control)label_TRP6_SharedName).Location = new Point(56, 300);
		((Control)label_TRP6_SharedName).Name = "label_TRP6_SharedName";
		((Control)label_TRP6_SharedName).Size = new Size(73, 12);
		((Control)label_TRP6_SharedName).TabIndex = 11;
		((Control)label_TRP6_SharedName).Text = "Shared Name";
		((Control)label_TRP6Head).AutoSize = true;
		((Control)label_TRP6Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		label_TRP6Head.ImeMode = (ImeMode)0;
		((Control)label_TRP6Head).Location = new Point(40, 21);
		((Control)label_TRP6Head).Name = "label_TRP6Head";
		((Control)label_TRP6Head).Size = new Size(109, 16);
		((Control)label_TRP6Head).TabIndex = 0;
		((Control)label_TRP6Head).Text = "CreateFolder";
		((Control)label_TRP6_comment).AutoSize = true;
		((Control)label_TRP6_comment).Font = new Font("MS UI Gothic", 9f);
		label_TRP6_comment.ImeMode = (ImeMode)0;
		((Control)label_TRP6_comment).Location = new Point(45, 75);
		((Control)label_TRP6_comment).Name = "label_TRP6_comment";
		((Control)label_TRP6_comment).Size = new Size(125, 12);
		((Control)label_TRP6_comment).TabIndex = 2;
		((Control)label_TRP6_comment).Text = "Folder setting message";
		((Control)panel_TRP6_1).BackColor = SystemColors.Control;
		panel_TRP6_1.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP6_1).Location = new Point(0, 3);
		((Control)panel_TRP6_1).Margin = new Padding(0);
		((Control)panel_TRP6_1).Name = "panel_TRP6_1";
		((Control)panel_TRP6_1).Size = new Size(181, 470);
		((Control)panel_TRP6_1).TabIndex = 23;
		((Control)tabTRP7_shareFolder).Controls.Add((Control)(object)panel_TRP7_3);
		((Control)tabTRP7_shareFolder).Controls.Add((Control)(object)panel_TRP7_2);
		((Control)tabTRP7_shareFolder).Controls.Add((Control)(object)panel_TRP7_1);
		tabTRP7_shareFolder.Location = new Point(4, 22);
		((Control)tabTRP7_shareFolder).Margin = new Padding(0);
		((Control)tabTRP7_shareFolder).Name = "tabTRP7_shareFolder";
		((Control)tabTRP7_shareFolder).Size = new Size(760, 497);
		tabTRP7_shareFolder.TabIndex = 10;
		((Control)tabTRP7_shareFolder).Text = "tabTRP7_shareFolder";
		tabTRP7_shareFolder.UseVisualStyleBackColor = true;
		((Control)panel_TRP7_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_TRP7_3.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP7_3).Controls.Add((Control)(object)btnTRP7Back);
		((Control)panel_TRP7_3).Controls.Add((Control)(object)btnTRP7Next);
		((Control)panel_TRP7_3).Dock = (DockStyle)2;
		((Control)panel_TRP7_3).Location = new Point(0, 446);
		((Control)panel_TRP7_3).Margin = new Padding(0);
		((Control)panel_TRP7_3).Name = "panel_TRP7_3";
		((Control)panel_TRP7_3).Size = new Size(760, 51);
		((Control)panel_TRP7_3).TabIndex = 21;
		((Control)panel_TRP7_2).BackColor = Color.White;
		panel_TRP7_2.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP7_2).Controls.Add((Control)(object)cmbTRP7PcUser);
		((Control)panel_TRP7_2).Controls.Add((Control)(object)label_TRP7_UserName);
		((Control)panel_TRP7_2).Controls.Add((Control)(object)label_TRP7_PasswordConfirm);
		((Control)panel_TRP7_2).Controls.Add((Control)(object)textBoxTRP7PassConfirm);
		((Control)panel_TRP7_2).Controls.Add((Control)(object)textBoxTRP7Pass);
		((Control)panel_TRP7_2).Controls.Add((Control)(object)label_TRP7_Password);
		((Control)panel_TRP7_2).Controls.Add((Control)(object)pictureBox12);
		((Control)panel_TRP7_2).Controls.Add((Control)(object)label_TRP7Head);
		((Control)panel_TRP7_2).Controls.Add((Control)(object)label_TRP7_comment);
		((Control)panel_TRP7_2).Location = new Point(184, 3);
		((Control)panel_TRP7_2).Name = "panel_TRP7_2";
		((Control)panel_TRP7_2).Size = new Size(575, 470);
		((Control)panel_TRP7_2).TabIndex = 22;
		cmbTRP7PcUser.DropDownStyle = (ComboBoxStyle)2;
		((Control)cmbTRP7PcUser).Enabled = false;
		((Control)cmbTRP7PcUser).Font = new Font("MS UI Gothic", 9f);
		((ListControl)cmbTRP7PcUser).FormattingEnabled = true;
		((Control)cmbTRP7PcUser).Location = new Point(155, 125);
		((Control)cmbTRP7PcUser).Name = "cmbTRP7PcUser";
		((Control)cmbTRP7PcUser).Size = new Size(388, 20);
		((Control)cmbTRP7PcUser).TabIndex = 25;
		((Control)label_TRP7_UserName).AutoSize = true;
		((Control)label_TRP7_UserName).Font = new Font("MS UI Gothic", 9f);
		((Control)label_TRP7_UserName).ForeColor = Color.Blue;
		label_TRP7_UserName.ImeMode = (ImeMode)0;
		((Control)label_TRP7_UserName).Location = new Point(47, 128);
		((Control)label_TRP7_UserName).Name = "label_TRP7_UserName";
		((Control)label_TRP7_UserName).Size = new Size(58, 12);
		((Control)label_TRP7_UserName).TabIndex = 23;
		((Control)label_TRP7_UserName).Text = "UserName";
		((Control)label_TRP7_PasswordConfirm).AutoSize = true;
		((Control)label_TRP7_PasswordConfirm).Font = new Font("MS UI Gothic", 9f);
		((Control)label_TRP7_PasswordConfirm).ForeColor = Color.Blue;
		label_TRP7_PasswordConfirm.ImeMode = (ImeMode)0;
		((Control)label_TRP7_PasswordConfirm).Location = new Point(47, 198);
		((Control)label_TRP7_PasswordConfirm).Name = "label_TRP7_PasswordConfirm";
		((Control)label_TRP7_PasswordConfirm).Size = new Size(102, 12);
		((Control)label_TRP7_PasswordConfirm).TabIndex = 22;
		((Control)label_TRP7_PasswordConfirm).Text = "Password(Confirm)";
		((Control)textBoxTRP7PassConfirm).Font = new Font("MS UI Gothic", 9f);
		((Control)textBoxTRP7PassConfirm).Location = new Point(155, 195);
		((Control)textBoxTRP7PassConfirm).Name = "textBoxTRP7PassConfirm";
		textBoxTRP7PassConfirm.PasswordChar = '*';
		((Control)textBoxTRP7PassConfirm).Size = new Size(388, 19);
		((Control)textBoxTRP7PassConfirm).TabIndex = 11;
		((Control)textBoxTRP7PassConfirm).Enter += textBoxTRP6PassConfirm_Enter;
		((Control)textBoxTRP7PassConfirm).Leave += textBoxTRP6PassConfirm_Leave;
		((Control)textBoxTRP7Pass).Font = new Font("MS UI Gothic", 9f);
		((Control)textBoxTRP7Pass).Location = new Point(155, 160);
		((Control)textBoxTRP7Pass).Name = "textBoxTRP7Pass";
		textBoxTRP7Pass.PasswordChar = '*';
		((Control)textBoxTRP7Pass).Size = new Size(388, 19);
		((Control)textBoxTRP7Pass).TabIndex = 10;
		((Control)textBoxTRP7Pass).Enter += textBoxTRP6Pass_Enter;
		((Control)textBoxTRP7Pass).Leave += textBoxTRP6Pass_Leave;
		((Control)label_TRP7_Password).AutoSize = true;
		((Control)label_TRP7_Password).Font = new Font("MS UI Gothic", 9f);
		((Control)label_TRP7_Password).ForeColor = Color.Blue;
		label_TRP7_Password.ImeMode = (ImeMode)0;
		((Control)label_TRP7_Password).Location = new Point(47, 163);
		((Control)label_TRP7_Password).Name = "label_TRP7_Password";
		((Control)label_TRP7_Password).Size = new Size(54, 12);
		((Control)label_TRP7_Password).TabIndex = 20;
		((Control)label_TRP7_Password).Text = "Password";
		pictureBox12.Image = (Image)(object)Resources.Line;
		pictureBox12.ImeMode = (ImeMode)0;
		((Control)pictureBox12).Location = new Point(39, 48);
		((Control)pictureBox12).Margin = new Padding(1);
		((Control)pictureBox12).Name = "pictureBox12";
		((Control)pictureBox12).Size = new Size(539, 10);
		pictureBox12.TabIndex = 1;
		pictureBox12.TabStop = false;
		((Control)label_TRP7Head).AutoSize = true;
		((Control)label_TRP7Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		label_TRP7Head.ImeMode = (ImeMode)0;
		((Control)label_TRP7Head).Location = new Point(40, 21);
		((Control)label_TRP7Head).Name = "label_TRP7Head";
		((Control)label_TRP7Head).Size = new Size(80, 16);
		((Control)label_TRP7Head).TabIndex = 0;
		((Control)label_TRP7Head).Text = "Password";
		((Control)label_TRP7_comment).AutoSize = true;
		((Control)label_TRP7_comment).Font = new Font("MS UI Gothic", 9f);
		label_TRP7_comment.ImeMode = (ImeMode)0;
		((Control)label_TRP7_comment).Location = new Point(47, 75);
		((Control)label_TRP7_comment).Name = "label_TRP7_comment";
		((Control)label_TRP7_comment).Size = new Size(142, 12);
		((Control)label_TRP7_comment).TabIndex = 2;
		((Control)label_TRP7_comment).Text = "Password setting message";
		((Control)panel_TRP7_1).BackColor = SystemColors.Control;
		panel_TRP7_1.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP7_1).Location = new Point(0, 3);
		((Control)panel_TRP7_1).Margin = new Padding(0);
		((Control)panel_TRP7_1).Name = "panel_TRP7_1";
		((Control)panel_TRP7_1).Size = new Size(181, 470);
		((Control)panel_TRP7_1).TabIndex = 20;
		((Control)tabTRP8_address).Controls.Add((Control)(object)panel_TRP8_3);
		((Control)tabTRP8_address).Controls.Add((Control)(object)panel_TRP8_2);
		((Control)tabTRP8_address).Controls.Add((Control)(object)panel_TRP8_1);
		tabTRP8_address.Location = new Point(4, 22);
		((Control)tabTRP8_address).Name = "tabTRP8_address";
		((Control)tabTRP8_address).Size = new Size(760, 497);
		tabTRP8_address.TabIndex = 15;
		((Control)tabTRP8_address).Text = "tabTRP8_address";
		tabTRP8_address.UseVisualStyleBackColor = true;
		((Control)panel_TRP8_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_TRP8_3.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP8_3).Controls.Add((Control)(object)btnTRP8Back);
		((Control)panel_TRP8_3).Controls.Add((Control)(object)btnTRP8Next);
		((Control)panel_TRP8_3).Dock = (DockStyle)2;
		((Control)panel_TRP8_3).Location = new Point(0, 446);
		((Control)panel_TRP8_3).Margin = new Padding(0);
		((Control)panel_TRP8_3).Name = "panel_TRP8_3";
		((Control)panel_TRP8_3).Size = new Size(760, 51);
		((Control)panel_TRP8_3).TabIndex = 19;
		((Control)panel_TRP8_2).BackColor = Color.White;
		((Control)panel_TRP8_2).Controls.Add((Control)(object)label_TRP8_Path);
		((Control)panel_TRP8_2).Controls.Add((Control)(object)cmbTRP8FolderPath);
		((Control)panel_TRP8_2).Controls.Add((Control)(object)buttonTRP8HeadLine);
		((Control)panel_TRP8_2).Controls.Add((Control)(object)textTRP8Destination);
		((Control)panel_TRP8_2).Controls.Add((Control)(object)pictureBox17);
		((Control)panel_TRP8_2).Controls.Add((Control)(object)label_TRP8Head);
		((Control)panel_TRP8_2).Controls.Add((Control)(object)label_TRP8_Destination);
		((Control)panel_TRP8_2).Controls.Add((Control)(object)label_TRP8_comment);
		((Control)panel_TRP8_2).Location = new Point(184, 3);
		((Control)panel_TRP8_2).Name = "panel_TRP8_2";
		((Control)panel_TRP8_2).Size = new Size(575, 470);
		((Control)panel_TRP8_2).TabIndex = 23;
		((Control)label_TRP8_Path).AutoSize = true;
		((Control)label_TRP8_Path).Font = new Font("MS UI Gothic", 9f);
		((Control)label_TRP8_Path).ForeColor = Color.Blue;
		label_TRP8_Path.ImeMode = (ImeMode)0;
		((Control)label_TRP8_Path).Location = new Point(44, 165);
		((Control)label_TRP8_Path).Name = "label_TRP8_Path";
		((Control)label_TRP8_Path).Size = new Size(28, 12);
		((Control)label_TRP8_Path).TabIndex = 38;
		((Control)label_TRP8_Path).Text = "Path";
		cmbTRP8FolderPath.DropDownStyle = (ComboBoxStyle)2;
		((Control)cmbTRP8FolderPath).Font = new Font("MS UI Gothic", 9f);
		((ListControl)cmbTRP8FolderPath).FormattingEnabled = true;
		((Control)cmbTRP8FolderPath).Location = new Point(118, 163);
		((Control)cmbTRP8FolderPath).Name = "cmbTRP8FolderPath";
		((Control)cmbTRP8FolderPath).Size = new Size(314, 20);
		((Control)cmbTRP8FolderPath).TabIndex = 17;
		((Control)buttonTRP8HeadLine).AutoSize = true;
		((Control)buttonTRP8HeadLine).Font = new Font("MS UI Gothic", 9f);
		((ButtonBase)buttonTRP8HeadLine).ImeMode = (ImeMode)0;
		((Control)buttonTRP8HeadLine).Location = new Point(435, 128);
		((Control)buttonTRP8HeadLine).Name = "buttonTRP8HeadLine";
		((Control)buttonTRP8HeadLine).Size = new Size(114, 23);
		((Control)buttonTRP8HeadLine).TabIndex = 16;
		((Control)buttonTRP8HeadLine).Text = "Index";
		((ButtonBase)buttonTRP8HeadLine).UseVisualStyleBackColor = true;
		((Control)buttonTRP8HeadLine).Click += buttonTRP8HeadLine_Click;
		((Control)textTRP8Destination).Font = new Font("MS UI Gothic", 9f);
		((Control)textTRP8Destination).Location = new Point(118, 130);
		((Control)textTRP8Destination).Name = "textTRP8Destination";
		((Control)textTRP8Destination).Size = new Size(314, 19);
		((Control)textTRP8Destination).TabIndex = 15;
		((Control)textTRP8Destination).Enter += textTRP8Destination_Enter;
		((Control)textTRP8Destination).Leave += textTRP8Destination_Leave;
		pictureBox17.Image = (Image)(object)Resources.Line;
		pictureBox17.ImeMode = (ImeMode)0;
		((Control)pictureBox17).Location = new Point(39, 48);
		((Control)pictureBox17).Margin = new Padding(1);
		((Control)pictureBox17).Name = "pictureBox17";
		((Control)pictureBox17).Size = new Size(539, 10);
		pictureBox17.TabIndex = 1;
		pictureBox17.TabStop = false;
		((Control)label_TRP8Head).AutoSize = true;
		((Control)label_TRP8Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		label_TRP8Head.ImeMode = (ImeMode)0;
		((Control)label_TRP8Head).Location = new Point(40, 21);
		((Control)label_TRP8Head).Name = "label_TRP8Head";
		((Control)label_TRP8Head).Size = new Size(94, 16);
		((Control)label_TRP8Head).TabIndex = 0;
		((Control)label_TRP8Head).Text = "Destination";
		((Control)label_TRP8_Destination).AutoSize = true;
		((Control)label_TRP8_Destination).Font = new Font("MS UI Gothic", 9f);
		((Control)label_TRP8_Destination).ForeColor = Color.Blue;
		label_TRP8_Destination.ImeMode = (ImeMode)0;
		((Control)label_TRP8_Destination).Location = new Point(44, 130);
		((Control)label_TRP8_Destination).Name = "label_TRP8_Destination";
		((Control)label_TRP8_Destination).Size = new Size(63, 12);
		((Control)label_TRP8_Destination).TabIndex = 2;
		((Control)label_TRP8_Destination).Text = "Destination";
		((Control)label_TRP8_comment).AutoSize = true;
		((Control)label_TRP8_comment).Font = new Font("MS UI Gothic", 9f);
		label_TRP8_comment.ImeMode = (ImeMode)0;
		((Control)label_TRP8_comment).Location = new Point(44, 75);
		((Control)label_TRP8_comment).Name = "label_TRP8_comment";
		((Control)label_TRP8_comment).Size = new Size(151, 12);
		((Control)label_TRP8_comment).TabIndex = 2;
		((Control)label_TRP8_comment).Text = "Destination setting message";
		((Control)panel_TRP8_1).BackColor = SystemColors.Control;
		panel_TRP8_1.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP8_1).Location = new Point(0, 3);
		((Control)panel_TRP8_1).Margin = new Padding(0);
		((Control)panel_TRP8_1).Name = "panel_TRP8_1";
		((Control)panel_TRP8_1).Size = new Size(181, 470);
		((Control)panel_TRP8_1).TabIndex = 21;
		((Control)tabTRP9_confirm).Controls.Add((Control)(object)panel_TRP9_3);
		((Control)tabTRP9_confirm).Controls.Add((Control)(object)panel_TRP9_2);
		((Control)tabTRP9_confirm).Controls.Add((Control)(object)panel_TRP9_1);
		tabTRP9_confirm.Location = new Point(4, 22);
		((Control)tabTRP9_confirm).Name = "tabTRP9_confirm";
		((Control)tabTRP9_confirm).Size = new Size(760, 497);
		tabTRP9_confirm.TabIndex = 13;
		((Control)tabTRP9_confirm).Text = "tabTRP9_confirm";
		tabTRP9_confirm.UseVisualStyleBackColor = true;
		((Control)panel_TRP9_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_TRP9_3.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP9_3).Controls.Add((Control)(object)btnTRP9Back);
		((Control)panel_TRP9_3).Controls.Add((Control)(object)btnTRP9Execute);
		((Control)panel_TRP9_3).Dock = (DockStyle)2;
		((Control)panel_TRP9_3).Location = new Point(0, 446);
		((Control)panel_TRP9_3).Margin = new Padding(0);
		((Control)panel_TRP9_3).Name = "panel_TRP9_3";
		((Control)panel_TRP9_3).Size = new Size(760, 51);
		((Control)panel_TRP9_3).TabIndex = 25;
		((Control)panel_TRP9_2).BackColor = Color.White;
		panel_TRP9_2.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP9_2).Controls.Add((Control)(object)label_TRP9_comment);
		((Control)panel_TRP9_2).Controls.Add((Control)(object)pictureBox14);
		((Control)panel_TRP9_2).Controls.Add((Control)(object)label_TRP9Head);
		((Control)panel_TRP9_2).Controls.Add((Control)(object)panel45);
		((Control)panel_TRP9_2).Location = new Point(184, 3);
		((Control)panel_TRP9_2).Name = "panel_TRP9_2";
		((Control)panel_TRP9_2).Size = new Size(575, 470);
		((Control)panel_TRP9_2).TabIndex = 27;
		((Control)label_TRP9_comment).AutoSize = true;
		((Control)label_TRP9_comment).Font = new Font("MS UI Gothic", 9f);
		label_TRP9_comment.ImeMode = (ImeMode)0;
		((Control)label_TRP9_comment).Location = new Point(45, 77);
		((Control)label_TRP9_comment).Name = "label_TRP9_comment";
		((Control)label_TRP9_comment).Size = new Size(119, 12);
		((Control)label_TRP9_comment).TabIndex = 7;
		((Control)label_TRP9_comment).Text = "Confirmation message";
		pictureBox14.Image = (Image)(object)Resources.Line;
		pictureBox14.ImeMode = (ImeMode)0;
		((Control)pictureBox14).Location = new Point(39, 48);
		((Control)pictureBox14).Margin = new Padding(1);
		((Control)pictureBox14).Name = "pictureBox14";
		((Control)pictureBox14).Size = new Size(537, 10);
		pictureBox14.TabIndex = 1;
		pictureBox14.TabStop = false;
		((Control)label_TRP9Head).AutoSize = true;
		((Control)label_TRP9Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		label_TRP9Head.ImeMode = (ImeMode)0;
		((Control)label_TRP9Head).Location = new Point(40, 21);
		((Control)label_TRP9Head).Name = "label_TRP9Head";
		((Control)label_TRP9Head).Size = new Size(68, 16);
		((Control)label_TRP9Head).TabIndex = 0;
		((Control)label_TRP9Head).Text = "Confirm";
		panel45.BorderStyle = (BorderStyle)2;
		((Control)panel45).Controls.Add((Control)(object)richTextBoxTRP9);
		((Control)panel45).Font = new Font("MS UI Gothic", 9f);
		((Control)panel45).Location = new Point(44, 117);
		((Control)panel45).Name = "panel45";
		((Control)panel45).Size = new Size(503, 316);
		((Control)panel45).TabIndex = 6;
		((TextBoxBase)richTextBoxTRP9).BorderStyle = (BorderStyle)0;
		richTextBoxTRP9.DetectUrls = false;
		((Control)richTextBoxTRP9).Location = new Point(3, 3);
		((Control)richTextBoxTRP9).Name = "richTextBoxTRP9";
		((Control)richTextBoxTRP9).Size = new Size(490, 305);
		((Control)richTextBoxTRP9).TabIndex = 2;
		((Control)richTextBoxTRP9).Text = "";
		((Control)panel_TRP9_1).BackColor = SystemColors.Control;
		panel_TRP9_1.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP9_1).Location = new Point(0, 3);
		((Control)panel_TRP9_1).Margin = new Padding(0);
		((Control)panel_TRP9_1).Name = "panel_TRP9_1";
		((Control)panel_TRP9_1).Size = new Size(181, 470);
		((Control)panel_TRP9_1).TabIndex = 26;
		((Control)tabTRP10_finish).Controls.Add((Control)(object)panel_TRP10_3);
		((Control)tabTRP10_finish).Controls.Add((Control)(object)panel_TRP10_2);
		((Control)tabTRP10_finish).Controls.Add((Control)(object)panel_TRP10_1);
		tabTRP10_finish.Location = new Point(4, 22);
		((Control)tabTRP10_finish).Margin = new Padding(0);
		((Control)tabTRP10_finish).Name = "tabTRP10_finish";
		((Control)tabTRP10_finish).Size = new Size(760, 497);
		tabTRP10_finish.TabIndex = 11;
		((Control)tabTRP10_finish).Text = "tabTRP10_finish";
		tabTRP10_finish.UseVisualStyleBackColor = true;
		((Control)panel_TRP10_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_TRP10_3.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP10_3).Controls.Add((Control)(object)btnTRP10Top);
		((Control)panel_TRP10_3).Controls.Add((Control)(object)btnTRP10End);
		((Control)panel_TRP10_3).Dock = (DockStyle)2;
		((Control)panel_TRP10_3).Location = new Point(0, 446);
		((Control)panel_TRP10_3).Margin = new Padding(0);
		((Control)panel_TRP10_3).Name = "panel_TRP10_3";
		((Control)panel_TRP10_3).Size = new Size(760, 51);
		((Control)panel_TRP10_3).TabIndex = 30;
		((Control)panel_TRP10_2).BackColor = Color.White;
		panel_TRP10_2.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP10_2).Controls.Add((Control)(object)linkLabelTRP10HelpSend);
		((Control)panel_TRP10_2).Controls.Add((Control)(object)linkLabelTRP10HelpRegist);
		((Control)panel_TRP10_2).Controls.Add((Control)(object)panelTRP10);
		((Control)panel_TRP10_2).Controls.Add((Control)(object)pictureBox11);
		((Control)panel_TRP10_2).Controls.Add((Control)(object)label_TRP10Head);
		((Control)panel_TRP10_2).Controls.Add((Control)(object)label_TRP10_ReportTitle);
		((Control)panel_TRP10_2).Controls.Add((Control)(object)label_TRP10_comment);
		((Control)panel_TRP10_2).Location = new Point(184, 3);
		((Control)panel_TRP10_2).Name = "panel_TRP10_2";
		((Control)panel_TRP10_2).Size = new Size(575, 470);
		((Control)panel_TRP10_2).TabIndex = 29;
		((Control)linkLabelTRP10HelpSend).AutoSize = true;
		((Control)linkLabelTRP10HelpSend).Font = new Font("MS UI Gothic", 9f);
		((Label)linkLabelTRP10HelpSend).ImeMode = (ImeMode)0;
		((Control)linkLabelTRP10HelpSend).Location = new Point(46, 109);
		((Control)linkLabelTRP10HelpSend).Name = "linkLabelTRP10HelpSend";
		((Control)linkLabelTRP10HelpSend).Size = new Size(141, 12);
		((Control)linkLabelTRP10HelpSend).TabIndex = 26;
		linkLabelTRP10HelpSend.TabStop = true;
		((Control)linkLabelTRP10HelpSend).Text = "Folder send procedure link";
		linkLabelTRP10HelpSend.LinkClicked += new LinkLabelLinkClickedEventHandler(linkLabel1_LinkClicked);
		((Control)linkLabelTRP10HelpRegist).AutoSize = true;
		((Control)linkLabelTRP10HelpRegist).Font = new Font("MS UI Gothic", 9f);
		((Label)linkLabelTRP10HelpRegist).ImeMode = (ImeMode)0;
		linkLabelTRP10HelpRegist.LinkColor = Color.Red;
		((Control)linkLabelTRP10HelpRegist).Location = new Point(46, 94);
		((Control)linkLabelTRP10HelpRegist).Name = "linkLabelTRP10HelpRegist";
		((Control)linkLabelTRP10HelpRegist).Size = new Size(145, 12);
		((Control)linkLabelTRP10HelpRegist).TabIndex = 25;
		linkLabelTRP10HelpRegist.TabStop = true;
		((Control)linkLabelTRP10HelpRegist).Text = "Direct regist procedure link";
		linkLabelTRP10HelpRegist.LinkClicked += new LinkLabelLinkClickedEventHandler(linkLabelP7Help_LinkClicked);
		((ScrollableControl)panelTRP10).AutoScroll = true;
		panelTRP10.BorderStyle = (BorderStyle)2;
		((Control)panelTRP10).Controls.Add((Control)(object)label_TRP10Report);
		((Control)panelTRP10).Controls.Add((Control)(object)labelTRP10finish);
		((Control)panelTRP10).Controls.Add((Control)(object)richTextBoxTRP10);
		((Control)panelTRP10).Font = new Font("MS UI Gothic", 9f);
		((Control)panelTRP10).Location = new Point(48, 159);
		((Control)panelTRP10).Name = "panelTRP10";
		((Control)panelTRP10).Size = new Size(469, 280);
		((Control)panelTRP10).TabIndex = 4;
		((Control)label_TRP10Report).AutoSize = true;
		label_TRP10Report.ImeMode = (ImeMode)0;
		((Control)label_TRP10Report).Location = new Point(4, 11);
		((Control)label_TRP10Report).Name = "label_TRP10Report";
		((Control)label_TRP10Report).Size = new Size(35, 12);
		((Control)label_TRP10Report).TabIndex = 2;
		((Control)label_TRP10Report).Text = "label7";
		((Control)labelTRP10finish).AutoSize = true;
		((Label)labelTRP10finish).ImeMode = (ImeMode)0;
		((Control)labelTRP10finish).Location = new Point(381, 0);
		((Control)labelTRP10finish).Name = "labelTRP10finish";
		((Control)labelTRP10finish).Size = new Size(45, 12);
		((Control)labelTRP10finish).TabIndex = 1;
		labelTRP10finish.TabStop = true;
		((Control)labelTRP10finish).Text = "Reports";
		((Control)labelTRP10finish).Visible = false;
		((TextBoxBase)richTextBoxTRP10).BorderStyle = (BorderStyle)0;
		richTextBoxTRP10.DetectUrls = false;
		((Control)richTextBoxTRP10).Location = new Point(3, 3);
		((Control)richTextBoxTRP10).Name = "richTextBoxTRP10";
		((Control)richTextBoxTRP10).Size = new Size(458, 270);
		((Control)richTextBoxTRP10).TabIndex = 3;
		((Control)richTextBoxTRP10).Text = "";
		pictureBox11.Image = (Image)(object)Resources.Line;
		pictureBox11.ImeMode = (ImeMode)0;
		((Control)pictureBox11).Location = new Point(39, 48);
		((Control)pictureBox11).Margin = new Padding(1);
		((Control)pictureBox11).Name = "pictureBox11";
		((Control)pictureBox11).Size = new Size(539, 10);
		pictureBox11.TabIndex = 1;
		pictureBox11.TabStop = false;
		((Control)label_TRP10Head).AutoSize = true;
		((Control)label_TRP10Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		label_TRP10Head.ImeMode = (ImeMode)0;
		((Control)label_TRP10Head).Location = new Point(40, 21);
		((Control)label_TRP10Head).Name = "label_TRP10Head";
		((Control)label_TRP10Head).Size = new Size(52, 16);
		((Control)label_TRP10Head).TabIndex = 0;
		((Control)label_TRP10Head).Text = "Finish";
		((Control)label_TRP10_ReportTitle).AutoSize = true;
		((Control)label_TRP10_ReportTitle).Font = new Font("MS UI Gothic", 9f);
		label_TRP10_ReportTitle.ImeMode = (ImeMode)0;
		((Control)label_TRP10_ReportTitle).Location = new Point(41, 142);
		((Control)label_TRP10_ReportTitle).Name = "label_TRP10_ReportTitle";
		((Control)label_TRP10_ReportTitle).Size = new Size(45, 12);
		((Control)label_TRP10_ReportTitle).TabIndex = 2;
		((Control)label_TRP10_ReportTitle).Text = "Report :";
		((Control)label_TRP10_comment).AutoSize = true;
		((Control)label_TRP10_comment).Font = new Font("MS UI Gothic", 9f);
		label_TRP10_comment.ImeMode = (ImeMode)0;
		((Control)label_TRP10_comment).Location = new Point(45, 75);
		((Control)label_TRP10_comment).Name = "label_TRP10_comment";
		((Control)label_TRP10_comment).Size = new Size(102, 12);
		((Control)label_TRP10_comment).TabIndex = 2;
		((Control)label_TRP10_comment).Text = "Complete message";
		((Control)panel_TRP10_1).BackColor = SystemColors.Control;
		panel_TRP10_1.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP10_1).Location = new Point(0, 3);
		((Control)panel_TRP10_1).Margin = new Padding(0);
		((Control)panel_TRP10_1).Name = "panel_TRP10_1";
		((Control)panel_TRP10_1).Size = new Size(181, 470);
		((Control)panel_TRP10_1).TabIndex = 28;
		((ToolStrip)menuStrip1).Items.AddRange((ToolStripItem[])(object)new ToolStripItem[5]
		{
			(ToolStripItem)ToolStripMenuItemDetail_D,
			(ToolStripItem)ToolStripMenuItemChange,
			(ToolStripItem)ToolStripMenuItemSecurity_S,
			(ToolStripItem)ToolStripMenuItemEnvironments_E,
			(ToolStripItem)ToolStripMenuItemVersion_H
		});
		((Control)menuStrip1).Location = new Point(0, 0);
		((Control)menuStrip1).Name = "menuStrip1";
		((Control)menuStrip1).Size = new Size(759, 24);
		((Control)menuStrip1).TabIndex = 1;
		((Control)menuStrip1).Text = "menuStrip1";
		((ToolStripItem)ToolStripMenuItemDetail_D).Name = "ToolStripMenuItemDetail_D";
		((ToolStripItem)ToolStripMenuItemDetail_D).Size = new Size(65, 20);
		((ToolStripItem)ToolStripMenuItemDetail_D).Text = "Individual(&D)";
		((ToolStripItem)ToolStripMenuItemDetail_D).Click += ToolStripMenuManual_Click;
		((ToolStripItem)ToolStripMenuItemChange).Name = "ToolStripMenuItemChange";
		((ToolStripItem)ToolStripMenuItemChange).Size = new Size(74, 20);
		((ToolStripItem)ToolStripMenuItemChange).Text = "Change(&C)";
		((ToolStripItem)ToolStripMenuItemChange).Click += AddressBookChangeMenuItem_Click;
		((ToolStripItem)ToolStripMenuItemSecurity_S).Name = "ToolStripMenuItemSecurity_S";
		((ToolStripItem)ToolStripMenuItemSecurity_S).Size = new Size(75, 20);
		((ToolStripItem)ToolStripMenuItemSecurity_S).Text = "Security(&S)";
		((ToolStripItem)ToolStripMenuItemSecurity_S).Click += ToolStripMenuSecurity_Click;
		((ToolStripDropDownItem)ToolStripMenuItemEnvironments_E).DropDownItems.AddRange((ToolStripItem[])(object)new ToolStripItem[2]
		{
			(ToolStripItem)ToolStripMenuItemMachine,
			(ToolStripItem)ToolStripMenuItemComputer
		});
		((ToolStripItem)ToolStripMenuItemEnvironments_E).Name = "ToolStripMenuItemEnvironments_E";
		((ToolStripItem)ToolStripMenuItemEnvironments_E).Size = new Size(105, 20);
		((ToolStripItem)ToolStripMenuItemEnvironments_E).Text = "Environments(&E)";
		((ToolStripItem)ToolStripMenuItemMachine).Name = "ToolStripMenuItemMachine";
		((ToolStripItem)ToolStripMenuItemMachine).Size = new Size(153, 22);
		((ToolStripItem)ToolStripMenuItemMachine).Text = "Machine Info.";
		((ToolStripItem)ToolStripMenuItemMachine).Click += ToolStripMenuMachineInfo_Click;
		((ToolStripItem)ToolStripMenuItemComputer).Name = "ToolStripMenuItemComputer";
		((ToolStripItem)ToolStripMenuItemComputer).Size = new Size(153, 22);
		((ToolStripItem)ToolStripMenuItemComputer).Text = "Computer Info.";
		((ToolStripItem)ToolStripMenuItemComputer).Click += ToolStripMenuPCInfo_Click;
		((ToolStripItem)ToolStripMenuItemVersion_H).Name = "ToolStripMenuItemVersion_H";
		((ToolStripItem)ToolStripMenuItemVersion_H).Size = new Size(74, 20);
		((ToolStripItem)ToolStripMenuItemVersion_H).Text = "Version(&H)";
		((ToolStripItem)ToolStripMenuItemVersion_H).Click += ToolStripMenuVersion_Click;
		((Control)label165).AutoSize = true;
		((Control)label165).Font = new Font("MS UI Gothic", 14.25f, (FontStyle)1);
		label165.ImeMode = (ImeMode)0;
		((Control)label165).Location = new Point(12, 23);
		((Control)label165).Name = "label165";
		((Control)label165).Size = new Size(89, 19);
		((Control)label165).TabIndex = 0;
		((Control)label164).AutoSize = true;
		((Control)label164).Font = new Font("MS UI Gothic", 11.25f);
		((Control)label164).ForeColor = Color.Gray;
		label164.ImeMode = (ImeMode)0;
		((Control)label164).Location = new Point(24, 61);
		((Control)label164).Name = "label164";
		((Control)label164).Size = new Size(55, 15);
		((Control)label164).TabIndex = 1;
		((Control)label163).AutoSize = true;
		((Control)label163).Font = new Font("MS UI Gothic", 11.25f);
		((Control)label163).ForeColor = Color.Gray;
		label163.ImeMode = (ImeMode)0;
		((Control)label163).Location = new Point(24, 95);
		((Control)label163).Name = "label163";
		((Control)label163).Size = new Size(134, 15);
		((Control)label163).TabIndex = 2;
		((Control)label162).AutoSize = true;
		((Control)label162).Font = new Font("MS UI Gothic", 11.25f);
		((Control)label162).ForeColor = Color.Gray;
		label162.ImeMode = (ImeMode)0;
		((Control)label162).Location = new Point(34, 129);
		((Control)label162).Name = "label162";
		((Control)label162).Size = new Size(114, 15);
		((Control)label162).TabIndex = 3;
		((Control)label161).AutoSize = true;
		((Control)label161).Font = new Font("MS UI Gothic", 11.25f);
		((Control)label161).ForeColor = Color.Gray;
		label161.ImeMode = (ImeMode)0;
		((Control)label161).Location = new Point(43, 158);
		((Control)label161).Name = "label161";
		((Control)label161).Size = new Size(79, 15);
		((Control)label161).TabIndex = 4;
		((Control)label149).AutoSize = true;
		((Control)label149).Font = new Font("MS UI Gothic", 11.25f, (FontStyle)1);
		((Control)label149).ForeColor = SystemColors.Highlight;
		label149.ImeMode = (ImeMode)0;
		((Control)label149).Location = new Point(24, 197);
		((Control)label149).Name = "label149";
		((Control)label149).Size = new Size(39, 15);
		((Control)label149).TabIndex = 5;
		((Control)label148).AutoSize = true;
		((Control)label148).Font = new Font("MS UI Gothic", 11.25f);
		label148.ImeMode = (ImeMode)0;
		((Control)label148).Location = new Point(24, 265);
		((Control)label148).Name = "label148";
		((Control)label148).Size = new Size(37, 15);
		((Control)label148).TabIndex = 6;
		((Control)label147).AutoSize = true;
		((Control)label147).Font = new Font("MS UI Gothic", 10f);
		label147.ImeMode = (ImeMode)0;
		((Control)label147).Location = new Point(45, 75);
		((Control)label147).Name = "label147";
		((Control)label147).Size = new Size(130, 28);
		((Control)label147).TabIndex = 2;
		((Control)label145).AutoSize = true;
		((Control)label145).Font = new Font("MS UI Gothic", 14.25f, (FontStyle)1);
		label145.ImeMode = (ImeMode)0;
		((Control)label145).Location = new Point(40, 21);
		((Control)label145).Name = "label145";
		((Control)label145).Size = new Size(49, 19);
		((Control)label145).TabIndex = 0;
		pictureBox15.Image = (Image)componentResourceManager.GetObject("pictureBox15.Image");
		pictureBox15.ImeMode = (ImeMode)0;
		((Control)pictureBox15).Location = new Point(39, 48);
		((Control)pictureBox15).Margin = new Padding(1);
		((Control)pictureBox15).Name = "pictureBox15";
		((Control)pictureBox15).Size = new Size(539, 10);
		pictureBox15.TabIndex = 1;
		pictureBox15.TabStop = false;
		((Control)btnP1TRNext).AutoSize = true;
		((Control)btnP1TRNext).BackColor = Color.FromArgb(224, 224, 224);
		((Control)btnP1TRNext).Enabled = false;
		((ButtonBase)btnP1TRNext).FlatStyle = (FlatStyle)0;
		((Control)btnP1TRNext).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP1TRNext).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP1TRNext).ImeMode = (ImeMode)0;
		((Control)btnP1TRNext).Location = new Point(503, 10);
		((Control)btnP1TRNext).Name = "btnP1TRNext";
		((Control)btnP1TRNext).Size = new Size(116, 24);
		((Control)btnP1TRNext).TabIndex = 3;
		((Control)btnP1TRNext).Text = "Next";
		((ButtonBase)btnP1TRNext).UseVisualStyleBackColor = false;
		((Control)btnP1TRNext).Visible = false;
		((Control)btnP1Cancel).AutoSize = true;
		((Control)btnP1Cancel).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP1Cancel).FlatStyle = (FlatStyle)0;
		((Control)btnP1Cancel).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP1Cancel).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP1Cancel).ImeMode = (ImeMode)0;
		((Control)btnP1Cancel).Location = new Point(632, 10);
		((Control)btnP1Cancel).Name = "btnP1Cancel";
		((Control)btnP1Cancel).Size = new Size(116, 24);
		((Control)btnP1Cancel).TabIndex = 2;
		((Control)btnP1Cancel).Text = "Cancel";
		((ButtonBase)btnP1Cancel).UseVisualStyleBackColor = false;
		((Control)btnP1Next).AutoSize = true;
		((Control)btnP1Next).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP1Next).FlatStyle = (FlatStyle)0;
		((Control)btnP1Next).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP1Next).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP1Next).ImeMode = (ImeMode)0;
		((Control)btnP1Next).Location = new Point(503, 10);
		((Control)btnP1Next).Name = "btnP1Next";
		((Control)btnP1Next).Size = new Size(116, 24);
		((Control)btnP1Next).TabIndex = 1;
		((Control)btnP1Next).Text = "Next";
		((ButtonBase)btnP1Next).UseVisualStyleBackColor = false;
		((Control)btnP2Back).AutoSize = true;
		((Control)btnP2Back).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP2Back).FlatStyle = (FlatStyle)0;
		((Control)btnP2Back).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP2Back).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP2Back).ImeMode = (ImeMode)0;
		((Control)btnP2Back).Location = new Point(372, 10);
		((Control)btnP2Back).Name = "btnP2Back";
		((Control)btnP2Back).Size = new Size(116, 24);
		((Control)btnP2Back).TabIndex = 6;
		((Control)btnP2Back).Text = "Back";
		((ButtonBase)btnP2Back).UseVisualStyleBackColor = false;
		((Control)btnP2Back).Click += btnP2Back_Click;
		((Control)btnP2Cancel).AutoSize = true;
		((Control)btnP2Cancel).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP2Cancel).FlatStyle = (FlatStyle)0;
		((Control)btnP2Cancel).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP2Cancel).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP2Cancel).ImeMode = (ImeMode)0;
		((Control)btnP2Cancel).Location = new Point(632, 10);
		((Control)btnP2Cancel).Name = "btnP2Cancel";
		((Control)btnP2Cancel).Size = new Size(116, 24);
		((Control)btnP2Cancel).TabIndex = 8;
		((Control)btnP2Cancel).Text = "Cancel";
		((ButtonBase)btnP2Cancel).UseVisualStyleBackColor = false;
		((Control)btnP2Cancel).Visible = false;
		((Control)btnP2Next).AutoSize = true;
		((Control)btnP2Next).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP2Next).FlatStyle = (FlatStyle)0;
		((Control)btnP2Next).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP2Next).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP2Next).ImeMode = (ImeMode)0;
		((Control)btnP2Next).Location = new Point(503, 10);
		((Control)btnP2Next).Name = "btnP2Next";
		((Control)btnP2Next).Size = new Size(116, 24);
		((Control)btnP2Next).TabIndex = 7;
		((Control)btnP2Next).Text = "Next";
		((ButtonBase)btnP2Next).UseVisualStyleBackColor = false;
		((Control)btnP2Next).Click += btnP2Next_Click;
		((Control)btnP3Cancel).AutoSize = true;
		((Control)btnP3Cancel).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP3Cancel).FlatStyle = (FlatStyle)0;
		((Control)btnP3Cancel).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP3Cancel).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP3Cancel).ImeMode = (ImeMode)0;
		((Control)btnP3Cancel).Location = new Point(632, 10);
		((Control)btnP3Cancel).Name = "btnP3Cancel";
		((Control)btnP3Cancel).Size = new Size(116, 24);
		((Control)btnP3Cancel).TabIndex = 14;
		((Control)btnP3Cancel).Text = "Cancel";
		((ButtonBase)btnP3Cancel).UseVisualStyleBackColor = false;
		((Control)btnP3Cancel).Visible = false;
		((Control)btnP3Back).AutoSize = true;
		((Control)btnP3Back).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP3Back).FlatStyle = (FlatStyle)0;
		((Control)btnP3Back).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP3Back).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP3Back).ImeMode = (ImeMode)0;
		((Control)btnP3Back).Location = new Point(372, 10);
		((Control)btnP3Back).Name = "btnP3Back";
		((Control)btnP3Back).Size = new Size(116, 24);
		((Control)btnP3Back).TabIndex = 12;
		((Control)btnP3Back).Text = "Back";
		((ButtonBase)btnP3Back).UseVisualStyleBackColor = false;
		((Control)btnP3Back).Click += btnP3Back_Click;
		((Control)btnP3Next).AutoSize = true;
		((Control)btnP3Next).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP3Next).FlatStyle = (FlatStyle)0;
		((Control)btnP3Next).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP3Next).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP3Next).ImeMode = (ImeMode)0;
		((Control)btnP3Next).Location = new Point(503, 10);
		((Control)btnP3Next).Name = "btnP3Next";
		((Control)btnP3Next).Size = new Size(116, 24);
		((Control)btnP3Next).TabIndex = 13;
		((Control)btnP3Next).Text = "Next";
		((ButtonBase)btnP3Next).UseVisualStyleBackColor = false;
		((Control)btnP3Next).Click += btnP3Next_Click;
		((Control)btnP4Cancel).AutoSize = true;
		((Control)btnP4Cancel).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP4Cancel).FlatStyle = (FlatStyle)0;
		((Control)btnP4Cancel).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP4Cancel).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP4Cancel).ImeMode = (ImeMode)0;
		((Control)btnP4Cancel).Location = new Point(632, 10);
		((Control)btnP4Cancel).Name = "btnP4Cancel";
		((Control)btnP4Cancel).Size = new Size(116, 24);
		((Control)btnP4Cancel).TabIndex = 24;
		((Control)btnP4Cancel).Text = "Cancel";
		((ButtonBase)btnP4Cancel).UseVisualStyleBackColor = false;
		((Control)btnP4Cancel).Visible = false;
		((Control)btnP4Back).AutoSize = true;
		((Control)btnP4Back).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP4Back).FlatStyle = (FlatStyle)0;
		((Control)btnP4Back).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP4Back).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP4Back).ImeMode = (ImeMode)0;
		((Control)btnP4Back).Location = new Point(372, 10);
		((Control)btnP4Back).Name = "btnP4Back";
		((Control)btnP4Back).Size = new Size(116, 24);
		((Control)btnP4Back).TabIndex = 22;
		((Control)btnP4Back).Text = "Back";
		((ButtonBase)btnP4Back).UseVisualStyleBackColor = false;
		((Control)btnP4Next).AutoSize = true;
		((Control)btnP4Next).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP4Next).FlatStyle = (FlatStyle)0;
		((Control)btnP4Next).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP4Next).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP4Next).ImeMode = (ImeMode)0;
		((Control)btnP4Next).Location = new Point(503, 10);
		((Control)btnP4Next).Name = "btnP4Next";
		((Control)btnP4Next).Size = new Size(116, 24);
		((Control)btnP4Next).TabIndex = 23;
		((Control)btnP4Next).Text = "Next";
		((ButtonBase)btnP4Next).UseVisualStyleBackColor = false;
		((Control)btnP4Next).Click += btnP4Next_Click;
		((Control)machineSelectControl).Location = new Point(111, 196);
		((Control)machineSelectControl).Name = "machineSelectControl";
		((Control)machineSelectControl).Size = new Size(442, 224);
		((Control)machineSelectControl).TabIndex = 41;
		machineSelectControl.SearchButtonClicked += machineSelectControl_SearchButtonClicked;
		((Control)btnP5Cancel).AutoSize = true;
		((Control)btnP5Cancel).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP5Cancel).FlatStyle = (FlatStyle)0;
		((Control)btnP5Cancel).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP5Cancel).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP5Cancel).ImeMode = (ImeMode)0;
		((Control)btnP5Cancel).Location = new Point(632, 10);
		((Control)btnP5Cancel).Name = "btnP5Cancel";
		((Control)btnP5Cancel).Size = new Size(116, 24);
		((Control)btnP5Cancel).TabIndex = 29;
		((Control)btnP5Cancel).Text = "Cancel";
		((ButtonBase)btnP5Cancel).UseVisualStyleBackColor = false;
		((Control)btnP5Cancel).Visible = false;
		((Control)btnP5Back).AutoSize = true;
		((Control)btnP5Back).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP5Back).FlatStyle = (FlatStyle)0;
		((Control)btnP5Back).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP5Back).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP5Back).ImeMode = (ImeMode)0;
		((Control)btnP5Back).Location = new Point(372, 10);
		((Control)btnP5Back).Name = "btnP5Back";
		((Control)btnP5Back).Size = new Size(116, 24);
		((Control)btnP5Back).TabIndex = 27;
		((Control)btnP5Back).Text = "Back";
		((ButtonBase)btnP5Back).UseVisualStyleBackColor = false;
		((Control)btnP5Execute).AutoSize = true;
		((Control)btnP5Execute).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP5Execute).FlatStyle = (FlatStyle)0;
		((Control)btnP5Execute).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP5Execute).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP5Execute).ImeMode = (ImeMode)0;
		((Control)btnP5Execute).Location = new Point(503, 10);
		((Control)btnP5Execute).Name = "btnP5Execute";
		((Control)btnP5Execute).Size = new Size(116, 24);
		((Control)btnP5Execute).TabIndex = 28;
		((Control)btnP5Execute).Text = "Execute";
		((ButtonBase)btnP5Execute).UseVisualStyleBackColor = false;
		((Control)btnP5Execute).Click += btnP5Execute_Click;
		((ButtonBase)btnP6Excecute).ImeMode = (ImeMode)0;
		((Control)btnP6Excecute).Location = new Point(445, 392);
		((Control)btnP6Excecute).Name = "btnP6Excecute";
		((Control)btnP6Excecute).Size = new Size(75, 23);
		((Control)btnP6Excecute).TabIndex = 3;
		((Control)btnP6Excecute).Text = "Execute";
		((ButtonBase)btnP6Excecute).UseVisualStyleBackColor = true;
		((Control)btnP6Excecute).Visible = false;
		((Control)btnP6Excecute).Click += buttonP6Excecute_Click;
		((Control)btnP7Top).AutoSize = true;
		((Control)btnP7Top).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP7Top).FlatStyle = (FlatStyle)0;
		((Control)btnP7Top).Font = new Font("MS UI Gothic", 9f);
		((ButtonBase)btnP7Top).ImeMode = (ImeMode)0;
		((Control)btnP7Top).Location = new Point(503, 10);
		((Control)btnP7Top).Name = "btnP7Top";
		((Control)btnP7Top).Size = new Size(116, 24);
		((Control)btnP7Top).TabIndex = 30;
		((Control)btnP7Top).Text = "Top";
		((ButtonBase)btnP7Top).UseVisualStyleBackColor = false;
		((Control)btnP7End).AutoSize = true;
		((Control)btnP7End).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP7End).FlatStyle = (FlatStyle)0;
		((Control)btnP7End).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP7End).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP7End).ImeMode = (ImeMode)0;
		((Control)btnP7End).Location = new Point(632, 10);
		((Control)btnP7End).Name = "btnP7End";
		((Control)btnP7End).Size = new Size(116, 24);
		((Control)btnP7End).TabIndex = 31;
		((Control)btnP7End).Text = "End";
		((ButtonBase)btnP7End).UseVisualStyleBackColor = false;
		((Control)btnTRP2Back).AutoSize = true;
		((Control)btnTRP2Back).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP2Back).FlatStyle = (FlatStyle)0;
		((Control)btnTRP2Back).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP2Back).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP2Back).ImeMode = (ImeMode)0;
		((Control)btnTRP2Back).Location = new Point(372, 10);
		((Control)btnTRP2Back).Name = "btnTRP2Back";
		((Control)btnTRP2Back).Size = new Size(116, 24);
		((Control)btnTRP2Back).TabIndex = 22;
		((Control)btnTRP2Back).Text = "Back";
		((ButtonBase)btnTRP2Back).UseVisualStyleBackColor = false;
		((Control)btnTRP2Next).AutoSize = true;
		((Control)btnTRP2Next).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP2Next).FlatStyle = (FlatStyle)0;
		((Control)btnTRP2Next).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP2Next).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP2Next).ImeMode = (ImeMode)0;
		((Control)btnTRP2Next).Location = new Point(503, 10);
		((Control)btnTRP2Next).Name = "btnTRP2Next";
		((Control)btnTRP2Next).Size = new Size(116, 24);
		((Control)btnTRP2Next).TabIndex = 23;
		((Control)btnTRP2Next).Text = "Next";
		((ButtonBase)btnTRP2Next).UseVisualStyleBackColor = false;
		((Control)btnTRP2Next).Click += btnTRP2Next_Click;
		((Control)machineSelectControlTRP2).Location = new Point(111, 126);
		((Control)machineSelectControlTRP2).Name = "machineSelectControlTRP2";
		((Control)machineSelectControlTRP2).Size = new Size(442, 224);
		((Control)machineSelectControlTRP2).TabIndex = 41;
		machineSelectControlTRP2.SearchButtonClicked += machineSelectControlTRP2_SearchButtonClicked;
		((Control)btnTRP3Back).AutoSize = true;
		((Control)btnTRP3Back).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP3Back).FlatStyle = (FlatStyle)0;
		((Control)btnTRP3Back).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP3Back).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP3Back).ImeMode = (ImeMode)0;
		((Control)btnTRP3Back).Location = new Point(372, 10);
		((Control)btnTRP3Back).Name = "btnTRP3Back";
		((Control)btnTRP3Back).Size = new Size(116, 24);
		((Control)btnTRP3Back).TabIndex = 22;
		((Control)btnTRP3Back).Text = "Back";
		((ButtonBase)btnTRP3Back).UseVisualStyleBackColor = false;
		((Control)btnTRP3Back).Click += btnTRP3Back_Click;
		((Control)btnTRP3Next).AutoSize = true;
		((Control)btnTRP3Next).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP3Next).FlatStyle = (FlatStyle)0;
		((Control)btnTRP3Next).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP3Next).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP3Next).ImeMode = (ImeMode)0;
		((Control)btnTRP3Next).Location = new Point(503, 10);
		((Control)btnTRP3Next).Name = "btnTRP3Next";
		((Control)btnTRP3Next).Size = new Size(116, 24);
		((Control)btnTRP3Next).TabIndex = 23;
		((Control)btnTRP3Next).Text = "Next";
		((ButtonBase)btnTRP3Next).UseVisualStyleBackColor = false;
		((Control)btnTRP3Next).Visible = false;
		((Control)btnTRP3Next).Click += btnTRP3Next_Click;
		((Control)btnTRP5Back).AutoSize = true;
		((Control)btnTRP5Back).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP5Back).FlatStyle = (FlatStyle)0;
		((Control)btnTRP5Back).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP5Back).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP5Back).ImeMode = (ImeMode)0;
		((Control)btnTRP5Back).Location = new Point(372, 10);
		((Control)btnTRP5Back).Name = "btnTRP5Back";
		((Control)btnTRP5Back).Size = new Size(116, 24);
		((Control)btnTRP5Back).TabIndex = 27;
		((Control)btnTRP5Back).Text = "Back";
		((ButtonBase)btnTRP5Back).UseVisualStyleBackColor = false;
		((Control)btnTRP5Next).AutoSize = true;
		((Control)btnTRP5Next).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP5Next).FlatStyle = (FlatStyle)0;
		((Control)btnTRP5Next).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP5Next).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP5Next).ImeMode = (ImeMode)0;
		((Control)btnTRP5Next).Location = new Point(503, 10);
		((Control)btnTRP5Next).Name = "btnTRP5Next";
		((Control)btnTRP5Next).Size = new Size(116, 24);
		((Control)btnTRP5Next).TabIndex = 28;
		((Control)btnTRP5Next).Text = "Next";
		((ButtonBase)btnTRP5Next).UseVisualStyleBackColor = false;
		((Control)btnTRP5Next).Click += btnTRP5Next_Click;
		((Control)btnTRP6Back).AutoSize = true;
		((Control)btnTRP6Back).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP6Back).FlatStyle = (FlatStyle)0;
		((Control)btnTRP6Back).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP6Back).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP6Back).ImeMode = (ImeMode)0;
		((Control)btnTRP6Back).Location = new Point(372, 10);
		((Control)btnTRP6Back).Name = "btnTRP6Back";
		((Control)btnTRP6Back).Size = new Size(116, 24);
		((Control)btnTRP6Back).TabIndex = 6;
		((Control)btnTRP6Back).Text = "Back";
		((ButtonBase)btnTRP6Back).UseVisualStyleBackColor = false;
		((Control)btnTRP6Next).AutoSize = true;
		((Control)btnTRP6Next).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP6Next).FlatStyle = (FlatStyle)0;
		((Control)btnTRP6Next).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP6Next).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP6Next).ImeMode = (ImeMode)0;
		((Control)btnTRP6Next).Location = new Point(503, 10);
		((Control)btnTRP6Next).Name = "btnTRP6Next";
		((Control)btnTRP6Next).Size = new Size(116, 24);
		((Control)btnTRP6Next).TabIndex = 7;
		((Control)btnTRP6Next).Text = "Next";
		((ButtonBase)btnTRP6Next).UseVisualStyleBackColor = false;
		((Control)btnTRP6Next).Click += btnTRP6Next_Click;
		((Control)btnTRP7Back).AutoSize = true;
		((Control)btnTRP7Back).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP7Back).FlatStyle = (FlatStyle)0;
		((Control)btnTRP7Back).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP7Back).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP7Back).ImeMode = (ImeMode)0;
		((Control)btnTRP7Back).Location = new Point(372, 10);
		((Control)btnTRP7Back).Name = "btnTRP7Back";
		((Control)btnTRP7Back).Size = new Size(116, 24);
		((Control)btnTRP7Back).TabIndex = 12;
		((Control)btnTRP7Back).Text = "Back";
		((ButtonBase)btnTRP7Back).UseVisualStyleBackColor = false;
		((Control)btnTRP7Back).Click += btnTRP7Back_Click;
		((Control)btnTRP7Next).AutoSize = true;
		((Control)btnTRP7Next).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP7Next).FlatStyle = (FlatStyle)0;
		((Control)btnTRP7Next).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP7Next).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP7Next).ImeMode = (ImeMode)0;
		((Control)btnTRP7Next).Location = new Point(503, 10);
		((Control)btnTRP7Next).Name = "btnTRP7Next";
		((Control)btnTRP7Next).Size = new Size(116, 24);
		((Control)btnTRP7Next).TabIndex = 13;
		((Control)btnTRP7Next).Text = "Next";
		((ButtonBase)btnTRP7Next).UseVisualStyleBackColor = false;
		((Control)btnTRP7Next).Click += btnTRP7Next_Click;
		((Control)btnTRP8Back).AutoSize = true;
		((Control)btnTRP8Back).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP8Back).FlatStyle = (FlatStyle)0;
		((Control)btnTRP8Back).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP8Back).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP8Back).ImeMode = (ImeMode)0;
		((Control)btnTRP8Back).Location = new Point(372, 10);
		((Control)btnTRP8Back).Name = "btnTRP8Back";
		((Control)btnTRP8Back).Size = new Size(116, 24);
		((Control)btnTRP8Back).TabIndex = 12;
		((Control)btnTRP8Back).Text = "Back";
		((ButtonBase)btnTRP8Back).UseVisualStyleBackColor = false;
		((Control)btnTRP8Next).AutoSize = true;
		((Control)btnTRP8Next).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP8Next).FlatStyle = (FlatStyle)0;
		((Control)btnTRP8Next).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP8Next).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP8Next).ImeMode = (ImeMode)0;
		((Control)btnTRP8Next).Location = new Point(503, 10);
		((Control)btnTRP8Next).Name = "btnTRP8Next";
		((Control)btnTRP8Next).Size = new Size(116, 24);
		((Control)btnTRP8Next).TabIndex = 13;
		((Control)btnTRP8Next).Text = "Next";
		((ButtonBase)btnTRP8Next).UseVisualStyleBackColor = false;
		((Control)btnTRP8Next).Click += btnTRP8Next_Click;
		((Control)btnTRP9Back).AutoSize = true;
		((Control)btnTRP9Back).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP9Back).FlatStyle = (FlatStyle)0;
		((Control)btnTRP9Back).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP9Back).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP9Back).ImeMode = (ImeMode)0;
		((Control)btnTRP9Back).Location = new Point(372, 10);
		((Control)btnTRP9Back).Name = "btnTRP9Back";
		((Control)btnTRP9Back).Size = new Size(116, 24);
		((Control)btnTRP9Back).TabIndex = 27;
		((Control)btnTRP9Back).Text = "Back";
		((ButtonBase)btnTRP9Back).UseVisualStyleBackColor = false;
		((Control)btnTRP9Back).Click += btnTRP9Back_Click;
		((Control)btnTRP9Execute).AutoSize = true;
		((Control)btnTRP9Execute).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP9Execute).FlatStyle = (FlatStyle)0;
		((Control)btnTRP9Execute).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP9Execute).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP9Execute).ImeMode = (ImeMode)0;
		((Control)btnTRP9Execute).Location = new Point(503, 10);
		((Control)btnTRP9Execute).Name = "btnTRP9Execute";
		((Control)btnTRP9Execute).Size = new Size(116, 24);
		((Control)btnTRP9Execute).TabIndex = 28;
		((Control)btnTRP9Execute).Text = "Go";
		((ButtonBase)btnTRP9Execute).UseVisualStyleBackColor = false;
		((Control)btnTRP9Execute).Click += btnTRP9Execute_Click;
		((Control)btnTRP10Top).AutoSize = true;
		((Control)btnTRP10Top).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP10Top).FlatStyle = (FlatStyle)0;
		((Control)btnTRP10Top).Font = new Font("MS UI Gothic", 9f);
		((ButtonBase)btnTRP10Top).ImeMode = (ImeMode)0;
		((Control)btnTRP10Top).Location = new Point(503, 10);
		((Control)btnTRP10Top).Name = "btnTRP10Top";
		((Control)btnTRP10Top).Size = new Size(116, 24);
		((Control)btnTRP10Top).TabIndex = 30;
		((Control)btnTRP10Top).Text = "Top";
		((ButtonBase)btnTRP10Top).UseVisualStyleBackColor = false;
		((Control)btnTRP10End).AutoSize = true;
		((Control)btnTRP10End).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP10End).FlatStyle = (FlatStyle)0;
		((Control)btnTRP10End).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP10End).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP10End).ImeMode = (ImeMode)0;
		((Control)btnTRP10End).Location = new Point(632, 10);
		((Control)btnTRP10End).Name = "btnTRP10End";
		((Control)btnTRP10End).Size = new Size(116, 24);
		((Control)btnTRP10End).TabIndex = 31;
		((Control)btnTRP10End).Text = "End";
		((ButtonBase)btnTRP10End).UseVisualStyleBackColor = false;
		((ContainerControl)this).AutoScaleDimensions = new SizeF(6f, 12f);
		((ContainerControl)this).AutoScaleMode = (AutoScaleMode)1;
		((Control)this).BackColor = Color.White;
		((Form)this).ClientSize = new Size(759, 539);
		((Control)this).Controls.Add((Control)(object)menuStrip1);
		((Control)this).Controls.Add((Control)(object)tabControl1_Main);
		((Form)this).FormBorderStyle = (FormBorderStyle)1;
		((Form)this).Icon = (Icon)componentResourceManager.GetObject("$this.Icon");
		((Form)this).MaximizeBox = false;
		((Control)this).Name = "FormWizard";
		((Form)this).StartPosition = (FormStartPosition)1;
		((Control)this).Text = "Send Folder Environment Tool";
		((Control)tabPage5_confirm).ResumeLayout(false);
		((Control)panel_P5_3).ResumeLayout(false);
		((Control)panel_P5_3).PerformLayout();
		((Control)panel_P5_2).ResumeLayout(false);
		((Control)panel_P5_2).PerformLayout();
		((Control)panel15).ResumeLayout(false);
		((Control)panel15).PerformLayout();
		((ISupportInitialize)pictureBox5).EndInit();
		((Control)tabPage4_address).ResumeLayout(false);
		((Control)panel_P4_3).ResumeLayout(false);
		((Control)panel_P4_3).PerformLayout();
		((Control)panel_P4_2).ResumeLayout(false);
		((Control)panel_P4_2).PerformLayout();
		((ISupportInitialize)pictureBox4).EndInit();
		((Control)tabPage3_shareFolder).ResumeLayout(false);
		((Control)panel_P3_3).ResumeLayout(false);
		((Control)panel_P3_3).PerformLayout();
		((Control)panel_P3_2).ResumeLayout(false);
		((Control)panel_P3_2).PerformLayout();
		((ISupportInitialize)pictureBox3).EndInit();
		((Control)tabPage2_setupSelect).ResumeLayout(false);
		((Control)panel_P2_3).ResumeLayout(false);
		((Control)panel_P2_3).PerformLayout();
		((Control)panel_P2_2).ResumeLayout(false);
		((Control)panel_P2_2).PerformLayout();
		((ISupportInitialize)pictureBox2).EndInit();
		((Control)tabPage1_introduction).ResumeLayout(false);
		((Control)panel_P1_3).ResumeLayout(false);
		((Control)panel_P1_3).PerformLayout();
		((Control)panel_P1_2).ResumeLayout(false);
		((Control)panel_P1_2).PerformLayout();
		((Control)attentionGroup).ResumeLayout(false);
		((ISupportInitialize)pictureBox1).EndInit();
		((Control)tabControl1_Main).ResumeLayout(false);
		((Control)tabPage6_exec).ResumeLayout(false);
		((Control)panel_P6_2).ResumeLayout(false);
		((Control)panel_P6_2).PerformLayout();
		((ISupportInitialize)pictureBox6).EndInit();
		((Control)tabPage7_finish).ResumeLayout(false);
		((Control)panel_P7_3).ResumeLayout(false);
		((Control)panel_P7_3).PerformLayout();
		((Control)panel_P7_2).ResumeLayout(false);
		((Control)panel_P7_2).PerformLayout();
		((Control)panel22).ResumeLayout(false);
		((Control)panel22).PerformLayout();
		((ISupportInitialize)pictureBox7).EndInit();
		((Control)tabTRP2_device).ResumeLayout(false);
		((Control)panel_TRP2_3).ResumeLayout(false);
		((Control)panel_TRP2_3).PerformLayout();
		((Control)panel_TRP2_2).ResumeLayout(false);
		((Control)panel_TRP2_2).PerformLayout();
		((ISupportInitialize)pictureBox8).EndInit();
		((Control)tabTRP3_user).ResumeLayout(false);
		((Control)panel_TRP3_3).ResumeLayout(false);
		((Control)panel_TRP3_3).PerformLayout();
		((Control)panel_TRP3_2).ResumeLayout(false);
		((Control)panel_TRP3_2).PerformLayout();
		((ISupportInitialize)pictureBox9).EndInit();
		((Control)tabTRP4_analyze).ResumeLayout(false);
		((Control)panel_TRP4_2).ResumeLayout(false);
		((Control)panel_TRP4_2).PerformLayout();
		((ISupportInitialize)pictureBox10).EndInit();
		((Control)tabTRP5_result).ResumeLayout(false);
		((Control)panel_TRP5_3).ResumeLayout(false);
		((Control)panel_TRP5_3).PerformLayout();
		((Control)panel_TRP5_2).ResumeLayout(false);
		((Control)panel_TRP5_2).PerformLayout();
		((ISupportInitialize)pictureBox13).EndInit();
		((Control)panel40).ResumeLayout(false);
		((Control)tabTRP6_setupSelect).ResumeLayout(false);
		((Control)panel_TRP6_3).ResumeLayout(false);
		((Control)panel_TRP6_3).PerformLayout();
		((Control)panel_TRP6_2).ResumeLayout(false);
		((Control)panel_TRP6_2).PerformLayout();
		((ISupportInitialize)pictureBox16).EndInit();
		((Control)tabTRP7_shareFolder).ResumeLayout(false);
		((Control)panel_TRP7_3).ResumeLayout(false);
		((Control)panel_TRP7_3).PerformLayout();
		((Control)panel_TRP7_2).ResumeLayout(false);
		((Control)panel_TRP7_2).PerformLayout();
		((ISupportInitialize)pictureBox12).EndInit();
		((Control)tabTRP8_address).ResumeLayout(false);
		((Control)panel_TRP8_3).ResumeLayout(false);
		((Control)panel_TRP8_3).PerformLayout();
		((Control)panel_TRP8_2).ResumeLayout(false);
		((Control)panel_TRP8_2).PerformLayout();
		((ISupportInitialize)pictureBox17).EndInit();
		((Control)tabTRP9_confirm).ResumeLayout(false);
		((Control)panel_TRP9_3).ResumeLayout(false);
		((Control)panel_TRP9_3).PerformLayout();
		((Control)panel_TRP9_2).ResumeLayout(false);
		((Control)panel_TRP9_2).PerformLayout();
		((ISupportInitialize)pictureBox14).EndInit();
		((Control)panel45).ResumeLayout(false);
		((Control)tabTRP10_finish).ResumeLayout(false);
		((Control)panel_TRP10_3).ResumeLayout(false);
		((Control)panel_TRP10_3).PerformLayout();
		((Control)panel_TRP10_2).ResumeLayout(false);
		((Control)panel_TRP10_2).PerformLayout();
		((Control)panelTRP10).ResumeLayout(false);
		((Control)panelTRP10).PerformLayout();
		((ISupportInitialize)pictureBox11).EndInit();
		((Control)menuStrip1).ResumeLayout(false);
		((Control)menuStrip1).PerformLayout();
		((ISupportInitialize)pictureBox15).EndInit();
		((Control)this).ResumeLayout(false);
		((Control)this).PerformLayout();
	}

	private void InitializeComponent_MultiLang()
	{
		//IL_0011: Unknown result type (might be due to invalid IL or missing references)
		//IL_001b: Expected O, but got Unknown
		//IL_001c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0026: Expected O, but got Unknown
		//IL_0027: Unknown result type (might be due to invalid IL or missing references)
		//IL_0031: Expected O, but got Unknown
		//IL_0032: Unknown result type (might be due to invalid IL or missing references)
		//IL_003c: Expected O, but got Unknown
		//IL_003d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0047: Expected O, but got Unknown
		//IL_0048: Unknown result type (might be due to invalid IL or missing references)
		//IL_0052: Expected O, but got Unknown
		//IL_0053: Unknown result type (might be due to invalid IL or missing references)
		//IL_005d: Expected O, but got Unknown
		//IL_005e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0068: Expected O, but got Unknown
		//IL_0069: Unknown result type (might be due to invalid IL or missing references)
		//IL_0073: Expected O, but got Unknown
		//IL_0074: Unknown result type (might be due to invalid IL or missing references)
		//IL_007e: Expected O, but got Unknown
		//IL_007f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0089: Expected O, but got Unknown
		//IL_008a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0094: Expected O, but got Unknown
		//IL_0095: Unknown result type (might be due to invalid IL or missing references)
		//IL_009f: Expected O, but got Unknown
		//IL_00a0: Unknown result type (might be due to invalid IL or missing references)
		//IL_00aa: Expected O, but got Unknown
		//IL_00ab: Unknown result type (might be due to invalid IL or missing references)
		//IL_00b5: Expected O, but got Unknown
		//IL_00b6: Unknown result type (might be due to invalid IL or missing references)
		//IL_00c0: Expected O, but got Unknown
		//IL_00c1: Unknown result type (might be due to invalid IL or missing references)
		//IL_00cb: Expected O, but got Unknown
		//IL_00cc: Unknown result type (might be due to invalid IL or missing references)
		//IL_00d6: Expected O, but got Unknown
		//IL_00d7: Unknown result type (might be due to invalid IL or missing references)
		//IL_00e1: Expected O, but got Unknown
		//IL_00e2: Unknown result type (might be due to invalid IL or missing references)
		//IL_00ec: Expected O, but got Unknown
		//IL_00ed: Unknown result type (might be due to invalid IL or missing references)
		//IL_00f7: Expected O, but got Unknown
		//IL_00f8: Unknown result type (might be due to invalid IL or missing references)
		//IL_0102: Expected O, but got Unknown
		//IL_0103: Unknown result type (might be due to invalid IL or missing references)
		//IL_010d: Expected O, but got Unknown
		//IL_010e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0118: Expected O, but got Unknown
		//IL_0119: Unknown result type (might be due to invalid IL or missing references)
		//IL_0123: Expected O, but got Unknown
		//IL_0124: Unknown result type (might be due to invalid IL or missing references)
		//IL_012e: Expected O, but got Unknown
		//IL_012f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0139: Expected O, but got Unknown
		//IL_013a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0144: Expected O, but got Unknown
		//IL_0145: Unknown result type (might be due to invalid IL or missing references)
		//IL_014f: Expected O, but got Unknown
		//IL_0150: Unknown result type (might be due to invalid IL or missing references)
		//IL_015a: Expected O, but got Unknown
		//IL_015b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0165: Expected O, but got Unknown
		//IL_0166: Unknown result type (might be due to invalid IL or missing references)
		//IL_0170: Expected O, but got Unknown
		//IL_0171: Unknown result type (might be due to invalid IL or missing references)
		//IL_017b: Expected O, but got Unknown
		//IL_017c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0186: Expected O, but got Unknown
		//IL_0187: Unknown result type (might be due to invalid IL or missing references)
		//IL_0191: Expected O, but got Unknown
		//IL_0192: Unknown result type (might be due to invalid IL or missing references)
		//IL_019c: Expected O, but got Unknown
		//IL_019d: Unknown result type (might be due to invalid IL or missing references)
		//IL_01a7: Expected O, but got Unknown
		//IL_01a8: Unknown result type (might be due to invalid IL or missing references)
		//IL_01b2: Expected O, but got Unknown
		//IL_01b3: Unknown result type (might be due to invalid IL or missing references)
		//IL_01bd: Expected O, but got Unknown
		//IL_01be: Unknown result type (might be due to invalid IL or missing references)
		//IL_01c8: Expected O, but got Unknown
		//IL_01c9: Unknown result type (might be due to invalid IL or missing references)
		//IL_01d3: Expected O, but got Unknown
		//IL_01d4: Unknown result type (might be due to invalid IL or missing references)
		//IL_01de: Expected O, but got Unknown
		//IL_01df: Unknown result type (might be due to invalid IL or missing references)
		//IL_01e9: Expected O, but got Unknown
		//IL_01ea: Unknown result type (might be due to invalid IL or missing references)
		//IL_01f4: Expected O, but got Unknown
		//IL_01f5: Unknown result type (might be due to invalid IL or missing references)
		//IL_01ff: Expected O, but got Unknown
		//IL_0200: Unknown result type (might be due to invalid IL or missing references)
		//IL_020a: Expected O, but got Unknown
		//IL_020b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0215: Expected O, but got Unknown
		//IL_0216: Unknown result type (might be due to invalid IL or missing references)
		//IL_0220: Expected O, but got Unknown
		//IL_0221: Unknown result type (might be due to invalid IL or missing references)
		//IL_022b: Expected O, but got Unknown
		//IL_022c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0236: Expected O, but got Unknown
		//IL_0237: Unknown result type (might be due to invalid IL or missing references)
		//IL_0241: Expected O, but got Unknown
		//IL_0242: Unknown result type (might be due to invalid IL or missing references)
		//IL_024c: Expected O, but got Unknown
		//IL_024d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0257: Expected O, but got Unknown
		//IL_0258: Unknown result type (might be due to invalid IL or missing references)
		//IL_0262: Expected O, but got Unknown
		//IL_0263: Unknown result type (might be due to invalid IL or missing references)
		//IL_026d: Expected O, but got Unknown
		//IL_026e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0278: Expected O, but got Unknown
		//IL_0279: Unknown result type (might be due to invalid IL or missing references)
		//IL_0283: Expected O, but got Unknown
		//IL_0284: Unknown result type (might be due to invalid IL or missing references)
		//IL_028e: Expected O, but got Unknown
		//IL_028f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0299: Expected O, but got Unknown
		//IL_029a: Unknown result type (might be due to invalid IL or missing references)
		//IL_02a4: Expected O, but got Unknown
		//IL_02a5: Unknown result type (might be due to invalid IL or missing references)
		//IL_02af: Expected O, but got Unknown
		//IL_02b0: Unknown result type (might be due to invalid IL or missing references)
		//IL_02ba: Expected O, but got Unknown
		//IL_02bb: Unknown result type (might be due to invalid IL or missing references)
		//IL_02c5: Expected O, but got Unknown
		//IL_02c6: Unknown result type (might be due to invalid IL or missing references)
		//IL_02d0: Expected O, but got Unknown
		//IL_02d1: Unknown result type (might be due to invalid IL or missing references)
		//IL_02db: Expected O, but got Unknown
		//IL_02dc: Unknown result type (might be due to invalid IL or missing references)
		//IL_02e6: Expected O, but got Unknown
		//IL_02e7: Unknown result type (might be due to invalid IL or missing references)
		//IL_02f1: Expected O, but got Unknown
		//IL_02f2: Unknown result type (might be due to invalid IL or missing references)
		//IL_02fc: Expected O, but got Unknown
		//IL_02fd: Unknown result type (might be due to invalid IL or missing references)
		//IL_0307: Expected O, but got Unknown
		//IL_0308: Unknown result type (might be due to invalid IL or missing references)
		//IL_0312: Expected O, but got Unknown
		//IL_0313: Unknown result type (might be due to invalid IL or missing references)
		//IL_031d: Expected O, but got Unknown
		//IL_031e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0328: Expected O, but got Unknown
		//IL_0329: Unknown result type (might be due to invalid IL or missing references)
		//IL_0333: Expected O, but got Unknown
		//IL_0334: Unknown result type (might be due to invalid IL or missing references)
		//IL_033e: Expected O, but got Unknown
		//IL_033f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0349: Expected O, but got Unknown
		//IL_034a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0354: Expected O, but got Unknown
		//IL_0355: Unknown result type (might be due to invalid IL or missing references)
		//IL_035f: Expected O, but got Unknown
		//IL_0360: Unknown result type (might be due to invalid IL or missing references)
		//IL_036a: Expected O, but got Unknown
		//IL_036b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0375: Expected O, but got Unknown
		//IL_0376: Unknown result type (might be due to invalid IL or missing references)
		//IL_0380: Expected O, but got Unknown
		//IL_0381: Unknown result type (might be due to invalid IL or missing references)
		//IL_038b: Expected O, but got Unknown
		//IL_038c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0396: Expected O, but got Unknown
		//IL_0397: Unknown result type (might be due to invalid IL or missing references)
		//IL_03a1: Expected O, but got Unknown
		//IL_03a2: Unknown result type (might be due to invalid IL or missing references)
		//IL_03ac: Expected O, but got Unknown
		//IL_03ad: Unknown result type (might be due to invalid IL or missing references)
		//IL_03b7: Expected O, but got Unknown
		//IL_03b8: Unknown result type (might be due to invalid IL or missing references)
		//IL_03c2: Expected O, but got Unknown
		//IL_03c3: Unknown result type (might be due to invalid IL or missing references)
		//IL_03cd: Expected O, but got Unknown
		//IL_03ce: Unknown result type (might be due to invalid IL or missing references)
		//IL_03d8: Expected O, but got Unknown
		//IL_03d9: Unknown result type (might be due to invalid IL or missing references)
		//IL_03e3: Expected O, but got Unknown
		//IL_03e4: Unknown result type (might be due to invalid IL or missing references)
		//IL_03ee: Expected O, but got Unknown
		//IL_03ef: Unknown result type (might be due to invalid IL or missing references)
		//IL_03f9: Expected O, but got Unknown
		//IL_03fa: Unknown result type (might be due to invalid IL or missing references)
		//IL_0404: Expected O, but got Unknown
		//IL_0405: Unknown result type (might be due to invalid IL or missing references)
		//IL_040f: Expected O, but got Unknown
		//IL_0410: Unknown result type (might be due to invalid IL or missing references)
		//IL_041a: Expected O, but got Unknown
		//IL_041b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0425: Expected O, but got Unknown
		//IL_0426: Unknown result type (might be due to invalid IL or missing references)
		//IL_0430: Expected O, but got Unknown
		//IL_0431: Unknown result type (might be due to invalid IL or missing references)
		//IL_043b: Expected O, but got Unknown
		//IL_043c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0446: Expected O, but got Unknown
		//IL_0447: Unknown result type (might be due to invalid IL or missing references)
		//IL_0451: Expected O, but got Unknown
		//IL_0452: Unknown result type (might be due to invalid IL or missing references)
		//IL_045c: Expected O, but got Unknown
		//IL_045d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0467: Expected O, but got Unknown
		//IL_0468: Unknown result type (might be due to invalid IL or missing references)
		//IL_0472: Expected O, but got Unknown
		//IL_0473: Unknown result type (might be due to invalid IL or missing references)
		//IL_047d: Expected O, but got Unknown
		//IL_047e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0488: Expected O, but got Unknown
		//IL_0489: Unknown result type (might be due to invalid IL or missing references)
		//IL_0493: Expected O, but got Unknown
		//IL_0494: Unknown result type (might be due to invalid IL or missing references)
		//IL_049e: Expected O, but got Unknown
		//IL_049f: Unknown result type (might be due to invalid IL or missing references)
		//IL_04a9: Expected O, but got Unknown
		//IL_04aa: Unknown result type (might be due to invalid IL or missing references)
		//IL_04b4: Expected O, but got Unknown
		//IL_04b5: Unknown result type (might be due to invalid IL or missing references)
		//IL_04bf: Expected O, but got Unknown
		//IL_04c0: Unknown result type (might be due to invalid IL or missing references)
		//IL_04ca: Expected O, but got Unknown
		//IL_04cb: Unknown result type (might be due to invalid IL or missing references)
		//IL_04d5: Expected O, but got Unknown
		//IL_04d6: Unknown result type (might be due to invalid IL or missing references)
		//IL_04e0: Expected O, but got Unknown
		//IL_04e1: Unknown result type (might be due to invalid IL or missing references)
		//IL_04eb: Expected O, but got Unknown
		//IL_04ec: Unknown result type (might be due to invalid IL or missing references)
		//IL_04f6: Expected O, but got Unknown
		//IL_04f7: Unknown result type (might be due to invalid IL or missing references)
		//IL_0501: Expected O, but got Unknown
		//IL_0502: Unknown result type (might be due to invalid IL or missing references)
		//IL_050c: Expected O, but got Unknown
		//IL_050d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0517: Expected O, but got Unknown
		//IL_0518: Unknown result type (might be due to invalid IL or missing references)
		//IL_0522: Expected O, but got Unknown
		//IL_0523: Unknown result type (might be due to invalid IL or missing references)
		//IL_052d: Expected O, but got Unknown
		//IL_052e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0538: Expected O, but got Unknown
		//IL_0539: Unknown result type (might be due to invalid IL or missing references)
		//IL_0543: Expected O, but got Unknown
		//IL_0544: Unknown result type (might be due to invalid IL or missing references)
		//IL_054e: Expected O, but got Unknown
		//IL_054f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0559: Expected O, but got Unknown
		//IL_055a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0564: Expected O, but got Unknown
		//IL_0565: Unknown result type (might be due to invalid IL or missing references)
		//IL_056f: Expected O, but got Unknown
		//IL_0570: Unknown result type (might be due to invalid IL or missing references)
		//IL_057a: Expected O, but got Unknown
		//IL_057b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0585: Expected O, but got Unknown
		//IL_0586: Unknown result type (might be due to invalid IL or missing references)
		//IL_0590: Expected O, but got Unknown
		//IL_0591: Unknown result type (might be due to invalid IL or missing references)
		//IL_059b: Expected O, but got Unknown
		//IL_059c: Unknown result type (might be due to invalid IL or missing references)
		//IL_05a6: Expected O, but got Unknown
		//IL_05a7: Unknown result type (might be due to invalid IL or missing references)
		//IL_05b1: Expected O, but got Unknown
		//IL_05b2: Unknown result type (might be due to invalid IL or missing references)
		//IL_05bc: Expected O, but got Unknown
		//IL_05bd: Unknown result type (might be due to invalid IL or missing references)
		//IL_05c7: Expected O, but got Unknown
		//IL_05c8: Unknown result type (might be due to invalid IL or missing references)
		//IL_05d2: Expected O, but got Unknown
		//IL_05d3: Unknown result type (might be due to invalid IL or missing references)
		//IL_05dd: Expected O, but got Unknown
		//IL_05de: Unknown result type (might be due to invalid IL or missing references)
		//IL_05e8: Expected O, but got Unknown
		//IL_05e9: Unknown result type (might be due to invalid IL or missing references)
		//IL_05f3: Expected O, but got Unknown
		//IL_05f4: Unknown result type (might be due to invalid IL or missing references)
		//IL_05fe: Expected O, but got Unknown
		//IL_05ff: Unknown result type (might be due to invalid IL or missing references)
		//IL_0609: Expected O, but got Unknown
		//IL_060a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0614: Expected O, but got Unknown
		//IL_0615: Unknown result type (might be due to invalid IL or missing references)
		//IL_061f: Expected O, but got Unknown
		//IL_0620: Unknown result type (might be due to invalid IL or missing references)
		//IL_062a: Expected O, but got Unknown
		//IL_062b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0635: Expected O, but got Unknown
		//IL_0636: Unknown result type (might be due to invalid IL or missing references)
		//IL_0640: Expected O, but got Unknown
		//IL_0641: Unknown result type (might be due to invalid IL or missing references)
		//IL_064b: Expected O, but got Unknown
		//IL_064c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0656: Expected O, but got Unknown
		//IL_0657: Unknown result type (might be due to invalid IL or missing references)
		//IL_0661: Expected O, but got Unknown
		//IL_0662: Unknown result type (might be due to invalid IL or missing references)
		//IL_066c: Expected O, but got Unknown
		//IL_066d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0677: Expected O, but got Unknown
		//IL_0678: Unknown result type (might be due to invalid IL or missing references)
		//IL_0682: Expected O, but got Unknown
		//IL_0683: Unknown result type (might be due to invalid IL or missing references)
		//IL_068d: Expected O, but got Unknown
		//IL_068e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0698: Expected O, but got Unknown
		//IL_0699: Unknown result type (might be due to invalid IL or missing references)
		//IL_06a3: Expected O, but got Unknown
		//IL_06a4: Unknown result type (might be due to invalid IL or missing references)
		//IL_06ae: Expected O, but got Unknown
		//IL_06af: Unknown result type (might be due to invalid IL or missing references)
		//IL_06b9: Expected O, but got Unknown
		//IL_06ba: Unknown result type (might be due to invalid IL or missing references)
		//IL_06c4: Expected O, but got Unknown
		//IL_06c5: Unknown result type (might be due to invalid IL or missing references)
		//IL_06cf: Expected O, but got Unknown
		//IL_06d0: Unknown result type (might be due to invalid IL or missing references)
		//IL_06da: Expected O, but got Unknown
		//IL_06db: Unknown result type (might be due to invalid IL or missing references)
		//IL_06e5: Expected O, but got Unknown
		//IL_06e6: Unknown result type (might be due to invalid IL or missing references)
		//IL_06f0: Expected O, but got Unknown
		//IL_06f1: Unknown result type (might be due to invalid IL or missing references)
		//IL_06fb: Expected O, but got Unknown
		//IL_06fc: Unknown result type (might be due to invalid IL or missing references)
		//IL_0706: Expected O, but got Unknown
		//IL_0707: Unknown result type (might be due to invalid IL or missing references)
		//IL_0711: Expected O, but got Unknown
		//IL_0712: Unknown result type (might be due to invalid IL or missing references)
		//IL_071c: Expected O, but got Unknown
		//IL_071d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0727: Expected O, but got Unknown
		//IL_0728: Unknown result type (might be due to invalid IL or missing references)
		//IL_0732: Expected O, but got Unknown
		//IL_0733: Unknown result type (might be due to invalid IL or missing references)
		//IL_073d: Expected O, but got Unknown
		//IL_073e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0748: Expected O, but got Unknown
		//IL_0749: Unknown result type (might be due to invalid IL or missing references)
		//IL_0753: Expected O, but got Unknown
		//IL_0754: Unknown result type (might be due to invalid IL or missing references)
		//IL_075e: Expected O, but got Unknown
		//IL_075f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0769: Expected O, but got Unknown
		//IL_076a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0774: Expected O, but got Unknown
		//IL_0775: Unknown result type (might be due to invalid IL or missing references)
		//IL_077f: Expected O, but got Unknown
		//IL_0780: Unknown result type (might be due to invalid IL or missing references)
		//IL_078a: Expected O, but got Unknown
		//IL_078b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0795: Expected O, but got Unknown
		//IL_0796: Unknown result type (might be due to invalid IL or missing references)
		//IL_07a0: Expected O, but got Unknown
		//IL_07a1: Unknown result type (might be due to invalid IL or missing references)
		//IL_07ab: Expected O, but got Unknown
		//IL_07ac: Unknown result type (might be due to invalid IL or missing references)
		//IL_07b6: Expected O, but got Unknown
		//IL_07b7: Unknown result type (might be due to invalid IL or missing references)
		//IL_07c1: Expected O, but got Unknown
		//IL_07c2: Unknown result type (might be due to invalid IL or missing references)
		//IL_07cc: Expected O, but got Unknown
		//IL_07cd: Unknown result type (might be due to invalid IL or missing references)
		//IL_07d7: Expected O, but got Unknown
		//IL_07d8: Unknown result type (might be due to invalid IL or missing references)
		//IL_07e2: Expected O, but got Unknown
		//IL_07e3: Unknown result type (might be due to invalid IL or missing references)
		//IL_07ed: Expected O, but got Unknown
		//IL_07ee: Unknown result type (might be due to invalid IL or missing references)
		//IL_07f8: Expected O, but got Unknown
		//IL_07f9: Unknown result type (might be due to invalid IL or missing references)
		//IL_0803: Expected O, but got Unknown
		//IL_0804: Unknown result type (might be due to invalid IL or missing references)
		//IL_080e: Expected O, but got Unknown
		//IL_080f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0819: Expected O, but got Unknown
		//IL_081a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0824: Expected O, but got Unknown
		//IL_0825: Unknown result type (might be due to invalid IL or missing references)
		//IL_082f: Expected O, but got Unknown
		//IL_0830: Unknown result type (might be due to invalid IL or missing references)
		//IL_083a: Expected O, but got Unknown
		//IL_083b: Unknown result type (might be due to invalid IL or missing references)
		//IL_0845: Expected O, but got Unknown
		//IL_0846: Unknown result type (might be due to invalid IL or missing references)
		//IL_0850: Expected O, but got Unknown
		//IL_0851: Unknown result type (might be due to invalid IL or missing references)
		//IL_085b: Expected O, but got Unknown
		//IL_085c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0866: Expected O, but got Unknown
		//IL_0867: Unknown result type (might be due to invalid IL or missing references)
		//IL_0871: Expected O, but got Unknown
		//IL_0872: Unknown result type (might be due to invalid IL or missing references)
		//IL_087c: Expected O, but got Unknown
		//IL_087d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0887: Expected O, but got Unknown
		//IL_0888: Unknown result type (might be due to invalid IL or missing references)
		//IL_0892: Expected O, but got Unknown
		//IL_0893: Unknown result type (might be due to invalid IL or missing references)
		//IL_089d: Expected O, but got Unknown
		//IL_089e: Unknown result type (might be due to invalid IL or missing references)
		//IL_08a8: Expected O, but got Unknown
		//IL_08a9: Unknown result type (might be due to invalid IL or missing references)
		//IL_08b3: Expected O, but got Unknown
		//IL_08b4: Unknown result type (might be due to invalid IL or missing references)
		//IL_08be: Expected O, but got Unknown
		//IL_08bf: Unknown result type (might be due to invalid IL or missing references)
		//IL_08c9: Expected O, but got Unknown
		//IL_08ca: Unknown result type (might be due to invalid IL or missing references)
		//IL_08d4: Expected O, but got Unknown
		//IL_08d5: Unknown result type (might be due to invalid IL or missing references)
		//IL_08df: Expected O, but got Unknown
		//IL_08e0: Unknown result type (might be due to invalid IL or missing references)
		//IL_08ea: Expected O, but got Unknown
		//IL_08eb: Unknown result type (might be due to invalid IL or missing references)
		//IL_08f5: Expected O, but got Unknown
		//IL_08f6: Unknown result type (might be due to invalid IL or missing references)
		//IL_0900: Expected O, but got Unknown
		//IL_0901: Unknown result type (might be due to invalid IL or missing references)
		//IL_090b: Expected O, but got Unknown
		//IL_090c: Unknown result type (might be due to invalid IL or missing references)
		//IL_0916: Expected O, but got Unknown
		//IL_0917: Unknown result type (might be due to invalid IL or missing references)
		//IL_0921: Expected O, but got Unknown
		//IL_0922: Unknown result type (might be due to invalid IL or missing references)
		//IL_092c: Expected O, but got Unknown
		//IL_092d: Unknown result type (might be due to invalid IL or missing references)
		//IL_0937: Expected O, but got Unknown
		//IL_0938: Unknown result type (might be due to invalid IL or missing references)
		//IL_0942: Expected O, but got Unknown
		//IL_0943: Unknown result type (might be due to invalid IL or missing references)
		//IL_094d: Expected O, but got Unknown
		//IL_094e: Unknown result type (might be due to invalid IL or missing references)
		//IL_0958: Expected O, but got Unknown
		//IL_0959: Unknown result type (might be due to invalid IL or missing references)
		//IL_0963: Expected O, but got Unknown
		//IL_0964: Unknown result type (might be due to invalid IL or missing references)
		//IL_096e: Expected O, but got Unknown
		//IL_096f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0979: Expected O, but got Unknown
		//IL_097a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0984: Expected O, but got Unknown
		//IL_0985: Unknown result type (might be due to invalid IL or missing references)
		//IL_098f: Expected O, but got Unknown
		//IL_0990: Unknown result type (might be due to invalid IL or missing references)
		//IL_099a: Expected O, but got Unknown
		//IL_099b: Unknown result type (might be due to invalid IL or missing references)
		//IL_09a5: Expected O, but got Unknown
		//IL_09a6: Unknown result type (might be due to invalid IL or missing references)
		//IL_09b0: Expected O, but got Unknown
		//IL_09b1: Unknown result type (might be due to invalid IL or missing references)
		//IL_09bb: Expected O, but got Unknown
		//IL_09bc: Unknown result type (might be due to invalid IL or missing references)
		//IL_09c6: Expected O, but got Unknown
		//IL_09c7: Unknown result type (might be due to invalid IL or missing references)
		//IL_09d1: Expected O, but got Unknown
		//IL_09d2: Unknown result type (might be due to invalid IL or missing references)
		//IL_09dc: Expected O, but got Unknown
		//IL_09dd: Unknown result type (might be due to invalid IL or missing references)
		//IL_09e7: Expected O, but got Unknown
		//IL_09e8: Unknown result type (might be due to invalid IL or missing references)
		//IL_09f2: Expected O, but got Unknown
		//IL_09f3: Unknown result type (might be due to invalid IL or missing references)
		//IL_09fd: Expected O, but got Unknown
		//IL_09fe: Unknown result type (might be due to invalid IL or missing references)
		//IL_0a08: Expected O, but got Unknown
		//IL_0a09: Unknown result type (might be due to invalid IL or missing references)
		//IL_0a13: Expected O, but got Unknown
		//IL_0a14: Unknown result type (might be due to invalid IL or missing references)
		//IL_0a1e: Expected O, but got Unknown
		//IL_0a1f: Unknown result type (might be due to invalid IL or missing references)
		//IL_0a29: Expected O, but got Unknown
		//IL_0a2a: Unknown result type (might be due to invalid IL or missing references)
		//IL_0a34: Expected O, but got Unknown
		//IL_0a35: Unknown result type (might be due to invalid IL or missing references)
		//IL_0a3f: Expected O, but got Unknown
		//IL_0a40: Unknown result type (might be due to invalid IL or missing references)
		//IL_0a4a: Expected O, but got Unknown
		//IL_0f4f: Unknown result type (might be due to invalid IL or missing references)
		//IL_1036: Unknown result type (might be due to invalid IL or missing references)
		//IL_1167: Unknown result type (might be due to invalid IL or missing references)
		//IL_1171: Expected O, but got Unknown
		//IL_125d: Unknown result type (might be due to invalid IL or missing references)
		//IL_12c3: Unknown result type (might be due to invalid IL or missing references)
		//IL_12cd: Expected O, but got Unknown
		//IL_1349: Unknown result type (might be due to invalid IL or missing references)
		//IL_1353: Expected O, but got Unknown
		//IL_13e8: Unknown result type (might be due to invalid IL or missing references)
		//IL_1485: Unknown result type (might be due to invalid IL or missing references)
		//IL_156c: Unknown result type (might be due to invalid IL or missing references)
		//IL_1757: Unknown result type (might be due to invalid IL or missing references)
		//IL_1761: Expected O, but got Unknown
		//IL_1800: Unknown result type (might be due to invalid IL or missing references)
		//IL_180a: Expected O, but got Unknown
		//IL_189a: Unknown result type (might be due to invalid IL or missing references)
		//IL_18a4: Expected O, but got Unknown
		//IL_1931: Unknown result type (might be due to invalid IL or missing references)
		//IL_193b: Expected O, but got Unknown
		//IL_19d6: Unknown result type (might be due to invalid IL or missing references)
		//IL_19e0: Expected O, but got Unknown
		//IL_1b05: Unknown result type (might be due to invalid IL or missing references)
		//IL_1b0f: Expected O, but got Unknown
		//IL_1b1f: Unknown result type (might be due to invalid IL or missing references)
		//IL_1b29: Expected O, but got Unknown
		//IL_1bdc: Unknown result type (might be due to invalid IL or missing references)
		//IL_1c42: Unknown result type (might be due to invalid IL or missing references)
		//IL_1c4c: Expected O, but got Unknown
		//IL_1cc8: Unknown result type (might be due to invalid IL or missing references)
		//IL_1cd2: Expected O, but got Unknown
		//IL_1d70: Unknown result type (might be due to invalid IL or missing references)
		//IL_1d7a: Expected O, but got Unknown
		//IL_1e09: Unknown result type (might be due to invalid IL or missing references)
		//IL_1e13: Expected O, but got Unknown
		//IL_1ea2: Unknown result type (might be due to invalid IL or missing references)
		//IL_1eac: Expected O, but got Unknown
		//IL_1f44: Unknown result type (might be due to invalid IL or missing references)
		//IL_1fe1: Unknown result type (might be due to invalid IL or missing references)
		//IL_20c8: Unknown result type (might be due to invalid IL or missing references)
		//IL_2251: Unknown result type (might be due to invalid IL or missing references)
		//IL_225b: Expected O, but got Unknown
		//IL_22df: Unknown result type (might be due to invalid IL or missing references)
		//IL_22e9: Expected O, but got Unknown
		//IL_2382: Unknown result type (might be due to invalid IL or missing references)
		//IL_238c: Expected O, but got Unknown
		//IL_2431: Unknown result type (might be due to invalid IL or missing references)
		//IL_243b: Expected O, but got Unknown
		//IL_24cb: Unknown result type (might be due to invalid IL or missing references)
		//IL_24d5: Expected O, but got Unknown
		//IL_2563: Unknown result type (might be due to invalid IL or missing references)
		//IL_25c9: Unknown result type (might be due to invalid IL or missing references)
		//IL_25d3: Expected O, but got Unknown
		//IL_264f: Unknown result type (might be due to invalid IL or missing references)
		//IL_2659: Expected O, but got Unknown
		//IL_26e8: Unknown result type (might be due to invalid IL or missing references)
		//IL_26f2: Expected O, but got Unknown
		//IL_278a: Unknown result type (might be due to invalid IL or missing references)
		//IL_2827: Unknown result type (might be due to invalid IL or missing references)
		//IL_290e: Unknown result type (might be due to invalid IL or missing references)
		//IL_2f96: Unknown result type (might be due to invalid IL or missing references)
		//IL_2fa0: Expected O, but got Unknown
		//IL_3045: Unknown result type (might be due to invalid IL or missing references)
		//IL_304f: Expected O, but got Unknown
		//IL_30f2: Unknown result type (might be due to invalid IL or missing references)
		//IL_30fc: Expected O, but got Unknown
		//IL_318c: Unknown result type (might be due to invalid IL or missing references)
		//IL_3196: Expected O, but got Unknown
		//IL_3239: Unknown result type (might be due to invalid IL or missing references)
		//IL_3243: Expected O, but got Unknown
		//IL_32d3: Unknown result type (might be due to invalid IL or missing references)
		//IL_32dd: Expected O, but got Unknown
		//IL_3376: Unknown result type (might be due to invalid IL or missing references)
		//IL_3380: Expected O, but got Unknown
		//IL_3417: Unknown result type (might be due to invalid IL or missing references)
		//IL_3421: Expected O, but got Unknown
		//IL_34a5: Unknown result type (might be due to invalid IL or missing references)
		//IL_34af: Expected O, but got Unknown
		//IL_3556: Unknown result type (might be due to invalid IL or missing references)
		//IL_3560: Expected O, but got Unknown
		//IL_360b: Unknown result type (might be due to invalid IL or missing references)
		//IL_3671: Unknown result type (might be due to invalid IL or missing references)
		//IL_367b: Expected O, but got Unknown
		//IL_36f7: Unknown result type (might be due to invalid IL or missing references)
		//IL_3701: Expected O, but got Unknown
		//IL_3796: Unknown result type (might be due to invalid IL or missing references)
		//IL_3843: Unknown result type (might be due to invalid IL or missing references)
		//IL_391e: Unknown result type (might be due to invalid IL or missing references)
		//IL_3a6c: Unknown result type (might be due to invalid IL or missing references)
		//IL_3a76: Expected O, but got Unknown
		//IL_3b14: Unknown result type (might be due to invalid IL or missing references)
		//IL_3b1e: Expected O, but got Unknown
		//IL_3bd7: Unknown result type (might be due to invalid IL or missing references)
		//IL_3be1: Expected O, but got Unknown
		//IL_3c76: Unknown result type (might be due to invalid IL or missing references)
		//IL_3c80: Expected O, but got Unknown
		//IL_3d1d: Unknown result type (might be due to invalid IL or missing references)
		//IL_3d83: Unknown result type (might be due to invalid IL or missing references)
		//IL_3d8d: Expected O, but got Unknown
		//IL_3e09: Unknown result type (might be due to invalid IL or missing references)
		//IL_3e13: Expected O, but got Unknown
		//IL_3ea8: Unknown result type (might be due to invalid IL or missing references)
		//IL_4064: Unknown result type (might be due to invalid IL or missing references)
		//IL_40cf: Unknown result type (might be due to invalid IL or missing references)
		//IL_40d9: Expected O, but got Unknown
		//IL_4135: Unknown result type (might be due to invalid IL or missing references)
		//IL_41da: Unknown result type (might be due to invalid IL or missing references)
		//IL_4383: Unknown result type (might be due to invalid IL or missing references)
		//IL_438d: Expected O, but got Unknown
		//IL_4427: Unknown result type (might be due to invalid IL or missing references)
		//IL_448d: Unknown result type (might be due to invalid IL or missing references)
		//IL_4497: Expected O, but got Unknown
		//IL_4513: Unknown result type (might be due to invalid IL or missing references)
		//IL_451d: Expected O, but got Unknown
		//IL_45b2: Unknown result type (might be due to invalid IL or missing references)
		//IL_464f: Unknown result type (might be due to invalid IL or missing references)
		//IL_4720: Unknown result type (might be due to invalid IL or missing references)
		//IL_487d: Unknown result type (might be due to invalid IL or missing references)
		//IL_4887: Expected O, but got Unknown
		//IL_4904: Unknown result type (might be due to invalid IL or missing references)
		//IL_490e: Expected O, but got Unknown
		//IL_492a: Unknown result type (might be due to invalid IL or missing references)
		//IL_4934: Expected O, but got Unknown
		//IL_49c1: Unknown result type (might be due to invalid IL or missing references)
		//IL_49cb: Expected O, but got Unknown
		//IL_4a1f: Unknown result type (might be due to invalid IL or missing references)
		//IL_4a29: Expected O, but got Unknown
		//IL_4b9e: Unknown result type (might be due to invalid IL or missing references)
		//IL_4c04: Unknown result type (might be due to invalid IL or missing references)
		//IL_4c0e: Expected O, but got Unknown
		//IL_4c8a: Unknown result type (might be due to invalid IL or missing references)
		//IL_4c94: Expected O, but got Unknown
		//IL_4d13: Unknown result type (might be due to invalid IL or missing references)
		//IL_4d1d: Expected O, but got Unknown
		//IL_4db2: Unknown result type (might be due to invalid IL or missing references)
		//IL_4e4f: Unknown result type (might be due to invalid IL or missing references)
		//IL_4f20: Unknown result type (might be due to invalid IL or missing references)
		//IL_5071: Unknown result type (might be due to invalid IL or missing references)
		//IL_507b: Expected O, but got Unknown
		//IL_51a1: Unknown result type (might be due to invalid IL or missing references)
		//IL_51ab: Expected O, but got Unknown
		//IL_51e2: Unknown result type (might be due to invalid IL or missing references)
		//IL_5248: Unknown result type (might be due to invalid IL or missing references)
		//IL_5252: Expected O, but got Unknown
		//IL_52ce: Unknown result type (might be due to invalid IL or missing references)
		//IL_52d8: Expected O, but got Unknown
		//IL_5367: Unknown result type (might be due to invalid IL or missing references)
		//IL_5371: Expected O, but got Unknown
		//IL_5406: Unknown result type (might be due to invalid IL or missing references)
		//IL_54a3: Unknown result type (might be due to invalid IL or missing references)
		//IL_5574: Unknown result type (might be due to invalid IL or missing references)
		//IL_586f: Unknown result type (might be due to invalid IL or missing references)
		//IL_5879: Expected O, but got Unknown
		//IL_5eac: Unknown result type (might be due to invalid IL or missing references)
		//IL_5eb6: Expected O, but got Unknown
		//IL_5f95: Unknown result type (might be due to invalid IL or missing references)
		//IL_5f9f: Expected O, but got Unknown
		//IL_5fac: Unknown result type (might be due to invalid IL or missing references)
		//IL_5fb6: Expected O, but got Unknown
		//IL_5fc3: Unknown result type (might be due to invalid IL or missing references)
		//IL_5fcd: Expected O, but got Unknown
		//IL_613f: Unknown result type (might be due to invalid IL or missing references)
		//IL_61a5: Unknown result type (might be due to invalid IL or missing references)
		//IL_61af: Expected O, but got Unknown
		//IL_6244: Unknown result type (might be due to invalid IL or missing references)
		//IL_62e1: Unknown result type (might be due to invalid IL or missing references)
		//IL_6387: Unknown result type (might be due to invalid IL or missing references)
		//IL_651a: Unknown result type (might be due to invalid IL or missing references)
		//IL_6524: Expected O, but got Unknown
		//IL_65be: Unknown result type (might be due to invalid IL or missing references)
		//IL_6624: Unknown result type (might be due to invalid IL or missing references)
		//IL_662e: Expected O, but got Unknown
		//IL_66aa: Unknown result type (might be due to invalid IL or missing references)
		//IL_66b4: Expected O, but got Unknown
		//IL_6749: Unknown result type (might be due to invalid IL or missing references)
		//IL_68a7: Unknown result type (might be due to invalid IL or missing references)
		//IL_69c2: Unknown result type (might be due to invalid IL or missing references)
		//IL_69cc: Expected O, but got Unknown
		//IL_6a63: Unknown result type (might be due to invalid IL or missing references)
		//IL_6ac9: Unknown result type (might be due to invalid IL or missing references)
		//IL_6ad3: Expected O, but got Unknown
		//IL_6b65: Unknown result type (might be due to invalid IL or missing references)
		//IL_6b6f: Expected O, but got Unknown
		//IL_6c5e: Unknown result type (might be due to invalid IL or missing references)
		//IL_6dbc: Unknown result type (might be due to invalid IL or missing references)
		//IL_742c: Unknown result type (might be due to invalid IL or missing references)
		//IL_7436: Expected O, but got Unknown
		//IL_74cf: Unknown result type (might be due to invalid IL or missing references)
		//IL_74d9: Expected O, but got Unknown
		//IL_7570: Unknown result type (might be due to invalid IL or missing references)
		//IL_757a: Expected O, but got Unknown
		//IL_75fe: Unknown result type (might be due to invalid IL or missing references)
		//IL_7608: Expected O, but got Unknown
		//IL_76af: Unknown result type (might be due to invalid IL or missing references)
		//IL_76b9: Expected O, but got Unknown
		//IL_7755: Unknown result type (might be due to invalid IL or missing references)
		//IL_775f: Expected O, but got Unknown
		//IL_77fb: Unknown result type (might be due to invalid IL or missing references)
		//IL_7805: Expected O, but got Unknown
		//IL_78aa: Unknown result type (might be due to invalid IL or missing references)
		//IL_78b4: Expected O, but got Unknown
		//IL_7966: Unknown result type (might be due to invalid IL or missing references)
		//IL_79cb: Unknown result type (might be due to invalid IL or missing references)
		//IL_79d5: Expected O, but got Unknown
		//IL_7a78: Unknown result type (might be due to invalid IL or missing references)
		//IL_7a82: Expected O, but got Unknown
		//IL_7b13: Unknown result type (might be due to invalid IL or missing references)
		//IL_7b1d: Expected O, but got Unknown
		//IL_7b99: Unknown result type (might be due to invalid IL or missing references)
		//IL_7ba3: Expected O, but got Unknown
		//IL_7c38: Unknown result type (might be due to invalid IL or missing references)
		//IL_7cd5: Unknown result type (might be due to invalid IL or missing references)
		//IL_7da7: Unknown result type (might be due to invalid IL or missing references)
		//IL_7f3c: Unknown result type (might be due to invalid IL or missing references)
		//IL_7f46: Expected O, but got Unknown
		//IL_7fb9: Unknown result type (might be due to invalid IL or missing references)
		//IL_7fc3: Expected O, but got Unknown
		//IL_8053: Unknown result type (might be due to invalid IL or missing references)
		//IL_805d: Expected O, but got Unknown
		//IL_80e1: Unknown result type (might be due to invalid IL or missing references)
		//IL_80eb: Expected O, but got Unknown
		//IL_8184: Unknown result type (might be due to invalid IL or missing references)
		//IL_818e: Expected O, but got Unknown
		//IL_8233: Unknown result type (might be due to invalid IL or missing references)
		//IL_823d: Expected O, but got Unknown
		//IL_82e8: Unknown result type (might be due to invalid IL or missing references)
		//IL_834e: Unknown result type (might be due to invalid IL or missing references)
		//IL_8358: Expected O, but got Unknown
		//IL_83d4: Unknown result type (might be due to invalid IL or missing references)
		//IL_83de: Expected O, but got Unknown
		//IL_8476: Unknown result type (might be due to invalid IL or missing references)
		//IL_85d4: Unknown result type (might be due to invalid IL or missing references)
		//IL_873b: Unknown result type (might be due to invalid IL or missing references)
		//IL_8745: Expected O, but got Unknown
		//IL_87d5: Unknown result type (might be due to invalid IL or missing references)
		//IL_87df: Expected O, but got Unknown
		//IL_8855: Unknown result type (might be due to invalid IL or missing references)
		//IL_885f: Expected O, but got Unknown
		//IL_88f9: Unknown result type (might be due to invalid IL or missing references)
		//IL_8903: Expected O, but got Unknown
		//IL_89b6: Unknown result type (might be due to invalid IL or missing references)
		//IL_8a1c: Unknown result type (might be due to invalid IL or missing references)
		//IL_8a26: Expected O, but got Unknown
		//IL_8aa2: Unknown result type (might be due to invalid IL or missing references)
		//IL_8aac: Expected O, but got Unknown
		//IL_8b3b: Unknown result type (might be due to invalid IL or missing references)
		//IL_8b45: Expected O, but got Unknown
		//IL_8bdd: Unknown result type (might be due to invalid IL or missing references)
		//IL_8d3b: Unknown result type (might be due to invalid IL or missing references)
		//IL_8e56: Unknown result type (might be due to invalid IL or missing references)
		//IL_8e60: Expected O, but got Unknown
		//IL_8ef7: Unknown result type (might be due to invalid IL or missing references)
		//IL_8f5d: Unknown result type (might be due to invalid IL or missing references)
		//IL_8f67: Expected O, but got Unknown
		//IL_8ff9: Unknown result type (might be due to invalid IL or missing references)
		//IL_9003: Expected O, but got Unknown
		//IL_90f2: Unknown result type (might be due to invalid IL or missing references)
		//IL_918f: Unknown result type (might be due to invalid IL or missing references)
		//IL_9261: Unknown result type (might be due to invalid IL or missing references)
		//IL_93be: Unknown result type (might be due to invalid IL or missing references)
		//IL_93c8: Expected O, but got Unknown
		//IL_9445: Unknown result type (might be due to invalid IL or missing references)
		//IL_944f: Expected O, but got Unknown
		//IL_946b: Unknown result type (might be due to invalid IL or missing references)
		//IL_9475: Expected O, but got Unknown
		//IL_9502: Unknown result type (might be due to invalid IL or missing references)
		//IL_950c: Expected O, but got Unknown
		//IL_9576: Unknown result type (might be due to invalid IL or missing references)
		//IL_9580: Expected O, but got Unknown
		//IL_9765: Unknown result type (might be due to invalid IL or missing references)
		//IL_97cb: Unknown result type (might be due to invalid IL or missing references)
		//IL_97d5: Expected O, but got Unknown
		//IL_9851: Unknown result type (might be due to invalid IL or missing references)
		//IL_985b: Expected O, but got Unknown
		//IL_98da: Unknown result type (might be due to invalid IL or missing references)
		//IL_98e4: Expected O, but got Unknown
		//IL_9979: Unknown result type (might be due to invalid IL or missing references)
		//IL_9c93: Unknown result type (might be due to invalid IL or missing references)
		//IL_9c9d: Expected O, but got Unknown
		//IL_9d09: Unknown result type (might be due to invalid IL or missing references)
		//IL_9d13: Expected O, but got Unknown
		//IL_9d8f: Unknown result type (might be due to invalid IL or missing references)
		//IL_9d99: Expected O, but got Unknown
		//IL_9e18: Unknown result type (might be due to invalid IL or missing references)
		//IL_9e22: Expected O, but got Unknown
		//IL_9ea1: Unknown result type (might be due to invalid IL or missing references)
		//IL_9eab: Expected O, but got Unknown
		//IL_9f2b: Unknown result type (might be due to invalid IL or missing references)
		//IL_9f35: Expected O, but got Unknown
		//IL_9fb4: Unknown result type (might be due to invalid IL or missing references)
		//IL_9fbe: Expected O, but got Unknown
		//IL_a02d: Unknown result type (might be due to invalid IL or missing references)
		//IL_a037: Expected O, but got Unknown
		//IL_a0a7: Unknown result type (might be due to invalid IL or missing references)
		//IL_a0b1: Expected O, but got Unknown
		//IL_a112: Unknown result type (might be due to invalid IL or missing references)
		//IL_a11c: Expected O, but got Unknown
		//IL_a143: Unknown result type (might be due to invalid IL or missing references)
		//IL_a1df: Unknown result type (might be due to invalid IL or missing references)
		//IL_a1e9: Expected O, but got Unknown
		//IL_a2c1: Unknown result type (might be due to invalid IL or missing references)
		//IL_a2cb: Expected O, but got Unknown
		//IL_a397: Unknown result type (might be due to invalid IL or missing references)
		//IL_a3a1: Expected O, but got Unknown
		//IL_a46d: Unknown result type (might be due to invalid IL or missing references)
		//IL_a477: Expected O, but got Unknown
		//IL_a55a: Unknown result type (might be due to invalid IL or missing references)
		//IL_a564: Expected O, but got Unknown
		//IL_a63c: Unknown result type (might be due to invalid IL or missing references)
		//IL_a646: Expected O, but got Unknown
		//IL_a729: Unknown result type (might be due to invalid IL or missing references)
		//IL_a733: Expected O, but got Unknown
		//IL_a80c: Unknown result type (might be due to invalid IL or missing references)
		//IL_a816: Expected O, but got Unknown
		//IL_a8fa: Unknown result type (might be due to invalid IL or missing references)
		//IL_a904: Expected O, but got Unknown
		//IL_a9e8: Unknown result type (might be due to invalid IL or missing references)
		//IL_a9f2: Expected O, but got Unknown
		//IL_aacb: Unknown result type (might be due to invalid IL or missing references)
		//IL_aad5: Expected O, but got Unknown
		//IL_aba2: Unknown result type (might be due to invalid IL or missing references)
		//IL_abac: Expected O, but got Unknown
		//IL_acf8: Unknown result type (might be due to invalid IL or missing references)
		//IL_ad02: Expected O, but got Unknown
		//IL_addb: Unknown result type (might be due to invalid IL or missing references)
		//IL_ade5: Expected O, but got Unknown
		//IL_aeb2: Unknown result type (might be due to invalid IL or missing references)
		//IL_aebc: Expected O, but got Unknown
		//IL_b035: Unknown result type (might be due to invalid IL or missing references)
		//IL_b03f: Expected O, but got Unknown
		//IL_b0f6: Unknown result type (might be due to invalid IL or missing references)
		//IL_b100: Expected O, but got Unknown
		//IL_b1cd: Unknown result type (might be due to invalid IL or missing references)
		//IL_b1d7: Expected O, but got Unknown
		//IL_b2a4: Unknown result type (might be due to invalid IL or missing references)
		//IL_b2ae: Expected O, but got Unknown
		//IL_b3f7: Unknown result type (might be due to invalid IL or missing references)
		//IL_b401: Expected O, but got Unknown
		//IL_b4e5: Unknown result type (might be due to invalid IL or missing references)
		//IL_b4ef: Expected O, but got Unknown
		//IL_b5df: Unknown result type (might be due to invalid IL or missing references)
		//IL_b5e9: Expected O, but got Unknown
		//IL_b6b6: Unknown result type (might be due to invalid IL or missing references)
		//IL_b6c0: Expected O, but got Unknown
		//IL_b7a4: Unknown result type (might be due to invalid IL or missing references)
		//IL_b7ae: Expected O, but got Unknown
		//IL_b87a: Unknown result type (might be due to invalid IL or missing references)
		//IL_b884: Expected O, but got Unknown
		//IL_b967: Unknown result type (might be due to invalid IL or missing references)
		//IL_b971: Expected O, but got Unknown
		//IL_ba55: Unknown result type (might be due to invalid IL or missing references)
		//IL_ba5f: Expected O, but got Unknown
		//IL_bb43: Unknown result type (might be due to invalid IL or missing references)
		//IL_bb4d: Expected O, but got Unknown
		//IL_bc1a: Unknown result type (might be due to invalid IL or missing references)
		//IL_bc24: Expected O, but got Unknown
		//IL_bd08: Unknown result type (might be due to invalid IL or missing references)
		//IL_bd12: Expected O, but got Unknown
		//IL_bdf6: Unknown result type (might be due to invalid IL or missing references)
		//IL_be00: Expected O, but got Unknown
		//IL_bee4: Unknown result type (might be due to invalid IL or missing references)
		//IL_beee: Expected O, but got Unknown
		//IL_bfa5: Unknown result type (might be due to invalid IL or missing references)
		//IL_bfaf: Expected O, but got Unknown
		//IL_c0a6: Unknown result type (might be due to invalid IL or missing references)
		//IL_c0b0: Expected O, but got Unknown
		ComponentResourceManager componentResourceManager = new ComponentResourceManager(typeof(FormWizard));
		tabPage5_confirm = new TabPage();
		panel_P5_3 = new Panel();
		panel_P5_2 = new Panel();
		panel15 = new Panel();
		labelP5Info = new Label();
		pictureBox5 = new PictureBox();
		labelP5Head = new Label();
		labelP5_comment = new Label();
		panel_P5_1 = new Panel();
		tabPage4_address = new TabPage();
		panel_P4_3 = new Panel();
		panel_P4_2 = new Panel();
		label7 = new Label();
		labelP4_Path = new Label();
		cmbP4FolderPath = new ComboBox();
		labelP4ConnectCheck = new Label();
		buttonP4HeadLine = new Button();
		linkLabelP4Connect = new LinkLabel();
		textP4Destination = new TextBox();
		pictureBox4 = new PictureBox();
		labelP4Head = new Label();
		label60 = new Label();
		labelP4_Destination = new Label();
		labelP4_Machine = new Label();
		labelP4_comment = new Label();
		panel_P4_1 = new Panel();
		tabPage3_shareFolder = new TabPage();
		panel_P3_3 = new Panel();
		panel_P3_2 = new Panel();
		labelP3_PasswordConfirm = new Label();
		textBoxP3PassConfirm = new TextBox();
		textBoxP3Pass = new TextBox();
		labelP3_Password = new Label();
		cmbP3UserName = new ComboBox();
		pictureBox3 = new PictureBox();
		labelP3Head = new Label();
		labelP3_UserName = new Label();
		labelP3_comment = new Label();
		panel_P3_1 = new Panel();
		tabPage2_setupSelect = new TabPage();
		panel_P2_3 = new Panel();
		panel_P2_2 = new Panel();
		labelP2_selectFolder = new Label();
		labelP2_selectNonSharedFolder = new Label();
		cmbP2Folder = new ComboBox();
		selectFolderRadioButton = new RadioButton();
		createNewFolderRadioButton = new RadioButton();
		selectNonSharedFolderRadioButton = new RadioButton();
		labelP2_Folder = new Label();
		buttonSelectNonSharedFolder = new Button();
		textBoxNonSharedFolderPath = new TextBox();
		labelP2_NonSharedFolderPath = new Label();
		textBoxSharedName = new TextBox();
		labelP2_SharedName = new Label();
		buttonSelectFolder = new Button();
		textBoxFolderPath = new TextBox();
		labelP2_FolderPath = new Label();
		textBoxFolderName = new TextBox();
		labelP2_FolderName = new Label();
		pictureBox2 = new PictureBox();
		labelP2Head = new Label();
		labelP2_comment = new Label();
		panel_P2_1 = new Panel();
		tabPage1_introduction = new TabPage();
		panel_P1_3 = new Panel();
		panel_P1_2 = new Panel();
		radioButtonTroubleShoot = new RadioButton();
		radioButtonCreateFolder = new RadioButton();
		attentionGroup = new GroupBox();
		attentionRichTextBox = new RichTextBox();
		pictureBox1 = new PictureBox();
		labelP1Head = new Label();
		labelP1_comment = new Label();
		panel_P1_1 = new Panel();
		tabControl1_Main = new TabControl();
		tabPage6_exec = new TabPage();
		panel_P6_3 = new Panel();
		panel_P6_2 = new Panel();
		progressBar1 = new ProgressBar();
		labelP6Execute = new Label();
		pictureBox6 = new PictureBox();
		labelP6Head = new Label();
		labelP6_comment = new Label();
		panel_P6_1 = new Panel();
		tabPage7_finish = new TabPage();
		panel_P7_3 = new Panel();
		panel_P7_2 = new Panel();
		linkLabelP7HelpSend = new LinkLabel();
		linkLabelP7HelpRegist = new LinkLabel();
		panel22 = new Panel();
		labelP7Report = new Label();
		labelP7finsh = new LinkLabel();
		pictureBox7 = new PictureBox();
		labelP7Head = new Label();
		labelP7_ReportTitle = new Label();
		labelP7_comment = new Label();
		panel_P7_1 = new Panel();
		tabTRP2_device = new TabPage();
		panel_TRP2_3 = new Panel();
		panel_TRP2_2 = new Panel();
		label_TRP2ConnectCheck = new Label();
		linkLabelTRP2 = new LinkLabel();
		pictureBox8 = new PictureBox();
		label_TRP2Head = new Label();
		label_TRP2_Machine = new Label();
		label_TRP2_comment = new Label();
		panel_TRP2_1 = new Panel();
		tabTRP3_user = new TabPage();
		panel_TRP3_3 = new Panel();
		panel_TRP3_2 = new Panel();
		buttonTRP3Resume = new Button();
		label_TRP3_comment = new Label();
		buttonTRP3Break = new Button();
		labelTRP3progressText = new Label();
		buttonTRP3ToBottom = new Button();
		buttonTRP3Next = new Button();
		buttonTRP3Previous = new Button();
		buttonTRP3ToTop = new Button();
		label_TRP3DisplayedPage = new Label();
		label_TRP3Page = new Label();
		comboBoxTRP3SelectWay = new ComboBox();
		buttonTRP3Search = new Button();
		textBoxTRP3Search = new TextBox();
		listViewAddressList = new ListView();
		labelTRP3MFP_Selected = new Label();
		label_TRP3_SelectedDevice = new Label();
		label17 = new Label();
		pictureBox9 = new PictureBox();
		label_TRP3Head = new Label();
		panel_TRP3_1 = new Panel();
		tabTRP4_analyze = new TabPage();
		panel_TRP4_3 = new Panel();
		panel_TRP4_2 = new Panel();
		progressBarTRP4 = new ProgressBar();
		label_TRP4_progress = new Label();
		pictureBox10 = new PictureBox();
		label_TRP4Head = new Label();
		label_TRP4_comment = new Label();
		panel_TRP4_1 = new Panel();
		tabTRP5_result = new TabPage();
		panel_TRP5_3 = new Panel();
		panel_TRP5_2 = new Panel();
		label_TRP5_comment = new Label();
		pictureBox13 = new PictureBox();
		label_TRP5Head = new Label();
		panel40 = new Panel();
		richTextBoxTRP5 = new RichTextBox();
		panel_TRP5_1 = new Panel();
		tabTRP6_setupSelect = new TabPage();
		panel_TRP6_3 = new Panel();
		panel_TRP6_2 = new Panel();
		label_TRP6_SelectFolder = new Label();
		label_TRP6_SelectNonSharedFolder = new Label();
		cmbTRP6Folder = new ComboBox();
		radioButtonTRP6selectNonSharedFolder = new RadioButton();
		radioButtonTRP6selectExistFolder = new RadioButton();
		radioButtonTRP6createNewFolder = new RadioButton();
		label_TRP6_Folder = new Label();
		buttonTRP6SelectFolder = new Button();
		textBoxTRP6FolderPath = new TextBox();
		label_TRP6_FolderPath = new Label();
		textBoxTRP6FolderName = new TextBox();
		label_TRP6_FolderName = new Label();
		label_TRP6_NonSharedFolderPath = new Label();
		buttonTRP6SelectNonSharedFolder = new Button();
		textBoxTRP6NonSharedFolderPath = new TextBox();
		pictureBox16 = new PictureBox();
		textBoxTRP6SharedName = new TextBox();
		label_TRP6_SharedName = new Label();
		label_TRP6Head = new Label();
		label_TRP6_comment = new Label();
		panel_TRP6_1 = new Panel();
		tabTRP7_shareFolder = new TabPage();
		panel_TRP7_3 = new Panel();
		panel_TRP7_2 = new Panel();
		cmbTRP7PcUser = new ComboBox();
		label_TRP7_UserName = new Label();
		label_TRP7_PasswordConfirm = new Label();
		textBoxTRP7PassConfirm = new TextBox();
		textBoxTRP7Pass = new TextBox();
		label_TRP7_Password = new Label();
		pictureBox12 = new PictureBox();
		label_TRP7Head = new Label();
		label_TRP7_comment = new Label();
		panel_TRP7_1 = new Panel();
		tabTRP8_address = new TabPage();
		panel_TRP8_3 = new Panel();
		panel_TRP8_2 = new Panel();
		label_TRP8_Path = new Label();
		cmbTRP8FolderPath = new ComboBox();
		buttonTRP8HeadLine = new Button();
		textTRP8Destination = new TextBox();
		pictureBox17 = new PictureBox();
		label_TRP8Head = new Label();
		label_TRP8_Destination = new Label();
		label_TRP8_comment = new Label();
		panel_TRP8_1 = new Panel();
		tabTRP9_confirm = new TabPage();
		panel_TRP9_3 = new Panel();
		panel_TRP9_2 = new Panel();
		label_TRP9_comment = new Label();
		pictureBox14 = new PictureBox();
		label_TRP9Head = new Label();
		panel45 = new Panel();
		richTextBoxTRP9 = new RichTextBox();
		panel_TRP9_1 = new Panel();
		tabTRP10_finish = new TabPage();
		panel_TRP10_3 = new Panel();
		panel_TRP10_2 = new Panel();
		linkLabelTRP10HelpSend = new LinkLabel();
		linkLabelTRP10HelpRegist = new LinkLabel();
		panelTRP10 = new Panel();
		label_TRP10Report = new Label();
		labelTRP10finish = new LinkLabel();
		richTextBoxTRP10 = new RichTextBox();
		pictureBox11 = new PictureBox();
		label_TRP10Head = new Label();
		label_TRP10_ReportTitle = new Label();
		label_TRP10_comment = new Label();
		panel_TRP10_1 = new Panel();
		menuStrip1 = new MenuStrip();
		ToolStripMenuItemDetail_D = new ToolStripMenuItem();
		ToolStripMenuItemChange = new ToolStripMenuItem();
		ToolStripMenuItemSecurity_S = new ToolStripMenuItem();
		ToolStripMenuItemEnvironments_E = new ToolStripMenuItem();
		ToolStripMenuItemMachine = new ToolStripMenuItem();
		ToolStripMenuItemComputer = new ToolStripMenuItem();
		ToolStripMenuItemVersion_H = new ToolStripMenuItem();
		label165 = new Label();
		label164 = new Label();
		label163 = new Label();
		label162 = new Label();
		label161 = new Label();
		label149 = new Label();
		label148 = new Label();
		label147 = new Label();
		label145 = new Label();
		pictureBox15 = new PictureBox();
		btnP1TRNext = new NextButtonTroubleShoot();
		btnP1Cancel = new CancelButton();
		btnP1Next = new NextButton();
		btnP2Back = new BackButton();
		btnP2Cancel = new CancelButton();
		btnP2Next = new NextButton();
		btnP3Cancel = new CancelButton();
		btnP3Back = new BackButton();
		btnP3Next = new NextButton();
		btnP4Cancel = new CancelButton();
		btnP4Back = new BackButton();
		btnP4Next = new NextButton();
		machineSelectControl = new MachineSelectControl("");
		btnP5Cancel = new CancelButton();
		btnP5Back = new BackButton();
		btnP5Execute = new NextButton();
		btnP6Excecute = new NextButton();
		btnP7Top = new NextButton();
		btnP7End = new EndButton();
		btnTRP2Back = new BackButtonTroubleShoot();
		btnTRP2Next = new NextButtonTroubleShoot();
		machineSelectControlTRP2 = new MachineSelectControl("");
		btnTRP3Back = new BackButtonTroubleShoot();
		btnTRP3Next = new NextButtonTroubleShoot();
		btnTRP5Back = new BackButtonTroubleShoot();
		btnTRP5Next = new NextButtonTroubleShoot();
		btnTRP6Back = new BackButtonTroubleShoot();
		btnTRP6Next = new NextButtonTroubleShoot();
		btnTRP7Back = new BackButtonTroubleShoot();
		btnTRP7Next = new NextButtonTroubleShoot();
		btnTRP8Back = new BackButtonTroubleShoot();
		btnTRP8Next = new NextButtonTroubleShoot();
		btnTRP9Back = new BackButtonTroubleShoot();
		btnTRP9Execute = new NextButtonTroubleShoot();
		btnTRP10Top = new NextButtonTroubleShoot();
		btnTRP10End = new EndButton();
		((Control)tabPage5_confirm).SuspendLayout();
		((Control)panel_P5_3).SuspendLayout();
		((Control)panel_P5_2).SuspendLayout();
		((Control)panel15).SuspendLayout();
		((ISupportInitialize)pictureBox5).BeginInit();
		((Control)tabPage4_address).SuspendLayout();
		((Control)panel_P4_3).SuspendLayout();
		((Control)panel_P4_2).SuspendLayout();
		((ISupportInitialize)pictureBox4).BeginInit();
		((Control)tabPage3_shareFolder).SuspendLayout();
		((Control)panel_P3_3).SuspendLayout();
		((Control)panel_P3_2).SuspendLayout();
		((ISupportInitialize)pictureBox3).BeginInit();
		((Control)tabPage2_setupSelect).SuspendLayout();
		((Control)panel_P2_3).SuspendLayout();
		((Control)panel_P2_2).SuspendLayout();
		((ISupportInitialize)pictureBox2).BeginInit();
		((Control)tabPage1_introduction).SuspendLayout();
		((Control)panel_P1_3).SuspendLayout();
		((Control)panel_P1_2).SuspendLayout();
		((Control)attentionGroup).SuspendLayout();
		((ISupportInitialize)pictureBox1).BeginInit();
		((Control)tabControl1_Main).SuspendLayout();
		((Control)tabPage6_exec).SuspendLayout();
		((Control)panel_P6_2).SuspendLayout();
		((ISupportInitialize)pictureBox6).BeginInit();
		((Control)tabPage7_finish).SuspendLayout();
		((Control)panel_P7_3).SuspendLayout();
		((Control)panel_P7_2).SuspendLayout();
		((Control)panel22).SuspendLayout();
		((ISupportInitialize)pictureBox7).BeginInit();
		((Control)tabTRP2_device).SuspendLayout();
		((Control)panel_TRP2_3).SuspendLayout();
		((Control)panel_TRP2_2).SuspendLayout();
		((ISupportInitialize)pictureBox8).BeginInit();
		((Control)tabTRP3_user).SuspendLayout();
		((Control)panel_TRP3_3).SuspendLayout();
		((Control)panel_TRP3_2).SuspendLayout();
		((ISupportInitialize)pictureBox9).BeginInit();
		((Control)tabTRP4_analyze).SuspendLayout();
		((Control)panel_TRP4_2).SuspendLayout();
		((ISupportInitialize)pictureBox10).BeginInit();
		((Control)tabTRP5_result).SuspendLayout();
		((Control)panel_TRP5_3).SuspendLayout();
		((Control)panel_TRP5_2).SuspendLayout();
		((ISupportInitialize)pictureBox13).BeginInit();
		((Control)panel40).SuspendLayout();
		((Control)tabTRP6_setupSelect).SuspendLayout();
		((Control)panel_TRP6_3).SuspendLayout();
		((Control)panel_TRP6_2).SuspendLayout();
		((ISupportInitialize)pictureBox16).BeginInit();
		((Control)tabTRP7_shareFolder).SuspendLayout();
		((Control)panel_TRP7_3).SuspendLayout();
		((Control)panel_TRP7_2).SuspendLayout();
		((ISupportInitialize)pictureBox12).BeginInit();
		((Control)tabTRP8_address).SuspendLayout();
		((Control)panel_TRP8_3).SuspendLayout();
		((Control)panel_TRP8_2).SuspendLayout();
		((ISupportInitialize)pictureBox17).BeginInit();
		((Control)tabTRP9_confirm).SuspendLayout();
		((Control)panel_TRP9_3).SuspendLayout();
		((Control)panel_TRP9_2).SuspendLayout();
		((ISupportInitialize)pictureBox14).BeginInit();
		((Control)panel45).SuspendLayout();
		((Control)tabTRP10_finish).SuspendLayout();
		((Control)panel_TRP10_3).SuspendLayout();
		((Control)panel_TRP10_2).SuspendLayout();
		((Control)panelTRP10).SuspendLayout();
		((ISupportInitialize)pictureBox11).BeginInit();
		((Control)menuStrip1).SuspendLayout();
		((ISupportInitialize)pictureBox15).BeginInit();
		((Control)this).SuspendLayout();
		((Control)tabPage5_confirm).Controls.Add((Control)(object)panel_P5_3);
		((Control)tabPage5_confirm).Controls.Add((Control)(object)panel_P5_2);
		((Control)tabPage5_confirm).Controls.Add((Control)(object)panel_P5_1);
		tabPage5_confirm.Location = new Point(4, 22);
		((Control)tabPage5_confirm).Margin = new Padding(0);
		((Control)tabPage5_confirm).Name = "tabPage5_confirm";
		((Control)tabPage5_confirm).Size = new Size(960, 497);
		tabPage5_confirm.TabIndex = 4;
		((Control)tabPage5_confirm).Text = "tabP5_confirm";
		tabPage5_confirm.UseVisualStyleBackColor = true;
		((Control)panel_P5_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_P5_3.BorderStyle = (BorderStyle)1;
		((Control)panel_P5_3).Controls.Add((Control)(object)btnP5Cancel);
		((Control)panel_P5_3).Controls.Add((Control)(object)btnP5Back);
		((Control)panel_P5_3).Controls.Add((Control)(object)btnP5Execute);
		((Control)panel_P5_3).Dock = (DockStyle)2;
		((Control)panel_P5_3).Location = new Point(0, 446);
		((Control)panel_P5_3).Margin = new Padding(0);
		((Control)panel_P5_3).Name = "panel_P5_3";
		((Control)panel_P5_3).Size = new Size(960, 51);
		((Control)panel_P5_3).TabIndex = 18;
		((Control)panel_P5_2).BackColor = Color.White;
		panel_P5_2.BorderStyle = (BorderStyle)1;
		((Control)panel_P5_2).Controls.Add((Control)(object)panel15);
		((Control)panel_P5_2).Controls.Add((Control)(object)pictureBox5);
		((Control)panel_P5_2).Controls.Add((Control)(object)labelP5Head);
		((Control)panel_P5_2).Controls.Add((Control)(object)labelP5_comment);
		((Control)panel_P5_2).Location = new Point(234, 3);
		((Control)panel_P5_2).Name = "panel_P5_2";
		((Control)panel_P5_2).Size = new Size(725, 470);
		((Control)panel_P5_2).TabIndex = 17;
		panel15.BorderStyle = (BorderStyle)2;
		((Control)panel15).Controls.Add((Control)(object)labelP5Info);
		((Control)panel15).Font = new Font("MS UI Gothic", 9f);
		((Control)panel15).Location = new Point(44, 117);
		((Control)panel15).Name = "panel15";
		((Control)panel15).Size = new Size(603, 316);
		((Control)panel15).TabIndex = 3;
		((Control)labelP5Info).AutoSize = true;
		labelP5Info.ImeMode = (ImeMode)0;
		((Control)labelP5Info).Location = new Point(5, 13);
		((Control)labelP5Info).Name = "labelP5Info";
		((Control)labelP5Info).Size = new Size(61, 12);
		((Control)labelP5Info).TabIndex = 1;
		((Control)labelP5Info).Text = "labelP5Info";
		pictureBox5.Image = (Image)(object)Resources.Line;
		pictureBox5.ImeMode = (ImeMode)0;
		((Control)pictureBox5).Location = new Point(39, 48);
		((Control)pictureBox5).Margin = new Padding(1);
		((Control)pictureBox5).Name = "pictureBox5";
		((Control)pictureBox5).Size = new Size(689, 10);
		pictureBox5.TabIndex = 1;
		pictureBox5.TabStop = false;
		((Control)labelP5Head).AutoSize = true;
		((Control)labelP5Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		labelP5Head.ImeMode = (ImeMode)0;
		((Control)labelP5Head).Location = new Point(40, 21);
		((Control)labelP5Head).Name = "labelP5Head";
		((Control)labelP5Head).Size = new Size(106, 16);
		((Control)labelP5Head).TabIndex = 0;
		((Control)labelP5Head).Text = "Confirmation";
		((Control)labelP5_comment).AutoSize = true;
		((Control)labelP5_comment).Font = new Font("MS UI Gothic", 9f);
		labelP5_comment.ImeMode = (ImeMode)0;
		((Control)labelP5_comment).Location = new Point(45, 77);
		((Control)labelP5_comment).Name = "labelP5_comment";
		((Control)labelP5_comment).Size = new Size(119, 12);
		((Control)labelP5_comment).TabIndex = 2;
		((Control)labelP5_comment).Text = "Confirmation message";
		((Control)panel_P5_1).BackColor = SystemColors.Control;
		panel_P5_1.BorderStyle = (BorderStyle)1;
		((Control)panel_P5_1).Location = new Point(0, 3);
		((Control)panel_P5_1).Margin = new Padding(0);
		((Control)panel_P5_1).Name = "panel_P5_1";
		((Control)panel_P5_1).Size = new Size(231, 470);
		((Control)panel_P5_1).TabIndex = 16;
		((Control)tabPage4_address).Controls.Add((Control)(object)panel_P4_3);
		((Control)tabPage4_address).Controls.Add((Control)(object)panel_P4_2);
		((Control)tabPage4_address).Controls.Add((Control)(object)panel_P4_1);
		tabPage4_address.Location = new Point(4, 22);
		((Control)tabPage4_address).Margin = new Padding(0);
		((Control)tabPage4_address).Name = "tabPage4_address";
		((Control)tabPage4_address).Size = new Size(960, 497);
		tabPage4_address.TabIndex = 3;
		((Control)tabPage4_address).Text = "tabP4_address";
		tabPage4_address.UseVisualStyleBackColor = true;
		((Control)panel_P4_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_P4_3.BorderStyle = (BorderStyle)1;
		((Control)panel_P4_3).Controls.Add((Control)(object)btnP4Cancel);
		((Control)panel_P4_3).Controls.Add((Control)(object)btnP4Back);
		((Control)panel_P4_3).Controls.Add((Control)(object)btnP4Next);
		((Control)panel_P4_3).Dock = (DockStyle)2;
		((Control)panel_P4_3).Location = new Point(0, 446);
		((Control)panel_P4_3).Margin = new Padding(0);
		((Control)panel_P4_3).Name = "panel_P4_3";
		((Control)panel_P4_3).Size = new Size(960, 51);
		((Control)panel_P4_3).TabIndex = 23;
		((Control)panel_P4_2).BackColor = Color.White;
		((Control)panel_P4_2).Controls.Add((Control)(object)machineSelectControl);
		((Control)panel_P4_2).Controls.Add((Control)(object)label7);
		((Control)panel_P4_2).Controls.Add((Control)(object)labelP4_Path);
		((Control)panel_P4_2).Controls.Add((Control)(object)cmbP4FolderPath);
		((Control)panel_P4_2).Controls.Add((Control)(object)labelP4ConnectCheck);
		((Control)panel_P4_2).Controls.Add((Control)(object)buttonP4HeadLine);
		((Control)panel_P4_2).Controls.Add((Control)(object)linkLabelP4Connect);
		((Control)panel_P4_2).Controls.Add((Control)(object)textP4Destination);
		((Control)panel_P4_2).Controls.Add((Control)(object)pictureBox4);
		((Control)panel_P4_2).Controls.Add((Control)(object)labelP4Head);
		((Control)panel_P4_2).Controls.Add((Control)(object)label60);
		((Control)panel_P4_2).Controls.Add((Control)(object)labelP4_Destination);
		((Control)panel_P4_2).Controls.Add((Control)(object)labelP4_Machine);
		((Control)panel_P4_2).Controls.Add((Control)(object)labelP4_comment);
		((Control)panel_P4_2).Location = new Point(234, 3);
		((Control)panel_P4_2).Name = "panel_P4_2";
		((Control)panel_P4_2).Size = new Size(725, 470);
		((Control)panel_P4_2).TabIndex = 22;
		((Control)label7).AutoSize = true;
		((Control)label7).Font = new Font("MS UI Gothic", 10f);
		((Control)label7).ForeColor = Color.Blue;
		label7.ImeMode = (ImeMode)0;
		((Control)label7).Location = new Point(158, 336);
		((Control)label7).Name = "label7";
		((Control)label7).Size = new Size(85, 14);
		((Control)label7).TabIndex = 40;
		((Control)label7).Text = "共有フォルダー";
		((Control)label7).Visible = false;
		((Control)labelP4_Path).AutoSize = true;
		((Control)labelP4_Path).Font = new Font("MS UI Gothic", 9f);
		((Control)labelP4_Path).ForeColor = Color.Blue;
		labelP4_Path.ImeMode = (ImeMode)0;
		((Control)labelP4_Path).Location = new Point(45, 165);
		((Control)labelP4_Path).Name = "labelP4_Path";
		((Control)labelP4_Path).Size = new Size(28, 12);
		((Control)labelP4_Path).TabIndex = 38;
		((Control)labelP4_Path).Text = "Path";
		cmbP4FolderPath.DropDownStyle = (ComboBoxStyle)2;
		((Control)cmbP4FolderPath).Font = new Font("MS UI Gothic", 9f);
		((ListControl)cmbP4FolderPath).FormattingEnabled = true;
		((Control)cmbP4FolderPath).Location = new Point(218, 163);
		((Control)cmbP4FolderPath).Name = "cmbP4FolderPath";
		((Control)cmbP4FolderPath).Size = new Size(314, 20);
		((Control)cmbP4FolderPath).TabIndex = 17;
		cmbP4FolderPath.SelectedIndexChanged += cmbP4FolderPass_SelectedIndexChanged;
		((Control)labelP4ConnectCheck).AutoSize = true;
		((Control)labelP4ConnectCheck).Font = new Font("MS UI Gothic", 9f);
		((Control)labelP4ConnectCheck).ForeColor = Color.Black;
		labelP4ConnectCheck.ImeMode = (ImeMode)0;
		((Control)labelP4ConnectCheck).Location = new Point(5, 423);
		((Control)labelP4ConnectCheck).Name = "labelP4ConnectCheck";
		((Control)labelP4ConnectCheck).Size = new Size(80, 12);
		((Control)labelP4ConnectCheck).TabIndex = 34;
		((Control)labelP4ConnectCheck).Text = "Connecting . . .";
		((Control)labelP4ConnectCheck).Visible = false;
		((Control)buttonP4HeadLine).AutoSize = true;
		((Control)buttonP4HeadLine).Font = new Font("MS UI Gothic", 9f);
		((ButtonBase)buttonP4HeadLine).ImeMode = (ImeMode)0;
		((Control)buttonP4HeadLine).Location = new Point(535, 128);
		((Control)buttonP4HeadLine).Name = "buttonP4HeadLine";
		((Control)buttonP4HeadLine).Size = new Size(103, 23);
		((Control)buttonP4HeadLine).TabIndex = 16;
		((Control)buttonP4HeadLine).Text = "Index";
		((ButtonBase)buttonP4HeadLine).UseVisualStyleBackColor = true;
		((Control)buttonP4HeadLine).Click += buttonHeadLine_Click;
		((Control)linkLabelP4Connect).AutoSize = true;
		((Label)linkLabelP4Connect).ImeMode = (ImeMode)0;
		linkLabelP4Connect.LinkColor = Color.Red;
		((Control)linkLabelP4Connect).Location = new Point(3, 423);
		((Control)linkLabelP4Connect).Name = "linkLabelP4Connect";
		((Control)linkLabelP4Connect).Size = new Size(156, 12);
		((Control)linkLabelP4Connect).TabIndex = 18;
		linkLabelP4Connect.TabStop = true;
		((Control)linkLabelP4Connect).Text = "Cannot connect link message";
		linkLabelP4Connect.LinkClicked += new LinkLabelLinkClickedEventHandler(linkLabelConnect_LinkClicked);
		((Control)textP4Destination).Font = new Font("MS UI Gothic", 9f);
		((Control)textP4Destination).Location = new Point(218, 130);
		((Control)textP4Destination).Name = "textP4Destination";
		((Control)textP4Destination).Size = new Size(314, 19);
		((Control)textP4Destination).TabIndex = 15;
		((Control)textP4Destination).Enter += textP4AddressName_Enter;
		((Control)textP4Destination).Leave += textP4AddressName_Leave;
		pictureBox4.Image = (Image)(object)Resources.Line;
		pictureBox4.ImeMode = (ImeMode)0;
		((Control)pictureBox4).Location = new Point(39, 48);
		((Control)pictureBox4).Margin = new Padding(1);
		((Control)pictureBox4).Name = "pictureBox4";
		((Control)pictureBox4).Size = new Size(689, 10);
		pictureBox4.TabIndex = 1;
		pictureBox4.TabStop = false;
		((Control)labelP4Head).AutoSize = true;
		((Control)labelP4Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		labelP4Head.ImeMode = (ImeMode)0;
		((Control)labelP4Head).Location = new Point(40, 21);
		((Control)labelP4Head).Name = "labelP4Head";
		((Control)labelP4Head).Size = new Size(94, 16);
		((Control)labelP4Head).TabIndex = 0;
		((Control)labelP4Head).Text = "Destination";
		((Control)label60).AutoSize = true;
		((Control)label60).Font = new Font("MS UI Gothic", 10f);
		((Control)label60).ForeColor = Color.Blue;
		label60.ImeMode = (ImeMode)0;
		((Control)label60).Location = new Point(158, 387);
		((Control)label60).Name = "label60";
		((Control)label60).Size = new Size(120, 14);
		((Control)label60).TabIndex = 2;
		((Control)label60).Text = "パソコンのユーザー名";
		((Control)label60).Visible = false;
		((Control)labelP4_Destination).AutoSize = true;
		((Control)labelP4_Destination).Font = new Font("MS UI Gothic", 9f);
		((Control)labelP4_Destination).ForeColor = Color.Blue;
		labelP4_Destination.ImeMode = (ImeMode)0;
		((Control)labelP4_Destination).Location = new Point(45, 130);
		((Control)labelP4_Destination).Name = "labelP4_Destination";
		((Control)labelP4_Destination).Size = new Size(63, 12);
		((Control)labelP4_Destination).TabIndex = 2;
		((Control)labelP4_Destination).Text = "Destination";
		((Control)labelP4_Machine).AutoSize = true;
		((Control)labelP4_Machine).Font = new Font("MS UI Gothic", 9f);
		((Control)labelP4_Machine).ForeColor = Color.Blue;
		labelP4_Machine.ImeMode = (ImeMode)0;
		((Control)labelP4_Machine).Location = new Point(45, 200);
		((Control)labelP4_Machine).Name = "labelP4_Machine";
		((Control)labelP4_Machine).Size = new Size(47, 12);
		((Control)labelP4_Machine).TabIndex = 2;
		((Control)labelP4_Machine).Text = "Machine";
		((Control)labelP4_comment).AutoSize = true;
		((Control)labelP4_comment).Font = new Font("MS UI Gothic", 9f);
		labelP4_comment.ImeMode = (ImeMode)0;
		((Control)labelP4_comment).Location = new Point(45, 75);
		((Control)labelP4_comment).Name = "labelP4_comment";
		((Control)labelP4_comment).Size = new Size(151, 12);
		((Control)labelP4_comment).TabIndex = 2;
		((Control)labelP4_comment).Text = "Destination setting message";
		((Control)panel_P4_1).BackColor = SystemColors.Control;
		panel_P4_1.BorderStyle = (BorderStyle)1;
		((Control)panel_P4_1).Location = new Point(0, 3);
		((Control)panel_P4_1).Margin = new Padding(0);
		((Control)panel_P4_1).Name = "panel_P4_1";
		((Control)panel_P4_1).Size = new Size(231, 470);
		((Control)panel_P4_1).TabIndex = 20;
		((Control)tabPage3_shareFolder).Controls.Add((Control)(object)panel_P3_3);
		((Control)tabPage3_shareFolder).Controls.Add((Control)(object)panel_P3_2);
		((Control)tabPage3_shareFolder).Controls.Add((Control)(object)panel_P3_1);
		tabPage3_shareFolder.Location = new Point(4, 22);
		((Control)tabPage3_shareFolder).Margin = new Padding(0);
		((Control)tabPage3_shareFolder).Name = "tabPage3_shareFolder";
		((Control)tabPage3_shareFolder).Size = new Size(960, 497);
		tabPage3_shareFolder.TabIndex = 2;
		((Control)tabPage3_shareFolder).Text = "tabP3_shareFolder";
		tabPage3_shareFolder.UseVisualStyleBackColor = true;
		((Control)panel_P3_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_P3_3.BorderStyle = (BorderStyle)1;
		((Control)panel_P3_3).Controls.Add((Control)(object)btnP3Cancel);
		((Control)panel_P3_3).Controls.Add((Control)(object)btnP3Back);
		((Control)panel_P3_3).Controls.Add((Control)(object)btnP3Next);
		((Control)panel_P3_3).Dock = (DockStyle)2;
		((Control)panel_P3_3).Location = new Point(0, 446);
		((Control)panel_P3_3).Margin = new Padding(0);
		((Control)panel_P3_3).Name = "panel_P3_3";
		((Control)panel_P3_3).Size = new Size(960, 51);
		((Control)panel_P3_3).TabIndex = 18;
		((Control)panel_P3_2).BackColor = Color.White;
		panel_P3_2.BorderStyle = (BorderStyle)1;
		((Control)panel_P3_2).Controls.Add((Control)(object)labelP3_PasswordConfirm);
		((Control)panel_P3_2).Controls.Add((Control)(object)textBoxP3PassConfirm);
		((Control)panel_P3_2).Controls.Add((Control)(object)textBoxP3Pass);
		((Control)panel_P3_2).Controls.Add((Control)(object)labelP3_Password);
		((Control)panel_P3_2).Controls.Add((Control)(object)cmbP3UserName);
		((Control)panel_P3_2).Controls.Add((Control)(object)pictureBox3);
		((Control)panel_P3_2).Controls.Add((Control)(object)labelP3Head);
		((Control)panel_P3_2).Controls.Add((Control)(object)labelP3_UserName);
		((Control)panel_P3_2).Controls.Add((Control)(object)labelP3_comment);
		((Control)panel_P3_2).Location = new Point(234, 3);
		((Control)panel_P3_2).Name = "panel_P3_2";
		((Control)panel_P3_2).Size = new Size(725, 470);
		((Control)panel_P3_2).TabIndex = 19;
		((Control)labelP3_PasswordConfirm).AutoSize = true;
		((Control)labelP3_PasswordConfirm).Font = new Font("MS UI Gothic", 9f);
		((Control)labelP3_PasswordConfirm).ForeColor = Color.Blue;
		labelP3_PasswordConfirm.ImeMode = (ImeMode)0;
		((Control)labelP3_PasswordConfirm).Location = new Point(45, 190);
		((Control)labelP3_PasswordConfirm).Name = "labelP3_PasswordConfirm";
		((Control)labelP3_PasswordConfirm).Size = new Size(102, 12);
		((Control)labelP3_PasswordConfirm).TabIndex = 22;
		((Control)labelP3_PasswordConfirm).Text = "Password(Confirm)";
		((Control)textBoxP3PassConfirm).Font = new Font("MS UI Gothic", 9f);
		((Control)textBoxP3PassConfirm).Location = new Point(255, 188);
		((Control)textBoxP3PassConfirm).Name = "textBoxP3PassConfirm";
		textBoxP3PassConfirm.PasswordChar = '*';
		((Control)textBoxP3PassConfirm).Size = new Size(388, 19);
		((Control)textBoxP3PassConfirm).TabIndex = 11;
		((Control)textBoxP3PassConfirm).Enter += textBox4PassConfirm_Enter;
		((Control)textBoxP3PassConfirm).Leave += textBox4PassConfirm_Leave;
		((Control)textBoxP3Pass).Font = new Font("MS UI Gothic", 9f);
		((Control)textBoxP3Pass).Location = new Point(255, 157);
		((Control)textBoxP3Pass).Name = "textBoxP3Pass";
		textBoxP3Pass.PasswordChar = '*';
		((Control)textBoxP3Pass).Size = new Size(388, 19);
		((Control)textBoxP3Pass).TabIndex = 10;
		((Control)textBoxP3Pass).Enter += textBoxP4Pass_Enter;
		((Control)textBoxP3Pass).Leave += textBoxP4Pass_Leave;
		((Control)labelP3_Password).AutoSize = true;
		((Control)labelP3_Password).Font = new Font("MS UI Gothic", 9f);
		((Control)labelP3_Password).ForeColor = Color.Blue;
		labelP3_Password.ImeMode = (ImeMode)0;
		((Control)labelP3_Password).Location = new Point(45, 159);
		((Control)labelP3_Password).Name = "labelP3_Password";
		((Control)labelP3_Password).Size = new Size(54, 12);
		((Control)labelP3_Password).TabIndex = 20;
		((Control)labelP3_Password).Text = "Password";
		cmbP3UserName.DropDownStyle = (ComboBoxStyle)2;
		((Control)cmbP3UserName).Font = new Font("MS UI Gothic", 9f);
		((ListControl)cmbP3UserName).FormattingEnabled = true;
		((Control)cmbP3UserName).Location = new Point(255, 125);
		((Control)cmbP3UserName).Name = "cmbP3UserName";
		((Control)cmbP3UserName).Size = new Size(388, 20);
		((Control)cmbP3UserName).TabIndex = 9;
		pictureBox3.Image = (Image)(object)Resources.Line;
		pictureBox3.ImeMode = (ImeMode)0;
		((Control)pictureBox3).Location = new Point(39, 48);
		((Control)pictureBox3).Margin = new Padding(1);
		((Control)pictureBox3).Name = "pictureBox3";
		((Control)pictureBox3).Size = new Size(689, 10);
		pictureBox3.TabIndex = 1;
		pictureBox3.TabStop = false;
		((Control)labelP3Head).AutoSize = true;
		((Control)labelP3Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		labelP3Head.ImeMode = (ImeMode)0;
		((Control)labelP3Head).Location = new Point(40, 21);
		((Control)labelP3Head).Name = "labelP3Head";
		((Control)labelP3Head).Size = new Size(80, 16);
		((Control)labelP3Head).TabIndex = 0;
		((Control)labelP3Head).Text = "Password";
		((Control)labelP3_UserName).AutoSize = true;
		((Control)labelP3_UserName).Font = new Font("MS UI Gothic", 9f);
		((Control)labelP3_UserName).ForeColor = Color.Blue;
		labelP3_UserName.ImeMode = (ImeMode)0;
		((Control)labelP3_UserName).Location = new Point(45, 128);
		((Control)labelP3_UserName).Name = "labelP3_UserName";
		((Control)labelP3_UserName).Size = new Size(62, 12);
		((Control)labelP3_UserName).TabIndex = 2;
		((Control)labelP3_UserName).Text = "User Name";
		((Control)labelP3_comment).AutoSize = true;
		((Control)labelP3_comment).Font = new Font("MS UI Gothic", 9f);
		labelP3_comment.ImeMode = (ImeMode)0;
		((Control)labelP3_comment).Location = new Point(45, 75);
		((Control)labelP3_comment).Name = "labelP3_comment";
		((Control)labelP3_comment).Size = new Size(142, 12);
		((Control)labelP3_comment).TabIndex = 2;
		((Control)labelP3_comment).Text = "Password setting message";
		((Control)panel_P3_1).BackColor = SystemColors.Control;
		panel_P3_1.BorderStyle = (BorderStyle)1;
		((Control)panel_P3_1).Location = new Point(0, 3);
		((Control)panel_P3_1).Margin = new Padding(0);
		((Control)panel_P3_1).Name = "panel_P3_1";
		((Control)panel_P3_1).Size = new Size(231, 470);
		((Control)panel_P3_1).TabIndex = 15;
		((Control)tabPage2_setupSelect).Controls.Add((Control)(object)panel_P2_3);
		((Control)tabPage2_setupSelect).Controls.Add((Control)(object)panel_P2_2);
		((Control)tabPage2_setupSelect).Controls.Add((Control)(object)panel_P2_1);
		tabPage2_setupSelect.Location = new Point(4, 22);
		((Control)tabPage2_setupSelect).Margin = new Padding(0);
		((Control)tabPage2_setupSelect).Name = "tabPage2_setupSelect";
		((Control)tabPage2_setupSelect).Size = new Size(960, 497);
		tabPage2_setupSelect.TabIndex = 1;
		((Control)tabPage2_setupSelect).Text = "tabP2_setupSelect";
		tabPage2_setupSelect.UseVisualStyleBackColor = true;
		((Control)panel_P2_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_P2_3.BorderStyle = (BorderStyle)1;
		((Control)panel_P2_3).Controls.Add((Control)(object)btnP2Back);
		((Control)panel_P2_3).Controls.Add((Control)(object)btnP2Cancel);
		((Control)panel_P2_3).Controls.Add((Control)(object)btnP2Next);
		((Control)panel_P2_3).Dock = (DockStyle)2;
		((Control)panel_P2_3).Location = new Point(0, 446);
		((Control)panel_P2_3).Margin = new Padding(0);
		((Control)panel_P2_3).Name = "panel_P2_3";
		((Control)panel_P2_3).Size = new Size(960, 51);
		((Control)panel_P2_3).TabIndex = 17;
		((Control)panel_P2_2).BackColor = Color.White;
		panel_P2_2.BorderStyle = (BorderStyle)1;
		((Control)panel_P2_2).Controls.Add((Control)(object)labelP2_selectFolder);
		((Control)panel_P2_2).Controls.Add((Control)(object)labelP2_selectNonSharedFolder);
		((Control)panel_P2_2).Controls.Add((Control)(object)cmbP2Folder);
		((Control)panel_P2_2).Controls.Add((Control)(object)selectFolderRadioButton);
		((Control)panel_P2_2).Controls.Add((Control)(object)createNewFolderRadioButton);
		((Control)panel_P2_2).Controls.Add((Control)(object)selectNonSharedFolderRadioButton);
		((Control)panel_P2_2).Controls.Add((Control)(object)labelP2_Folder);
		((Control)panel_P2_2).Controls.Add((Control)(object)buttonSelectNonSharedFolder);
		((Control)panel_P2_2).Controls.Add((Control)(object)textBoxNonSharedFolderPath);
		((Control)panel_P2_2).Controls.Add((Control)(object)labelP2_NonSharedFolderPath);
		((Control)panel_P2_2).Controls.Add((Control)(object)textBoxSharedName);
		((Control)panel_P2_2).Controls.Add((Control)(object)labelP2_SharedName);
		((Control)panel_P2_2).Controls.Add((Control)(object)buttonSelectFolder);
		((Control)panel_P2_2).Controls.Add((Control)(object)textBoxFolderPath);
		((Control)panel_P2_2).Controls.Add((Control)(object)labelP2_FolderPath);
		((Control)panel_P2_2).Controls.Add((Control)(object)textBoxFolderName);
		((Control)panel_P2_2).Controls.Add((Control)(object)labelP2_FolderName);
		((Control)panel_P2_2).Controls.Add((Control)(object)pictureBox2);
		((Control)panel_P2_2).Controls.Add((Control)(object)labelP2Head);
		((Control)panel_P2_2).Controls.Add((Control)(object)labelP2_comment);
		((Control)panel_P2_2).Location = new Point(234, 3);
		((Control)panel_P2_2).Name = "panel_P2_2";
		((Control)panel_P2_2).Size = new Size(725, 470);
		((Control)panel_P2_2).TabIndex = 16;
		((Control)labelP2_selectFolder).AutoSize = true;
		((Control)labelP2_selectFolder).Enabled = false;
		labelP2_selectFolder.ImeMode = (ImeMode)0;
		((Control)labelP2_selectFolder).Location = new Point(56, 367);
		((Control)labelP2_selectFolder).Name = "labelP2_selectFolder";
		((Control)labelP2_selectFolder).Size = new Size(149, 17);
		((Control)labelP2_selectFolder).TabIndex = 16;
		((Control)labelP2_selectFolder).Text = "Select folder for destination";
		labelP2_selectFolder.UseCompatibleTextRendering = true;
		((Control)labelP2_selectNonSharedFolder).AutoSize = true;
		((Control)labelP2_selectNonSharedFolder).Enabled = false;
		labelP2_selectNonSharedFolder.ImeMode = (ImeMode)0;
		((Control)labelP2_selectNonSharedFolder).Location = new Point(56, 250);
		((Control)labelP2_selectNonSharedFolder).Name = "labelP2_selectNonSharedFolder";
		((Control)labelP2_selectNonSharedFolder).Size = new Size(149, 17);
		((Control)labelP2_selectNonSharedFolder).TabIndex = 16;
		((Control)labelP2_selectNonSharedFolder).Text = "Select folder for destination";
		labelP2_selectNonSharedFolder.UseCompatibleTextRendering = true;
		cmbP2Folder.DropDownStyle = (ComboBoxStyle)2;
		cmbP2Folder.DropDownWidth = 401;
		((Control)cmbP2Folder).Enabled = false;
		((ListControl)cmbP2Folder).FormattingEnabled = true;
		((Control)cmbP2Folder).Location = new Point(280, 388);
		((Control)cmbP2Folder).Name = "cmbP2Folder";
		((Control)cmbP2Folder).Size = new Size(343, 20);
		cmbP2Folder.Sorted = true;
		((Control)cmbP2Folder).TabIndex = 15;
		((Control)selectFolderRadioButton).AutoSize = true;
		((ButtonBase)selectFolderRadioButton).ImeMode = (ImeMode)0;
		((Control)selectFolderRadioButton).Location = new Point(50, 342);
		((Control)selectFolderRadioButton).Name = "selectFolderRadioButton";
		((Control)selectFolderRadioButton).Size = new Size(88, 16);
		((Control)selectFolderRadioButton).TabIndex = 14;
		((Control)selectFolderRadioButton).Text = "Select folder";
		((ButtonBase)selectFolderRadioButton).UseVisualStyleBackColor = true;
		selectFolderRadioButton.CheckedChanged += createNewFolderRadioButton_CheckedChanged;
		((Control)createNewFolderRadioButton).AutoSize = true;
		createNewFolderRadioButton.Checked = true;
		((ButtonBase)createNewFolderRadioButton).ImeMode = (ImeMode)0;
		((Control)createNewFolderRadioButton).Location = new Point(50, 132);
		((Control)createNewFolderRadioButton).Name = "createNewFolderRadioButton";
		((Control)createNewFolderRadioButton).Size = new Size(114, 16);
		((Control)createNewFolderRadioButton).TabIndex = 13;
		createNewFolderRadioButton.TabStop = true;
		((Control)createNewFolderRadioButton).Text = "Create new folder";
		((ButtonBase)createNewFolderRadioButton).UseVisualStyleBackColor = true;
		createNewFolderRadioButton.CheckedChanged += createNewFolderRadioButton_CheckedChanged;
		((Control)selectNonSharedFolderRadioButton).AutoSize = true;
		((ButtonBase)selectNonSharedFolderRadioButton).ImeMode = (ImeMode)0;
		((Control)selectNonSharedFolderRadioButton).Location = new Point(50, 226);
		((Control)selectNonSharedFolderRadioButton).Name = "selectNonSharedFolderRadioButton";
		((Control)selectNonSharedFolderRadioButton).Size = new Size(88, 16);
		((Control)selectNonSharedFolderRadioButton).TabIndex = 14;
		((Control)selectNonSharedFolderRadioButton).Text = "Select folder";
		((ButtonBase)selectNonSharedFolderRadioButton).UseVisualStyleBackColor = true;
		selectNonSharedFolderRadioButton.CheckedChanged += createNewFolderRadioButton_CheckedChanged;
		((Control)labelP2_Folder).AutoSize = true;
		((Control)labelP2_Folder).Enabled = false;
		((Control)labelP2_Folder).ForeColor = Color.Blue;
		labelP2_Folder.ImeMode = (ImeMode)0;
		((Control)labelP2_Folder).Location = new Point(56, 390);
		((Control)labelP2_Folder).Name = "labelP2_Folder";
		((Control)labelP2_Folder).Size = new Size(37, 12);
		((Control)labelP2_Folder).TabIndex = 12;
		((Control)labelP2_Folder).Text = "Folder";
		((Control)buttonSelectNonSharedFolder).AutoSize = true;
		((Control)buttonSelectNonSharedFolder).Enabled = false;
		((Control)buttonSelectNonSharedFolder).Font = new Font("MS UI Gothic", 9f);
		((ButtonBase)buttonSelectNonSharedFolder).ImeMode = (ImeMode)0;
		((Control)buttonSelectNonSharedFolder).Location = new Point(547, 272);
		((Control)buttonSelectNonSharedFolder).Name = "buttonSelectNonSharedFolder";
		((Control)buttonSelectNonSharedFolder).Size = new Size(105, 22);
		((Control)buttonSelectNonSharedFolder).TabIndex = 5;
		((Control)buttonSelectNonSharedFolder).Text = "参照";
		((ButtonBase)buttonSelectNonSharedFolder).UseVisualStyleBackColor = true;
		((Control)buttonSelectNonSharedFolder).Click += buttonNonSharedSelectFolder_Click;
		((Control)textBoxNonSharedFolderPath).Enabled = false;
		((Control)textBoxNonSharedFolderPath).Font = new Font("MS UI Gothic", 9f);
		((Control)textBoxNonSharedFolderPath).Location = new Point(280, 273);
		((Control)textBoxNonSharedFolderPath).Name = "textBoxNonSharedFolderPath";
		((Control)textBoxNonSharedFolderPath).Size = new Size(261, 19);
		((Control)textBoxNonSharedFolderPath).TabIndex = 4;
		((Control)textBoxNonSharedFolderPath).Enter += textBoxNonSharedFolderPath_Enter;
		((Control)textBoxNonSharedFolderPath).Leave += textBoxNonSharedFolderPath_Leave;
		((Control)labelP2_NonSharedFolderPath).AutoSize = true;
		((Control)labelP2_NonSharedFolderPath).Enabled = false;
		((Control)labelP2_NonSharedFolderPath).Font = new Font("MS UI Gothic", 9f);
		((Control)labelP2_NonSharedFolderPath).ForeColor = Color.Blue;
		labelP2_NonSharedFolderPath.ImeMode = (ImeMode)0;
		((Control)labelP2_NonSharedFolderPath).Location = new Point(56, 275);
		((Control)labelP2_NonSharedFolderPath).Name = "labelP2_NonSharedFolderPath";
		((Control)labelP2_NonSharedFolderPath).Size = new Size(64, 12);
		((Control)labelP2_NonSharedFolderPath).TabIndex = 11;
		((Control)labelP2_NonSharedFolderPath).Text = "Folder Path";
		((Control)textBoxSharedName).Enabled = false;
		((Control)textBoxSharedName).Font = new Font("MS UI Gothic", 9f);
		((Control)textBoxSharedName).Location = new Point(280, 303);
		((Control)textBoxSharedName).Name = "textBoxSharedName";
		((Control)textBoxSharedName).Size = new Size(373, 19);
		((Control)textBoxSharedName).TabIndex = 4;
		((Control)textBoxSharedName).Enter += textBoxSharedName_Enter;
		((Control)textBoxSharedName).Leave += textBoxSharedName_Leave;
		((Control)labelP2_SharedName).AutoSize = true;
		((Control)labelP2_SharedName).Enabled = false;
		((Control)labelP2_SharedName).Font = new Font("MS UI Gothic", 9f);
		((Control)labelP2_SharedName).ForeColor = Color.Blue;
		labelP2_SharedName.ImeMode = (ImeMode)0;
		((Control)labelP2_SharedName).Location = new Point(56, 305);
		((Control)labelP2_SharedName).Name = "labelP2_SharedName";
		((Control)labelP2_SharedName).Size = new Size(73, 12);
		((Control)labelP2_SharedName).TabIndex = 11;
		((Control)labelP2_SharedName).Text = "Shared Name";
		((Control)buttonSelectFolder).AutoSize = true;
		((Control)buttonSelectFolder).Font = new Font("MS UI Gothic", 9f);
		((ButtonBase)buttonSelectFolder).ImeMode = (ImeMode)0;
		((Control)buttonSelectFolder).Location = new Point(547, 157);
		((Control)buttonSelectFolder).Name = "buttonSelectFolder";
		((Control)buttonSelectFolder).Size = new Size(105, 22);
		((Control)buttonSelectFolder).TabIndex = 5;
		((Control)buttonSelectFolder).Text = "参照";
		((ButtonBase)buttonSelectFolder).UseVisualStyleBackColor = true;
		((Control)buttonSelectFolder).Click += buttonSelectFolder_Click;
		((Control)textBoxFolderPath).Font = new Font("MS UI Gothic", 9f);
		((Control)textBoxFolderPath).Location = new Point(280, 158);
		((Control)textBoxFolderPath).Name = "textBoxFolderPath";
		((Control)textBoxFolderPath).Size = new Size(261, 19);
		((Control)textBoxFolderPath).TabIndex = 4;
		((Control)textBoxFolderPath).Enter += textBoxFolderPath_Enter;
		((Control)textBoxFolderPath).Leave += textBoxFolderPath_Leave;
		((Control)labelP2_FolderPath).AutoSize = true;
		((Control)labelP2_FolderPath).Font = new Font("MS UI Gothic", 9f);
		((Control)labelP2_FolderPath).ForeColor = Color.Blue;
		labelP2_FolderPath.ImeMode = (ImeMode)0;
		((Control)labelP2_FolderPath).Location = new Point(56, 160);
		((Control)labelP2_FolderPath).Name = "labelP2_FolderPath";
		((Control)labelP2_FolderPath).Size = new Size(64, 12);
		((Control)labelP2_FolderPath).TabIndex = 11;
		((Control)labelP2_FolderPath).Text = "Folder Path";
		((Control)textBoxFolderName).Font = new Font("MS UI Gothic", 9f);
		((Control)textBoxFolderName).Location = new Point(280, 186);
		((Control)textBoxFolderName).Name = "textBoxFolderName";
		((Control)textBoxFolderName).Size = new Size(373, 19);
		((Control)textBoxFolderName).TabIndex = 3;
		((Control)textBoxFolderName).Text = "ScanDoc";
		((Control)textBoxFolderName).Enter += textBoxFolderName_Enter;
		((Control)textBoxFolderName).Leave += textBoxFolderName_Leave;
		((Control)labelP2_FolderName).AutoSize = true;
		((Control)labelP2_FolderName).Font = new Font("MS UI Gothic", 9f);
		((Control)labelP2_FolderName).ForeColor = Color.Blue;
		labelP2_FolderName.ImeMode = (ImeMode)0;
		((Control)labelP2_FolderName).Location = new Point(56, 188);
		((Control)labelP2_FolderName).Name = "labelP2_FolderName";
		((Control)labelP2_FolderName).Size = new Size(66, 12);
		((Control)labelP2_FolderName).TabIndex = 9;
		((Control)labelP2_FolderName).Text = "FolderName";
		pictureBox2.Image = (Image)(object)Resources.Line;
		pictureBox2.ImeMode = (ImeMode)0;
		((Control)pictureBox2).Location = new Point(39, 48);
		((Control)pictureBox2).Margin = new Padding(1);
		((Control)pictureBox2).Name = "pictureBox2";
		((Control)pictureBox2).Size = new Size(689, 10);
		pictureBox2.TabIndex = 1;
		pictureBox2.TabStop = false;
		((Control)labelP2Head).AutoSize = true;
		((Control)labelP2Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		labelP2Head.ImeMode = (ImeMode)0;
		((Control)labelP2Head).Location = new Point(40, 21);
		((Control)labelP2Head).Name = "labelP2Head";
		((Control)labelP2Head).Size = new Size(109, 16);
		((Control)labelP2Head).TabIndex = 0;
		((Control)labelP2Head).Text = "CreateFolder";
		((Control)labelP2_comment).AutoSize = true;
		((Control)labelP2_comment).Font = new Font("MS UI Gothic", 9f);
		labelP2_comment.ImeMode = (ImeMode)0;
		((Control)labelP2_comment).Location = new Point(45, 75);
		((Control)labelP2_comment).Name = "labelP2_comment";
		((Control)labelP2_comment).Size = new Size(125, 12);
		((Control)labelP2_comment).TabIndex = 2;
		((Control)labelP2_comment).Text = "Folder setting message";
		((Control)panel_P2_1).BackColor = SystemColors.Control;
		panel_P2_1.BorderStyle = (BorderStyle)1;
		((Control)panel_P2_1).Location = new Point(0, 3);
		((Control)panel_P2_1).Margin = new Padding(0);
		((Control)panel_P2_1).Name = "panel_P2_1";
		((Control)panel_P2_1).Size = new Size(231, 470);
		((Control)panel_P2_1).TabIndex = 14;
		((Control)tabPage1_introduction).BackColor = SystemColors.Control;
		((Control)tabPage1_introduction).Controls.Add((Control)(object)panel_P1_3);
		((Control)tabPage1_introduction).Controls.Add((Control)(object)panel_P1_2);
		((Control)tabPage1_introduction).Controls.Add((Control)(object)panel_P1_1);
		tabPage1_introduction.Location = new Point(4, 22);
		((Control)tabPage1_introduction).Margin = new Padding(0);
		((Control)tabPage1_introduction).Name = "tabPage1_introduction";
		((Control)tabPage1_introduction).Size = new Size(960, 497);
		tabPage1_introduction.TabIndex = 0;
		((Control)tabPage1_introduction).Text = "tabP1_introduction";
		((Control)panel_P1_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_P1_3.BorderStyle = (BorderStyle)1;
		((Control)panel_P1_3).Controls.Add((Control)(object)btnP1TRNext);
		((Control)panel_P1_3).Controls.Add((Control)(object)btnP1Cancel);
		((Control)panel_P1_3).Controls.Add((Control)(object)btnP1Next);
		((Control)panel_P1_3).Dock = (DockStyle)2;
		((Control)panel_P1_3).Location = new Point(0, 446);
		((Control)panel_P1_3).Margin = new Padding(0);
		((Control)panel_P1_3).Name = "panel_P1_3";
		((Control)panel_P1_3).Size = new Size(960, 51);
		((Control)panel_P1_3).TabIndex = 14;
		((Control)panel_P1_2).BackColor = Color.White;
		panel_P1_2.BorderStyle = (BorderStyle)1;
		((Control)panel_P1_2).Controls.Add((Control)(object)radioButtonTroubleShoot);
		((Control)panel_P1_2).Controls.Add((Control)(object)radioButtonCreateFolder);
		((Control)panel_P1_2).Controls.Add((Control)(object)attentionGroup);
		((Control)panel_P1_2).Controls.Add((Control)(object)pictureBox1);
		((Control)panel_P1_2).Controls.Add((Control)(object)labelP1Head);
		((Control)panel_P1_2).Controls.Add((Control)(object)labelP1_comment);
		((Control)panel_P1_2).Location = new Point(234, 3);
		((Control)panel_P1_2).Name = "panel_P1_2";
		((Control)panel_P1_2).Size = new Size(725, 470);
		((Control)panel_P1_2).TabIndex = 15;
		((Control)radioButtonTroubleShoot).AutoSize = true;
		((Control)radioButtonTroubleShoot).Font = new Font("MS UI Gothic", 9f, (FontStyle)1, (GraphicsUnit)3, (byte)128);
		((ButtonBase)radioButtonTroubleShoot).ImeMode = (ImeMode)0;
		((Control)radioButtonTroubleShoot).Location = new Point(56, 175);
		((Control)radioButtonTroubleShoot).Name = "radioButtonTroubleShoot";
		((Control)radioButtonTroubleShoot).Size = new Size(107, 16);
		((Control)radioButtonTroubleShoot).TabIndex = 7;
		((Control)radioButtonTroubleShoot).Text = "Trouble Shoot";
		((ButtonBase)radioButtonTroubleShoot).UseVisualStyleBackColor = true;
		((Control)radioButtonCreateFolder).AutoSize = true;
		radioButtonCreateFolder.Checked = true;
		((Control)radioButtonCreateFolder).Font = new Font("MS UI Gothic", 9f, (FontStyle)1, (GraphicsUnit)3, (byte)128);
		((ButtonBase)radioButtonCreateFolder).ImeMode = (ImeMode)0;
		((Control)radioButtonCreateFolder).Location = new Point(56, 140);
		((Control)radioButtonCreateFolder).Name = "radioButtonCreateFolder";
		((Control)radioButtonCreateFolder).Size = new Size(74, 16);
		((Control)radioButtonCreateFolder).TabIndex = 5;
		radioButtonCreateFolder.TabStop = true;
		((Control)radioButtonCreateFolder).Text = "Register";
		((ButtonBase)radioButtonCreateFolder).UseVisualStyleBackColor = true;
		radioButtonCreateFolder.CheckedChanged += radioButtonCreateFolder_CheckedChanged;
		((Control)attentionGroup).Controls.Add((Control)(object)attentionRichTextBox);
		((Control)attentionGroup).Font = new Font("MS UI Gothic", 9f, (FontStyle)1);
		((Control)attentionGroup).Location = new Point(37, 224);
		((Control)attentionGroup).Name = "attentionGroup";
		((Control)attentionGroup).Size = new Size(653, 185);
		((Control)attentionGroup).TabIndex = 3;
		attentionGroup.TabStop = false;
		((Control)attentionGroup).Text = "attention_title";
		((Control)attentionRichTextBox).BackColor = SystemColors.Window;
		((TextBoxBase)attentionRichTextBox).BorderStyle = (BorderStyle)0;
		((Control)attentionRichTextBox).Font = new Font("MS UI Gothic", 9f);
		((Control)attentionRichTextBox).Location = new Point(19, 27);
		((Control)attentionRichTextBox).Name = "attentionRichTextBox";
		((TextBoxBase)attentionRichTextBox).ReadOnly = true;
		((Control)attentionRichTextBox).Size = new Size(617, 145);
		((Control)attentionRichTextBox).TabIndex = 4;
		((Control)attentionRichTextBox).Text = "";
		pictureBox1.Image = (Image)(object)Resources.Line;
		pictureBox1.ImeMode = (ImeMode)0;
		((Control)pictureBox1).Location = new Point(39, 48);
		((Control)pictureBox1).Margin = new Padding(1);
		((Control)pictureBox1).Name = "pictureBox1";
		((Control)pictureBox1).Size = new Size(689, 10);
		pictureBox1.TabIndex = 1;
		pictureBox1.TabStop = false;
		((Control)labelP1Head).AutoSize = true;
		((Control)labelP1Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		labelP1Head.ImeMode = (ImeMode)0;
		((Control)labelP1Head).Location = new Point(40, 21);
		((Control)labelP1Head).Name = "labelP1Head";
		((Control)labelP1Head).Size = new Size(74, 16);
		((Control)labelP1Head).TabIndex = 0;
		((Control)labelP1Head).Text = "Prologue";
		((Control)labelP1_comment).AutoSize = true;
		((Control)labelP1_comment).Font = new Font("MS UI Gothic", 9f);
		labelP1_comment.ImeMode = (ImeMode)0;
		((Control)labelP1_comment).Location = new Point(41, 91);
		((Control)labelP1_comment).Name = "labelP1_comment";
		((Control)labelP1_comment).Size = new Size(114, 12);
		((Control)labelP1_comment).TabIndex = 2;
		((Control)labelP1_comment).Text = "Introduction message";
		((Control)panel_P1_1).BackColor = SystemColors.Control;
		panel_P1_1.BorderStyle = (BorderStyle)1;
		((Control)panel_P1_1).Location = new Point(0, 3);
		((Control)panel_P1_1).Margin = new Padding(0);
		((Control)panel_P1_1).Name = "panel_P1_1";
		((Control)panel_P1_1).Size = new Size(231, 470);
		((Control)panel_P1_1).TabIndex = 13;
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabPage1_introduction);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabPage2_setupSelect);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabPage3_shareFolder);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabPage4_address);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabPage5_confirm);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabPage6_exec);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabPage7_finish);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabTRP2_device);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabTRP3_user);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabTRP4_analyze);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabTRP5_result);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabTRP6_setupSelect);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabTRP7_shareFolder);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabTRP8_address);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabTRP9_confirm);
		((Control)tabControl1_Main).Controls.Add((Control)(object)tabTRP10_finish);
		((Control)tabControl1_Main).Location = new Point(-3, 21);
		((Control)tabControl1_Main).Margin = new Padding(0);
		((Control)tabControl1_Main).Name = "tabControl1_Main";
		tabControl1_Main.Padding = new Point(0, 0);
		tabControl1_Main.SelectedIndex = 0;
		((Control)tabControl1_Main).Size = new Size(968, 523);
		((Control)tabControl1_Main).TabIndex = 0;
		tabControl1_Main.Selected += new TabControlEventHandler(tabControl1_Main_Selected);
		((Control)tabPage6_exec).Controls.Add((Control)(object)panel_P6_3);
		((Control)tabPage6_exec).Controls.Add((Control)(object)panel_P6_2);
		((Control)tabPage6_exec).Controls.Add((Control)(object)panel_P6_1);
		tabPage6_exec.Location = new Point(4, 22);
		((Control)tabPage6_exec).Margin = new Padding(0);
		((Control)tabPage6_exec).Name = "tabPage6_exec";
		((Control)tabPage6_exec).Size = new Size(960, 497);
		tabPage6_exec.TabIndex = 5;
		((Control)tabPage6_exec).Text = "tabP6_exec";
		tabPage6_exec.UseVisualStyleBackColor = true;
		((Control)panel_P6_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_P6_3.BorderStyle = (BorderStyle)1;
		((Control)panel_P6_3).Dock = (DockStyle)2;
		((Control)panel_P6_3).Location = new Point(0, 446);
		((Control)panel_P6_3).Margin = new Padding(0);
		((Control)panel_P6_3).Name = "panel_P6_3";
		((Control)panel_P6_3).Size = new Size(960, 51);
		((Control)panel_P6_3).TabIndex = 21;
		((Control)panel_P6_2).BackColor = Color.White;
		panel_P6_2.BorderStyle = (BorderStyle)1;
		((Control)panel_P6_2).Controls.Add((Control)(object)progressBar1);
		((Control)panel_P6_2).Controls.Add((Control)(object)labelP6Execute);
		((Control)panel_P6_2).Controls.Add((Control)(object)btnP6Excecute);
		((Control)panel_P6_2).Controls.Add((Control)(object)pictureBox6);
		((Control)panel_P6_2).Controls.Add((Control)(object)labelP6Head);
		((Control)panel_P6_2).Controls.Add((Control)(object)labelP6_comment);
		((Control)panel_P6_2).Location = new Point(234, 3);
		((Control)panel_P6_2).Name = "panel_P6_2";
		((Control)panel_P6_2).Size = new Size(725, 470);
		((Control)panel_P6_2).TabIndex = 20;
		progressBar1.ImeMode = (ImeMode)0;
		((Control)progressBar1).Location = new Point(44, 145);
		progressBar1.Maximum = 7;
		((Control)progressBar1).Name = "progressBar1";
		((Control)progressBar1).Size = new Size(576, 23);
		((Control)progressBar1).TabIndex = 5;
		((Control)labelP6Execute).AutoSize = true;
		((Control)labelP6Execute).Font = new Font("MS UI Gothic", 9f);
		labelP6Execute.ImeMode = (ImeMode)0;
		((Control)labelP6Execute).Location = new Point(46, 130);
		((Control)labelP6Execute).Name = "labelP6Execute";
		((Control)labelP6Execute).Size = new Size(41, 12);
		((Control)labelP6Execute).TabIndex = 4;
		((Control)labelP6Execute).Text = "label19";
		pictureBox6.Image = (Image)(object)Resources.Line;
		pictureBox6.ImeMode = (ImeMode)0;
		((Control)pictureBox6).Location = new Point(39, 48);
		((Control)pictureBox6).Margin = new Padding(1);
		((Control)pictureBox6).Name = "pictureBox6";
		((Control)pictureBox6).Size = new Size(687, 10);
		pictureBox6.TabIndex = 1;
		pictureBox6.TabStop = false;
		((Control)labelP6Head).AutoSize = true;
		((Control)labelP6Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		labelP6Head.ImeMode = (ImeMode)0;
		((Control)labelP6Head).Location = new Point(40, 21);
		((Control)labelP6Head).Name = "labelP6Head";
		((Control)labelP6Head).Size = new Size(81, 16);
		((Control)labelP6Head).TabIndex = 0;
		((Control)labelP6Head).Text = "Executing";
		((Control)labelP6_comment).AutoSize = true;
		((Control)labelP6_comment).Font = new Font("MS UI Gothic", 9f);
		labelP6_comment.ImeMode = (ImeMode)0;
		((Control)labelP6_comment).Location = new Point(45, 75);
		((Control)labelP6_comment).Name = "labelP6_comment";
		((Control)labelP6_comment).Size = new Size(104, 12);
		((Control)labelP6_comment).TabIndex = 2;
		((Control)labelP6_comment).Text = "Executing message";
		((Control)panel_P6_1).BackColor = SystemColors.Control;
		panel_P6_1.BorderStyle = (BorderStyle)1;
		((Control)panel_P6_1).Location = new Point(0, 3);
		((Control)panel_P6_1).Margin = new Padding(0);
		((Control)panel_P6_1).Name = "panel_P6_1";
		((Control)panel_P6_1).Size = new Size(231, 470);
		((Control)panel_P6_1).TabIndex = 19;
		((Control)tabPage7_finish).Controls.Add((Control)(object)panel_P7_3);
		((Control)tabPage7_finish).Controls.Add((Control)(object)panel_P7_2);
		((Control)tabPage7_finish).Controls.Add((Control)(object)panel_P7_1);
		tabPage7_finish.Location = new Point(4, 22);
		((Control)tabPage7_finish).Margin = new Padding(0);
		((Control)tabPage7_finish).Name = "tabPage7_finish";
		((Control)tabPage7_finish).Size = new Size(960, 497);
		tabPage7_finish.TabIndex = 6;
		((Control)tabPage7_finish).Text = "tabP7_finish";
		tabPage7_finish.UseVisualStyleBackColor = true;
		((Control)panel_P7_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_P7_3.BorderStyle = (BorderStyle)1;
		((Control)panel_P7_3).Controls.Add((Control)(object)btnP7Top);
		((Control)panel_P7_3).Controls.Add((Control)(object)btnP7End);
		((Control)panel_P7_3).Dock = (DockStyle)2;
		((Control)panel_P7_3).Location = new Point(0, 446);
		((Control)panel_P7_3).Margin = new Padding(0);
		((Control)panel_P7_3).Name = "panel_P7_3";
		((Control)panel_P7_3).Size = new Size(960, 51);
		((Control)panel_P7_3).TabIndex = 24;
		((Control)panel_P7_2).BackColor = Color.White;
		panel_P7_2.BorderStyle = (BorderStyle)1;
		((Control)panel_P7_2).Controls.Add((Control)(object)linkLabelP7HelpSend);
		((Control)panel_P7_2).Controls.Add((Control)(object)linkLabelP7HelpRegist);
		((Control)panel_P7_2).Controls.Add((Control)(object)panel22);
		((Control)panel_P7_2).Controls.Add((Control)(object)pictureBox7);
		((Control)panel_P7_2).Controls.Add((Control)(object)labelP7Head);
		((Control)panel_P7_2).Controls.Add((Control)(object)labelP7_ReportTitle);
		((Control)panel_P7_2).Controls.Add((Control)(object)labelP7_comment);
		((Control)panel_P7_2).Location = new Point(234, 3);
		((Control)panel_P7_2).Name = "panel_P7_2";
		((Control)panel_P7_2).Size = new Size(725, 470);
		((Control)panel_P7_2).TabIndex = 23;
		((Control)linkLabelP7HelpSend).AutoSize = true;
		((Control)linkLabelP7HelpSend).Font = new Font("MS UI Gothic", 9f);
		((Label)linkLabelP7HelpSend).ImeMode = (ImeMode)0;
		((Control)linkLabelP7HelpSend).Location = new Point(45, 109);
		((Control)linkLabelP7HelpSend).Name = "linkLabelP7HelpSend";
		((Control)linkLabelP7HelpSend).Size = new Size(141, 12);
		((Control)linkLabelP7HelpSend).TabIndex = 26;
		linkLabelP7HelpSend.TabStop = true;
		((Control)linkLabelP7HelpSend).Text = "Folder send procedure link";
		linkLabelP7HelpSend.LinkClicked += new LinkLabelLinkClickedEventHandler(linkLabel1_LinkClicked);
		((Control)linkLabelP7HelpRegist).AutoSize = true;
		((Control)linkLabelP7HelpRegist).Font = new Font("MS UI Gothic", 9f);
		((Label)linkLabelP7HelpRegist).ImeMode = (ImeMode)0;
		linkLabelP7HelpRegist.LinkColor = Color.Red;
		((Control)linkLabelP7HelpRegist).Location = new Point(45, 94);
		((Control)linkLabelP7HelpRegist).Name = "linkLabelP7HelpRegist";
		((Control)linkLabelP7HelpRegist).Size = new Size(145, 12);
		((Control)linkLabelP7HelpRegist).TabIndex = 25;
		linkLabelP7HelpRegist.TabStop = true;
		((Control)linkLabelP7HelpRegist).Text = "Direct regist procedure link";
		linkLabelP7HelpRegist.LinkClicked += new LinkLabelLinkClickedEventHandler(linkLabelP7Help_LinkClicked);
		((ScrollableControl)panel22).AutoScroll = true;
		panel22.BorderStyle = (BorderStyle)2;
		((Control)panel22).Controls.Add((Control)(object)labelP7Report);
		((Control)panel22).Controls.Add((Control)(object)labelP7finsh);
		((Control)panel22).Font = new Font("MS UI Gothic", 9f);
		((Control)panel22).Location = new Point(48, 159);
		((Control)panel22).Name = "panel22";
		((Control)panel22).Size = new Size(569, 242);
		((Control)panel22).TabIndex = 4;
		((Control)labelP7Report).AutoSize = true;
		labelP7Report.ImeMode = (ImeMode)0;
		((Control)labelP7Report).Location = new Point(4, 11);
		((Control)labelP7Report).Name = "labelP7Report";
		((Control)labelP7Report).Size = new Size(35, 12);
		((Control)labelP7Report).TabIndex = 2;
		((Control)labelP7Report).Text = "label7";
		((Control)labelP7finsh).AutoSize = true;
		((Label)labelP7finsh).ImeMode = (ImeMode)0;
		((Control)labelP7finsh).Location = new Point(381, 0);
		((Control)labelP7finsh).Name = "labelP7finsh";
		((Control)labelP7finsh).Size = new Size(41, 12);
		((Control)labelP7finsh).TabIndex = 1;
		labelP7finsh.TabStop = true;
		((Control)labelP7finsh).Text = "reports";
		((Control)labelP7finsh).Visible = false;
		pictureBox7.Image = (Image)(object)Resources.Line;
		pictureBox7.ImeMode = (ImeMode)0;
		((Control)pictureBox7).Location = new Point(39, 48);
		((Control)pictureBox7).Margin = new Padding(1);
		((Control)pictureBox7).Name = "pictureBox7";
		((Control)pictureBox7).Size = new Size(689, 10);
		pictureBox7.TabIndex = 1;
		pictureBox7.TabStop = false;
		((Control)labelP7Head).AutoSize = true;
		((Control)labelP7Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		labelP7Head.ImeMode = (ImeMode)0;
		((Control)labelP7Head).Location = new Point(40, 21);
		((Control)labelP7Head).Name = "labelP7Head";
		((Control)labelP7Head).Size = new Size(80, 16);
		((Control)labelP7Head).TabIndex = 0;
		((Control)labelP7Head).Text = "Complete";
		((Control)labelP7_ReportTitle).AutoSize = true;
		((Control)labelP7_ReportTitle).Font = new Font("MS UI Gothic", 9f);
		labelP7_ReportTitle.ImeMode = (ImeMode)0;
		((Control)labelP7_ReportTitle).Location = new Point(45, 142);
		((Control)labelP7_ReportTitle).Name = "labelP7_ReportTitle";
		((Control)labelP7_ReportTitle).Size = new Size(45, 12);
		((Control)labelP7_ReportTitle).TabIndex = 2;
		((Control)labelP7_ReportTitle).Text = "Report :";
		((Control)labelP7_comment).AutoSize = true;
		((Control)labelP7_comment).Font = new Font("MS UI Gothic", 9f);
		labelP7_comment.ImeMode = (ImeMode)0;
		((Control)labelP7_comment).Location = new Point(45, 75);
		((Control)labelP7_comment).Name = "labelP7_comment";
		((Control)labelP7_comment).Size = new Size(102, 12);
		((Control)labelP7_comment).TabIndex = 2;
		((Control)labelP7_comment).Text = "Complete message";
		((Control)panel_P7_1).BackColor = SystemColors.Control;
		panel_P7_1.BorderStyle = (BorderStyle)1;
		((Control)panel_P7_1).Location = new Point(0, 3);
		((Control)panel_P7_1).Margin = new Padding(0);
		((Control)panel_P7_1).Name = "panel_P7_1";
		((Control)panel_P7_1).Size = new Size(231, 470);
		((Control)panel_P7_1).TabIndex = 22;
		((Control)tabTRP2_device).Controls.Add((Control)(object)panel_TRP2_3);
		((Control)tabTRP2_device).Controls.Add((Control)(object)panel_TRP2_2);
		((Control)tabTRP2_device).Controls.Add((Control)(object)panel_TRP2_1);
		tabTRP2_device.Location = new Point(4, 22);
		((Control)tabTRP2_device).Margin = new Padding(0);
		((Control)tabTRP2_device).Name = "tabTRP2_device";
		((Control)tabTRP2_device).Size = new Size(1060, 497);
		tabTRP2_device.TabIndex = 7;
		((Control)tabTRP2_device).Text = "tabTRP2_device";
		tabTRP2_device.UseVisualStyleBackColor = true;
		((Control)panel_TRP2_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_TRP2_3.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP2_3).Controls.Add((Control)(object)btnTRP2Back);
		((Control)panel_TRP2_3).Controls.Add((Control)(object)btnTRP2Next);
		((Control)panel_TRP2_3).Dock = (DockStyle)2;
		((Control)panel_TRP2_3).Location = new Point(0, 446);
		((Control)panel_TRP2_3).Margin = new Padding(0);
		((Control)panel_TRP2_3).Name = "panel_TRP2_3";
		((Control)panel_TRP2_3).Size = new Size(960, 51);
		((Control)panel_TRP2_3).TabIndex = 26;
		((Control)panel_TRP2_2).BackColor = Color.White;
		((Control)panel_TRP2_2).Controls.Add((Control)(object)label_TRP2ConnectCheck);
		((Control)panel_TRP2_2).Controls.Add((Control)(object)linkLabelTRP2);
		((Control)panel_TRP2_2).Controls.Add((Control)(object)machineSelectControlTRP2);
		((Control)panel_TRP2_2).Controls.Add((Control)(object)pictureBox8);
		((Control)panel_TRP2_2).Controls.Add((Control)(object)label_TRP2Head);
		((Control)panel_TRP2_2).Controls.Add((Control)(object)label_TRP2_Machine);
		((Control)panel_TRP2_2).Controls.Add((Control)(object)label_TRP2_comment);
		((Control)panel_TRP2_2).Location = new Point(234, 3);
		((Control)panel_TRP2_2).Name = "panel_TRP2_2";
		((Control)panel_TRP2_2).Size = new Size(725, 470);
		((Control)panel_TRP2_2).TabIndex = 27;
		((Control)label_TRP2ConnectCheck).AutoSize = true;
		((Control)label_TRP2ConnectCheck).Font = new Font("MS UI Gothic", 9f);
		((Control)label_TRP2ConnectCheck).ForeColor = Color.Black;
		label_TRP2ConnectCheck.ImeMode = (ImeMode)0;
		((Control)label_TRP2ConnectCheck).Location = new Point(5, 423);
		((Control)label_TRP2ConnectCheck).Name = "label_TRP2ConnectCheck";
		((Control)label_TRP2ConnectCheck).Size = new Size(80, 12);
		((Control)label_TRP2ConnectCheck).TabIndex = 34;
		((Control)label_TRP2ConnectCheck).Text = "Connecting . . .";
		((Control)label_TRP2ConnectCheck).Visible = false;
		((Control)linkLabelTRP2).AutoSize = true;
		((Label)linkLabelTRP2).ImeMode = (ImeMode)0;
		linkLabelTRP2.LinkColor = Color.Red;
		((Control)linkLabelTRP2).Location = new Point(3, 423);
		((Control)linkLabelTRP2).Name = "linkLabelTRP2";
		((Control)linkLabelTRP2).Size = new Size(569, 12);
		((Control)linkLabelTRP2).TabIndex = 42;
		linkLabelTRP2.TabStop = true;
		((Control)linkLabelTRP2).Text = "接続の問題が解消しない場合はこちらをクリックしてください。機器の操作パネルから宛先を登録する手順が表示されます。";
		((Control)linkLabelTRP2).Visible = false;
		linkLabelTRP2.LinkClicked += new LinkLabelLinkClickedEventHandler(linkLabelConnect_LinkClicked);
		pictureBox8.Image = (Image)(object)Resources.Line;
		pictureBox8.ImeMode = (ImeMode)0;
		((Control)pictureBox8).Location = new Point(39, 48);
		((Control)pictureBox8).Margin = new Padding(1);
		((Control)pictureBox8).Name = "pictureBox8";
		((Control)pictureBox8).Size = new Size(689, 10);
		pictureBox8.TabIndex = 1;
		pictureBox8.TabStop = false;
		((Control)label_TRP2Head).AutoSize = true;
		((Control)label_TRP2Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		label_TRP2Head.ImeMode = (ImeMode)0;
		((Control)label_TRP2Head).Location = new Point(40, 21);
		((Control)label_TRP2Head).Name = "label_TRP2Head";
		((Control)label_TRP2Head).Size = new Size(114, 16);
		((Control)label_TRP2Head).TabIndex = 0;
		((Control)label_TRP2Head).Text = "Select Device";
		((Control)label_TRP2_Machine).AutoSize = true;
		((Control)label_TRP2_Machine).Font = new Font("MS UI Gothic", 9f);
		((Control)label_TRP2_Machine).ForeColor = Color.Blue;
		label_TRP2_Machine.ImeMode = (ImeMode)0;
		((Control)label_TRP2_Machine).Location = new Point(44, 130);
		((Control)label_TRP2_Machine).Name = "label_TRP2_Machine";
		((Control)label_TRP2_Machine).Size = new Size(40, 12);
		((Control)label_TRP2_Machine).TabIndex = 2;
		((Control)label_TRP2_Machine).Text = "Device";
		((Control)label_TRP2_comment).AutoSize = true;
		((Control)label_TRP2_comment).Font = new Font("MS UI Gothic", 9f);
		label_TRP2_comment.ImeMode = (ImeMode)0;
		((Control)label_TRP2_comment).Location = new Point(44, 75);
		((Control)label_TRP2_comment).Name = "label_TRP2_comment";
		((Control)label_TRP2_comment).Size = new Size(51, 12);
		((Control)label_TRP2_comment).TabIndex = 2;
		((Control)label_TRP2_comment).Text = "comment";
		((Control)panel_TRP2_1).BackColor = SystemColors.Control;
		panel_TRP2_1.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP2_1).Location = new Point(0, 3);
		((Control)panel_TRP2_1).Margin = new Padding(0);
		((Control)panel_TRP2_1).Name = "panel_TRP2_1";
		((Control)panel_TRP2_1).Size = new Size(231, 470);
		((Control)panel_TRP2_1).TabIndex = 24;
		((Control)tabTRP3_user).Controls.Add((Control)(object)panel_TRP3_3);
		((Control)tabTRP3_user).Controls.Add((Control)(object)panel_TRP3_2);
		((Control)tabTRP3_user).Controls.Add((Control)(object)panel_TRP3_1);
		tabTRP3_user.Location = new Point(4, 22);
		((Control)tabTRP3_user).Margin = new Padding(0);
		((Control)tabTRP3_user).Name = "tabTRP3_user";
		((Control)tabTRP3_user).Size = new Size(1060, 497);
		tabTRP3_user.TabIndex = 8;
		((Control)tabTRP3_user).Text = "tabTRP3_user";
		tabTRP3_user.UseVisualStyleBackColor = true;
		((Control)panel_TRP3_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_TRP3_3.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP3_3).Controls.Add((Control)(object)btnTRP3Back);
		((Control)panel_TRP3_3).Controls.Add((Control)(object)btnTRP3Next);
		((Control)panel_TRP3_3).Dock = (DockStyle)2;
		((Control)panel_TRP3_3).Location = new Point(0, 446);
		((Control)panel_TRP3_3).Margin = new Padding(0);
		((Control)panel_TRP3_3).Name = "panel_TRP3_3";
		((Control)panel_TRP3_3).Size = new Size(960, 51);
		((Control)panel_TRP3_3).TabIndex = 29;
		((Control)panel_TRP3_2).BackColor = Color.White;
		((Control)panel_TRP3_2).Controls.Add((Control)(object)buttonTRP3Resume);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)label_TRP3_comment);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)buttonTRP3Break);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)labelTRP3progressText);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)buttonTRP3ToBottom);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)buttonTRP3Next);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)buttonTRP3Previous);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)buttonTRP3ToTop);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)label_TRP3DisplayedPage);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)label_TRP3Page);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)comboBoxTRP3SelectWay);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)buttonTRP3Search);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)textBoxTRP3Search);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)listViewAddressList);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)labelTRP3MFP_Selected);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)label_TRP3_SelectedDevice);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)label17);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)pictureBox9);
		((Control)panel_TRP3_2).Controls.Add((Control)(object)label_TRP3Head);
		((Control)panel_TRP3_2).Location = new Point(234, 3);
		((Control)panel_TRP3_2).Name = "panel_TRP3_2";
		((Control)panel_TRP3_2).Size = new Size(725, 470);
		((Control)panel_TRP3_2).TabIndex = 28;
		((Control)buttonTRP3Resume).AutoSize = true;
		((ButtonBase)buttonTRP3Resume).ImeMode = (ImeMode)0;
		((Control)buttonTRP3Resume).Location = new Point(500, 182);
		((Control)buttonTRP3Resume).Name = "buttonTRP3Resume";
		((Control)buttonTRP3Resume).Size = new Size(65, 23);
		((Control)buttonTRP3Resume).TabIndex = 40;
		((Control)buttonTRP3Resume).Text = "btn3";
		((ButtonBase)buttonTRP3Resume).UseVisualStyleBackColor = true;
		((Control)buttonTRP3Resume).Visible = false;
		((Control)buttonTRP3Resume).Click += buttonResume_Click;
		((Control)label_TRP3_comment).AutoSize = true;
		((Control)label_TRP3_comment).Font = new Font("MS UI Gothic", 9f);
		label_TRP3_comment.ImeMode = (ImeMode)0;
		((Control)label_TRP3_comment).Location = new Point(44, 75);
		((Control)label_TRP3_comment).Name = "label_TRP3_comment";
		((Control)label_TRP3_comment).Size = new Size(51, 12);
		((Control)label_TRP3_comment).TabIndex = 41;
		((Control)label_TRP3_comment).Text = "comment";
		((Control)buttonTRP3Break).AutoSize = true;
		((ButtonBase)buttonTRP3Break).ImeMode = (ImeMode)0;
		((Control)buttonTRP3Break).Location = new Point(571, 182);
		((Control)buttonTRP3Break).Name = "buttonTRP3Break";
		((Control)buttonTRP3Break).Size = new Size(65, 23);
		((Control)buttonTRP3Break).TabIndex = 39;
		((Control)buttonTRP3Break).Text = "btn4";
		((ButtonBase)buttonTRP3Break).UseVisualStyleBackColor = true;
		((Control)buttonTRP3Break).Visible = false;
		((Control)buttonTRP3Break).Click += buttonTRP3Break_Click;
		labelTRP3progressText.ImeMode = (ImeMode)0;
		((Control)labelTRP3progressText).Location = new Point(387, 187);
		((Control)labelTRP3progressText).Name = "labelTRP3progressText";
		((Control)labelTRP3progressText).Size = new Size(249, 17);
		((Control)labelTRP3progressText).TabIndex = 38;
		((Control)labelTRP3progressText).Text = "label7";
		labelTRP3progressText.TextAlign = (ContentAlignment)4;
		((Control)buttonTRP3ToBottom).AutoSize = true;
		((ButtonBase)buttonTRP3ToBottom).ImeMode = (ImeMode)0;
		((Control)buttonTRP3ToBottom).Location = new Point(230, 182);
		((Control)buttonTRP3ToBottom).Name = "buttonTRP3ToBottom";
		((Control)buttonTRP3ToBottom).Size = new Size(30, 23);
		((Control)buttonTRP3ToBottom).TabIndex = 37;
		((Control)buttonTRP3ToBottom).Text = ">>";
		((ButtonBase)buttonTRP3ToBottom).UseVisualStyleBackColor = true;
		((Control)buttonTRP3ToBottom).Visible = false;
		((Control)buttonTRP3ToBottom).Click += buttonToBottom_Click;
		((Control)buttonTRP3Next).AutoSize = true;
		((ButtonBase)buttonTRP3Next).ImeMode = (ImeMode)0;
		((Control)buttonTRP3Next).Location = new Point(194, 182);
		((Control)buttonTRP3Next).Name = "buttonTRP3Next";
		((Control)buttonTRP3Next).Size = new Size(30, 23);
		((Control)buttonTRP3Next).TabIndex = 36;
		((Control)buttonTRP3Next).Text = ">";
		((ButtonBase)buttonTRP3Next).UseVisualStyleBackColor = true;
		((Control)buttonTRP3Next).Visible = false;
		((Control)buttonTRP3Next).Click += buttonNext_Click;
		((Control)buttonTRP3Previous).AutoSize = true;
		((ButtonBase)buttonTRP3Previous).ImeMode = (ImeMode)0;
		((Control)buttonTRP3Previous).Location = new Point(123, 182);
		((Control)buttonTRP3Previous).Name = "buttonTRP3Previous";
		((Control)buttonTRP3Previous).Size = new Size(30, 23);
		((Control)buttonTRP3Previous).TabIndex = 35;
		((Control)buttonTRP3Previous).Text = "<";
		((ButtonBase)buttonTRP3Previous).UseVisualStyleBackColor = true;
		((Control)buttonTRP3Previous).Visible = false;
		((Control)buttonTRP3Previous).Click += buttonPrevious_Click;
		((Control)buttonTRP3ToTop).AutoSize = true;
		((ButtonBase)buttonTRP3ToTop).ImeMode = (ImeMode)0;
		((Control)buttonTRP3ToTop).Location = new Point(87, 182);
		((Control)buttonTRP3ToTop).Name = "buttonTRP3ToTop";
		((Control)buttonTRP3ToTop).Size = new Size(30, 23);
		((Control)buttonTRP3ToTop).TabIndex = 34;
		((Control)buttonTRP3ToTop).Text = "<<";
		((ButtonBase)buttonTRP3ToTop).UseVisualStyleBackColor = true;
		((Control)buttonTRP3ToTop).Visible = false;
		((Control)buttonTRP3ToTop).Click += buttonToTop_Click;
		((Control)label_TRP3DisplayedPage).AutoSize = true;
		label_TRP3DisplayedPage.ImeMode = (ImeMode)0;
		((Control)label_TRP3DisplayedPage).Location = new Point(159, 187);
		((Control)label_TRP3DisplayedPage).Name = "label_TRP3DisplayedPage";
		((Control)label_TRP3DisplayedPage).Size = new Size(35, 12);
		((Control)label_TRP3DisplayedPage).TabIndex = 33;
		((Control)label_TRP3DisplayedPage).Text = "label6";
		((Control)label_TRP3Page).AutoSize = true;
		label_TRP3Page.ImeMode = (ImeMode)0;
		((Control)label_TRP3Page).Location = new Point(50, 187);
		((Control)label_TRP3Page).Name = "label_TRP3Page";
		((Control)label_TRP3Page).Size = new Size(35, 12);
		((Control)label_TRP3Page).TabIndex = 32;
		((Control)label_TRP3Page).Text = "label5";
		((ListControl)comboBoxTRP3SelectWay).FormattingEnabled = true;
		((Control)comboBoxTRP3SelectWay).Location = new Point(49, 149);
		((Control)comboBoxTRP3SelectWay).Name = "comboBoxTRP3SelectWay";
		((Control)comboBoxTRP3SelectWay).Size = new Size(160, 20);
		((Control)comboBoxTRP3SelectWay).TabIndex = 31;
		((Control)buttonTRP3Search).Anchor = (AnchorStyles)9;
		((Control)buttonTRP3Search).AutoSize = true;
		((ButtonBase)buttonTRP3Search).ImeMode = (ImeMode)0;
		((Control)buttonTRP3Search).Location = new Point(538, 148);
		((Control)buttonTRP3Search).Name = "buttonTRP3Search";
		((Control)buttonTRP3Search).Size = new Size(98, 23);
		((Control)buttonTRP3Search).TabIndex = 30;
		((Control)buttonTRP3Search).Text = "button2";
		((ButtonBase)buttonTRP3Search).UseVisualStyleBackColor = true;
		((Control)buttonTRP3Search).Click += buttonTRP3Search_Click;
		((Control)textBoxTRP3Search).Location = new Point(214, 150);
		((Control)textBoxTRP3Search).Name = "textBoxTRP3Search";
		((Control)textBoxTRP3Search).Size = new Size(319, 19);
		((Control)textBoxTRP3Search).TabIndex = 29;
		((Control)textBoxTRP3Search).KeyPress += new KeyPressEventHandler(textBoxSearch_KeyPress);
		listViewAddressList.Activation = (ItemActivation)1;
		listViewAddressList.AutoArrange = false;
		listViewAddressList.FullRowSelect = true;
		listViewAddressList.GridLines = true;
		listViewAddressList.HeaderStyle = (ColumnHeaderStyle)1;
		listViewAddressList.HideSelection = false;
		((Control)listViewAddressList).Location = new Point(49, 214);
		listViewAddressList.MultiSelect = false;
		((Control)listViewAddressList).Name = "listViewAddressList";
		listViewAddressList.OwnerDraw = true;
		listViewAddressList.ShowGroups = false;
		((Control)listViewAddressList).Size = new Size(587, 210);
		((Control)listViewAddressList).TabIndex = 27;
		listViewAddressList.UseCompatibleStateImageBehavior = false;
		listViewAddressList.View = (View)1;
		listViewAddressList.DrawColumnHeader += new DrawListViewColumnHeaderEventHandler(listViewAddressList_DrawColumnHeader);
		listViewAddressList.DrawItem += new DrawListViewItemEventHandler(listViewAddressList_DrawItem);
		listViewAddressList.ItemSelectionChanged += new ListViewItemSelectionChangedEventHandler(listViewAddressList_ItemSelectionChanged);
		((Control)labelTRP3MFP_Selected).AutoSize = true;
		labelTRP3MFP_Selected.ImeMode = (ImeMode)0;
		((Control)labelTRP3MFP_Selected).Location = new Point(149, 119);
		((Control)labelTRP3MFP_Selected).Name = "labelTRP3MFP_Selected";
		((Control)labelTRP3MFP_Selected).Size = new Size(0, 12);
		((Control)labelTRP3MFP_Selected).TabIndex = 25;
		((Control)label_TRP3_SelectedDevice).AutoSize = true;
		label_TRP3_SelectedDevice.ImeMode = (ImeMode)0;
		((Control)label_TRP3_SelectedDevice).Location = new Point(50, 119);
		((Control)label_TRP3_SelectedDevice).Name = "label_TRP3_SelectedDevice";
		((Control)label_TRP3_SelectedDevice).Size = new Size(35, 12);
		((Control)label_TRP3_SelectedDevice).TabIndex = 24;
		((Control)label_TRP3_SelectedDevice).Text = "label3";
		((Control)label17).Anchor = (AnchorStyles)13;
		label17.BorderStyle = (BorderStyle)2;
		label17.ImeMode = (ImeMode)0;
		((Control)label17).Location = new Point(47, 428);
		((Control)label17).Name = "label17";
		((Control)label17).Size = new Size(481, 1);
		((Control)label17).TabIndex = 26;
		pictureBox9.Image = (Image)(object)Resources.Line;
		pictureBox9.ImeMode = (ImeMode)0;
		((Control)pictureBox9).Location = new Point(39, 48);
		((Control)pictureBox9).Margin = new Padding(1);
		((Control)pictureBox9).Name = "pictureBox9";
		((Control)pictureBox9).Size = new Size(689, 10);
		pictureBox9.TabIndex = 1;
		pictureBox9.TabStop = false;
		((Control)label_TRP3Head).AutoSize = true;
		((Control)label_TRP3Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		label_TRP3Head.ImeMode = (ImeMode)0;
		((Control)label_TRP3Head).Location = new Point(40, 21);
		((Control)label_TRP3Head).Name = "label_TRP3Head";
		((Control)label_TRP3Head).Size = new Size(98, 16);
		((Control)label_TRP3Head).TabIndex = 0;
		((Control)label_TRP3Head).Text = "Select User";
		((Control)panel_TRP3_1).BackColor = SystemColors.Control;
		panel_TRP3_1.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP3_1).Location = new Point(0, 3);
		((Control)panel_TRP3_1).Margin = new Padding(0);
		((Control)panel_TRP3_1).Name = "panel_TRP3_1";
		((Control)panel_TRP3_1).Size = new Size(231, 470);
		((Control)panel_TRP3_1).TabIndex = 27;
		((Control)tabTRP4_analyze).Controls.Add((Control)(object)panel_TRP4_3);
		((Control)tabTRP4_analyze).Controls.Add((Control)(object)panel_TRP4_2);
		((Control)tabTRP4_analyze).Controls.Add((Control)(object)panel_TRP4_1);
		tabTRP4_analyze.Location = new Point(4, 22);
		((Control)tabTRP4_analyze).Margin = new Padding(0);
		((Control)tabTRP4_analyze).Name = "tabTRP4_analyze";
		((Control)tabTRP4_analyze).Size = new Size(1060, 497);
		tabTRP4_analyze.TabIndex = 9;
		((Control)tabTRP4_analyze).Text = "tabTRP4_analyze";
		tabTRP4_analyze.UseVisualStyleBackColor = true;
		((Control)panel_TRP4_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_TRP4_3.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP4_3).Dock = (DockStyle)2;
		((Control)panel_TRP4_3).Location = new Point(0, 446);
		((Control)panel_TRP4_3).Margin = new Padding(0);
		((Control)panel_TRP4_3).Name = "panel_TRP4_3";
		((Control)panel_TRP4_3).Size = new Size(960, 51);
		((Control)panel_TRP4_3).TabIndex = 23;
		((Control)panel_TRP4_2).BackColor = Color.White;
		panel_TRP4_2.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP4_2).Controls.Add((Control)(object)progressBarTRP4);
		((Control)panel_TRP4_2).Controls.Add((Control)(object)label_TRP4_progress);
		((Control)panel_TRP4_2).Controls.Add((Control)(object)pictureBox10);
		((Control)panel_TRP4_2).Controls.Add((Control)(object)label_TRP4Head);
		((Control)panel_TRP4_2).Controls.Add((Control)(object)label_TRP4_comment);
		((Control)panel_TRP4_2).Location = new Point(234, 3);
		((Control)panel_TRP4_2).Name = "panel_TRP4_2";
		((Control)panel_TRP4_2).Size = new Size(725, 470);
		((Control)panel_TRP4_2).TabIndex = 22;
		progressBarTRP4.ImeMode = (ImeMode)0;
		((Control)progressBarTRP4).Location = new Point(44, 145);
		progressBarTRP4.Maximum = 7;
		((Control)progressBarTRP4).Name = "progressBarTRP4";
		((Control)progressBarTRP4).Size = new Size(576, 23);
		((Control)progressBarTRP4).TabIndex = 5;
		((Control)label_TRP4_progress).AutoSize = true;
		((Control)label_TRP4_progress).Font = new Font("MS UI Gothic", 9f);
		label_TRP4_progress.ImeMode = (ImeMode)0;
		((Control)label_TRP4_progress).Location = new Point(46, 130);
		((Control)label_TRP4_progress).Name = "label_TRP4_progress";
		((Control)label_TRP4_progress).Size = new Size(41, 12);
		((Control)label_TRP4_progress).TabIndex = 4;
		((Control)label_TRP4_progress).Text = "label28";
		pictureBox10.Image = (Image)(object)Resources.Line;
		pictureBox10.ImeMode = (ImeMode)0;
		((Control)pictureBox10).Location = new Point(39, 48);
		((Control)pictureBox10).Margin = new Padding(1);
		((Control)pictureBox10).Name = "pictureBox10";
		((Control)pictureBox10).Size = new Size(687, 10);
		pictureBox10.TabIndex = 1;
		pictureBox10.TabStop = false;
		((Control)label_TRP4Head).AutoSize = true;
		((Control)label_TRP4Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		label_TRP4Head.ImeMode = (ImeMode)0;
		((Control)label_TRP4Head).Location = new Point(40, 21);
		((Control)label_TRP4Head).Name = "label_TRP4Head";
		((Control)label_TRP4Head).Size = new Size(67, 16);
		((Control)label_TRP4Head).TabIndex = 0;
		((Control)label_TRP4Head).Text = "Analyze";
		((Control)label_TRP4_comment).AutoSize = true;
		((Control)label_TRP4_comment).Font = new Font("MS UI Gothic", 9f);
		label_TRP4_comment.ImeMode = (ImeMode)0;
		((Control)label_TRP4_comment).Location = new Point(45, 75);
		((Control)label_TRP4_comment).Name = "label_TRP4_comment";
		((Control)label_TRP4_comment).Size = new Size(103, 12);
		((Control)label_TRP4_comment).TabIndex = 2;
		((Control)label_TRP4_comment).Text = "Analyzing message";
		((Control)panel_TRP4_1).BackColor = SystemColors.Control;
		panel_TRP4_1.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP4_1).Location = new Point(0, 3);
		((Control)panel_TRP4_1).Margin = new Padding(0);
		((Control)panel_TRP4_1).Name = "panel_TRP4_1";
		((Control)panel_TRP4_1).Size = new Size(231, 470);
		((Control)panel_TRP4_1).TabIndex = 21;
		((Control)tabTRP5_result).Controls.Add((Control)(object)panel_TRP5_3);
		((Control)tabTRP5_result).Controls.Add((Control)(object)panel_TRP5_2);
		((Control)tabTRP5_result).Controls.Add((Control)(object)panel_TRP5_1);
		tabTRP5_result.Location = new Point(4, 22);
		((Control)tabTRP5_result).Name = "tabTRP5_result";
		((Control)tabTRP5_result).Size = new Size(1060, 497);
		tabTRP5_result.TabIndex = 12;
		((Control)tabTRP5_result).Text = "tabTRP5_result";
		tabTRP5_result.UseVisualStyleBackColor = true;
		((Control)panel_TRP5_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_TRP5_3.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP5_3).Controls.Add((Control)(object)btnTRP5Back);
		((Control)panel_TRP5_3).Controls.Add((Control)(object)btnTRP5Next);
		((Control)panel_TRP5_3).Dock = (DockStyle)2;
		((Control)panel_TRP5_3).Location = new Point(0, 446);
		((Control)panel_TRP5_3).Margin = new Padding(0);
		((Control)panel_TRP5_3).Name = "panel_TRP5_3";
		((Control)panel_TRP5_3).Size = new Size(960, 51);
		((Control)panel_TRP5_3).TabIndex = 24;
		((Control)panel_TRP5_2).BackColor = Color.White;
		panel_TRP5_2.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP5_2).Controls.Add((Control)(object)label_TRP5_comment);
		((Control)panel_TRP5_2).Controls.Add((Control)(object)pictureBox13);
		((Control)panel_TRP5_2).Controls.Add((Control)(object)label_TRP5Head);
		((Control)panel_TRP5_2).Controls.Add((Control)(object)panel40);
		((Control)panel_TRP5_2).Location = new Point(234, 3);
		((Control)panel_TRP5_2).Name = "panel_TRP5_2";
		((Control)panel_TRP5_2).Size = new Size(725, 470);
		((Control)panel_TRP5_2).TabIndex = 23;
		((Control)label_TRP5_comment).AutoSize = true;
		((Control)label_TRP5_comment).Font = new Font("MS UI Gothic", 9f);
		label_TRP5_comment.ImeMode = (ImeMode)0;
		((Control)label_TRP5_comment).Location = new Point(45, 77);
		((Control)label_TRP5_comment).Name = "label_TRP5_comment";
		((Control)label_TRP5_comment).Size = new Size(119, 12);
		((Control)label_TRP5_comment).TabIndex = 8;
		((Control)label_TRP5_comment).Text = "Confirmation message";
		pictureBox13.Image = (Image)(object)Resources.Line;
		pictureBox13.ImeMode = (ImeMode)0;
		((Control)pictureBox13).Location = new Point(39, 48);
		((Control)pictureBox13).Margin = new Padding(1);
		((Control)pictureBox13).Name = "pictureBox13";
		((Control)pictureBox13).Size = new Size(687, 10);
		pictureBox13.TabIndex = 1;
		pictureBox13.TabStop = false;
		((Control)label_TRP5Head).AutoSize = true;
		((Control)label_TRP5Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		label_TRP5Head.ImeMode = (ImeMode)0;
		((Control)label_TRP5Head).Location = new Point(40, 21);
		((Control)label_TRP5Head).Name = "label_TRP5Head";
		((Control)label_TRP5Head).Size = new Size(56, 16);
		((Control)label_TRP5Head).TabIndex = 0;
		((Control)label_TRP5Head).Text = "Result";
		panel40.BorderStyle = (BorderStyle)2;
		((Control)panel40).Controls.Add((Control)(object)richTextBoxTRP5);
		((Control)panel40).Font = new Font("MS UI Gothic", 9f);
		((Control)panel40).Location = new Point(44, 117);
		((Control)panel40).Name = "panel40";
		((Control)panel40).Size = new Size(603, 316);
		((Control)panel40).TabIndex = 6;
		((TextBoxBase)richTextBoxTRP5).BorderStyle = (BorderStyle)0;
		richTextBoxTRP5.DetectUrls = false;
		((Control)richTextBoxTRP5).Location = new Point(3, 3);
		((Control)richTextBoxTRP5).Name = "richTextBoxTRP5";
		((Control)richTextBoxTRP5).Size = new Size(590, 306);
		((Control)richTextBoxTRP5).TabIndex = 2;
		((Control)richTextBoxTRP5).Text = "";
		((Control)panel_TRP5_1).BackColor = SystemColors.Control;
		panel_TRP5_1.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP5_1).Location = new Point(0, 3);
		((Control)panel_TRP5_1).Margin = new Padding(0);
		((Control)panel_TRP5_1).Name = "panel_TRP5_1";
		((Control)panel_TRP5_1).Size = new Size(231, 470);
		((Control)panel_TRP5_1).TabIndex = 22;
		((Control)tabTRP6_setupSelect).Controls.Add((Control)(object)panel_TRP6_3);
		((Control)tabTRP6_setupSelect).Controls.Add((Control)(object)panel_TRP6_2);
		((Control)tabTRP6_setupSelect).Controls.Add((Control)(object)panel_TRP6_1);
		tabTRP6_setupSelect.Location = new Point(4, 22);
		((Control)tabTRP6_setupSelect).Name = "tabTRP6_setupSelect";
		((Control)tabTRP6_setupSelect).Size = new Size(1060, 497);
		tabTRP6_setupSelect.TabIndex = 14;
		((Control)tabTRP6_setupSelect).Text = "tabTRP6_setupSelect";
		tabTRP6_setupSelect.UseVisualStyleBackColor = true;
		((Control)panel_TRP6_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_TRP6_3.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP6_3).Controls.Add((Control)(object)btnTRP6Back);
		((Control)panel_TRP6_3).Controls.Add((Control)(object)btnTRP6Next);
		((Control)panel_TRP6_3).Dock = (DockStyle)2;
		((Control)panel_TRP6_3).Location = new Point(0, 446);
		((Control)panel_TRP6_3).Margin = new Padding(0);
		((Control)panel_TRP6_3).Name = "panel_TRP6_3";
		((Control)panel_TRP6_3).Size = new Size(960, 51);
		((Control)panel_TRP6_3).TabIndex = 18;
		((Control)panel_TRP6_2).BackColor = Color.White;
		panel_TRP6_2.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP6_2).Controls.Add((Control)(object)label_TRP6_SelectFolder);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)label_TRP6_SelectNonSharedFolder);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)cmbTRP6Folder);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)radioButtonTRP6selectNonSharedFolder);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)radioButtonTRP6selectExistFolder);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)radioButtonTRP6createNewFolder);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)label_TRP6_Folder);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)buttonTRP6SelectFolder);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)textBoxTRP6FolderPath);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)label_TRP6_FolderPath);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)textBoxTRP6FolderName);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)label_TRP6_FolderName);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)label_TRP6_NonSharedFolderPath);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)buttonTRP6SelectNonSharedFolder);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)textBoxTRP6NonSharedFolderPath);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)pictureBox16);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)textBoxTRP6SharedName);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)label_TRP6_SharedName);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)label_TRP6Head);
		((Control)panel_TRP6_2).Controls.Add((Control)(object)label_TRP6_comment);
		((Control)panel_TRP6_2).Location = new Point(234, 3);
		((Control)panel_TRP6_2).Name = "panel_TRP6_2";
		((Control)panel_TRP6_2).Size = new Size(725, 470);
		((Control)panel_TRP6_2).TabIndex = 19;
		((Control)label_TRP6_SelectFolder).AutoSize = true;
		((Control)label_TRP6_SelectFolder).Enabled = false;
		label_TRP6_SelectFolder.ImeMode = (ImeMode)0;
		((Control)label_TRP6_SelectFolder).Location = new Point(56, 355);
		((Control)label_TRP6_SelectFolder).Name = "label_TRP6_SelectFolder";
		((Control)label_TRP6_SelectFolder).Size = new Size(148, 12);
		((Control)label_TRP6_SelectFolder).TabIndex = 16;
		((Control)label_TRP6_SelectFolder).Text = "Select folder for destination";
		((Control)label_TRP6_SelectNonSharedFolder).AutoSize = true;
		((Control)label_TRP6_SelectNonSharedFolder).Enabled = false;
		label_TRP6_SelectNonSharedFolder.ImeMode = (ImeMode)0;
		((Control)label_TRP6_SelectNonSharedFolder).Location = new Point(56, 246);
		((Control)label_TRP6_SelectNonSharedFolder).Name = "label_TRP6_SelectNonSharedFolder";
		((Control)label_TRP6_SelectNonSharedFolder).Size = new Size(130, 12);
		((Control)label_TRP6_SelectNonSharedFolder).TabIndex = 16;
		((Control)label_TRP6_SelectNonSharedFolder).Text = "Select non shared folder";
		cmbTRP6Folder.DropDownStyle = (ComboBoxStyle)2;
		cmbTRP6Folder.DropDownWidth = 401;
		((Control)cmbTRP6Folder).Enabled = false;
		((ListControl)cmbTRP6Folder).FormattingEnabled = true;
		((Control)cmbTRP6Folder).Location = new Point(280, 380);
		((Control)cmbTRP6Folder).Name = "cmbTRP6Folder";
		((Control)cmbTRP6Folder).Size = new Size(343, 20);
		cmbTRP6Folder.Sorted = true;
		((Control)cmbTRP6Folder).TabIndex = 15;
		((Control)radioButtonTRP6selectNonSharedFolder).AutoSize = true;
		((ButtonBase)radioButtonTRP6selectNonSharedFolder).ImeMode = (ImeMode)0;
		((Control)radioButtonTRP6selectNonSharedFolder).Location = new Point(50, 224);
		((Control)radioButtonTRP6selectNonSharedFolder).Name = "radioButtonTRP6selectNonSharedFolder";
		((Control)radioButtonTRP6selectNonSharedFolder).Size = new Size(114, 16);
		((Control)radioButtonTRP6selectNonSharedFolder).TabIndex = 13;
		radioButtonTRP6selectNonSharedFolder.TabStop = true;
		((Control)radioButtonTRP6selectNonSharedFolder).Text = "Create new folder";
		((ButtonBase)radioButtonTRP6selectNonSharedFolder).UseVisualStyleBackColor = true;
		radioButtonTRP6selectNonSharedFolder.CheckedChanged += radioButtonTRP6createNewFolder_CheckedChanged;
		((Control)radioButtonTRP6selectExistFolder).AutoSize = true;
		((ButtonBase)radioButtonTRP6selectExistFolder).ImeMode = (ImeMode)0;
		((Control)radioButtonTRP6selectExistFolder).Location = new Point(50, 333);
		((Control)radioButtonTRP6selectExistFolder).Name = "radioButtonTRP6selectExistFolder";
		((Control)radioButtonTRP6selectExistFolder).Size = new Size(117, 16);
		((Control)radioButtonTRP6selectExistFolder).TabIndex = 14;
		((Control)radioButtonTRP6selectExistFolder).Text = "Select exist folder";
		((ButtonBase)radioButtonTRP6selectExistFolder).UseVisualStyleBackColor = true;
		radioButtonTRP6selectExistFolder.CheckedChanged += radioButtonTRP6createNewFolder_CheckedChanged;
		((Control)radioButtonTRP6createNewFolder).AutoSize = true;
		radioButtonTRP6createNewFolder.Checked = true;
		((ButtonBase)radioButtonTRP6createNewFolder).ImeMode = (ImeMode)0;
		((Control)radioButtonTRP6createNewFolder).Location = new Point(50, 132);
		((Control)radioButtonTRP6createNewFolder).Name = "radioButtonTRP6createNewFolder";
		((Control)radioButtonTRP6createNewFolder).Size = new Size(114, 16);
		((Control)radioButtonTRP6createNewFolder).TabIndex = 13;
		radioButtonTRP6createNewFolder.TabStop = true;
		((Control)radioButtonTRP6createNewFolder).Text = "Create new folder";
		((ButtonBase)radioButtonTRP6createNewFolder).UseVisualStyleBackColor = true;
		radioButtonTRP6createNewFolder.CheckedChanged += radioButtonTRP6createNewFolder_CheckedChanged;
		((Control)label_TRP6_Folder).AutoSize = true;
		((Control)label_TRP6_Folder).Enabled = false;
		((Control)label_TRP6_Folder).ForeColor = Color.Blue;
		label_TRP6_Folder.ImeMode = (ImeMode)0;
		((Control)label_TRP6_Folder).Location = new Point(56, 384);
		((Control)label_TRP6_Folder).Name = "label_TRP6_Folder";
		((Control)label_TRP6_Folder).Size = new Size(37, 12);
		((Control)label_TRP6_Folder).TabIndex = 12;
		((Control)label_TRP6_Folder).Text = "Folder";
		((Control)buttonTRP6SelectFolder).AutoSize = true;
		((Control)buttonTRP6SelectFolder).Font = new Font("MS UI Gothic", 9f);
		((ButtonBase)buttonTRP6SelectFolder).ImeMode = (ImeMode)0;
		((Control)buttonTRP6SelectFolder).Location = new Point(547, 157);
		((Control)buttonTRP6SelectFolder).Name = "buttonTRP6SelectFolder";
		((Control)buttonTRP6SelectFolder).Size = new Size(105, 22);
		((Control)buttonTRP6SelectFolder).TabIndex = 5;
		((Control)buttonTRP6SelectFolder).Text = "参照";
		((ButtonBase)buttonTRP6SelectFolder).UseVisualStyleBackColor = true;
		((Control)buttonTRP6SelectFolder).Click += buttonTRP6SelectFolder_Click;
		((Control)textBoxTRP6FolderPath).Font = new Font("MS UI Gothic", 9f);
		((Control)textBoxTRP6FolderPath).Location = new Point(280, 158);
		((Control)textBoxTRP6FolderPath).Name = "textBoxTRP6FolderPath";
		((Control)textBoxTRP6FolderPath).Size = new Size(261, 19);
		((Control)textBoxTRP6FolderPath).TabIndex = 4;
		((Control)textBoxTRP6FolderPath).Enter += textBoxTRP6FolderPath_Enter;
		((Control)textBoxTRP6FolderPath).Leave += textBoxTRP6FolderPath_Leave;
		((Control)label_TRP6_FolderPath).AutoSize = true;
		((Control)label_TRP6_FolderPath).Font = new Font("MS UI Gothic", 9f);
		((Control)label_TRP6_FolderPath).ForeColor = Color.Blue;
		label_TRP6_FolderPath.ImeMode = (ImeMode)0;
		((Control)label_TRP6_FolderPath).Location = new Point(56, 160);
		((Control)label_TRP6_FolderPath).Name = "label_TRP6_FolderPath";
		((Control)label_TRP6_FolderPath).Size = new Size(64, 12);
		((Control)label_TRP6_FolderPath).TabIndex = 11;
		((Control)label_TRP6_FolderPath).Text = "Folder Path";
		((Control)textBoxTRP6FolderName).Font = new Font("MS UI Gothic", 9f);
		((Control)textBoxTRP6FolderName).Location = new Point(280, 186);
		((Control)textBoxTRP6FolderName).Name = "textBoxTRP6FolderName";
		((Control)textBoxTRP6FolderName).Size = new Size(373, 19);
		((Control)textBoxTRP6FolderName).TabIndex = 3;
		((Control)textBoxTRP6FolderName).Text = "ScanDoc";
		((Control)textBoxTRP6FolderName).Enter += textBoxTRP6FolderName_Enter;
		((Control)textBoxTRP6FolderName).Leave += textBoxTRP6FolderName_Leave;
		((Control)label_TRP6_FolderName).AutoSize = true;
		((Control)label_TRP6_FolderName).Font = new Font("MS UI Gothic", 9f);
		((Control)label_TRP6_FolderName).ForeColor = Color.Blue;
		label_TRP6_FolderName.ImeMode = (ImeMode)0;
		((Control)label_TRP6_FolderName).Location = new Point(56, 188);
		((Control)label_TRP6_FolderName).Name = "label_TRP6_FolderName";
		((Control)label_TRP6_FolderName).Size = new Size(66, 12);
		((Control)label_TRP6_FolderName).TabIndex = 9;
		((Control)label_TRP6_FolderName).Text = "FolderName";
		((Control)label_TRP6_NonSharedFolderPath).AutoSize = true;
		((Control)label_TRP6_NonSharedFolderPath).Enabled = false;
		((Control)label_TRP6_NonSharedFolderPath).Font = new Font("MS UI Gothic", 9f);
		((Control)label_TRP6_NonSharedFolderPath).ForeColor = Color.Blue;
		label_TRP6_NonSharedFolderPath.ImeMode = (ImeMode)0;
		((Control)label_TRP6_NonSharedFolderPath).Location = new Point(56, 270);
		((Control)label_TRP6_NonSharedFolderPath).Name = "label_TRP6_NonSharedFolderPath";
		((Control)label_TRP6_NonSharedFolderPath).Size = new Size(64, 12);
		((Control)label_TRP6_NonSharedFolderPath).TabIndex = 11;
		((Control)label_TRP6_NonSharedFolderPath).Text = "Folder Path";
		((Control)buttonTRP6SelectNonSharedFolder).AutoSize = true;
		((Control)buttonTRP6SelectNonSharedFolder).Enabled = false;
		((Control)buttonTRP6SelectNonSharedFolder).Font = new Font("MS UI Gothic", 9f);
		((ButtonBase)buttonTRP6SelectNonSharedFolder).ImeMode = (ImeMode)0;
		((Control)buttonTRP6SelectNonSharedFolder).Location = new Point(547, 268);
		((Control)buttonTRP6SelectNonSharedFolder).Name = "buttonTRP6SelectNonSharedFolder";
		((Control)buttonTRP6SelectNonSharedFolder).Size = new Size(105, 22);
		((Control)buttonTRP6SelectNonSharedFolder).TabIndex = 5;
		((Control)buttonTRP6SelectNonSharedFolder).Text = "参照";
		((ButtonBase)buttonTRP6SelectNonSharedFolder).UseVisualStyleBackColor = true;
		((Control)buttonTRP6SelectNonSharedFolder).Click += buttonTRP6SelectNonSharedFolder_Click;
		((Control)textBoxTRP6NonSharedFolderPath).Enabled = false;
		((Control)textBoxTRP6NonSharedFolderPath).Font = new Font("MS UI Gothic", 9f);
		((Control)textBoxTRP6NonSharedFolderPath).Location = new Point(280, 268);
		((Control)textBoxTRP6NonSharedFolderPath).Name = "textBoxTRP6NonSharedFolderPath";
		((Control)textBoxTRP6NonSharedFolderPath).Size = new Size(261, 19);
		((Control)textBoxTRP6NonSharedFolderPath).TabIndex = 4;
		((Control)textBoxTRP6NonSharedFolderPath).Enter += textBoxTRP6NonSharedFolderPath_Enter;
		((Control)textBoxTRP6NonSharedFolderPath).Leave += textBoxTRP6NonSharedFolderPath_Leave;
		pictureBox16.Image = (Image)(object)Resources.Line;
		pictureBox16.ImeMode = (ImeMode)0;
		((Control)pictureBox16).Location = new Point(39, 48);
		((Control)pictureBox16).Margin = new Padding(1);
		((Control)pictureBox16).Name = "pictureBox16";
		((Control)pictureBox16).Size = new Size(689, 10);
		pictureBox16.TabIndex = 1;
		pictureBox16.TabStop = false;
		((Control)textBoxTRP6SharedName).Enabled = false;
		((Control)textBoxTRP6SharedName).Font = new Font("MS UI Gothic", 9f);
		((Control)textBoxTRP6SharedName).Location = new Point(280, 298);
		((Control)textBoxTRP6SharedName).Name = "textBoxTRP6SharedName";
		((Control)textBoxTRP6SharedName).Size = new Size(371, 19);
		((Control)textBoxTRP6SharedName).TabIndex = 4;
		((Control)textBoxTRP6SharedName).Enter += textBoxTRP6SharedName_Enter;
		((Control)textBoxTRP6SharedName).Leave += textBoxTRP6SharedName_Leave;
		((Control)label_TRP6_SharedName).AutoSize = true;
		((Control)label_TRP6_SharedName).Enabled = false;
		((Control)label_TRP6_SharedName).Font = new Font("MS UI Gothic", 9f);
		((Control)label_TRP6_SharedName).ForeColor = Color.Blue;
		label_TRP6_SharedName.ImeMode = (ImeMode)0;
		((Control)label_TRP6_SharedName).Location = new Point(56, 300);
		((Control)label_TRP6_SharedName).Name = "label_TRP6_SharedName";
		((Control)label_TRP6_SharedName).Size = new Size(73, 12);
		((Control)label_TRP6_SharedName).TabIndex = 11;
		((Control)label_TRP6_SharedName).Text = "Shared Name";
		((Control)label_TRP6Head).AutoSize = true;
		((Control)label_TRP6Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		label_TRP6Head.ImeMode = (ImeMode)0;
		((Control)label_TRP6Head).Location = new Point(40, 21);
		((Control)label_TRP6Head).Name = "label_TRP6Head";
		((Control)label_TRP6Head).Size = new Size(109, 16);
		((Control)label_TRP6Head).TabIndex = 0;
		((Control)label_TRP6Head).Text = "CreateFolder";
		((Control)label_TRP6_comment).AutoSize = true;
		((Control)label_TRP6_comment).Font = new Font("MS UI Gothic", 9f);
		label_TRP6_comment.ImeMode = (ImeMode)0;
		((Control)label_TRP6_comment).Location = new Point(45, 75);
		((Control)label_TRP6_comment).Name = "label_TRP6_comment";
		((Control)label_TRP6_comment).Size = new Size(125, 12);
		((Control)label_TRP6_comment).TabIndex = 2;
		((Control)label_TRP6_comment).Text = "Folder setting message";
		((Control)panel_TRP6_1).BackColor = SystemColors.Control;
		panel_TRP6_1.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP6_1).Location = new Point(0, 3);
		((Control)panel_TRP6_1).Margin = new Padding(0);
		((Control)panel_TRP6_1).Name = "panel_TRP6_1";
		((Control)panel_TRP6_1).Size = new Size(231, 470);
		((Control)panel_TRP6_1).TabIndex = 23;
		((Control)tabTRP7_shareFolder).Controls.Add((Control)(object)panel_TRP7_3);
		((Control)tabTRP7_shareFolder).Controls.Add((Control)(object)panel_TRP7_2);
		((Control)tabTRP7_shareFolder).Controls.Add((Control)(object)panel_TRP7_1);
		tabTRP7_shareFolder.Location = new Point(4, 22);
		((Control)tabTRP7_shareFolder).Margin = new Padding(0);
		((Control)tabTRP7_shareFolder).Name = "tabTRP7_shareFolder";
		((Control)tabTRP7_shareFolder).Size = new Size(1060, 497);
		tabTRP7_shareFolder.TabIndex = 10;
		((Control)tabTRP7_shareFolder).Text = "tabTRP7_shareFolder";
		tabTRP7_shareFolder.UseVisualStyleBackColor = true;
		((Control)panel_TRP7_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_TRP7_3.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP7_3).Controls.Add((Control)(object)btnTRP7Back);
		((Control)panel_TRP7_3).Controls.Add((Control)(object)btnTRP7Next);
		((Control)panel_TRP7_3).Dock = (DockStyle)2;
		((Control)panel_TRP7_3).Location = new Point(0, 446);
		((Control)panel_TRP7_3).Margin = new Padding(0);
		((Control)panel_TRP7_3).Name = "panel_TRP7_3";
		((Control)panel_TRP7_3).Size = new Size(960, 51);
		((Control)panel_TRP7_3).TabIndex = 21;
		((Control)panel_TRP7_2).BackColor = Color.White;
		panel_TRP7_2.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP7_2).Controls.Add((Control)(object)cmbTRP7PcUser);
		((Control)panel_TRP7_2).Controls.Add((Control)(object)label_TRP7_UserName);
		((Control)panel_TRP7_2).Controls.Add((Control)(object)label_TRP7_PasswordConfirm);
		((Control)panel_TRP7_2).Controls.Add((Control)(object)textBoxTRP7PassConfirm);
		((Control)panel_TRP7_2).Controls.Add((Control)(object)textBoxTRP7Pass);
		((Control)panel_TRP7_2).Controls.Add((Control)(object)label_TRP7_Password);
		((Control)panel_TRP7_2).Controls.Add((Control)(object)pictureBox12);
		((Control)panel_TRP7_2).Controls.Add((Control)(object)label_TRP7Head);
		((Control)panel_TRP7_2).Controls.Add((Control)(object)label_TRP7_comment);
		((Control)panel_TRP7_2).Location = new Point(234, 3);
		((Control)panel_TRP7_2).Name = "panel_TRP7_2";
		((Control)panel_TRP7_2).Size = new Size(725, 470);
		((Control)panel_TRP7_2).TabIndex = 22;
		cmbTRP7PcUser.DropDownStyle = (ComboBoxStyle)2;
		((Control)cmbTRP7PcUser).Enabled = false;
		((Control)cmbTRP7PcUser).Font = new Font("MS UI Gothic", 9f);
		((ListControl)cmbTRP7PcUser).FormattingEnabled = true;
		((Control)cmbTRP7PcUser).Location = new Point(255, 125);
		((Control)cmbTRP7PcUser).Name = "cmbTRP7PcUser";
		((Control)cmbTRP7PcUser).Size = new Size(388, 20);
		((Control)cmbTRP7PcUser).TabIndex = 25;
		((Control)label_TRP7_UserName).AutoSize = true;
		((Control)label_TRP7_UserName).Font = new Font("MS UI Gothic", 9f);
		((Control)label_TRP7_UserName).ForeColor = Color.Blue;
		label_TRP7_UserName.ImeMode = (ImeMode)0;
		((Control)label_TRP7_UserName).Location = new Point(47, 128);
		((Control)label_TRP7_UserName).Name = "label_TRP7_UserName";
		((Control)label_TRP7_UserName).Size = new Size(58, 12);
		((Control)label_TRP7_UserName).TabIndex = 23;
		((Control)label_TRP7_UserName).Text = "UserName";
		((Control)label_TRP7_PasswordConfirm).AutoSize = true;
		((Control)label_TRP7_PasswordConfirm).Font = new Font("MS UI Gothic", 9f);
		((Control)label_TRP7_PasswordConfirm).ForeColor = Color.Blue;
		label_TRP7_PasswordConfirm.ImeMode = (ImeMode)0;
		((Control)label_TRP7_PasswordConfirm).Location = new Point(47, 198);
		((Control)label_TRP7_PasswordConfirm).Name = "label_TRP7_PasswordConfirm";
		((Control)label_TRP7_PasswordConfirm).Size = new Size(102, 12);
		((Control)label_TRP7_PasswordConfirm).TabIndex = 22;
		((Control)label_TRP7_PasswordConfirm).Text = "Password(Confirm)";
		((Control)textBoxTRP7PassConfirm).Font = new Font("MS UI Gothic", 9f);
		((Control)textBoxTRP7PassConfirm).Location = new Point(255, 195);
		((Control)textBoxTRP7PassConfirm).Name = "textBoxTRP7PassConfirm";
		textBoxTRP7PassConfirm.PasswordChar = '*';
		((Control)textBoxTRP7PassConfirm).Size = new Size(388, 19);
		((Control)textBoxTRP7PassConfirm).TabIndex = 11;
		((Control)textBoxTRP7PassConfirm).Enter += textBoxTRP6PassConfirm_Enter;
		((Control)textBoxTRP7PassConfirm).Leave += textBoxTRP6PassConfirm_Leave;
		((Control)textBoxTRP7Pass).Font = new Font("MS UI Gothic", 9f);
		((Control)textBoxTRP7Pass).Location = new Point(255, 160);
		((Control)textBoxTRP7Pass).Name = "textBoxTRP7Pass";
		textBoxTRP7Pass.PasswordChar = '*';
		((Control)textBoxTRP7Pass).Size = new Size(388, 19);
		((Control)textBoxTRP7Pass).TabIndex = 10;
		((Control)textBoxTRP7Pass).Enter += textBoxTRP6Pass_Enter;
		((Control)textBoxTRP7Pass).Leave += textBoxTRP6Pass_Leave;
		((Control)label_TRP7_Password).AutoSize = true;
		((Control)label_TRP7_Password).Font = new Font("MS UI Gothic", 9f);
		((Control)label_TRP7_Password).ForeColor = Color.Blue;
		label_TRP7_Password.ImeMode = (ImeMode)0;
		((Control)label_TRP7_Password).Location = new Point(47, 163);
		((Control)label_TRP7_Password).Name = "label_TRP7_Password";
		((Control)label_TRP7_Password).Size = new Size(54, 12);
		((Control)label_TRP7_Password).TabIndex = 20;
		((Control)label_TRP7_Password).Text = "Password";
		pictureBox12.Image = (Image)(object)Resources.Line;
		pictureBox12.ImeMode = (ImeMode)0;
		((Control)pictureBox12).Location = new Point(39, 48);
		((Control)pictureBox12).Margin = new Padding(1);
		((Control)pictureBox12).Name = "pictureBox12";
		((Control)pictureBox12).Size = new Size(689, 10);
		pictureBox12.TabIndex = 1;
		pictureBox12.TabStop = false;
		((Control)label_TRP7Head).AutoSize = true;
		((Control)label_TRP7Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		label_TRP7Head.ImeMode = (ImeMode)0;
		((Control)label_TRP7Head).Location = new Point(40, 21);
		((Control)label_TRP7Head).Name = "label_TRP7Head";
		((Control)label_TRP7Head).Size = new Size(80, 16);
		((Control)label_TRP7Head).TabIndex = 0;
		((Control)label_TRP7Head).Text = "Password";
		((Control)label_TRP7_comment).AutoSize = true;
		((Control)label_TRP7_comment).Font = new Font("MS UI Gothic", 9f);
		label_TRP7_comment.ImeMode = (ImeMode)0;
		((Control)label_TRP7_comment).Location = new Point(47, 75);
		((Control)label_TRP7_comment).Name = "label_TRP7_comment";
		((Control)label_TRP7_comment).Size = new Size(142, 12);
		((Control)label_TRP7_comment).TabIndex = 2;
		((Control)label_TRP7_comment).Text = "Password setting message";
		((Control)panel_TRP7_1).BackColor = SystemColors.Control;
		panel_TRP7_1.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP7_1).Location = new Point(0, 3);
		((Control)panel_TRP7_1).Margin = new Padding(0);
		((Control)panel_TRP7_1).Name = "panel_TRP7_1";
		((Control)panel_TRP7_1).Size = new Size(231, 470);
		((Control)panel_TRP7_1).TabIndex = 20;
		((Control)tabTRP8_address).Controls.Add((Control)(object)panel_TRP8_3);
		((Control)tabTRP8_address).Controls.Add((Control)(object)panel_TRP8_2);
		((Control)tabTRP8_address).Controls.Add((Control)(object)panel_TRP8_1);
		tabTRP8_address.Location = new Point(4, 22);
		((Control)tabTRP8_address).Name = "tabTRP8_address";
		((Control)tabTRP8_address).Size = new Size(1060, 497);
		tabTRP8_address.TabIndex = 15;
		((Control)tabTRP8_address).Text = "tabTRP8_address";
		tabTRP8_address.UseVisualStyleBackColor = true;
		((Control)panel_TRP8_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_TRP8_3.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP8_3).Controls.Add((Control)(object)btnTRP8Back);
		((Control)panel_TRP8_3).Controls.Add((Control)(object)btnTRP8Next);
		((Control)panel_TRP8_3).Dock = (DockStyle)2;
		((Control)panel_TRP8_3).Location = new Point(0, 446);
		((Control)panel_TRP8_3).Margin = new Padding(0);
		((Control)panel_TRP8_3).Name = "panel_TRP8_3";
		((Control)panel_TRP8_3).Size = new Size(960, 51);
		((Control)panel_TRP8_3).TabIndex = 19;
		((Control)panel_TRP8_2).BackColor = Color.White;
		((Control)panel_TRP8_2).Controls.Add((Control)(object)label_TRP8_Path);
		((Control)panel_TRP8_2).Controls.Add((Control)(object)cmbTRP8FolderPath);
		((Control)panel_TRP8_2).Controls.Add((Control)(object)buttonTRP8HeadLine);
		((Control)panel_TRP8_2).Controls.Add((Control)(object)textTRP8Destination);
		((Control)panel_TRP8_2).Controls.Add((Control)(object)pictureBox17);
		((Control)panel_TRP8_2).Controls.Add((Control)(object)label_TRP8Head);
		((Control)panel_TRP8_2).Controls.Add((Control)(object)label_TRP8_Destination);
		((Control)panel_TRP8_2).Controls.Add((Control)(object)label_TRP8_comment);
		((Control)panel_TRP8_2).Location = new Point(234, 3);
		((Control)panel_TRP8_2).Name = "panel_TRP8_2";
		((Control)panel_TRP8_2).Size = new Size(725, 470);
		((Control)panel_TRP8_2).TabIndex = 23;
		((Control)label_TRP8_Path).AutoSize = true;
		((Control)label_TRP8_Path).Font = new Font("MS UI Gothic", 9f);
		((Control)label_TRP8_Path).ForeColor = Color.Blue;
		label_TRP8_Path.ImeMode = (ImeMode)0;
		((Control)label_TRP8_Path).Location = new Point(44, 165);
		((Control)label_TRP8_Path).Name = "label_TRP8_Path";
		((Control)label_TRP8_Path).Size = new Size(28, 12);
		((Control)label_TRP8_Path).TabIndex = 38;
		((Control)label_TRP8_Path).Text = "Path";
		cmbTRP8FolderPath.DropDownStyle = (ComboBoxStyle)2;
		((Control)cmbTRP8FolderPath).Font = new Font("MS UI Gothic", 9f);
		((ListControl)cmbTRP8FolderPath).FormattingEnabled = true;
		((Control)cmbTRP8FolderPath).Location = new Point(218, 163);
		((Control)cmbTRP8FolderPath).Name = "cmbTRP8FolderPath";
		((Control)cmbTRP8FolderPath).Size = new Size(314, 20);
		((Control)cmbTRP8FolderPath).TabIndex = 17;
		((Control)buttonTRP8HeadLine).AutoSize = true;
		((Control)buttonTRP8HeadLine).Font = new Font("MS UI Gothic", 9f);
		((ButtonBase)buttonTRP8HeadLine).ImeMode = (ImeMode)0;
		((Control)buttonTRP8HeadLine).Location = new Point(535, 128);
		((Control)buttonTRP8HeadLine).Name = "buttonTRP8HeadLine";
		((Control)buttonTRP8HeadLine).Size = new Size(114, 23);
		((Control)buttonTRP8HeadLine).TabIndex = 16;
		((Control)buttonTRP8HeadLine).Text = "Index";
		((ButtonBase)buttonTRP8HeadLine).UseVisualStyleBackColor = true;
		((Control)buttonTRP8HeadLine).Click += buttonTRP8HeadLine_Click;
		((Control)textTRP8Destination).Font = new Font("MS UI Gothic", 9f);
		((Control)textTRP8Destination).Location = new Point(218, 130);
		((Control)textTRP8Destination).Name = "textTRP8Destination";
		((Control)textTRP8Destination).Size = new Size(314, 19);
		((Control)textTRP8Destination).TabIndex = 15;
		((Control)textTRP8Destination).Enter += textTRP8Destination_Enter;
		((Control)textTRP8Destination).Leave += textTRP8Destination_Leave;
		pictureBox17.Image = (Image)(object)Resources.Line;
		pictureBox17.ImeMode = (ImeMode)0;
		((Control)pictureBox17).Location = new Point(39, 48);
		((Control)pictureBox17).Margin = new Padding(1);
		((Control)pictureBox17).Name = "pictureBox17";
		((Control)pictureBox17).Size = new Size(689, 10);
		pictureBox17.TabIndex = 1;
		pictureBox17.TabStop = false;
		((Control)label_TRP8Head).AutoSize = true;
		((Control)label_TRP8Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		label_TRP8Head.ImeMode = (ImeMode)0;
		((Control)label_TRP8Head).Location = new Point(40, 21);
		((Control)label_TRP8Head).Name = "label_TRP8Head";
		((Control)label_TRP8Head).Size = new Size(94, 16);
		((Control)label_TRP8Head).TabIndex = 0;
		((Control)label_TRP8Head).Text = "Destination";
		((Control)label_TRP8_Destination).AutoSize = true;
		((Control)label_TRP8_Destination).Font = new Font("MS UI Gothic", 9f);
		((Control)label_TRP8_Destination).ForeColor = Color.Blue;
		label_TRP8_Destination.ImeMode = (ImeMode)0;
		((Control)label_TRP8_Destination).Location = new Point(44, 130);
		((Control)label_TRP8_Destination).Name = "label_TRP8_Destination";
		((Control)label_TRP8_Destination).Size = new Size(63, 12);
		((Control)label_TRP8_Destination).TabIndex = 2;
		((Control)label_TRP8_Destination).Text = "Destination";
		((Control)label_TRP8_comment).AutoSize = true;
		((Control)label_TRP8_comment).Font = new Font("MS UI Gothic", 9f);
		label_TRP8_comment.ImeMode = (ImeMode)0;
		((Control)label_TRP8_comment).Location = new Point(44, 75);
		((Control)label_TRP8_comment).Name = "label_TRP8_comment";
		((Control)label_TRP8_comment).Size = new Size(151, 12);
		((Control)label_TRP8_comment).TabIndex = 2;
		((Control)label_TRP8_comment).Text = "Destination setting message";
		((Control)panel_TRP8_1).BackColor = SystemColors.Control;
		panel_TRP8_1.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP8_1).Location = new Point(0, 3);
		((Control)panel_TRP8_1).Margin = new Padding(0);
		((Control)panel_TRP8_1).Name = "panel_TRP8_1";
		((Control)panel_TRP8_1).Size = new Size(231, 470);
		((Control)panel_TRP8_1).TabIndex = 21;
		((Control)tabTRP9_confirm).Controls.Add((Control)(object)panel_TRP9_3);
		((Control)tabTRP9_confirm).Controls.Add((Control)(object)panel_TRP9_2);
		((Control)tabTRP9_confirm).Controls.Add((Control)(object)panel_TRP9_1);
		tabTRP9_confirm.Location = new Point(4, 22);
		((Control)tabTRP9_confirm).Name = "tabTRP9_confirm";
		((Control)tabTRP9_confirm).Size = new Size(1060, 497);
		tabTRP9_confirm.TabIndex = 13;
		((Control)tabTRP9_confirm).Text = "tabTRP9_confirm";
		tabTRP9_confirm.UseVisualStyleBackColor = true;
		((Control)panel_TRP9_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_TRP9_3.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP9_3).Controls.Add((Control)(object)btnTRP9Back);
		((Control)panel_TRP9_3).Controls.Add((Control)(object)btnTRP9Execute);
		((Control)panel_TRP9_3).Dock = (DockStyle)2;
		((Control)panel_TRP9_3).Location = new Point(0, 446);
		((Control)panel_TRP9_3).Margin = new Padding(0);
		((Control)panel_TRP9_3).Name = "panel_TRP9_3";
		((Control)panel_TRP9_3).Size = new Size(960, 51);
		((Control)panel_TRP9_3).TabIndex = 25;
		((Control)panel_TRP9_2).BackColor = Color.White;
		panel_TRP9_2.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP9_2).Controls.Add((Control)(object)label_TRP9_comment);
		((Control)panel_TRP9_2).Controls.Add((Control)(object)pictureBox14);
		((Control)panel_TRP9_2).Controls.Add((Control)(object)label_TRP9Head);
		((Control)panel_TRP9_2).Controls.Add((Control)(object)panel45);
		((Control)panel_TRP9_2).Location = new Point(234, 3);
		((Control)panel_TRP9_2).Name = "panel_TRP9_2";
		((Control)panel_TRP9_2).Size = new Size(725, 470);
		((Control)panel_TRP9_2).TabIndex = 27;
		((Control)label_TRP9_comment).AutoSize = true;
		((Control)label_TRP9_comment).Font = new Font("MS UI Gothic", 9f);
		label_TRP9_comment.ImeMode = (ImeMode)0;
		((Control)label_TRP9_comment).Location = new Point(45, 77);
		((Control)label_TRP9_comment).Name = "label_TRP9_comment";
		((Control)label_TRP9_comment).Size = new Size(119, 12);
		((Control)label_TRP9_comment).TabIndex = 7;
		((Control)label_TRP9_comment).Text = "Confirmation message";
		pictureBox14.Image = (Image)(object)Resources.Line;
		pictureBox14.ImeMode = (ImeMode)0;
		((Control)pictureBox14).Location = new Point(39, 48);
		((Control)pictureBox14).Margin = new Padding(1);
		((Control)pictureBox14).Name = "pictureBox14";
		((Control)pictureBox14).Size = new Size(687, 10);
		pictureBox14.TabIndex = 1;
		pictureBox14.TabStop = false;
		((Control)label_TRP9Head).AutoSize = true;
		((Control)label_TRP9Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		label_TRP9Head.ImeMode = (ImeMode)0;
		((Control)label_TRP9Head).Location = new Point(40, 21);
		((Control)label_TRP9Head).Name = "label_TRP9Head";
		((Control)label_TRP9Head).Size = new Size(68, 16);
		((Control)label_TRP9Head).TabIndex = 0;
		((Control)label_TRP9Head).Text = "Confirm";
		panel45.BorderStyle = (BorderStyle)2;
		((Control)panel45).Controls.Add((Control)(object)richTextBoxTRP9);
		((Control)panel45).Font = new Font("MS UI Gothic", 9f);
		((Control)panel45).Location = new Point(44, 117);
		((Control)panel45).Name = "panel45";
		((Control)panel45).Size = new Size(603, 316);
		((Control)panel45).TabIndex = 6;
		((TextBoxBase)richTextBoxTRP9).BorderStyle = (BorderStyle)0;
		richTextBoxTRP9.DetectUrls = false;
		((Control)richTextBoxTRP9).Location = new Point(3, 3);
		((Control)richTextBoxTRP9).Name = "richTextBoxTRP9";
		((Control)richTextBoxTRP9).Size = new Size(590, 305);
		((Control)richTextBoxTRP9).TabIndex = 2;
		((Control)richTextBoxTRP9).Text = "";
		((Control)panel_TRP9_1).BackColor = SystemColors.Control;
		panel_TRP9_1.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP9_1).Location = new Point(0, 3);
		((Control)panel_TRP9_1).Margin = new Padding(0);
		((Control)panel_TRP9_1).Name = "panel_TRP9_1";
		((Control)panel_TRP9_1).Size = new Size(231, 470);
		((Control)panel_TRP9_1).TabIndex = 26;
		((Control)tabTRP10_finish).Controls.Add((Control)(object)panel_TRP10_3);
		((Control)tabTRP10_finish).Controls.Add((Control)(object)panel_TRP10_2);
		((Control)tabTRP10_finish).Controls.Add((Control)(object)panel_TRP10_1);
		tabTRP10_finish.Location = new Point(4, 22);
		((Control)tabTRP10_finish).Margin = new Padding(0);
		((Control)tabTRP10_finish).Name = "tabTRP10_finish";
		((Control)tabTRP10_finish).Size = new Size(1060, 497);
		tabTRP10_finish.TabIndex = 11;
		((Control)tabTRP10_finish).Text = "tabTRP10_finish";
		tabTRP10_finish.UseVisualStyleBackColor = true;
		((Control)panel_TRP10_3).BackColor = Color.FromArgb(0, 0, 64);
		panel_TRP10_3.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP10_3).Controls.Add((Control)(object)btnTRP10Top);
		((Control)panel_TRP10_3).Controls.Add((Control)(object)btnTRP10End);
		((Control)panel_TRP10_3).Dock = (DockStyle)2;
		((Control)panel_TRP10_3).Location = new Point(0, 446);
		((Control)panel_TRP10_3).Margin = new Padding(0);
		((Control)panel_TRP10_3).Name = "panel_TRP10_3";
		((Control)panel_TRP10_3).Size = new Size(960, 51);
		((Control)panel_TRP10_3).TabIndex = 30;
		((Control)panel_TRP10_2).BackColor = Color.White;
		panel_TRP10_2.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP10_2).Controls.Add((Control)(object)linkLabelTRP10HelpSend);
		((Control)panel_TRP10_2).Controls.Add((Control)(object)linkLabelTRP10HelpRegist);
		((Control)panel_TRP10_2).Controls.Add((Control)(object)panelTRP10);
		((Control)panel_TRP10_2).Controls.Add((Control)(object)pictureBox11);
		((Control)panel_TRP10_2).Controls.Add((Control)(object)label_TRP10Head);
		((Control)panel_TRP10_2).Controls.Add((Control)(object)label_TRP10_ReportTitle);
		((Control)panel_TRP10_2).Controls.Add((Control)(object)label_TRP10_comment);
		((Control)panel_TRP10_2).Location = new Point(234, 3);
		((Control)panel_TRP10_2).Name = "panel_TRP10_2";
		((Control)panel_TRP10_2).Size = new Size(725, 470);
		((Control)panel_TRP10_2).TabIndex = 29;
		((Control)linkLabelTRP10HelpSend).AutoSize = true;
		((Control)linkLabelTRP10HelpSend).Font = new Font("MS UI Gothic", 9f);
		((Label)linkLabelTRP10HelpSend).ImeMode = (ImeMode)0;
		((Control)linkLabelTRP10HelpSend).Location = new Point(46, 109);
		((Control)linkLabelTRP10HelpSend).Name = "linkLabelTRP10HelpSend";
		((Control)linkLabelTRP10HelpSend).Size = new Size(141, 12);
		((Control)linkLabelTRP10HelpSend).TabIndex = 26;
		linkLabelTRP10HelpSend.TabStop = true;
		((Control)linkLabelTRP10HelpSend).Text = "Folder send procedure link";
		linkLabelTRP10HelpSend.LinkClicked += new LinkLabelLinkClickedEventHandler(linkLabel1_LinkClicked);
		((Control)linkLabelTRP10HelpRegist).AutoSize = true;
		((Control)linkLabelTRP10HelpRegist).Font = new Font("MS UI Gothic", 9f);
		((Label)linkLabelTRP10HelpRegist).ImeMode = (ImeMode)0;
		linkLabelTRP10HelpRegist.LinkColor = Color.Red;
		((Control)linkLabelTRP10HelpRegist).Location = new Point(46, 94);
		((Control)linkLabelTRP10HelpRegist).Name = "linkLabelTRP10HelpRegist";
		((Control)linkLabelTRP10HelpRegist).Size = new Size(145, 12);
		((Control)linkLabelTRP10HelpRegist).TabIndex = 25;
		linkLabelTRP10HelpRegist.TabStop = true;
		((Control)linkLabelTRP10HelpRegist).Text = "Direct regist procedure link";
		linkLabelTRP10HelpRegist.LinkClicked += new LinkLabelLinkClickedEventHandler(linkLabelP7Help_LinkClicked);
		((ScrollableControl)panelTRP10).AutoScroll = true;
		panelTRP10.BorderStyle = (BorderStyle)2;
		((Control)panelTRP10).Controls.Add((Control)(object)label_TRP10Report);
		((Control)panelTRP10).Controls.Add((Control)(object)labelTRP10finish);
		((Control)panelTRP10).Controls.Add((Control)(object)richTextBoxTRP10);
		((Control)panelTRP10).Font = new Font("MS UI Gothic", 9f);
		((Control)panelTRP10).Location = new Point(48, 159);
		((Control)panelTRP10).Name = "panelTRP10";
		((Control)panelTRP10).Size = new Size(569, 280);
		((Control)panelTRP10).TabIndex = 4;
		((Control)label_TRP10Report).AutoSize = true;
		label_TRP10Report.ImeMode = (ImeMode)0;
		((Control)label_TRP10Report).Location = new Point(4, 11);
		((Control)label_TRP10Report).Name = "label_TRP10Report";
		((Control)label_TRP10Report).Size = new Size(35, 12);
		((Control)label_TRP10Report).TabIndex = 2;
		((Control)label_TRP10Report).Text = "label7";
		((Control)labelTRP10finish).AutoSize = true;
		((Label)labelTRP10finish).ImeMode = (ImeMode)0;
		((Control)labelTRP10finish).Location = new Point(381, 0);
		((Control)labelTRP10finish).Name = "labelTRP10finish";
		((Control)labelTRP10finish).Size = new Size(45, 12);
		((Control)labelTRP10finish).TabIndex = 1;
		labelTRP10finish.TabStop = true;
		((Control)labelTRP10finish).Text = "Reports";
		((Control)labelTRP10finish).Visible = false;
		((TextBoxBase)richTextBoxTRP10).BorderStyle = (BorderStyle)0;
		richTextBoxTRP10.DetectUrls = false;
		((Control)richTextBoxTRP10).Location = new Point(3, 3);
		((Control)richTextBoxTRP10).Name = "richTextBoxTRP10";
		((Control)richTextBoxTRP10).Size = new Size(558, 270);
		((Control)richTextBoxTRP10).TabIndex = 3;
		((Control)richTextBoxTRP10).Text = "";
		pictureBox11.Image = (Image)(object)Resources.Line;
		pictureBox11.ImeMode = (ImeMode)0;
		((Control)pictureBox11).Location = new Point(39, 48);
		((Control)pictureBox11).Margin = new Padding(1);
		((Control)pictureBox11).Name = "pictureBox11";
		((Control)pictureBox11).Size = new Size(689, 10);
		pictureBox11.TabIndex = 1;
		pictureBox11.TabStop = false;
		((Control)label_TRP10Head).AutoSize = true;
		((Control)label_TRP10Head).Font = new Font("MS UI Gothic", 12f, (FontStyle)1);
		label_TRP10Head.ImeMode = (ImeMode)0;
		((Control)label_TRP10Head).Location = new Point(40, 21);
		((Control)label_TRP10Head).Name = "label_TRP10Head";
		((Control)label_TRP10Head).Size = new Size(52, 16);
		((Control)label_TRP10Head).TabIndex = 0;
		((Control)label_TRP10Head).Text = "Finish";
		((Control)label_TRP10_ReportTitle).AutoSize = true;
		((Control)label_TRP10_ReportTitle).Font = new Font("MS UI Gothic", 9f);
		label_TRP10_ReportTitle.ImeMode = (ImeMode)0;
		((Control)label_TRP10_ReportTitle).Location = new Point(41, 142);
		((Control)label_TRP10_ReportTitle).Name = "label_TRP10_ReportTitle";
		((Control)label_TRP10_ReportTitle).Size = new Size(45, 12);
		((Control)label_TRP10_ReportTitle).TabIndex = 2;
		((Control)label_TRP10_ReportTitle).Text = "Report :";
		((Control)label_TRP10_comment).AutoSize = true;
		((Control)label_TRP10_comment).Font = new Font("MS UI Gothic", 9f);
		label_TRP10_comment.ImeMode = (ImeMode)0;
		((Control)label_TRP10_comment).Location = new Point(45, 75);
		((Control)label_TRP10_comment).Name = "label_TRP10_comment";
		((Control)label_TRP10_comment).Size = new Size(102, 12);
		((Control)label_TRP10_comment).TabIndex = 2;
		((Control)label_TRP10_comment).Text = "Complete message";
		((Control)panel_TRP10_1).BackColor = SystemColors.Control;
		panel_TRP10_1.BorderStyle = (BorderStyle)1;
		((Control)panel_TRP10_1).Location = new Point(0, 3);
		((Control)panel_TRP10_1).Margin = new Padding(0);
		((Control)panel_TRP10_1).Name = "panel_TRP10_1";
		((Control)panel_TRP10_1).Size = new Size(231, 470);
		((Control)panel_TRP10_1).TabIndex = 28;
		((ToolStrip)menuStrip1).Items.AddRange((ToolStripItem[])(object)new ToolStripItem[5]
		{
			(ToolStripItem)ToolStripMenuItemDetail_D,
			(ToolStripItem)ToolStripMenuItemChange,
			(ToolStripItem)ToolStripMenuItemSecurity_S,
			(ToolStripItem)ToolStripMenuItemEnvironments_E,
			(ToolStripItem)ToolStripMenuItemVersion_H
		});
		((Control)menuStrip1).Location = new Point(0, 0);
		((Control)menuStrip1).Name = "menuStrip1";
		((Control)menuStrip1).Size = new Size(1059, 24);
		((Control)menuStrip1).TabIndex = 1;
		((Control)menuStrip1).Text = "menuStrip1";
		((ToolStripItem)ToolStripMenuItemDetail_D).Name = "ToolStripMenuItemDetail_D";
		((ToolStripItem)ToolStripMenuItemDetail_D).Size = new Size(65, 20);
		((ToolStripItem)ToolStripMenuItemDetail_D).Text = "Detail(&D)";
		((ToolStripItem)ToolStripMenuItemDetail_D).Click += ToolStripMenuManual_Click;
		((ToolStripItem)ToolStripMenuItemChange).Name = "ToolStripMenuItemChange";
		((ToolStripItem)ToolStripMenuItemChange).Size = new Size(74, 20);
		((ToolStripItem)ToolStripMenuItemChange).Text = "Change(&C)";
		((ToolStripItem)ToolStripMenuItemChange).Click += AddressBookChangeMenuItem_Click;
		((ToolStripItem)ToolStripMenuItemSecurity_S).Name = "ToolStripMenuItemSecurity_S";
		((ToolStripItem)ToolStripMenuItemSecurity_S).Size = new Size(75, 20);
		((ToolStripItem)ToolStripMenuItemSecurity_S).Text = "Security(&S)";
		((ToolStripItem)ToolStripMenuItemSecurity_S).Click += ToolStripMenuSecurity_Click;
		((ToolStripDropDownItem)ToolStripMenuItemEnvironments_E).DropDownItems.AddRange((ToolStripItem[])(object)new ToolStripItem[2]
		{
			(ToolStripItem)ToolStripMenuItemMachine,
			(ToolStripItem)ToolStripMenuItemComputer
		});
		((ToolStripItem)ToolStripMenuItemEnvironments_E).Name = "ToolStripMenuItemEnvironments_E";
		((ToolStripItem)ToolStripMenuItemEnvironments_E).Size = new Size(105, 20);
		((ToolStripItem)ToolStripMenuItemEnvironments_E).Text = "Environments(&E)";
		((ToolStripItem)ToolStripMenuItemMachine).Name = "ToolStripMenuItemMachine";
		((ToolStripItem)ToolStripMenuItemMachine).Size = new Size(153, 22);
		((ToolStripItem)ToolStripMenuItemMachine).Text = "Machine Info.";
		((ToolStripItem)ToolStripMenuItemMachine).Click += ToolStripMenuMachineInfo_Click;
		((ToolStripItem)ToolStripMenuItemComputer).Name = "ToolStripMenuItemComputer";
		((ToolStripItem)ToolStripMenuItemComputer).Size = new Size(153, 22);
		((ToolStripItem)ToolStripMenuItemComputer).Text = "Computer Info.";
		((ToolStripItem)ToolStripMenuItemComputer).Click += ToolStripMenuPCInfo_Click;
		((ToolStripItem)ToolStripMenuItemVersion_H).Name = "ToolStripMenuItemVersion_H";
		((ToolStripItem)ToolStripMenuItemVersion_H).Size = new Size(74, 20);
		((ToolStripItem)ToolStripMenuItemVersion_H).Text = "Version(&H)";
		((ToolStripItem)ToolStripMenuItemVersion_H).Click += ToolStripMenuVersion_Click;
		((Control)label165).AutoSize = true;
		((Control)label165).Font = new Font("MS UI Gothic", 14.25f, (FontStyle)1);
		label165.ImeMode = (ImeMode)0;
		((Control)label165).Location = new Point(12, 23);
		((Control)label165).Name = "label165";
		((Control)label165).Size = new Size(89, 19);
		((Control)label165).TabIndex = 0;
		((Control)label164).AutoSize = true;
		((Control)label164).Font = new Font("MS UI Gothic", 11.25f);
		((Control)label164).ForeColor = Color.Gray;
		label164.ImeMode = (ImeMode)0;
		((Control)label164).Location = new Point(24, 61);
		((Control)label164).Name = "label164";
		((Control)label164).Size = new Size(55, 15);
		((Control)label164).TabIndex = 1;
		((Control)label163).AutoSize = true;
		((Control)label163).Font = new Font("MS UI Gothic", 11.25f);
		((Control)label163).ForeColor = Color.Gray;
		label163.ImeMode = (ImeMode)0;
		((Control)label163).Location = new Point(24, 95);
		((Control)label163).Name = "label163";
		((Control)label163).Size = new Size(134, 15);
		((Control)label163).TabIndex = 2;
		((Control)label162).AutoSize = true;
		((Control)label162).Font = new Font("MS UI Gothic", 11.25f);
		((Control)label162).ForeColor = Color.Gray;
		label162.ImeMode = (ImeMode)0;
		((Control)label162).Location = new Point(34, 129);
		((Control)label162).Name = "label162";
		((Control)label162).Size = new Size(114, 15);
		((Control)label162).TabIndex = 3;
		((Control)label161).AutoSize = true;
		((Control)label161).Font = new Font("MS UI Gothic", 11.25f);
		((Control)label161).ForeColor = Color.Gray;
		label161.ImeMode = (ImeMode)0;
		((Control)label161).Location = new Point(43, 158);
		((Control)label161).Name = "label161";
		((Control)label161).Size = new Size(79, 15);
		((Control)label161).TabIndex = 4;
		((Control)label149).AutoSize = true;
		((Control)label149).Font = new Font("MS UI Gothic", 11.25f, (FontStyle)1);
		((Control)label149).ForeColor = SystemColors.Highlight;
		label149.ImeMode = (ImeMode)0;
		((Control)label149).Location = new Point(24, 197);
		((Control)label149).Name = "label149";
		((Control)label149).Size = new Size(39, 15);
		((Control)label149).TabIndex = 5;
		((Control)label148).AutoSize = true;
		((Control)label148).Font = new Font("MS UI Gothic", 11.25f);
		label148.ImeMode = (ImeMode)0;
		((Control)label148).Location = new Point(24, 265);
		((Control)label148).Name = "label148";
		((Control)label148).Size = new Size(37, 15);
		((Control)label148).TabIndex = 6;
		((Control)label147).AutoSize = true;
		((Control)label147).Font = new Font("MS UI Gothic", 10f);
		label147.ImeMode = (ImeMode)0;
		((Control)label147).Location = new Point(45, 75);
		((Control)label147).Name = "label147";
		((Control)label147).Size = new Size(130, 28);
		((Control)label147).TabIndex = 2;
		((Control)label145).AutoSize = true;
		((Control)label145).Font = new Font("MS UI Gothic", 14.25f, (FontStyle)1);
		label145.ImeMode = (ImeMode)0;
		((Control)label145).Location = new Point(40, 21);
		((Control)label145).Name = "label145";
		((Control)label145).Size = new Size(49, 19);
		((Control)label145).TabIndex = 0;
		pictureBox15.Image = (Image)componentResourceManager.GetObject("pictureBox15.Image");
		pictureBox15.ImeMode = (ImeMode)0;
		((Control)pictureBox15).Location = new Point(39, 48);
		((Control)pictureBox15).Margin = new Padding(1);
		((Control)pictureBox15).Name = "pictureBox15";
		((Control)pictureBox15).Size = new Size(689, 10);
		pictureBox15.TabIndex = 1;
		pictureBox15.TabStop = false;
		((Control)btnP1TRNext).AutoSize = true;
		((Control)btnP1TRNext).BackColor = Color.FromArgb(224, 224, 224);
		((Control)btnP1TRNext).Enabled = false;
		((ButtonBase)btnP1TRNext).FlatStyle = (FlatStyle)0;
		((Control)btnP1TRNext).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP1TRNext).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP1TRNext).ImeMode = (ImeMode)0;
		((Control)btnP1TRNext).Location = new Point(703, 10);
		((Control)btnP1TRNext).Name = "btnP1TRNext";
		((Control)btnP1TRNext).Size = new Size(116, 24);
		((Control)btnP1TRNext).TabIndex = 3;
		((Control)btnP1TRNext).Text = "Next";
		((ButtonBase)btnP1TRNext).UseVisualStyleBackColor = false;
		((Control)btnP1TRNext).Visible = false;
		((Control)btnP1Cancel).AutoSize = true;
		((Control)btnP1Cancel).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP1Cancel).FlatStyle = (FlatStyle)0;
		((Control)btnP1Cancel).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP1Cancel).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP1Cancel).ImeMode = (ImeMode)0;
		((Control)btnP1Cancel).Location = new Point(832, 10);
		((Control)btnP1Cancel).Name = "btnP1Cancel";
		((Control)btnP1Cancel).Size = new Size(116, 24);
		((Control)btnP1Cancel).TabIndex = 2;
		((Control)btnP1Cancel).Text = "Cancel";
		((ButtonBase)btnP1Cancel).UseVisualStyleBackColor = false;
		((Control)btnP1Next).AutoSize = true;
		((Control)btnP1Next).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP1Next).FlatStyle = (FlatStyle)0;
		((Control)btnP1Next).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP1Next).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP1Next).ImeMode = (ImeMode)0;
		((Control)btnP1Next).Location = new Point(703, 10);
		((Control)btnP1Next).Name = "btnP1Next";
		((Control)btnP1Next).Size = new Size(116, 24);
		((Control)btnP1Next).TabIndex = 1;
		((Control)btnP1Next).Text = "Next";
		((ButtonBase)btnP1Next).UseVisualStyleBackColor = false;
		((Control)btnP2Back).AutoSize = true;
		((Control)btnP2Back).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP2Back).FlatStyle = (FlatStyle)0;
		((Control)btnP2Back).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP2Back).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP2Back).ImeMode = (ImeMode)0;
		((Control)btnP2Back).Location = new Point(572, 10);
		((Control)btnP2Back).Name = "btnP2Back";
		((Control)btnP2Back).Size = new Size(116, 24);
		((Control)btnP2Back).TabIndex = 6;
		((Control)btnP2Back).Text = "Back";
		((ButtonBase)btnP2Back).UseVisualStyleBackColor = false;
		((Control)btnP2Back).Click += btnP2Back_Click;
		((Control)btnP2Cancel).AutoSize = true;
		((Control)btnP2Cancel).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP2Cancel).FlatStyle = (FlatStyle)0;
		((Control)btnP2Cancel).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP2Cancel).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP2Cancel).ImeMode = (ImeMode)0;
		((Control)btnP2Cancel).Location = new Point(832, 10);
		((Control)btnP2Cancel).Name = "btnP2Cancel";
		((Control)btnP2Cancel).Size = new Size(116, 24);
		((Control)btnP2Cancel).TabIndex = 8;
		((Control)btnP2Cancel).Text = "Cancel";
		((ButtonBase)btnP2Cancel).UseVisualStyleBackColor = false;
		((Control)btnP2Cancel).Visible = false;
		((Control)btnP2Next).AutoSize = true;
		((Control)btnP2Next).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP2Next).FlatStyle = (FlatStyle)0;
		((Control)btnP2Next).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP2Next).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP2Next).ImeMode = (ImeMode)0;
		((Control)btnP2Next).Location = new Point(703, 10);
		((Control)btnP2Next).Name = "btnP2Next";
		((Control)btnP2Next).Size = new Size(116, 24);
		((Control)btnP2Next).TabIndex = 7;
		((Control)btnP2Next).Text = "Next";
		((ButtonBase)btnP2Next).UseVisualStyleBackColor = false;
		((Control)btnP2Next).Click += btnP2Next_Click;
		((Control)btnP3Cancel).AutoSize = true;
		((Control)btnP3Cancel).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP3Cancel).FlatStyle = (FlatStyle)0;
		((Control)btnP3Cancel).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP3Cancel).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP3Cancel).ImeMode = (ImeMode)0;
		((Control)btnP3Cancel).Location = new Point(832, 10);
		((Control)btnP3Cancel).Name = "btnP3Cancel";
		((Control)btnP3Cancel).Size = new Size(116, 24);
		((Control)btnP3Cancel).TabIndex = 14;
		((Control)btnP3Cancel).Text = "Cancel";
		((ButtonBase)btnP3Cancel).UseVisualStyleBackColor = false;
		((Control)btnP3Cancel).Visible = false;
		((Control)btnP3Back).AutoSize = true;
		((Control)btnP3Back).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP3Back).FlatStyle = (FlatStyle)0;
		((Control)btnP3Back).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP3Back).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP3Back).ImeMode = (ImeMode)0;
		((Control)btnP3Back).Location = new Point(572, 10);
		((Control)btnP3Back).Name = "btnP3Back";
		((Control)btnP3Back).Size = new Size(116, 24);
		((Control)btnP3Back).TabIndex = 12;
		((Control)btnP3Back).Text = "Back";
		((ButtonBase)btnP3Back).UseVisualStyleBackColor = false;
		((Control)btnP3Back).Click += btnP3Back_Click;
		((Control)btnP3Next).AutoSize = true;
		((Control)btnP3Next).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP3Next).FlatStyle = (FlatStyle)0;
		((Control)btnP3Next).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP3Next).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP3Next).ImeMode = (ImeMode)0;
		((Control)btnP3Next).Location = new Point(703, 10);
		((Control)btnP3Next).Name = "btnP3Next";
		((Control)btnP3Next).Size = new Size(116, 24);
		((Control)btnP3Next).TabIndex = 13;
		((Control)btnP3Next).Text = "Next";
		((ButtonBase)btnP3Next).UseVisualStyleBackColor = false;
		((Control)btnP3Next).Click += btnP3Next_Click;
		((Control)btnP4Cancel).AutoSize = true;
		((Control)btnP4Cancel).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP4Cancel).FlatStyle = (FlatStyle)0;
		((Control)btnP4Cancel).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP4Cancel).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP4Cancel).ImeMode = (ImeMode)0;
		((Control)btnP4Cancel).Location = new Point(832, 10);
		((Control)btnP4Cancel).Name = "btnP4Cancel";
		((Control)btnP4Cancel).Size = new Size(116, 24);
		((Control)btnP4Cancel).TabIndex = 24;
		((Control)btnP4Cancel).Text = "Cancel";
		((ButtonBase)btnP4Cancel).UseVisualStyleBackColor = false;
		((Control)btnP4Cancel).Visible = false;
		((Control)btnP4Back).AutoSize = true;
		((Control)btnP4Back).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP4Back).FlatStyle = (FlatStyle)0;
		((Control)btnP4Back).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP4Back).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP4Back).ImeMode = (ImeMode)0;
		((Control)btnP4Back).Location = new Point(572, 10);
		((Control)btnP4Back).Name = "btnP4Back";
		((Control)btnP4Back).Size = new Size(116, 24);
		((Control)btnP4Back).TabIndex = 22;
		((Control)btnP4Back).Text = "Back";
		((ButtonBase)btnP4Back).UseVisualStyleBackColor = false;
		((Control)btnP4Next).AutoSize = true;
		((Control)btnP4Next).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP4Next).FlatStyle = (FlatStyle)0;
		((Control)btnP4Next).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP4Next).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP4Next).ImeMode = (ImeMode)0;
		((Control)btnP4Next).Location = new Point(703, 10);
		((Control)btnP4Next).Name = "btnP4Next";
		((Control)btnP4Next).Size = new Size(116, 24);
		((Control)btnP4Next).TabIndex = 23;
		((Control)btnP4Next).Text = "Next";
		((ButtonBase)btnP4Next).UseVisualStyleBackColor = false;
		((Control)btnP4Next).Click += btnP4Next_Click;
		((Control)machineSelectControl).Location = new Point(211, 196);
		((Control)machineSelectControl).Name = "machineSelectControl";
		((Control)machineSelectControl).Size = new Size(492, 224);
		((Control)machineSelectControl).TabIndex = 41;
		machineSelectControl.SearchButtonClicked += machineSelectControl_SearchButtonClicked;
		((Control)btnP5Cancel).AutoSize = true;
		((Control)btnP5Cancel).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP5Cancel).FlatStyle = (FlatStyle)0;
		((Control)btnP5Cancel).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP5Cancel).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP5Cancel).ImeMode = (ImeMode)0;
		((Control)btnP5Cancel).Location = new Point(832, 10);
		((Control)btnP5Cancel).Name = "btnP5Cancel";
		((Control)btnP5Cancel).Size = new Size(116, 24);
		((Control)btnP5Cancel).TabIndex = 29;
		((Control)btnP5Cancel).Text = "Cancel";
		((ButtonBase)btnP5Cancel).UseVisualStyleBackColor = false;
		((Control)btnP5Cancel).Visible = false;
		((Control)btnP5Back).AutoSize = true;
		((Control)btnP5Back).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP5Back).FlatStyle = (FlatStyle)0;
		((Control)btnP5Back).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP5Back).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP5Back).ImeMode = (ImeMode)0;
		((Control)btnP5Back).Location = new Point(572, 10);
		((Control)btnP5Back).Name = "btnP5Back";
		((Control)btnP5Back).Size = new Size(116, 24);
		((Control)btnP5Back).TabIndex = 27;
		((Control)btnP5Back).Text = "Back";
		((ButtonBase)btnP5Back).UseVisualStyleBackColor = false;
		((Control)btnP5Execute).AutoSize = true;
		((Control)btnP5Execute).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP5Execute).FlatStyle = (FlatStyle)0;
		((Control)btnP5Execute).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP5Execute).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP5Execute).ImeMode = (ImeMode)0;
		((Control)btnP5Execute).Location = new Point(703, 10);
		((Control)btnP5Execute).Name = "btnP5Execute";
		((Control)btnP5Execute).Size = new Size(116, 24);
		((Control)btnP5Execute).TabIndex = 28;
		((Control)btnP5Execute).Text = "Execute";
		((ButtonBase)btnP5Execute).UseVisualStyleBackColor = false;
		((Control)btnP5Execute).Click += btnP5Execute_Click;
		((ButtonBase)btnP6Excecute).ImeMode = (ImeMode)0;
		((Control)btnP6Excecute).Location = new Point(545, 392);
		((Control)btnP6Excecute).Name = "btnP6Excecute";
		((Control)btnP6Excecute).Size = new Size(75, 23);
		((Control)btnP6Excecute).TabIndex = 3;
		((Control)btnP6Excecute).Text = "Execute";
		((ButtonBase)btnP6Excecute).UseVisualStyleBackColor = true;
		((Control)btnP6Excecute).Visible = false;
		((Control)btnP6Excecute).Click += buttonP6Excecute_Click;
		((Control)btnP7Top).AutoSize = true;
		((Control)btnP7Top).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP7Top).FlatStyle = (FlatStyle)0;
		((Control)btnP7Top).Font = new Font("MS UI Gothic", 9f);
		((ButtonBase)btnP7Top).ImeMode = (ImeMode)0;
		((Control)btnP7Top).Location = new Point(703, 10);
		((Control)btnP7Top).Name = "btnP7Top";
		((Control)btnP7Top).Size = new Size(116, 24);
		((Control)btnP7Top).TabIndex = 30;
		((Control)btnP7Top).Text = "Top";
		((ButtonBase)btnP7Top).UseVisualStyleBackColor = false;
		((Control)btnP7End).AutoSize = true;
		((Control)btnP7End).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnP7End).FlatStyle = (FlatStyle)0;
		((Control)btnP7End).Font = new Font("MS UI Gothic", 9f);
		((Control)btnP7End).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnP7End).ImeMode = (ImeMode)0;
		((Control)btnP7End).Location = new Point(832, 10);
		((Control)btnP7End).Name = "btnP7End";
		((Control)btnP7End).Size = new Size(116, 24);
		((Control)btnP7End).TabIndex = 31;
		((Control)btnP7End).Text = "End";
		((ButtonBase)btnP7End).UseVisualStyleBackColor = false;
		((Control)btnTRP2Back).AutoSize = true;
		((Control)btnTRP2Back).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP2Back).FlatStyle = (FlatStyle)0;
		((Control)btnTRP2Back).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP2Back).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP2Back).ImeMode = (ImeMode)0;
		((Control)btnTRP2Back).Location = new Point(572, 10);
		((Control)btnTRP2Back).Name = "btnTRP2Back";
		((Control)btnTRP2Back).Size = new Size(116, 24);
		((Control)btnTRP2Back).TabIndex = 22;
		((Control)btnTRP2Back).Text = "Back";
		((ButtonBase)btnTRP2Back).UseVisualStyleBackColor = false;
		((Control)btnTRP2Next).AutoSize = true;
		((Control)btnTRP2Next).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP2Next).FlatStyle = (FlatStyle)0;
		((Control)btnTRP2Next).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP2Next).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP2Next).ImeMode = (ImeMode)0;
		((Control)btnTRP2Next).Location = new Point(703, 10);
		((Control)btnTRP2Next).Name = "btnTRP2Next";
		((Control)btnTRP2Next).Size = new Size(116, 24);
		((Control)btnTRP2Next).TabIndex = 23;
		((Control)btnTRP2Next).Text = "Next";
		((ButtonBase)btnTRP2Next).UseVisualStyleBackColor = false;
		((Control)btnTRP2Next).Click += btnTRP2Next_Click;
		((Control)machineSelectControlTRP2).Location = new Point(211, 126);
		((Control)machineSelectControlTRP2).Name = "machineSelectControlTRP2";
		((Control)machineSelectControlTRP2).Size = new Size(492, 224);
		((Control)machineSelectControlTRP2).TabIndex = 41;
		machineSelectControlTRP2.SearchButtonClicked += machineSelectControlTRP2_SearchButtonClicked;
		((Control)btnTRP3Back).AutoSize = true;
		((Control)btnTRP3Back).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP3Back).FlatStyle = (FlatStyle)0;
		((Control)btnTRP3Back).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP3Back).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP3Back).ImeMode = (ImeMode)0;
		((Control)btnTRP3Back).Location = new Point(572, 10);
		((Control)btnTRP3Back).Name = "btnTRP3Back";
		((Control)btnTRP3Back).Size = new Size(116, 24);
		((Control)btnTRP3Back).TabIndex = 22;
		((Control)btnTRP3Back).Text = "Back";
		((ButtonBase)btnTRP3Back).UseVisualStyleBackColor = false;
		((Control)btnTRP3Back).Click += btnTRP3Back_Click;
		((Control)btnTRP3Next).AutoSize = true;
		((Control)btnTRP3Next).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP3Next).FlatStyle = (FlatStyle)0;
		((Control)btnTRP3Next).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP3Next).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP3Next).ImeMode = (ImeMode)0;
		((Control)btnTRP3Next).Location = new Point(703, 10);
		((Control)btnTRP3Next).Name = "btnTRP3Next";
		((Control)btnTRP3Next).Size = new Size(116, 24);
		((Control)btnTRP3Next).TabIndex = 23;
		((Control)btnTRP3Next).Text = "Next";
		((ButtonBase)btnTRP3Next).UseVisualStyleBackColor = false;
		((Control)btnTRP3Next).Visible = false;
		((Control)btnTRP3Next).Click += btnTRP3Next_Click;
		((Control)btnTRP5Back).AutoSize = true;
		((Control)btnTRP5Back).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP5Back).FlatStyle = (FlatStyle)0;
		((Control)btnTRP5Back).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP5Back).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP5Back).ImeMode = (ImeMode)0;
		((Control)btnTRP5Back).Location = new Point(572, 10);
		((Control)btnTRP5Back).Name = "btnTRP5Back";
		((Control)btnTRP5Back).Size = new Size(116, 24);
		((Control)btnTRP5Back).TabIndex = 27;
		((Control)btnTRP5Back).Text = "Back";
		((ButtonBase)btnTRP5Back).UseVisualStyleBackColor = false;
		((Control)btnTRP5Next).AutoSize = true;
		((Control)btnTRP5Next).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP5Next).FlatStyle = (FlatStyle)0;
		((Control)btnTRP5Next).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP5Next).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP5Next).ImeMode = (ImeMode)0;
		((Control)btnTRP5Next).Location = new Point(703, 10);
		((Control)btnTRP5Next).Name = "btnTRP5Next";
		((Control)btnTRP5Next).Size = new Size(116, 24);
		((Control)btnTRP5Next).TabIndex = 28;
		((Control)btnTRP5Next).Text = "Next";
		((ButtonBase)btnTRP5Next).UseVisualStyleBackColor = false;
		((Control)btnTRP5Next).Click += btnTRP5Next_Click;
		((Control)btnTRP6Back).AutoSize = true;
		((Control)btnTRP6Back).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP6Back).FlatStyle = (FlatStyle)0;
		((Control)btnTRP6Back).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP6Back).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP6Back).ImeMode = (ImeMode)0;
		((Control)btnTRP6Back).Location = new Point(572, 10);
		((Control)btnTRP6Back).Name = "btnTRP6Back";
		((Control)btnTRP6Back).Size = new Size(116, 24);
		((Control)btnTRP6Back).TabIndex = 6;
		((Control)btnTRP6Back).Text = "Back";
		((ButtonBase)btnTRP6Back).UseVisualStyleBackColor = false;
		((Control)btnTRP6Next).AutoSize = true;
		((Control)btnTRP6Next).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP6Next).FlatStyle = (FlatStyle)0;
		((Control)btnTRP6Next).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP6Next).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP6Next).ImeMode = (ImeMode)0;
		((Control)btnTRP6Next).Location = new Point(703, 10);
		((Control)btnTRP6Next).Name = "btnTRP6Next";
		((Control)btnTRP6Next).Size = new Size(116, 24);
		((Control)btnTRP6Next).TabIndex = 7;
		((Control)btnTRP6Next).Text = "Next";
		((ButtonBase)btnTRP6Next).UseVisualStyleBackColor = false;
		((Control)btnTRP6Next).Click += btnTRP6Next_Click;
		((Control)btnTRP7Back).AutoSize = true;
		((Control)btnTRP7Back).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP7Back).FlatStyle = (FlatStyle)0;
		((Control)btnTRP7Back).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP7Back).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP7Back).ImeMode = (ImeMode)0;
		((Control)btnTRP7Back).Location = new Point(572, 10);
		((Control)btnTRP7Back).Name = "btnTRP7Back";
		((Control)btnTRP7Back).Size = new Size(116, 24);
		((Control)btnTRP7Back).TabIndex = 12;
		((Control)btnTRP7Back).Text = "Back";
		((ButtonBase)btnTRP7Back).UseVisualStyleBackColor = false;
		((Control)btnTRP7Back).Click += btnTRP7Back_Click;
		((Control)btnTRP7Next).AutoSize = true;
		((Control)btnTRP7Next).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP7Next).FlatStyle = (FlatStyle)0;
		((Control)btnTRP7Next).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP7Next).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP7Next).ImeMode = (ImeMode)0;
		((Control)btnTRP7Next).Location = new Point(703, 10);
		((Control)btnTRP7Next).Name = "btnTRP7Next";
		((Control)btnTRP7Next).Size = new Size(116, 24);
		((Control)btnTRP7Next).TabIndex = 13;
		((Control)btnTRP7Next).Text = "Next";
		((ButtonBase)btnTRP7Next).UseVisualStyleBackColor = false;
		((Control)btnTRP7Next).Click += btnTRP7Next_Click;
		((Control)btnTRP8Back).AutoSize = true;
		((Control)btnTRP8Back).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP8Back).FlatStyle = (FlatStyle)0;
		((Control)btnTRP8Back).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP8Back).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP8Back).ImeMode = (ImeMode)0;
		((Control)btnTRP8Back).Location = new Point(572, 10);
		((Control)btnTRP8Back).Name = "btnTRP8Back";
		((Control)btnTRP8Back).Size = new Size(116, 24);
		((Control)btnTRP8Back).TabIndex = 12;
		((Control)btnTRP8Back).Text = "Back";
		((ButtonBase)btnTRP8Back).UseVisualStyleBackColor = false;
		((Control)btnTRP8Next).AutoSize = true;
		((Control)btnTRP8Next).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP8Next).FlatStyle = (FlatStyle)0;
		((Control)btnTRP8Next).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP8Next).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP8Next).ImeMode = (ImeMode)0;
		((Control)btnTRP8Next).Location = new Point(703, 10);
		((Control)btnTRP8Next).Name = "btnTRP8Next";
		((Control)btnTRP8Next).Size = new Size(116, 24);
		((Control)btnTRP8Next).TabIndex = 13;
		((Control)btnTRP8Next).Text = "Next";
		((ButtonBase)btnTRP8Next).UseVisualStyleBackColor = false;
		((Control)btnTRP8Next).Click += btnTRP8Next_Click;
		((Control)btnTRP9Back).AutoSize = true;
		((Control)btnTRP9Back).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP9Back).FlatStyle = (FlatStyle)0;
		((Control)btnTRP9Back).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP9Back).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP9Back).ImeMode = (ImeMode)0;
		((Control)btnTRP9Back).Location = new Point(572, 10);
		((Control)btnTRP9Back).Name = "btnTRP9Back";
		((Control)btnTRP9Back).Size = new Size(116, 24);
		((Control)btnTRP9Back).TabIndex = 27;
		((Control)btnTRP9Back).Text = "Back";
		((ButtonBase)btnTRP9Back).UseVisualStyleBackColor = false;
		((Control)btnTRP9Back).Click += btnTRP9Back_Click;
		((Control)btnTRP9Execute).AutoSize = true;
		((Control)btnTRP9Execute).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP9Execute).FlatStyle = (FlatStyle)0;
		((Control)btnTRP9Execute).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP9Execute).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP9Execute).ImeMode = (ImeMode)0;
		((Control)btnTRP9Execute).Location = new Point(703, 10);
		((Control)btnTRP9Execute).Name = "btnTRP9Execute";
		((Control)btnTRP9Execute).Size = new Size(116, 24);
		((Control)btnTRP9Execute).TabIndex = 28;
		((Control)btnTRP9Execute).Text = "Go";
		((ButtonBase)btnTRP9Execute).UseVisualStyleBackColor = false;
		((Control)btnTRP9Execute).Click += btnTRP9Execute_Click;
		((Control)btnTRP10Top).AutoSize = true;
		((Control)btnTRP10Top).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP10Top).FlatStyle = (FlatStyle)0;
		((Control)btnTRP10Top).Font = new Font("MS UI Gothic", 9f);
		((ButtonBase)btnTRP10Top).ImeMode = (ImeMode)0;
		((Control)btnTRP10Top).Location = new Point(703, 10);
		((Control)btnTRP10Top).Name = "btnTRP10Top";
		((Control)btnTRP10Top).Size = new Size(116, 24);
		((Control)btnTRP10Top).TabIndex = 30;
		((Control)btnTRP10Top).Text = "Top";
		((ButtonBase)btnTRP10Top).UseVisualStyleBackColor = false;
		((Control)btnTRP10End).AutoSize = true;
		((Control)btnTRP10End).BackColor = Color.FromArgb(224, 224, 224);
		((ButtonBase)btnTRP10End).FlatStyle = (FlatStyle)0;
		((Control)btnTRP10End).Font = new Font("MS UI Gothic", 9f);
		((Control)btnTRP10End).ForeColor = Color.FromArgb(64, 64, 64);
		((ButtonBase)btnTRP10End).ImeMode = (ImeMode)0;
		((Control)btnTRP10End).Location = new Point(832, 10);
		((Control)btnTRP10End).Name = "btnTRP10End";
		((Control)btnTRP10End).Size = new Size(116, 24);
		((Control)btnTRP10End).TabIndex = 31;
		((Control)btnTRP10End).Text = "End";
		((ButtonBase)btnTRP10End).UseVisualStyleBackColor = false;
		((ContainerControl)this).AutoScaleDimensions = new SizeF(6f, 12f);
		((ContainerControl)this).AutoScaleMode = (AutoScaleMode)1;
		((Control)this).BackColor = Color.White;
		((Form)this).ClientSize = new Size(959, 539);
		((Control)this).Controls.Add((Control)(object)menuStrip1);
		((Control)this).Controls.Add((Control)(object)tabControl1_Main);
		((Form)this).FormBorderStyle = (FormBorderStyle)1;
		((Form)this).Icon = (Icon)componentResourceManager.GetObject("$this.Icon");
		((Form)this).MaximizeBox = false;
		((Control)this).Name = "FormWizard";
		((Form)this).StartPosition = (FormStartPosition)1;
		((Control)this).Text = "Send Folder Environment Tool";
		((Control)tabPage5_confirm).ResumeLayout(false);
		((Control)panel_P5_3).ResumeLayout(false);
		((Control)panel_P5_3).PerformLayout();
		((Control)panel_P5_2).ResumeLayout(false);
		((Control)panel_P5_2).PerformLayout();
		((Control)panel15).ResumeLayout(false);
		((Control)panel15).PerformLayout();
		((ISupportInitialize)pictureBox5).EndInit();
		((Control)tabPage4_address).ResumeLayout(false);
		((Control)panel_P4_3).ResumeLayout(false);
		((Control)panel_P4_3).PerformLayout();
		((Control)panel_P4_2).ResumeLayout(false);
		((Control)panel_P4_2).PerformLayout();
		((ISupportInitialize)pictureBox4).EndInit();
		((Control)tabPage3_shareFolder).ResumeLayout(false);
		((Control)panel_P3_3).ResumeLayout(false);
		((Control)panel_P3_3).PerformLayout();
		((Control)panel_P3_2).ResumeLayout(false);
		((Control)panel_P3_2).PerformLayout();
		((ISupportInitialize)pictureBox3).EndInit();
		((Control)tabPage2_setupSelect).ResumeLayout(false);
		((Control)panel_P2_3).ResumeLayout(false);
		((Control)panel_P2_3).PerformLayout();
		((Control)panel_P2_2).ResumeLayout(false);
		((Control)panel_P2_2).PerformLayout();
		((ISupportInitialize)pictureBox2).EndInit();
		((Control)tabPage1_introduction).ResumeLayout(false);
		((Control)panel_P1_3).ResumeLayout(false);
		((Control)panel_P1_3).PerformLayout();
		((Control)panel_P1_2).ResumeLayout(false);
		((Control)panel_P1_2).PerformLayout();
		((Control)attentionGroup).ResumeLayout(false);
		((ISupportInitialize)pictureBox1).EndInit();
		((Control)tabControl1_Main).ResumeLayout(false);
		((Control)tabPage6_exec).ResumeLayout(false);
		((Control)panel_P6_2).ResumeLayout(false);
		((Control)panel_P6_2).PerformLayout();
		((ISupportInitialize)pictureBox6).EndInit();
		((Control)tabPage7_finish).ResumeLayout(false);
		((Control)panel_P7_3).ResumeLayout(false);
		((Control)panel_P7_3).PerformLayout();
		((Control)panel_P7_2).ResumeLayout(false);
		((Control)panel_P7_2).PerformLayout();
		((Control)panel22).ResumeLayout(false);
		((Control)panel22).PerformLayout();
		((ISupportInitialize)pictureBox7).EndInit();
		((Control)tabTRP2_device).ResumeLayout(false);
		((Control)panel_TRP2_3).ResumeLayout(false);
		((Control)panel_TRP2_3).PerformLayout();
		((Control)panel_TRP2_2).ResumeLayout(false);
		((Control)panel_TRP2_2).PerformLayout();
		((ISupportInitialize)pictureBox8).EndInit();
		((Control)tabTRP3_user).ResumeLayout(false);
		((Control)panel_TRP3_3).ResumeLayout(false);
		((Control)panel_TRP3_3).PerformLayout();
		((Control)panel_TRP3_2).ResumeLayout(false);
		((Control)panel_TRP3_2).PerformLayout();
		((ISupportInitialize)pictureBox9).EndInit();
		((Control)tabTRP4_analyze).ResumeLayout(false);
		((Control)panel_TRP4_2).ResumeLayout(false);
		((Control)panel_TRP4_2).PerformLayout();
		((ISupportInitialize)pictureBox10).EndInit();
		((Control)tabTRP5_result).ResumeLayout(false);
		((Control)panel_TRP5_3).ResumeLayout(false);
		((Control)panel_TRP5_3).PerformLayout();
		((Control)panel_TRP5_2).ResumeLayout(false);
		((Control)panel_TRP5_2).PerformLayout();
		((ISupportInitialize)pictureBox13).EndInit();
		((Control)panel40).ResumeLayout(false);
		((Control)tabTRP6_setupSelect).ResumeLayout(false);
		((Control)panel_TRP6_3).ResumeLayout(false);
		((Control)panel_TRP6_3).PerformLayout();
		((Control)panel_TRP6_2).ResumeLayout(false);
		((Control)panel_TRP6_2).PerformLayout();
		((ISupportInitialize)pictureBox16).EndInit();
		((Control)tabTRP7_shareFolder).ResumeLayout(false);
		((Control)panel_TRP7_3).ResumeLayout(false);
		((Control)panel_TRP7_3).PerformLayout();
		((Control)panel_TRP7_2).ResumeLayout(false);
		((Control)panel_TRP7_2).PerformLayout();
		((ISupportInitialize)pictureBox12).EndInit();
		((Control)tabTRP8_address).ResumeLayout(false);
		((Control)panel_TRP8_3).ResumeLayout(false);
		((Control)panel_TRP8_3).PerformLayout();
		((Control)panel_TRP8_2).ResumeLayout(false);
		((Control)panel_TRP8_2).PerformLayout();
		((ISupportInitialize)pictureBox17).EndInit();
		((Control)tabTRP9_confirm).ResumeLayout(false);
		((Control)panel_TRP9_3).ResumeLayout(false);
		((Control)panel_TRP9_3).PerformLayout();
		((Control)panel_TRP9_2).ResumeLayout(false);
		((Control)panel_TRP9_2).PerformLayout();
		((ISupportInitialize)pictureBox14).EndInit();
		((Control)panel45).ResumeLayout(false);
		((Control)tabTRP10_finish).ResumeLayout(false);
		((Control)panel_TRP10_3).ResumeLayout(false);
		((Control)panel_TRP10_3).PerformLayout();
		((Control)panel_TRP10_2).ResumeLayout(false);
		((Control)panel_TRP10_2).PerformLayout();
		((Control)panelTRP10).ResumeLayout(false);
		((Control)panelTRP10).PerformLayout();
		((ISupportInitialize)pictureBox11).EndInit();
		((Control)menuStrip1).ResumeLayout(false);
		((Control)menuStrip1).PerformLayout();
		((ISupportInitialize)pictureBox15).EndInit();
		((Control)this).ResumeLayout(false);
		((Control)this).PerformLayout();
	}
}
